@@ -519,8 +519,8 @@ int stress_set_timer_slack_ns(const char *opt)
 #if defined(HAVE_PRCTL_TIMER_SLACK)
 	uint32_t timer_slack;
 
-	timer_slack = get_uint32(opt);
-	(void)set_setting("timer-slack", TYPE_ID_UINT32, &timer_slack);
+	timer_slack = stress_get_uint32(opt);
+	(void)stress_set_setting("timer-slack", TYPE_ID_UINT32, &timer_slack);
 #else
 	(void)opt;
 #endif
@@ -538,7 +538,7 @@ void stress_set_timer_slack(void)
     defined(HAVE_PRCTL_TIMER_SLACK)
 	uint32_t timer_slack;
 
-	if (get_setting("timer-slack", &timer_slack))
+	if (stress_get_setting("timer-slack", &timer_slack))
 		(void)prctl(PR_SET_TIMERSLACK, timer_slack);
 #endif
 }
@@ -687,7 +687,7 @@ int stress_temp_filename(
  *      construct a temp filename using info from args
  */
 int stress_temp_filename_args(
-	const args_t *args,
+	const stress_args_t *args,
 	char *path,
 	const size_t len,
 	const uint64_t magic)
@@ -716,7 +716,7 @@ int stress_temp_dir(
  *	create a temporary directory name using info from args
  */
 int stress_temp_dir_args(
-	const args_t *args,
+	const stress_args_t *args,
 	char *path,
 	const size_t len)
 {
@@ -751,7 +751,7 @@ int stress_temp_dir_mk(
  *   stress_temp_dir_mk_args()
  *	create a temporary director using info from args
  */
-int stress_temp_dir_mk_args(const args_t *args)
+int stress_temp_dir_mk_args(const stress_args_t *args)
 {
 	return stress_temp_dir_mk(args->name, args->pid, args->instance);
 }
@@ -783,7 +783,7 @@ int stress_temp_dir_rm(
  *  stress_temp_dir_rm_args()
  *	remove a temporary directory using info from args
  */
-int stress_temp_dir_rm_args(const args_t *args)
+int stress_temp_dir_rm_args(const stress_args_t *args)
 {
 	return stress_temp_dir_rm(args->name, args->pid, args->instance);
 }
@@ -841,7 +841,7 @@ void stress_strnrnd(char *str, const size_t len)
 	const char *end = str + len;
 
 	while (str < end - 1)
-		*str++ = (mwc8() % 26) + 'a';
+		*str++ = (stress_mwc8() % 26) + 'a';
 
 	*str = '\0';
 }
@@ -913,35 +913,35 @@ void pr_yaml_runinfo(FILE *yaml)
 int stress_cache_alloc(const char *name)
 {
 #if defined(__linux__)
-	cpus_t *cpu_caches;
-	cpu_cache_t *cache = NULL;
+	stress_cpus_t *cpu_caches;
+	stress_cpu_cache_t *cache = NULL;
 	uint16_t max_cache_level = 0;
 #endif
 
 #if !defined(__linux__)
 	g_shared->mem_cache_size = MEM_CACHE_SIZE;
 #else
-	cpu_caches = get_all_cpu_cache_details();
+	cpu_caches = stress_get_all_cpu_cache_details();
 	if (!cpu_caches) {
-		if (warn_once(WARN_ONCE_CACHE_DEFAULT))
+		if (stress_warn_once(WARN_ONCE_CACHE_DEFAULT))
 			pr_dbg("%s: using defaults, can't determine cache details from sysfs\n", name);
 		g_shared->mem_cache_size = MEM_CACHE_SIZE;
 		goto init_done;
 	}
 
-	max_cache_level = get_max_cache_level(cpu_caches);
+	max_cache_level = stress_get_max_cache_level(cpu_caches);
 
 	if (g_shared->mem_cache_level > max_cache_level) {
-		if (warn_once(WARN_ONCE_CACHE_REDUCED))
+		if (stress_warn_once(WARN_ONCE_CACHE_REDUCED))
 			pr_dbg("%s: reducing cache level from L%d (too high) "
 				"to L%d\n", name,
 				g_shared->mem_cache_level, max_cache_level);
 		g_shared->mem_cache_level = max_cache_level;
 	}
 
-	cache = get_cpu_cache(cpu_caches, g_shared->mem_cache_level);
+	cache = stress_get_cpu_cache(cpu_caches, g_shared->mem_cache_level);
 	if (!cache) {
-		if (warn_once(WARN_ONCE_CACHE_NONE))
+		if (stress_warn_once(WARN_ONCE_CACHE_NONE))
 			pr_dbg("%s: using built-in defaults as no suitable "
 				"cache found\n", name);
 		g_shared->mem_cache_size = MEM_CACHE_SIZE;
@@ -952,7 +952,7 @@ int stress_cache_alloc(const char *name)
 		uint64_t way_size;
 
 		if (g_shared->mem_cache_ways > cache->ways) {
-			if (warn_once(WARN_ONCE_CACHE_WAY))
+			if (stress_warn_once(WARN_ONCE_CACHE_WAY))
 				pr_inf("%s: cache way value too high - "
 					"defaulting to %d (the maximum)\n",
 					name, cache->ways);
@@ -969,13 +969,13 @@ int stress_cache_alloc(const char *name)
 	}
 
 	if (!g_shared->mem_cache_size) {
-		if (warn_once(WARN_ONCE_CACHE_DEFAULT))
+		if (stress_warn_once(WARN_ONCE_CACHE_DEFAULT))
 			pr_dbg("%s: using built-in defaults as "
 				"unable to determine cache size\n", name);
 		g_shared->mem_cache_size = MEM_CACHE_SIZE;
 	}
 init_done:
-	free_cpu_caches(cpu_caches);
+	stress_free_cpu_caches(cpu_caches);
 #endif
 	g_shared->mem_cache = calloc(g_shared->mem_cache_size, 1);
 	if (!g_shared->mem_cache) {
@@ -983,7 +983,7 @@ init_done:
 			name);
 		return -1;
 	}
-	if (warn_once(WARN_ONCE_CACHE_SIZE))
+	if (stress_warn_once(WARN_ONCE_CACHE_SIZE))
 		pr_dbg("%s: default cache size: %" PRIu64 "K\n",
 			name, g_shared->mem_cache_size / 1024);
 
@@ -1040,9 +1040,15 @@ int system_read(
 	if (fd < 0)
 		return -errno;
 	ret = read(fd, buf, buf_len);
-	if (ret < 0)
+	if (ret < 0) {
+		buf[0] = '\0';
 		ret = -errno;
+	}
 	(void)close(fd);
+	if ((ssize_t)buf_len == ret)
+		buf[buf_len - 1] = '\0';
+	else
+		buf[ret] = '\0';
 
 	return ret;
 }
@@ -1289,7 +1295,7 @@ const char *stress_get_uname_info(void)
  *	report that a stressor is not implemented
  *	on a particular arch or kernel
  */
-int stress_not_implemented(const args_t *args)
+int stress_not_implemented(const stress_args_t *args)
 {
 #if defined(HAVE_UNAME) && defined(HAVE_SYS_UTSNAME_H)
 	struct utsname buf;
@@ -1661,7 +1667,7 @@ bool stress_is_dev_tty(const int fd)
 
 	if (!name)
 		return true;
-	return !strncmp("/dev/tty", ttyname(fd), 8);
+	return !strncmp("/dev/tty", name, 8);
 #else
 	(void)fd;
 
