@@ -263,8 +263,8 @@ static inline void __pr_msg_fail(const uint64_t flag, const bool locked, char *f
 	va_end(ap);
 }
 
-PRAGMA_PUSH
-PRAGMA_WARN_OFF
+STRESS_PRAGMA_PUSH
+STRESS_PRAGMA_WARN_OFF
 /*
  *  pr_msg_fail()
  *	print failure message with errno
@@ -278,7 +278,7 @@ void pr_msg_fail(
 	__pr_msg_fail(flag, false, "%s: %s failed, errno=%d (%s)\n",
 		name, what, err, strerror(err));
 }
-PRAGMA_POP
+STRESS_PRAGMA_POP
 
 /*
  *  pr_dbg()
@@ -381,7 +381,7 @@ void pr_tidy(const char *fmt, ...)
  *  pr_fail_err__()
  *	helper for macro pr_fail_err to print error with errno
  */
-void pr_fail_err__(const args_t *args, const char *msg)
+void pr_fail_err__(const stress_args_t *args, const char *msg)
 {
 	pr_msg_fail(PR_FAIL | PR_ERROR, args->name, msg, errno);
 }
@@ -390,7 +390,7 @@ void pr_fail_err__(const args_t *args, const char *msg)
  *  pr_fail_errno__()
  *	helper for macro pr_fail_errno to print error with a given errno
  */
-void pr_fail_errno__(const args_t *args, const char *msg, int err)
+void pr_fail_errno__(const stress_args_t *args, const char *msg, int err)
 {
 	pr_msg_fail(PR_FAIL | PR_ERROR, args->name, msg, err);
 }
@@ -399,7 +399,7 @@ void pr_fail_errno__(const args_t *args, const char *msg, int err)
  *  pr_fail_dbg__()
  *	helper for macro pr_fail_dbg to print error
  */
-void pr_fail_dbg__(const args_t *args, const char *msg)
+void pr_fail_dbg__(const stress_args_t *args, const char *msg)
 {
 	pr_msg_fail(PR_DEBUG, args->name, msg, errno);
 }
