@@ -99,7 +99,7 @@ int  stress_madvise_random(void *addr, const size_t length)
 {
 #if defined(HAVE_MADVISE)
 	if (g_opt_flags & OPT_FLAGS_MMAP_MADVISE) {
-		int i = (mwc32() >> 7) % SIZEOF_ARRAY(madvise_options);
+		int i = (stress_mwc32() >> 7) % SIZEOF_ARRAY(madvise_options);
 
 		return madvise(addr, length, madvise_options[i]);
 	}
