@@ -47,8 +47,8 @@ void stress_set_net_port(
 	const int max_port,
 	int *port)
 {
-	*port = get_uint64(opt);
-	check_range(optname, *port,
+	*port = stress_get_uint64(opt);
+	stress_check_range(optname, *port,
 		min_port, max_port - STRESS_PROCS_MAX);
 }
 
