@@ -170,7 +170,7 @@ bool stress_process_oomed(const pid_t pid)
  *	OOM'd and we retry if it gets killed.
  */
 int stress_oomable_child(
-	const args_t *args,
+	const stress_args_t *args,
 	void *context,
 	stress_oomable_child_func_t func,
 	const int flag)
@@ -217,14 +217,14 @@ again:
 			/* If we got killed by OOM killer, re-start */
 			if (WTERMSIG(status) == SIGKILL) {
 				if (g_opt_flags & OPT_FLAGS_OOMABLE) {
-					log_system_mem_info();
+					stress_log_system_mem_info();
 					pr_dbg("%s: assuming killed by OOM "
 						"killer, bailing out "
 						"(instance %d)\n",
 						args->name, args->instance);
 					_exit(0);
 				} else {
-					log_system_mem_info();
+					stress_log_system_mem_info();
 					pr_dbg("%s: assuming killed by OOM "
 						"killer, restarting again "
 						"(instance %d)\n",
