@@ -25,10 +25,10 @@
 #include "stress-ng.h"
 
 /*
- *  check_value()
+ *  stress_check_value()
  *	sanity check number of workers
  */
-void check_value(
+void stress_check_value(
 	const char *const msg,
 	const int val)
 {
@@ -41,10 +41,10 @@ void check_value(
 
 
 /*
- *  check_range()
+ *  stress_check_range()
  *	Sanity check val against a lo - hi range
  */
-void check_range(
+void stress_check_range(
 	const char *const opt,
 	const uint64_t val,
 	const uint64_t lo,
@@ -59,10 +59,10 @@ void check_range(
 }
 
 /*
- *  check_range()
+ *  stress_check_range()
  *	Sanity check val against a lo - hi range
  */
-void check_range_bytes(
+void stress_check_range_bytes(
 	const char *const opt,
 	const uint64_t val,
 	const uint64_t lo,
@@ -81,12 +81,34 @@ void check_range_bytes(
 	}
 }
 
+/*
+ *  stress_ensure_numeric()
+ *	ensure just numeric values
+ */
+static void stress_ensure_numeric(const char *const str)
+{
+	const char *ptr = str;
+
+	if (*ptr == '-')
+		ptr++;
+	while (*ptr) {
+		if (!isdigit((int)*ptr))
+			break;
+		ptr++;
+	}
+	if (*ptr == '\0')
+		return;
+	(void)fprintf(stderr, "Value %s contains non-numeric: '%s'\n",
+		str, ptr);
+	longjmp(g_error_env, 1);
+}
+
 
 /*
- *  ensure_positive()
+ *  stress_ensure_positive()
  * 	ensure string contains just a +ve value
  */
-static void ensure_positive(const char *const str)
+static void stress_ensure_positive(const char *const str)
 {
 	const char *ptr;
 	bool negative = false;
@@ -108,14 +130,15 @@ static void ensure_positive(const char *const str)
 }
 
 /*
- *  get_uint32()
+ *  stress_get_uint32()
  *	string to uint32_t
  */
-uint32_t get_uint32(const char *const str)
+uint32_t stress_get_uint32(const char *const str)
 {
 	uint64_t val;
 
-	ensure_positive(str);
+	stress_ensure_positive(str);
+	stress_ensure_numeric(str);
 	if (sscanf(str, "%" SCNu64, &val) != 1) {
 		(void)fprintf(stderr, "Invalid number %s\n", str);
 		longjmp(g_error_env, 1);
@@ -129,39 +152,41 @@ uint32_t get_uint32(const char *const str)
 }
 
 /*
- *  get_int32()
+ *  stress_get_int32()
  *	string to int32_t
  */
-int32_t get_int32(const char *const str)
+int32_t stress_get_int32(const char *const str)
 {
 	int64_t val;
 
+	stress_ensure_numeric(str);
 	if (sscanf(str, "%" SCNd64, &val) != 1) {
 		(void)fprintf(stderr, "Invalid number %s\n", str);
 		longjmp(g_error_env, 1);
 	}
 	if (val > INT32_MAX) {
-		(void)fprintf(stderr, "Invalid number %s too large (> %d)\n",
-			str, INT32_MAX);
+		(void)fprintf(stderr, "Invalid number %s too large (> %ld)\n",
+			str, (long)INT32_MAX);
 		longjmp(g_error_env, 1);
 	}
 	if (val < INT32_MIN) {
-		(void)fprintf(stderr, "Invalid number %s too small (< %d)\n",
-			str, INT32_MIN);
+		(void)fprintf(stderr, "Invalid number %s too small (< %ld)\n",
+			str, (long)INT32_MIN);
 		longjmp(g_error_env, 1);
 	}
 	return (int32_t)val;
 }
 
 /*
- *  get_uint64()
+ *  stress_get_uint64()
  *	string to uint64_t
  */
-uint64_t get_uint64(const char *const str)
+uint64_t stress_get_uint64(const char *const str)
 {
 	uint64_t val;
 
-	ensure_positive(str);
+	stress_ensure_positive(str);
+	stress_ensure_numeric(str);
 	if (sscanf(str, "%" SCNu64, &val) != 1) {
 		(void)fprintf(stderr, "Invalid number %s\n", str);
 		longjmp(g_error_env, 1);
@@ -170,12 +195,12 @@ uint64_t get_uint64(const char *const str)
 }
 
 /*
- *  get_uint64_scale()
+ *  stress_get_uint64_scale()
  *	get a value and scale it by the given scale factor
  */
-uint64_t get_uint64_scale(
+uint64_t stress_get_uint64_scale(
 	const char *const str,
-	const scale_t scales[],
+	const stress_scale_t scales[],
 	const char *const msg)
 {
 	uint64_t val;
@@ -183,7 +208,12 @@ uint64_t get_uint64_scale(
 	int ch;
 	int i;
 
-	val = get_uint64(str);
+	stress_ensure_positive(str);
+	if (sscanf(str, "%" SCNu64, &val) != 1) {
+		(void)fprintf(stderr, "Invalid number %s\n", str);
+		longjmp(g_error_env, 1);
+	}
+
 	if (!len)  {
 		(void)fprintf(stderr, "Value %s is an invalid size\n", str);
 		longjmp(g_error_env, 1);
@@ -205,12 +235,12 @@ uint64_t get_uint64_scale(
 }
 
 /*
- *  get_uint64_byte()
+ *  stress_get_uint64_byte()
  *	size in bytes, K bytes, M bytes or G bytes
  */
-uint64_t get_uint64_byte(const char *const str)
+uint64_t stress_get_uint64_byte(const char *const str)
 {
-	static const scale_t scales[] = {
+	static const stress_scale_t scales[] = {
 		{ 'b', 	1ULL },		/* bytes */
 		{ 'k',  1ULL << 10 },	/* kilobytes */
 		{ 'm',  1ULL << 20 },	/* megabytes */
@@ -221,14 +251,14 @@ uint64_t get_uint64_byte(const char *const str)
 		{ 0,    0 },
 	};
 
-	return get_uint64_scale(str, scales, "length");
+	return stress_get_uint64_scale(str, scales, "length");
 }
 
 /*
- *  get_uint64_percent()
+ *  stress_get_uint64_percent()
  *	get a value by whole number or by percentage
  */
-uint64_t get_uint64_percent(
+uint64_t stress_get_uint64_percent(
 	const char *const str,
 	const uint32_t instances,
 	const uint64_t max,
@@ -261,50 +291,50 @@ uint64_t get_uint64_percent(
 		}
 		return (uint64_t)((double)(max * val) / (100.0 * instances));
         }
-	return get_uint64_byte(str);
+	return stress_get_uint64_byte(str);
 }
 
 /*
- *  get_uint64_byte_memory()
+ *  stress_get_uint64_byte_memory()
  *	get memory size from string. If it contains %
  *	at the end, then covert it into the available
  *	physical memory scaled by that percentage divided
  *	by the number of stressor instances
  */
-uint64_t get_uint64_byte_memory(
+uint64_t stress_get_uint64_byte_memory(
 	const char *const str,
 	const uint32_t instances)
 {
 	const uint64_t phys_mem = stress_get_phys_mem_size();
 
-	return get_uint64_percent(str, instances, phys_mem,
+	return stress_get_uint64_percent(str, instances, phys_mem,
 		"Cannot determine physical memory size");
 }
 
 /*
- *  get_uint64_byte_filesystem()
+ *  stress_get_uint64_byte_filesystem()
  *	get file size from string. If it contains %
  *	at the end, then covert it into the available
  *	file system space scaled by that percentage divided
  *	by the number of stressor instances
  */
-uint64_t get_uint64_byte_filesystem(
+uint64_t stress_get_uint64_byte_filesystem(
 	const char *const str,
 	const uint32_t instances)
 {
 	const uint64_t bytes = stress_get_filesystem_size();
 
-	return get_uint64_percent(str, instances, bytes,
+	return stress_get_uint64_percent(str, instances, bytes,
 		"Cannot determine available space on file system");
 }
 
 /*
- *  get_uint64_time()
+ *  stress_get_uint64_time()
  *	time in seconds, minutes, hours, days or years
  */
-uint64_t get_uint64_time(const char *const str)
+uint64_t stress_get_uint64_time(const char *const str)
 {
-	static const scale_t scales[] = {
+	static const stress_scale_t scales[] = {
 		{ 's', 	1ULL },			/* seconds */
 		{ 'm',  60ULL },		/* minutes */
 		{ 'h',  3600ULL },		/* hours */
@@ -313,5 +343,5 @@ uint64_t get_uint64_time(const char *const str)
 		{ 'y',  31556926ULL },		/* years (equinoctial) */
 	};
 
-	return get_uint64_scale(str, scales, "time");
+	return stress_get_uint64_scale(str, scales, "time");
 }
