@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2019 Canonical, Ltd.
+ * Copyright (C) 2013-2020 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,9 +27,9 @@
 typedef struct {
 	const int sched;
 	const char *const name;
-} sched_types_t;
+} stress_sched_types_t;
 
-static sched_types_t sched_types[] = {
+static stress_sched_types_t sched_types[] = {
 #if defined(SCHED_BATCH)
 	{ SCHED_BATCH,		"batch" },
 #endif
@@ -159,8 +159,18 @@ int stress_set_sched(
 		attr.sched_deadline = 100000;
 		attr.sched_period = 0;
 
+
 		rc = shim_sched_setattr(pid, &attr, 0);
 		if (rc < 0) {
+			/*
+			 *  Kernel supports older (smaller) attr
+			 *  but userspace supports newer (larger) attr,
+			 *  so report this and pass it back up to re-do
+			 *  the scheduling with a non SCHED_DEADLINE
+			 *  scheduler that requires the larger attr
+			 */
+			if (errno == E2BIG)
+				return -E2BIG;
 			rc = -errno;
 			if (!quiet)
 				pr_inf("Cannot set scheduler '%s': errno=%d (%s)\n",
@@ -212,7 +222,7 @@ int stress_set_sched(
  *  get_opt_sched()
  *	get scheduler policy
  */
-int32_t get_opt_sched(const char *const str)
+int32_t stress_get_opt_sched(const char *const str)
 {
 	size_t i;
 
