@@ -24,8 +24,8 @@
  */
 #include "stress-ng.h"
 
-static setting_t *setting_head;	/* setting list head */
-static setting_t *setting_tail;	/* setting list tail */
+static stress_setting_t *setting_head;	/* setting list head */
+static stress_setting_t *setting_tail;	/* setting list tail */
 
 #if defined(DEBUG_SETTINGS)
 #define	DBG(...)	pr_inf(__VA_ARGS__)
@@ -34,15 +34,15 @@ static setting_t *setting_tail;	/* setting list tail */
 #endif
 
 /*
- *  free_settings()
+ *  stress_free_settings()
  *	free the saved settings
  */
-void free_settings(void)
+void stress_free_settings(void)
 {
-	setting_t *setting = setting_head;
+	stress_setting_t *setting = setting_head;
 
 	while (setting) {
-		setting_t *next = setting->next;
+		stress_setting_t *next = setting->next;
 
 		free(setting->name);
 		free(setting);
@@ -54,16 +54,16 @@ void free_settings(void)
 
 
 /*
- *  set_setting_generic()
+ *  stress_set_setting_generic()
  *	set a new setting;
  */
-static int set_setting_generic(
+static int stress_set_setting_generic(
 	const char *name,
-	const type_id_t type_id,
+	const stress_type_id_t type_id,
 	const void *value,
 	const bool global)
 {
-	setting_t *setting;
+	stress_setting_t *setting;
 
 	if (!value) {
 		(void)fprintf(stderr, "invalid setting '%s' value address (null)\n", name);
@@ -179,37 +179,37 @@ err:
 }
 
 /*
- *  set_setting()
+ *  stress_set_setting()
  *	set a new setting;
  */
-int set_setting(
+int stress_set_setting(
 	const char *name,
-	const type_id_t type_id,
+	const stress_type_id_t type_id,
 	const void *value)
 {
-	return set_setting_generic(name, type_id, value, false);
+	return stress_set_setting_generic(name, type_id, value, false);
 }
 
 /*
- *  set_setting_global()
+ *  stress_set_setting_global()
  *	set a new global setting;
  */
-int set_setting_global(
+int stress_set_setting_global(
 	const char *name,
-	const type_id_t type_id,
+	const stress_type_id_t type_id,
 	const void *value)
 {
-	return set_setting_generic(name, type_id, value, true);
+	return stress_set_setting_generic(name, type_id, value, true);
 }
 
 
 /*
- *  get_setting()
+ *  stress_get_setting()
  *	get an existing setting;
  */
-bool get_setting(const char *name, void *value)
+bool stress_get_setting(const char *name, void *value)
 {
-	setting_t *setting;
+	stress_setting_t *setting;
 	bool set = false;
 	bool found = false;
 
