@@ -24,6 +24,22 @@
  */
 #include "stress-ng.h"
 
+/*
+ *  shim_unconstify_ptr()
+ *	some older system calls require non-const void *
+ *	or caddr_t args, so we need to unconstify them
+ */
+#if defined(__sun__)
+static inline void *shim_unconstify_ptr(const void *ptr)
+{
+	void *unconst_ptr = (void *)ptr;
+
+	return unconst_ptr;
+}
+#else
+#define shim_unconstify_ptr(ptr)	(ptr)
+#endif
+
 /*
  *  Various shim abstraction wrappers around systems calls and
  *  GCC helper functions that may not be supported by some
@@ -264,7 +280,7 @@ int shim_getrandom(void *buff, size_t buflen, unsigned int flags)
  */
 void shim_clear_cache(char* begin, char *end)
 {
-#if defined(__GNUC__) && defined(STRESS_ARM)
+#if defined(__GNUC__) && defined(STRESS_ARCH_ARM)
 	__clear_cache(begin, end);
 #else
 	(void)begin;
@@ -503,7 +519,7 @@ int shim_sched_setattr(
 int shim_mlock(const void *addr, size_t len)
 {
 #if defined(HAVE_MLOCK)
-	return mlock(addr, len);
+	return mlock(shim_unconstify_ptr(addr), len);
 #else
 	return shim_enosys(0, addr, len);
 #endif
@@ -516,7 +532,7 @@ int shim_mlock(const void *addr, size_t len)
 int shim_munlock(const void *addr, size_t len)
 {
 #if defined(HAVE_MUNLOCK)
-	return munlock(addr, len);
+	return munlock(shim_unconstify_ptr(addr), len);
 #else
 	return shim_enosys(0, addr, len);
 #endif
@@ -912,8 +928,8 @@ int shim_ioprio_get(int which, int who)
  *	brk system call shim
  */
 #if defined(__APPLE__)
-PRAGMA_PUSH
-PRAGMA_WARN_OFF
+STRESS_PRAGMA_PUSH
+STRESS_PRAGMA_WARN_OFF
 #endif
 int shim_brk(void *addr)
 {
@@ -937,7 +953,7 @@ int shim_brk(void *addr)
 #endif
 }
 #if defined(__APPLE__)
-PRAGMA_POP
+STRESS_PRAGMA_POP
 #endif
 
 /*
@@ -945,15 +961,15 @@ PRAGMA_POP
  *	sbrk system call shim
  */
 #if defined(__APPLE__)
-PRAGMA_PUSH
-PRAGMA_WARN_OFF
+STRESS_PRAGMA_PUSH
+STRESS_PRAGMA_WARN_OFF
 #endif
 void *shim_sbrk(intptr_t increment)
 {
 	return sbrk(increment);
 }
 #if defined(__APPLE__)
-PRAGMA_POP
+STRESS_PRAGMA_POP
 #endif
 
 /*
@@ -1152,27 +1168,6 @@ int shim_execveat(
 #endif
 }
 
-/*
- *   shim_getxattr
- *	wrapper for getxattr
- */
-ssize_t shim_getxattr(
-	const char *path,
-	const char *name,
-	void *value,
-	size_t size)
-{
-#if defined(HAVE_GETXATTR)
-#if defined(__APPLE__)
-	return getxattr(path, name, value, size, 0, 0);
-#else
-	return getxattr(path, name, value, size);
-#endif
-#else
-	return shim_enosys(0, path, name, value, size);
-#endif
-}
-
 /*
  *   shim_waitpid()
  *	wrapper for waitpid with EINTR retry
@@ -1272,3 +1267,188 @@ int sys_clone3(struct shim_clone_args *cl_args, size_t size)
 #endif
 }
 
+int shim_ustat(dev_t dev, struct shim_ustat *ubuf)
+{
+#if defined(HAVE_USTAT)
+	return ustat(dev, (void *)ubuf);
+#elif defined(__NR_ustat)
+	return syscall(__NR_ustat, dev, ubuf);
+#else
+	return shim_enosys(0, dev, ubuf);
+#endif
+}
+
+/*
+ *   shim_getxattr
+ *	wrapper for getxattr
+ */
+ssize_t shim_getxattr(
+	const char *path,
+	const char *name,
+	void *value,
+	size_t size)
+{
+#if defined(HAVE_GETXATTR)
+#if defined(__APPLE__)
+	return getxattr(path, name, value, size, 0, 0);
+#else
+	return getxattr(path, name, value, size);
+#endif
+#else
+	return shim_enosys(0, path, name, value, size);
+#endif
+}
+
+/*
+ *  shim_listxattr
+ *	wrapper for listxattr
+ */
+ssize_t shim_listxattr(const char *path, char *list, size_t size)
+{
+#if defined(HAVE_LISTXATTR)
+#if defined(__APPLE__)
+	return listxattr(path, list, size, 0);
+#else
+	return listxattr(path, list, size);
+#endif
+#else
+	return shim_enosys(0, path, list, size);
+#endif
+}
+
+/*
+ *  shim_flistxattr
+ *	wrapper for flistxattr
+ */
+ssize_t shim_flistxattr(int fd, char *list, size_t size)
+{
+#if defined(HAVE_FLISTXATTR)
+#if defined(__APPLE__)
+	return flistxattr(fd, list, size, 0);
+#else
+	return flistxattr(fd, list, size);
+#endif
+#else
+	return shim_enosys(0, fd, list, size);
+#endif
+}
+
+/*
+ *  shim_setxattr
+ *	wrapper for setxattr
+ */
+int shim_setxattr(const char *path, const char *name, const void *value, size_t size, int flags)
+{
+#if defined(HAVE_SETXATTR)
+#if defined(__APPLE__)
+	return setxattr(path, name, value, size, 0, flags);
+#else
+	return setxattr(path, name, value, size, flags);
+#endif
+#else
+	return shim_enosys(0, path, name, value, size, flags);
+#endif
+}
+
+/*
+ *  shim_fsetxattr
+ *	wrapper for fsetxattr
+ */
+int shim_fsetxattr(int fd, const char *name, const void *value, size_t size, int flags)
+{
+#if defined(HAVE_FSETXATTR)
+#if defined(__APPLE__)
+	return fsetxattr(fd, name, value, size, 0, flags);
+#else
+	return fsetxattr(fd, name, value, size, flags);
+#endif
+#else
+	return shim_enosys(0, fd, name, value, size, flags);
+#endif
+}
+
+/*
+ *  shim_lsetxattr
+ *	wrapper for lsetxattr
+ */
+int shim_lsetxattr(const char *path, const char *name, const void *value, size_t size, int flags)
+{
+#if defined(HAVE_LSETXATTR)
+	return lsetxattr(path, name, value, size, flags);
+#else
+	return shim_enosys(0, path, name, value, size, flags);
+#endif
+}
+
+/*
+ *  shim_lgetxattr
+ *	wrapper for lgetxattr
+ */
+ssize_t shim_lgetxattr(const char *path, const char *name, void *value, size_t size)
+{
+#if defined(HAVE_LGETXATTR)
+	return lgetxattr(path, name, value, size);
+#else
+	return shim_enosys(0, path, name, value, size);
+#endif
+}
+
+/*
+ *  shim_fgetxattr
+ *	wrapper for fgetxattr
+ */
+ssize_t shim_fgetxattr(int fd, const char *name, void *value, size_t size)
+{
+#if defined(HAVE_FGETXATTR)
+#if defined(__APPLE__)
+	return fgetxattr(fd, name, value, size, 0, 0);
+#else
+	return fgetxattr(fd, name, value, size);
+#endif
+#else
+	return shim_enosys(0, fd, name, value, size);
+#endif
+}
+
+/*
+ *  shim_fremovexattr
+ *	wrapper for fremovexattr
+ */
+int shim_fremovexattr(int fd, const char *name)
+{
+#if defined(HAVE_FREMOVEXATTR)
+#if defined(__APPLE__)
+	return fremovexattr(fd, name, 0);
+#else
+	return fremovexattr(fd, name);
+#endif
+#else
+	return shim_enosys(0, fd, name);
+#endif
+}
+
+/*
+ *  shim_llistxattr
+ *	wrapper for fllistxattr
+ */
+ssize_t shim_llistxattr(const char *path, char *list, size_t size)
+{
+#if defined(HAVE_LLISTXATTR)
+	return llistxattr(path, list, size);
+#else
+	return shim_enosys(0, path, list, size);
+#endif
+}
+
+/*
+ *  shim_reboot
+ *	wrapper for linux reboot system call
+ */
+int shim_reboot(int magic, int magic2, int cmd, void *arg)
+{
+#if defined(__linux__) && defined(__NR_reboot)
+        return syscall(__NR_reboot, magic, magic2, cmd, arg);
+#else
+	return shim_enosys(0, magic, magic2, cmd, arg);
+#endif
+}
