@@ -40,7 +40,7 @@ static void MLOCKED_TEXT stress_timer_handler(int sig)
  *  if it cannot be opened within timeout nanoseconds.
  */
 int stress_try_open(
-	const args_t *args,
+	const stress_args_t *args,
 	const char *path,
 	const int flags,
 	const unsigned long timeout_ns)
@@ -63,7 +63,8 @@ int stress_try_open(
 		return -1;
 	} else if (pid == 0) {
 		errno = 0;
-		if ((fd = open(path, flags)) < 0)
+		fd = open(path, flags);
+		if (fd < 0)
 			_exit(EXIT_FAILURE);
 		_exit(EXIT_SUCCESS);
 	} else {
@@ -107,7 +108,7 @@ int stress_try_open(
 }
 #else
 int stress_try_open(
-	const args_t *args,
+	const stress_args_t *args,
 	const char *path,
 	const int flags,
 	const unsigned long timeout_ns)
