@@ -91,7 +91,7 @@ static const stress_access_t modes[] = {
  *  stress_access
  *	stress access family of system calls
  */
-static int stress_access(const args_t *args)
+static int stress_access(const stress_args_t *args)
 {
 	int fd = -1, ret, rc = EXIT_FAILURE;
 	char filename[PATH_MAX];
@@ -104,7 +104,7 @@ static int stress_access(const args_t *args)
 		return exit_status(-ret);
 
 	(void)stress_temp_filename_args(args,
-		filename, sizeof(filename), mwc32());
+		filename, sizeof(filename), stress_mwc32());
 
 	(void)umask(0700);
 	if ((fd = creat(filename, S_IRUSR | S_IWUSR)) < 0) {
@@ -183,7 +183,7 @@ tidy:
 	return rc;
 }
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"access N",	"start N workers that stress file access permissions" },
 	{ NULL,	"access-ops N",	"stop after N file access bogo operations" },
 	{ NULL, NULL,		NULL }
