@@ -26,7 +26,7 @@
 
 #define ALLOC_SLOP	(64)
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"af-alg N",	"start N workers that stress AF_ALG socket domain" },
 	{ NULL,	"af-alg-ops N",	"stop after N af-alg bogo operations" },
 	{ NULL,	"af-alg-dump",	"dump internal list from /proc/crypto to stdout" },
@@ -38,10 +38,10 @@ static int stress_set_af_alg_dump(const char *opt)
 	bool af_alg_dump = true;
 
 	(void)opt;
-	return set_setting("af-alg-dump", TYPE_ID_BOOL, &af_alg_dump);
+	return stress_set_setting("af-alg-dump", TYPE_ID_BOOL, &af_alg_dump);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_af_alg_dump,	stress_set_af_alg_dump },
 	{ 0,			NULL }
 };
@@ -157,7 +157,7 @@ static const char *type_to_name(const stress_crypto_type_t type)
  *	some crypto engines may return EINVAL, so flag these up in
  *	debug and ignore them for the next iteration
  */
-static void stress_af_alg_ignore(const args_t *args, stress_crypto_info_t *info)
+static void stress_af_alg_ignore(const stress_args_t *args, stress_crypto_info_t *info)
 {
 	if ((args->instance == 0) && (!info->ignore)) {
 		pr_dbg("%s: sendmsg using %s failed with EINVAL, skipping crypto engine\n",
@@ -167,7 +167,7 @@ static void stress_af_alg_ignore(const args_t *args, stress_crypto_info_t *info)
 }
 
 static int stress_af_alg_hash(
-	const args_t *args,
+	const stress_args_t *args,
 	const int sockfd,
 	stress_crypto_info_t *info)
 {
@@ -183,7 +183,7 @@ static int stress_af_alg_hash(
 		return EXIT_NO_RESOURCE;
 	digest = malloc(digest_size + ALLOC_SLOP);
 	if (!digest) {
-		free(digest);
+		free(input);
 		return EXIT_NO_RESOURCE;
 	}
 
@@ -259,7 +259,7 @@ err:
 }
 
 static int stress_af_alg_cipher(
-	const args_t *args,
+	const stress_args_t *args,
 	const int sockfd,
 	stress_crypto_info_t *info)
 {
@@ -318,8 +318,9 @@ retry_bind:
 			goto err;
 		}
 
-		stress_strnrnd(key, sizeof(key));
+		stress_strnrnd(key, info->max_key_size);
 		if (setsockopt(sockfd, SOL_ALG, ALG_SET_KEY, key, info->max_key_size) < 0) {
+			free(key);
 			if (errno == ENOPROTOOPT) {
 				rc = EXIT_SUCCESS;
 				goto err;
@@ -346,8 +347,11 @@ retry_bind:
 
 		stress_strnrnd(assocdata, info->max_auth_size);
 		if (setsockopt(sockfd, SOL_ALG, ALG_SET_AEAD_ASSOCLEN, assocdata, info->max_auth_size) < 0) {
-			if (errno == ENOPROTOOPT)
-				return EXIT_SUCCESS;
+			free(assocdata);
+			if (errno == ENOPROTOOPT) {
+				rc = EXIT_SUCCESS;
+				goto err;
+			}
 			pr_fail_err("setsockopt");
 			rc = EXIT_FAILURE;
 			goto err;
@@ -506,7 +510,7 @@ err:
 }
 
 static int stress_af_alg_rng(
-	const args_t *args,
+	const stress_args_t *args,
 	const int sockfd,
 	stress_crypto_info_t *info)
 {
@@ -621,14 +625,14 @@ static void stress_af_alg_dump_crypto_list(void)
  *  stress_af_alg()
  *	stress socket AF_ALG domain
  */
-static int stress_af_alg(const args_t *args)
+static int stress_af_alg(const stress_args_t *args)
 {
 	int sockfd = -1, rc = EXIT_FAILURE;
 	int retries = MAX_AF_ALG_RETRIES;
 	int count = stress_af_alg_count_crypto();
 	bool af_alg_dump = false;
 
-	(void)get_setting("af-alg-dump", &af_alg_dump);
+	(void)stress_get_setting("af-alg-dump", &af_alg_dump);
 
 	if (af_alg_dump && args->instance == 0) {
 		pr_inf("%s: dumping cryptographic algorithms found in /proc/crypto to stdout\n",
@@ -809,6 +813,18 @@ static void stress_af_alg_add_crypto_defconfigs(void)
 		stress_af_alg_add_crypto(&crypto_info_defconfigs[i]);
 }
 
+/*
+ *  stress_af_alg_info_free()
+ *	free and clear stress_crypto_info_t data
+ */
+static void stress_af_alg_info_free(stress_crypto_info_t *info)
+{
+	if (info->name)
+		free(info->name);
+	if (info->type)
+		free(info->type);
+}
+
 /*
  *  stress_af_alg_init()
  *	populate cryto info list from data from /proc/crypto
@@ -828,10 +844,15 @@ static void stress_af_alg_init(void)
 	(void)memset(&info, 0, sizeof(info));
 
 	while (fgets(buffer, sizeof(buffer) - 1, fp)) {
-		if (!strncmp(buffer, "name", 4))
+		if (!strncmp(buffer, "name", 4)) {
+			if (info.name)
+				free(info.name);
 			info.name = dup_field(buffer);
+		}
 		else if (!strncmp(buffer, "type", 4)) {
 			info.crypto_type = name_to_type(buffer);
+			if (info.type)
+				free(info.type);
 			info.type = dup_field(buffer);
 		}
 		else if (!strncmp(buffer, "blocksize", 9))
@@ -849,9 +870,12 @@ static void stress_af_alg_init(void)
 		else if (buffer[0] == '\n') {
 			if (info.crypto_type != CRYPTO_UNKNOWN)
 				stress_af_alg_add_crypto(&info);
+			else
+				stress_af_alg_info_free(&info);
 			(void)memset(&info, 0, sizeof(info));
 		}
 	}
+	stress_af_alg_info_free(&info);
 
 	(void)fclose(fp);
 }
