@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"affinity N",	 "start N workers that rapidly change CPU affinity" },
 	{ NULL,	"affinity-ops N","stop after N affinity bogo operations" },
 	{ NULL,	"affinity-rand", "change affinity randomly rather than sequentially" },
@@ -36,10 +36,10 @@ static int stress_set_affinity_rand(const char *opt)
 	bool affinity_rand = true;
 
 	(void)opt;
-	return set_setting("affinity-rand", TYPE_ID_BOOL, &affinity_rand);
+	return stress_set_setting("affinity-rand", TYPE_ID_BOOL, &affinity_rand);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_affinity_rand,    stress_set_affinity_rand },
 	{ 0,			NULL }
 };
@@ -76,17 +76,17 @@ static int stress_affinity_supported(void)
         return 0;
 }
 
-static int stress_affinity(const args_t *args)
+static int stress_affinity(const stress_args_t *args)
 {
 	uint32_t cpu = args->instance;
 	const uint32_t cpus = (uint32_t)stress_get_processors_configured();
 	cpu_set_t mask;
 	bool affinity_rand = false;
 
-	(void)get_setting("affinity-rand", &affinity_rand);
+	(void)stress_get_setting("affinity-rand", &affinity_rand);
 
 	do {
-		cpu = affinity_rand ?  (mwc32() >> 4) : cpu + 1;
+		cpu = affinity_rand ?  (stress_mwc32() >> 4) : cpu + 1;
 		cpu %= cpus;
 		CPU_ZERO(&mask);
 		CPU_SET(cpu, &mask);
