@@ -27,7 +27,7 @@
 #define BUFFER_SZ		(4096)
 #define DEFAULT_AIO_MAX_NR	(65536)
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"aiol N",	   "start N workers that exercise Linux async I/O" },
 	{ NULL,	"aiol-ops N",	   "stop after N bogo Linux aio async I/O requests" },
 	{ NULL,	"aiol-requests N", "number of Linux aio async I/O requests per worker" },
@@ -38,13 +38,13 @@ static int stress_set_aio_linux_requests(const char *opt)
 {
 	size_t aio_linux_requests;
 
-	aio_linux_requests = get_uint32(opt);
-	check_range("aiol-requests", aio_linux_requests,
+	aio_linux_requests = stress_get_uint32(opt);
+	stress_check_range("aiol-requests", aio_linux_requests,
 		MIN_AIO_LINUX_REQUESTS, MAX_AIO_LINUX_REQUESTS);
-	return set_setting("aiol-requests", TYPE_ID_SIZE_T, &aio_linux_requests);
+	return stress_set_setting("aiol-requests", TYPE_ID_SIZE_T, &aio_linux_requests);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_aiol_requests,	stress_set_aio_linux_requests },
 	{ 0,			NULL }
 };
@@ -77,7 +77,7 @@ static inline void aio_linux_fill_buffer(
  *	submit async I/O requests
  */
 static int stress_aiol_submit(
-	const args_t *args,
+	const stress_args_t *args,
 	const io_context_t ctx,
 	struct iocb *cbs[],
 	const size_t n,
@@ -108,7 +108,7 @@ static int stress_aiol_submit(
  *	wait for async I/O requests to complete
  */
 static int stress_aiol_wait(
-	const args_t *args,
+	const stress_args_t *args,
 	const io_context_t ctx,
 	struct io_event events[],
 	size_t n)
@@ -154,7 +154,7 @@ static int stress_aiol_wait(
  *	and error reporting on out of memory errors.
  */
 static int stress_aiol_alloc(
-	const args_t *args,
+	const stress_args_t *args,
 	const size_t n,
 	uint8_t **buffer,
 	struct iocb **cb,
@@ -223,7 +223,7 @@ static void stress_aiol_free(
  *  stress_aiol
  *	stress asynchronous I/O using the linux specific aio ABI
  */
-static int stress_aiol(const args_t *args)
+static int stress_aiol(const stress_args_t *args)
 {
 	int ret, rc = EXIT_FAILURE;
 	char filename[PATH_MAX];
@@ -239,7 +239,7 @@ static int stress_aiol(const args_t *args)
 	uint16_t j;
 	size_t i;
 
-	if (!get_setting("aiol-requests", &aio_linux_requests)) {
+	if (!stress_get_setting("aiol-requests", &aio_linux_requests)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			aio_linux_requests = MAX_AIO_REQUESTS;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -318,7 +318,7 @@ static int stress_aiol(const args_t *args)
 	}
 
 	(void)stress_temp_filename_args(args,
-		filename, sizeof(filename), mwc32());
+		filename, sizeof(filename), stress_mwc32());
 
 	fds[0] = open(filename, O_CREAT | O_RDWR | O_DIRECT, S_IRUSR | S_IWUSR);
 	if (fds[0] < 0) {
@@ -353,7 +353,7 @@ static int stress_aiol(const args_t *args)
 			cb[i].aio_fildes = fds[i];
 			cb[i].aio_lio_opcode = IO_CMD_PWRITE;
 			cb[i].u.c.buf = bufptr;
-			cb[i].u.c.offset = mwc16() * BUFFER_SZ;
+			cb[i].u.c.offset = stress_mwc16() * BUFFER_SZ;
 			cb[i].u.c.nbytes = BUFFER_SZ;
 			cbs[i] = &cb[i];
 		}
@@ -373,7 +373,7 @@ static int stress_aiol(const args_t *args)
 			cb[i].aio_fildes = fds[i];
 			cb[i].aio_lio_opcode = IO_CMD_PREAD;
 			cb[i].u.c.buf = bufptr;
-			cb[i].u.c.offset = mwc16() * BUFFER_SZ;
+			cb[i].u.c.offset = stress_mwc16() * BUFFER_SZ;
 			cb[i].u.c.nbytes = BUFFER_SZ;
 			cbs[i] = &cb[i];
 		}
