@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"aio N",	"start N workers that issue async I/O requests" },
 	{ NULL,	"aio-ops N",	"stop after N bogo async I/O requests" },
 	{ NULL, "aio-requests N", "number of async I/O requests per worker" },
@@ -53,13 +53,13 @@ static int stress_set_aio_requests(const char *opt)
 {
 	uint64_t aio_requests;
 
-	aio_requests = get_uint64(opt);
-	check_range("aio-requests", aio_requests,
+	aio_requests = stress_get_uint64(opt);
+	stress_check_range("aio-requests", aio_requests,
 		MIN_AIO_REQUESTS, MAX_AIO_REQUESTS);
-	return set_setting("aio-requests", TYPE_ID_UINT64, &aio_requests);
+	return stress_set_setting("aio-requests", TYPE_ID_UINT64, &aio_requests);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_aio_requests,	stress_set_aio_requests },
 	{ 0,			NULL },
 };
@@ -169,7 +169,7 @@ static int issue_aio_request(
  *  stress_aio
  *	stress asynchronous I/O
  */
-static int stress_aio(const args_t *args)
+static int stress_aio(const stress_args_t *args)
 {
 	int ret, fd, rc = EXIT_FAILURE;
 	stress_io_req_t *io_reqs;
@@ -177,7 +177,7 @@ static int stress_aio(const args_t *args)
 	char filename[PATH_MAX];
 	uint64_t total = 0, i, opt_aio_requests = DEFAULT_AIO_REQUESTS;
 
-	if (!get_setting("aio-requests", &opt_aio_requests)) {
+	if (!stress_get_setting("aio-requests", &opt_aio_requests)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			opt_aio_requests = MAX_AIO_REQUESTS;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -196,7 +196,7 @@ static int stress_aio(const args_t *args)
 	}
 
 	(void)stress_temp_filename_args(args,
-		filename, sizeof(filename), mwc32());
+		filename, sizeof(filename), stress_mwc32());
 
 	if ((fd = open(filename, O_CREAT | O_RDWR, S_IRUSR | S_IWUSR)) < 0) {
 		rc = exit_status(errno);
@@ -239,7 +239,7 @@ static int stress_aio(const args_t *args)
 				inc_counter(args);
 				if (issue_aio_request(args->name, fd,
 					(off_t)i * BUFFER_SZ, &io_reqs[i], i,
-					mwc1() ? aio_read : aio_write) < 0)
+					stress_mwc1() ? aio_read : aio_write) < 0)
 					goto cancel;
 				break;
 			case EINPROGRESS:
