@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"apparmor",	  "start N workers exercising AppArmor interfaces" },
 	{ NULL,	"apparmor-ops N", "stop after N bogo AppArmor worker bogo operations" },
 	{ NULL,	NULL,		  NULL }
@@ -137,7 +137,7 @@ static void stress_apparmor_read(const char *path)
 	while (keep_stressing_flag() &&
 	       apparmor_run &&
 	       (i < (4096 * APPARMOR_BUF_SZ))) {
-		ssize_t ret, sz = 1 + (mwc32() % sizeof(buffer));
+		ssize_t ret, sz = 1 + (stress_mwc32() % sizeof(buffer));
 redo:
 		if (!keep_stressing_flag() || !apparmor_run)
 			break;
@@ -210,7 +210,7 @@ static void stress_apparmor_dir(
  *	spawn a process
  */
 static pid_t apparmor_spawn(
-	const args_t *args,
+	const stress_args_t *args,
 	const uint64_t max_ops,
 	uint64_t *counter,
 	stress_apparmor_func func)
@@ -387,10 +387,10 @@ static inline void apparmor_corrupt_flip_bits_random(
 	char *copy, const size_t len)
 {
 	uint32_t i;
-	const uint32_t n = mwc32() % 17;
+	const uint32_t n = stress_mwc32() % 17;
 
 	for (i = 0; i < n; i++) {
-		uint32_t rnd = mwc32();
+		uint32_t rnd = stress_mwc32();
 
 		copy[rnd % len] ^= (1 << ((rnd >> 16) & 7));
 	}
@@ -452,7 +452,7 @@ static inline void apparmor_corrupt_set_seq(
 static inline void apparmor_corrupt_flip_byte_random(
 	char *copy, const size_t len)
 {
-	copy[mwc32() % len] ^= 0xff;
+	copy[stress_mwc32() % len] ^= 0xff;
 }
 
 /*
@@ -463,10 +463,10 @@ static inline void apparmor_corrupt_clr_bits_random(
 	char *copy, const size_t len)
 {
 	uint32_t i;
-	const uint32_t n = mwc32() % 17;
+	const uint32_t n = stress_mwc32() % 17;
 
 	for (i = 0; i < n; i++) {
-		uint32_t rnd = mwc32();
+		uint32_t rnd = stress_mwc32();
 
 		copy[rnd % len] &= ~(1 << ((rnd >> 16) & 7));
 	}
@@ -480,10 +480,10 @@ static inline void apparmor_corrupt_set_bits_random(
 	char *copy, const size_t len)
 {
 	uint32_t i;
-	const uint32_t n = mwc32() % 17;
+	const uint32_t n = stress_mwc32() % 17;
 
 	for (i = 0; i < n; i++) {
-		uint32_t rnd = mwc32();
+		uint32_t rnd = stress_mwc32();
 
 		copy[rnd % len] |= (1 << ((rnd >> 16) & 7));
 	}
@@ -496,7 +496,7 @@ static inline void apparmor_corrupt_set_bits_random(
 static inline void apparmor_corrupt_clr_byte_random(
 	char *copy, const size_t len)
 {
-	copy[mwc32() % len] = 0;
+	copy[stress_mwc32() % len] = 0;
 }
 
 /*
@@ -506,7 +506,7 @@ static inline void apparmor_corrupt_clr_byte_random(
 static inline void apparmor_corrupt_set_byte_random(
 	char *copy, const size_t len)
 {
-	copy[mwc32() % len] = 0xff;
+	copy[stress_mwc32() % len] = 0xff;
 }
 
 /*
@@ -517,7 +517,7 @@ static inline void apparmor_corrupt_flip_bits_random_burst(
 	char *copy, const size_t len)
 {
 	uint32_t i;
-	size_t p = (size_t)mwc32() % (len * sizeof(char));
+	size_t p = (size_t)stress_mwc32() % (len * sizeof(char));
 
 	for (i = 0; i < 32; i++) {
 		if (p > len)
@@ -639,7 +639,7 @@ static const stress_apparmor_func apparmor_funcs[] = {
  *  stress_apparmor()
  *	stress AppArmor
  */
-static int stress_apparmor(const args_t *args)
+static int stress_apparmor(const stress_args_t *args)
 {
 	const size_t n = SIZEOF_ARRAY(apparmor_funcs);
 	pid_t pids[n];
