@@ -26,7 +26,7 @@
 
 #define DO_ATOMIC_OPS(type, var)			\
 {							\
-	type tmp = mwc64();				\
+	type tmp = stress_mwc64();			\
 							\
 	__atomic_store(var, &tmp, __ATOMIC_RELAXED); 	\
 	__atomic_load(var, &tmp, __ATOMIC_RELAXED);	\
@@ -93,7 +93,7 @@
 	__atomic_clear(var, __ATOMIC_RELAXED);		\
 }
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"atomic",	"start N workers exercising GCC atomic operations" },
 	{ NULL, "atomic-ops",	"stop after N bogo atomic bogo operations" },
 	{ NULL, NULL,		NULL }
@@ -101,7 +101,7 @@ static const help_t help[] = {
 
 #if defined(TEST_ATOMIC_BUILD)
 
-uint64_t mwc64(void)
+uint64_t stress_mwc64(void)
 {
 	static uint64_t v = 0xdeadbeef;
 
@@ -132,7 +132,7 @@ int main(void)
  *  stress_atomic()
  *      stress gcc atomic memory ops
  */
-static int stress_atomic(const args_t *args)
+static int stress_atomic(const stress_args_t *args)
 {
 	do {
 		DO_ATOMIC_OPS(uint64_t, &g_shared->atomic.val64);
