@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] =
+static const stress_help_t help[] =
 {
 	{ NULL,	"bad-altstack N",	"start N workers exercising bad signal stacks" },
 	{ NULL,	"bad-altstack-ops N",	"stop after N bogo signal stack SIGSEGVs" },
@@ -42,7 +42,7 @@ static inline void stress_bad_altstack_force_fault(uint8_t *stack_start)
 	volatile uint8_t *vol_stack = (volatile uint8_t *)stack_start;
 	/* trigger segfault on stack */
 
-	uint8_put(*vol_stack);
+	stress_uint8_put(*vol_stack);
 	*vol_stack = 0;
 	(void)*vol_stack;
 }
@@ -69,7 +69,7 @@ static void MLOCKED_TEXT stress_segv_handler(int signum)
  *	a SIGSEGV when handling SIGSEGVs. The kernel
  *	should kill these.
  */
-static int stress_bad_altstack(const args_t *args)
+static int stress_bad_altstack(const stress_args_t *args)
 {
 	stress_set_oom_adjustment(args->name, true);
 
@@ -84,7 +84,7 @@ static int stress_bad_altstack(const args_t *args)
 	do {
 		pid_t pid;
 
-		(void)mwc32();
+		(void)stress_mwc32();
 again:
 		if (!keep_stressing_flag())
 			return EXIT_SUCCESS;
@@ -112,14 +112,14 @@ again:
 				/* If we got killed by OOM killer, re-start */
 				if (WTERMSIG(status) == SIGKILL) {
 					if (g_opt_flags & OPT_FLAGS_OOMABLE) {
-						log_system_mem_info();
+						stress_log_system_mem_info();
 						pr_dbg("%s: assuming killed by OOM "
 							"killer, bailing out "
 							"(instance %d)\n",
 							args->name, args->instance);
 						_exit(0);
 					} else {
-						log_system_mem_info();
+						stress_log_system_mem_info();
 						pr_dbg("%s: assuming killed by OOM "
 							"killer, restarting again "
 							"(instance %d)\n",
@@ -152,8 +152,8 @@ again:
 				return EXIT_FAILURE;
 
 			/* Child */
-			mwc_reseed();
-			rnd = mwc32() % 7;
+			stress_mwc_reseed();
+			rnd = stress_mwc32() % 7;
 
 			stress_set_oom_adjustment(args->name, true);
 			stress_process_dumpable(false);
