@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ "B N","bigheap N",		"start N workers that grow the heap using calloc()" },
 	{ NULL,	"bigheap-ops N",	"stop after N bogo bigheap operations" },
 	{ NULL,	"bigheap-growth N",	"grow heap by N bytes per iteration" },
@@ -39,13 +39,13 @@ static int stress_set_bigheap_growth(const char *opt)
 {
 	uint64_t bigheap_growth;
 
-	bigheap_growth = get_uint64_byte(opt);
-	check_range_bytes("bigheap-growth", bigheap_growth,
+	bigheap_growth = stress_get_uint64_byte(opt);
+	stress_check_range_bytes("bigheap-growth", bigheap_growth,
 		MIN_BIGHEAP_GROWTH, MAX_BIGHEAP_GROWTH);
-	return set_setting("bigheap-growth", TYPE_ID_UINT64, &bigheap_growth);
+	return stress_set_setting("bigheap-growth", TYPE_ID_UINT64, &bigheap_growth);
 }
 
-static int stress_bigheap_child(const args_t *args, void *context)
+static int stress_bigheap_child(const stress_args_t *args, void *context)
 {
 	uint64_t bigheap_growth = DEFAULT_BIGHEAP_GROWTH;
 	void *ptr = NULL, *last_ptr = NULL;
@@ -56,7 +56,7 @@ static int stress_bigheap_child(const args_t *args, void *context)
 
 	(void)context;
 
-	if (!get_setting("bigheap-growth", &bigheap_growth)) {
+	if (!stress_get_setting("bigheap-growth", &bigheap_growth)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			bigheap_growth = MAX_BIGHEAP_GROWTH;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -142,12 +142,12 @@ abort:
  *  stress_bigheap()
  *	stress heap allocation
  */
-static int stress_bigheap(const args_t *args)
+static int stress_bigheap(const stress_args_t *args)
 {
 	return stress_oomable_child(args, NULL, stress_bigheap_child, STRESS_OOMABLE_NORMAL);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_bigheap_growth,	stress_set_bigheap_growth },
 	{ 0,			NULL },
 };
