@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"bind-mount N",	    "start N workers exercising bind mounts" },
 	{ NULL,	"bind-mount-ops N", "stop after N bogo bind mount operations" },
 	{ NULL,	NULL,		    NULL }
@@ -54,7 +54,7 @@ static void stress_bind_mount_child_handler(int signum)
  */
 static int stress_bind_mount_child(void *parg)
 {
-	const args_t *args = ((pthread_args_t *)parg)->args;
+	const stress_args_t *args = ((stress_pthread_args_t *)parg)->args;
 
 	if (stress_sighandler(args->name, SIGALRM,
 	    stress_bind_mount_child_handler, NULL) < 0) {
@@ -94,10 +94,10 @@ static int stress_bind_mount_child(void *parg)
  *  stress_bind_mount()
  *      stress bind mounting
  */
-static int stress_bind_mount(const args_t *args)
+static int stress_bind_mount(const stress_args_t *args)
 {
 	int pid = 0, status;
-	pthread_args_t pargs = { args, NULL, 0 };
+	stress_pthread_args_t pargs = { args, NULL, 0 };
 	const ssize_t stack_offset =
 		stress_get_stack_direction() *
 		(CLONE_STACK_SIZE - 64);
@@ -110,7 +110,7 @@ static int stress_bind_mount(const args_t *args)
 		(void)memset(stack, 0, sizeof stack);
 
 		pid = clone(stress_bind_mount_child,
-			align_stack(stack_top),
+			stress_align_stack(stack_top),
 			CLONE_NEWUSER | CLONE_NEWNS | CLONE_VM | SIGCHLD,
 			(void *)&pargs, 0);
 		if (pid < 0) {
