@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"branch N",	"start N workers that force branch misprediction" },
 	{ NULL,	"branch-ops N",	"stop after N branch misprediction branches" },
 	{ NULL,	NULL,		NULL }
@@ -32,16 +32,16 @@ static const help_t help[] = {
 
 #if defined(HAVE_LABEL_AS_VALUE)
 /*
- *  jmp_mwc8()
- *	special non-overly optimized mwc8 that gets inlined
+ *  jmp_stress_mwc8()
+ *	special non-overly optimized stress_mwc8 that gets inlined
  *	to remove a jmp and hence boost branch miss rates.
  *	Do not optimize this any further as this will lower
  *	the branch miss rate.
  */
-static inline uint8_t jmp_mwc8(void)
+static inline uint8_t jmp_stress_mwc8(void)
 {
-	static uint32_t w = MWC_SEED_W;
-	static uint32_t z = MWC_SEED_Z;
+	static uint32_t w = STRESS_MWC_SEED_W;
+	static uint32_t z = STRESS_MWC_SEED_Z;
 
         z = 36969 * (z & 65535) + (z >> 16);
         w = 18000 * (w & 65535) + (w >> 16);
@@ -57,7 +57,7 @@ static inline uint8_t jmp_mwc8(void)
 #define JMP(a)	label ## a: 				\
 {							\
 	register bool do_more;				\
-	register uint16_t _index = jmp_mwc8();		\
+	register uint16_t _index = jmp_stress_mwc8();	\
 							\
 	inc_counter(args);				\
 	do_more = LIKELY((int)keep_stressing_flag()) &	\
@@ -71,7 +71,7 @@ static inline uint8_t jmp_mwc8(void)
  *  stress_branch()
  *	stress instruction branch prediction
  */
-static int stress_branch(const args_t *args)
+static int stress_branch(const stress_args_t *args)
 {
 	static const void ALIGN64 *labels[] = {
 		&&ret, &&ret, &&ret, &&ret,
