@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"brk N",	"start N workers performing rapid brk calls" },
 	{ NULL,	"brk-ops N",	"stop after N brk bogo operations" },
 	{ NULL,	"brk-notouch",	"don't touch (page in) new data segment page" },
@@ -36,15 +36,15 @@ static int stress_set_brk_notouch(const char *opt)
 	(void)opt;
 	bool brk_notouch = true;
 
-	return set_setting("brk-notouch", TYPE_ID_BOOL, &brk_notouch);
+	return stress_set_setting("brk-notouch", TYPE_ID_BOOL, &brk_notouch);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_brk_notouch,	stress_set_brk_notouch },
 	{ 0,			NULL }
 };
 
-static int stress_brk_child(const args_t *args, void *context)
+static int stress_brk_child(const stress_args_t *args, void *context)
 {
 	uint8_t *start_ptr;
 	int i = 0;
@@ -53,7 +53,7 @@ static int stress_brk_child(const args_t *args, void *context)
 
 	(void)context;
 
-	(void)get_setting("brk-notouch", &brk_notouch);
+	(void)stress_get_setting("brk-notouch", &brk_notouch);
 
 	start_ptr = shim_sbrk(0);
 	if (start_ptr == (void *) -1) {
@@ -109,7 +109,7 @@ static int stress_brk_child(const args_t *args, void *context)
  *  stress_brk()
  *	stress brk and sbrk
  */
-static int stress_brk(const args_t *args)
+static int stress_brk(const stress_args_t *args)
 {
 	return stress_oomable_child(args, NULL, stress_brk_child, STRESS_OOMABLE_DROP_CAP);
 }
