@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] =  {
+static const stress_help_t help[] =  {
 	{ NULL,	"bsearch N",	  "start N workers that exercise a binary search" },
 	{ NULL,	"bsearch-ops N",  "stop after N binary search bogo operations" },
 	{ NULL,	"bsearch-size N", "number of 32 bit integers to bsearch" },
@@ -39,10 +39,10 @@ static int stress_set_bsearch_size(const char *opt)
 {
 	uint64_t bsearch_size;
 
-	bsearch_size = get_uint64(opt);
-	check_range("bsearch-size", bsearch_size,
+	bsearch_size = stress_get_uint64(opt);
+	stress_check_range("bsearch-size", bsearch_size,
 		MIN_BSEARCH_SIZE, MAX_BSEARCH_SIZE);
-	return set_setting("bsearch-size", TYPE_ID_UINT64, &bsearch_size);
+	return stress_set_setting("bsearch-size", TYPE_ID_UINT64, &bsearch_size);
 }
 
 /*
@@ -75,13 +75,13 @@ static int cmp(const void *p1, const void *p2)
  *  stress_bsearch()
  *	stress bsearch
  */
-static int stress_bsearch(const args_t *args)
+static int stress_bsearch(const stress_args_t *args)
 {
 	int32_t *data, *ptr, prev = 0;
 	size_t n, n8, i;
 	uint64_t bsearch_size = DEFAULT_BSEARCH_SIZE;
 
-	if (!get_setting("bsearch-size", &bsearch_size)) {
+	if (!stress_get_setting("bsearch-size", &bsearch_size)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			bsearch_size = MAX_BSEARCH_SIZE;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -99,7 +99,7 @@ static int stress_bsearch(const args_t *args)
 	/* Populate with ascending data */
 	prev = 0;
 	for (i = 0; i < n;) {
-		uint64_t v = mwc64();
+		uint64_t v = stress_mwc64();
 
 		SETDATA(data, i, v, prev);
 		SETDATA(data, i, v, prev);
@@ -134,7 +134,7 @@ static int stress_bsearch(const args_t *args)
 	return EXIT_SUCCESS;
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_bsearch_size,	stress_set_bsearch_size },
 	{ 0,			NULL },
 };
