@@ -32,7 +32,7 @@
 #define FLAGS_CACHE_SFENCE	(0x08)
 #define FLAGS_CACHE_NOAFF	(0x10)
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ "C N","cache N",	 "start N CPU cache thrashing workers" },
 	{ NULL,	"cache-ops N",	 "stop after N cache bogo operations" },
 	{ NULL,	"cache-prefetch","prefetch on memory reads/writes" },
@@ -50,9 +50,9 @@ static int stress_cache_set_flag(const uint32_t flag)
 {
 	uint32_t cache_flags = 0;
 
-	(void)get_setting("cache-flags", &cache_flags);
+	(void)stress_get_setting("cache-flags", &cache_flags);
 	cache_flags |= flag;
-	(void)set_setting("cache-flags", TYPE_ID_UINT32, &cache_flags);
+	(void)stress_set_setting("cache-flags", TYPE_ID_UINT32, &cache_flags);
 
 	return 0;
 }
@@ -92,7 +92,7 @@ static int stress_cache_set_sfence(const char *opt)
 	return stress_cache_set_flag(FLAGS_CACHE_SFENCE);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_cache_prefetch,		stress_cache_set_prefetch },
 	{ OPT_cache_flush,		stress_cache_set_flush },
 	{ OPT_cache_fence,		stress_cache_set_fence },
@@ -110,10 +110,10 @@ static const opt_set_func_t opt_set_funcs[] = {
 		}							\
 		mem_cache[i] += mem_cache[(mem_cache_size - 1) - i] + r;\
 		if ((flag) & FLAGS_CACHE_FLUSH) {			\
-			clflush(&mem_cache[i]);				\
+			shim_clflush(&mem_cache[i]);			\
 		}							\
 		if ((flag) & FLAGS_CACHE_FENCE) {			\
-			mfence();					\
+			shim_mfence();					\
 		}							\
 		if ((flag) & FLAGS_CACHE_SFENCE) {			\
 			__builtin_ia32_sfence();			\
@@ -130,10 +130,10 @@ static const opt_set_func_t opt_set_funcs[] = {
 		}							\
 		mem_cache[i] += mem_cache[(mem_cache_size - 1) - i] + r;\
 		if ((flag) & FLAGS_CACHE_FLUSH) {			\
-			clflush(&mem_cache[i]);				\
+			shim_clflush(&mem_cache[i]);			\
 		}							\
 		if ((flag) & FLAGS_CACHE_FENCE) {			\
-			mfence();					\
+			shim_mfence();					\
 		}							\
 		i = (i + 32769) & (mem_cache_size - 1);			\
 		if (!keep_stressing_flag())				\
@@ -147,7 +147,7 @@ static const opt_set_func_t opt_set_funcs[] = {
  *	if possible change CPU affinity to try to cause
  *	poor cache behaviour
  */
-static int stress_cache(const args_t *args)
+static int stress_cache(const stress_args_t *args)
 {
 #if defined(HAVE_SCHED_GETAFFINITY) &&	\
     defined(HAVE_SCHED_GETCPU)
@@ -163,7 +163,7 @@ static int stress_cache(const args_t *args)
 	uint8_t *const mem_cache = g_shared->mem_cache;
 	const uint64_t mem_cache_size = g_shared->mem_cache_size;
 
-	(void)get_setting("cache-flags", &cache_flags);
+	(void)stress_get_setting("cache-flags", &cache_flags);
 	if (args->instance == 0)
 		pr_dbg("%s: using cache buffer size of %" PRIu64 "K\n",
 			args->name, mem_cache_size / 1024);
@@ -191,8 +191,8 @@ static int stress_cache(const args_t *args)
 #endif
 
 	do {
-		uint64_t i = mwc64() % mem_cache_size;
-		uint64_t r = mwc64();
+		uint64_t i = stress_mwc64() % mem_cache_size;
+		uint64_t r = stress_mwc64();
 		register uint64_t j;
 
 		if ((r >> 13) & 1) {
@@ -287,12 +287,12 @@ static int stress_cache(const args_t *args)
 
 		}
 #endif
-		(void)shim_cacheflush((char *)stress_cache, 8192, ICACHE);
-		(void)shim_cacheflush((char *)mem_cache, (int)mem_cache_size, DCACHE);
+		(void)shim_cacheflush((char *)stress_cache, 8192, SHIM_ICACHE);
+		(void)shim_cacheflush((char *)mem_cache, (int)mem_cache_size, SHIM_DCACHE);
 		inc_counter(args);
 	} while (keep_stressing());
 
-	uint32_put(total);
+	stress_uint32_put(total);
 	return ret;
 }
 
