@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL, "chdir N",	"start N workers thrashing chdir on many paths" },
 	{ NULL, "chdir-ops N",	"stop chdir workers after N bogo chdir operations" },
 	{ NULL,	"chdir-dirs N",	"select number of directories to exercise chdir on" },
@@ -39,24 +39,24 @@ static int stress_set_chdir_dirs(const char *opt)
 {
 	uint64_t chdir_dirs;
 
-	chdir_dirs = get_uint32(opt);
-	check_range("chdir-dirs", chdir_dirs,
+	chdir_dirs = stress_get_uint32(opt);
+	stress_check_range("chdir-dirs", chdir_dirs,
 		MIN_CHDIR_DIRS, MAX_CHDIR_DIRS);
-	return set_setting("chdir-dirs", TYPE_ID_UINT32, &chdir_dirs);
+	return stress_set_setting("chdir-dirs", TYPE_ID_UINT32, &chdir_dirs);
 }
 
 /*
  *  stress_chdir
  *	stress chdir calls
  */
-static int stress_chdir(const args_t *args)
+static int stress_chdir(const stress_args_t *args)
 {
 	uint32_t i, chdir_dirs = DEFAULT_CHDIR_DIRS;
 	char path[PATH_MAX], cwd[PATH_MAX];
 	int rc, ret = EXIT_FAILURE, *fds;
 	char **paths;
 
-	(void)get_setting("chdir-dirs", &chdir_dirs);
+	(void)stress_get_setting("chdir-dirs", &chdir_dirs);
 	paths = calloc(chdir_dirs, sizeof(*paths));
 	if (!paths) {
 		pr_err("%s: out of memory allocating paths\n", args->name);
@@ -82,7 +82,7 @@ static int stress_chdir(const args_t *args)
 
 	/* Populate */
 	for (i = 0; i < chdir_dirs; i++) {
-		uint64_t rnd = (uint64_t)mwc32() << 32;
+		uint64_t rnd = (uint64_t)stress_mwc32() << 32;
 		uint32_t gray_code = (i >> 1) ^ i;
 		int flags = O_RDONLY;
 
@@ -107,7 +107,7 @@ static int stress_chdir(const args_t *args)
 
 	do {
 		for (i = 0; i < chdir_dirs; i++) {
-			uint32_t j = mwc32() % chdir_dirs;
+			uint32_t j = stress_mwc32() % chdir_dirs;
 			const int fd = fds[j] >= 0 ? fds[j] : fds[0];
 
 			if (!keep_stressing())
@@ -171,7 +171,7 @@ err:
 	return ret;
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_chdir_dirs,	stress_set_chdir_dirs },
 	{ 0,			NULL }
 };
