@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"chmod N",	"start N workers thrashing chmod file mode bits " },
 	{ NULL,	"chmod-ops N",	"stop chmod workers after N bogo operations" },
 	{ NULL,	NULL,		NULL }
@@ -126,7 +126,7 @@ static int do_chmod(
  *  stress_chmod
  *	stress chmod
  */
-static int stress_chmod(const args_t *args)
+static int stress_chmod(const stress_args_t *args)
 {
 	const pid_t ppid = getppid();
 	int i, fd = -1, rc = EXIT_FAILURE, retries = 0;
