@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"clock N",	"start N workers thrashing clocks and POSIX timers" },
 	{ NULL,	"clock-ops N",	"stop clock workers after N bogo operations" },
 	{ NULL,	NULL,		NULL }
@@ -131,7 +131,7 @@ static const char *stress_clock_name(int id)
  *  stress_clock()
  *	stress system by rapid clocking system calls
  */
-static int stress_clock(const args_t *args)
+static int stress_clock(const stress_args_t *args)
 {
 	do {
 #if defined(CLOCK_THREAD_CPUTIME_ID) && \
@@ -190,7 +190,7 @@ static int stress_clock(const args_t *args)
 		}
 #endif
 
-#if defined(HAVE_CLOCK_NANOSLEEP) 
+#if defined(HAVE_CLOCK_NANOSLEEP)
 		{
 			size_t i;
 			struct timespec t;
@@ -237,6 +237,7 @@ static int stress_clock(const args_t *args)
 				struct sigevent sevp;
 
 				timer_fail[i] = false;
+				timer_id[i] = (timer_t)-1;
 
 				(void)memset(&sevp, 0, sizeof(sevp));
 				sevp.sigev_notify = SIGEV_NONE;
@@ -270,7 +271,7 @@ static int stress_clock(const args_t *args)
 			}
 
 			for (i = 0; i < n; i++) {
-				if (timer_fail[i])
+				if (timer_fail[i] || timer_id[i] == (timer_t)-1)
 					continue;
 
 				ret = timer_gettime(timer_id[i], &its);
@@ -286,7 +287,7 @@ static int stress_clock(const args_t *args)
 			}
 
 			for (i = 0; i < n; i++) {
-				if (timer_fail[i])
+				if (timer_fail[i] || timer_id[i] == (timer_t)-1)
 					continue;
 				ret = timer_delete(timer_id[i]);
 				if ((ret < 0) && (g_opt_flags & OPT_FLAGS_VERIFY)) {
