@@ -27,7 +27,7 @@
 #define CLONE_STACK_SIZE	(16*1024)
 
 typedef struct stress_clone_args {
-	const args_t *args;
+	const stress_args_t *args;
 } stress_clone_args_t;
 
 typedef struct clone {
@@ -43,7 +43,7 @@ typedef struct {
 	uint32_t length;	/* Length of list */
 } stress_clone_list_t;
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"clone N",	"start N workers that rapidly create and reap clones" },
 	{ NULL,	"clone-ops N",	"stop after N bogo clone operations" },
 	{ NULL,	"clone-max N",	"set upper limit of N clones per worker" },
@@ -139,13 +139,13 @@ static int stress_set_clone_max(const char *opt)
 {
 	uint32_t clone_max;
 
-	clone_max = get_uint32(opt);
-	check_range("clone-max", clone_max,
+	clone_max = stress_get_uint32(opt);
+	stress_check_range("clone-max", clone_max,
 		MIN_ZOMBIES, MAX_ZOMBIES);
-	return set_setting("clone-max", TYPE_ID_UINT32, &clone_max);
+	return stress_set_setting("clone-max", TYPE_ID_UINT32, &clone_max);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_clone_max,	stress_set_clone_max },
 	{ 0,			NULL }
 };
@@ -284,7 +284,7 @@ static int clone_func(void *arg)
 	return 0;
 }
 
-static int stress_clone_child(const args_t *args, void *context)
+static int stress_clone_child(const stress_args_t *args, void *context)
 {
 	/* Child */
 	uint32_t max_clones = 0;
@@ -303,7 +303,7 @@ static int stress_clone_child(const args_t *args, void *context)
 
 	(void)context;
 
-	if (!get_setting("clone-max", &clone_max)) {
+	if (!stress_get_setting("clone-max", &clone_max)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			clone_max = MAX_ZOMBIES;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -322,7 +322,7 @@ static int stress_clone_child(const args_t *args, void *context)
 		if (clones.length < clone_max) {
 			stress_clone_t *clone_info;
 			stress_clone_args_t clone_arg = { args };
-			const uint32_t rnd = mwc32();
+			const uint32_t rnd = stress_mwc32();
 			const int flag = flags[rnd % SIZEOF_ARRAY(flags)];
 			const bool try_clone3 = rnd >> 31;
 
@@ -358,7 +358,7 @@ static int stress_clone_child(const args_t *args, void *context)
 				char *stack_top = clone_info->stack + stack_offset;
 
 				clone_info->pid = clone(clone_func,
-					align_stack(stack_top), flag, &clone_arg);
+					stress_align_stack(stack_top), flag, &clone_arg);
 			}
 			if (clone_info->pid == -1) {
 				/*
@@ -395,7 +395,7 @@ static int stress_clone_child(const args_t *args, void *context)
  *  stress_clone()
  *	stress by cloning and exiting
  */
-static int stress_clone(const args_t *args)
+static int stress_clone(const stress_args_t *args)
 {
 	stress_set_oom_adjustment(args->name, false);
 
