@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"copy-file N",		"start N workers that copy file data" },
 	{ NULL,	"copy-file-ops N",	"stop after N copy bogo operations" },
 	{ NULL,	"copy-file-bytes N",	"specify size of file to be copied" },
@@ -36,13 +36,13 @@ static int stress_set_copy_file_bytes(const char *opt)
 {
 	uint64_t copy_file_bytes;
 
-	copy_file_bytes = get_uint64_byte_filesystem(opt, 1);
-	check_range_bytes("copy-file-bytes", copy_file_bytes,
+	copy_file_bytes = stress_get_uint64_byte_filesystem(opt, 1);
+	stress_check_range_bytes("copy-file-bytes", copy_file_bytes,
 		MIN_COPY_FILE_BYTES, MAX_COPY_FILE_BYTES);
-	return set_setting("copy-file-bytes", TYPE_ID_UINT64, &copy_file_bytes);
+	return stress_set_setting("copy-file-bytes", TYPE_ID_UINT64, &copy_file_bytes);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_copy_file_bytes,	stress_set_copy_file_bytes },
 	{ 0,			NULL }
 };
@@ -53,13 +53,13 @@ static const opt_set_func_t opt_set_funcs[] = {
  *  stress_copy_file
  *	stress reading chunks of file using copy_file_range()
  */
-static int stress_copy_file(const args_t *args)
+static int stress_copy_file(const stress_args_t *args)
 {
 	int fd_in, fd_out, rc = EXIT_FAILURE;
 	char filename[PATH_MAX - 5], tmp[PATH_MAX];
 	uint64_t copy_file_bytes = DEFAULT_COPY_FILE_BYTES;
 
-	if (!get_setting("copy-file-bytes", &copy_file_bytes)) {
+	if (!stress_get_setting("copy-file-bytes", &copy_file_bytes)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			copy_file_bytes = MAX_HDD_BYTES;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -75,7 +75,7 @@ static int stress_copy_file(const args_t *args)
 	if (stress_temp_dir_mk(args->name, args->pid, args->instance) < 0)
 		goto tidy_dir;
 	(void)stress_temp_filename_args(args,
-			filename, sizeof(filename), mwc32());
+			filename, sizeof(filename), stress_mwc32());
 	(void)snprintf(tmp, sizeof(tmp), "%s-orig", filename);
 	if ((fd_in = open(tmp, O_CREAT | O_RDWR,  S_IRUSR | S_IWUSR)) < 0) {
 		rc = exit_status(errno);
@@ -105,8 +105,8 @@ static int stress_copy_file(const args_t *args)
 		ssize_t ret;
 		shim_loff_t off_in, off_out;
 
-		off_in = mwc64() % (copy_file_bytes - DEFAULT_COPY_FILE_SIZE);
-		off_out = mwc64() % (copy_file_bytes - DEFAULT_COPY_FILE_SIZE);
+		off_in = stress_mwc64() % (copy_file_bytes - DEFAULT_COPY_FILE_SIZE);
+		off_out = stress_mwc64() % (copy_file_bytes - DEFAULT_COPY_FILE_SIZE);
 
 		ret =  shim_copy_file_range(fd_in, &off_in, fd_out,
 			&off_out, DEFAULT_COPY_FILE_SIZE, 0);
