@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"cpu-online N",		"start N workers offlining/onlining the CPUs" },
 	{ NULL,	"cpu-online-ops N",	"stop after N offline/online operations" },
 	{ NULL,	NULL,			NULL }
@@ -37,7 +37,7 @@ static const help_t help[] = {
  *	set a specified CPUs online or offline
  */
 static int stress_cpu_online_set(
-	const args_t *args,
+	const stress_args_t *args,
 	const int32_t cpu,
 	const int setting)
 {
@@ -86,7 +86,7 @@ static int stress_cpu_online_supported(void)
  *  stress_cpu_online
  *	stress twiddling CPUs online/offline
  */
-static int stress_cpu_online(const args_t *args)
+static int stress_cpu_online(const stress_args_t *args)
 {
 	const int32_t cpus = stress_get_processors_configured();
 	int32_t i, cpu_online_count = 0;
@@ -155,7 +155,7 @@ static int stress_cpu_online(const args_t *args)
 	 *  Now randomly offline/online them all
 	 */
 	do {
-		unsigned long cpu = mwc32() % cpus;
+		unsigned long cpu = stress_mwc32() % cpus;
 
 		/*
 		 * Only allow CPU 0 to be offlined if OPT_FLAGS_CPU_ONLINE_ALL
