@@ -106,7 +106,7 @@ typedef struct {
 	const stress_cpu_func	func;	/* the cpu method function */
 } stress_cpu_method_info_t;
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ "c N", "cpu N",		"start N workers spinning on sqrt(rand())" },
 	{ NULL,  "cpu-ops N",		"stop after N cpu bogo operations" },
 	{ "l P", "cpu-load P",		"load CPU by P %, 0=sleep, 100=full load (see -c)" },
@@ -123,9 +123,9 @@ uint8_t pixels[STRESS_CPU_DITHER_X][STRESS_CPU_DITHER_Y];
 static int stress_set_cpu_load(const char *opt) {
 	int32_t cpu_load;
 
-	cpu_load = get_int32(opt);
-	check_range("cpu-load", cpu_load, 0, 100);
-	return set_setting("cpu-load", TYPE_ID_INT32, &cpu_load);
+	cpu_load = stress_get_int32(opt);
+	stress_check_range("cpu-load", cpu_load, 0, 100);
+	return stress_set_setting("cpu-load", TYPE_ID_INT32, &cpu_load);
 }
 
 /*
@@ -138,12 +138,12 @@ static int stress_set_cpu_load_slice(const char *opt)
 {
 	int32_t cpu_load_slice;
 
-	cpu_load_slice = get_int32(opt);
+	cpu_load_slice = stress_get_int32(opt);
 	if ((cpu_load_slice < -5000) || (cpu_load_slice > 5000)) {
 		(void)fprintf(stderr, "cpu-load-slice must in the range -5000 to 5000.\n");
 		_exit(EXIT_FAILURE);
 	}
-	return set_setting("cpu-load-slice", TYPE_ID_INT32, &cpu_load_slice);
+	return stress_set_setting("cpu-load-slice", TYPE_ID_INT32, &cpu_load_slice);
 }
 
 /*
@@ -155,15 +155,25 @@ static void HOT TARGET_CLONES stress_cpu_sqrt(const char *name)
 	int i;
 
 	for (i = 0; i < 16384; i++) {
-		uint64_t rnd = mwc32();
-		double r = sqrt((double)rnd) * sqrt((double)rnd);
+		uint64_t rnd = stress_mwc32();
+		double r_d = sqrt((double)rnd) * sqrt((double)rnd);
+                long double r_ld = sqrtl((long double)rnd) * sqrtl((long double)rnd);
+
 		if (UNLIKELY((g_opt_flags & OPT_FLAGS_VERIFY) &&
-		    (uint64_t)rint(r) != rnd)) {
+		    (uint64_t)rint(r_d) != rnd)) {
 			pr_fail("%s: sqrt error detected on "
 				"sqrt(%" PRIu64 ")\n", name, rnd);
 			if (!keep_stressing_flag())
 				break;
 		}
+
+		if (UNLIKELY((g_opt_flags & OPT_FLAGS_VERIFY) &&
+		    (uint64_t)rint(r_ld) != rnd)) {
+			pr_fail("%s: sqrtf error detected on "
+				"sqrt(%" PRIu64 ")\n", name, rnd);
+			if (!keep_stressing_flag())
+				break;
+		}
 	}
 }
 
@@ -226,7 +236,7 @@ static void HOT OPTIMIZE3 TARGET_CLONES stress_cpu_gcd(const char *name)
 
 	for (i = 0; i < 16384; i++) {
 		register uint32_t a = i, b = i % (3 + (1997 ^ i));
-		register uint64_t lcm = (a * b);
+		register uint64_t lcm = ((uint64_t)a * b);
 
 		while (b != 0) {
 			register uint32_t r = b;
@@ -336,7 +346,7 @@ static void HOT stress_cpu_trig(const char *name)
 			d_sum += sinf(theta3);
 		}
 	}
-	double_put(d_sum);
+	stress_double_put(d_sum);
 }
 
 /*
@@ -372,7 +382,7 @@ static void HOT stress_cpu_hyperbolic(const char *name)
 			d_sum += (double)sinhf(theta3);
 		}
 	}
-	double_put(d_sum);
+	stress_double_put(d_sum);
 }
 
 /*
@@ -385,9 +395,9 @@ static void HOT OPTIMIZE3 stress_cpu_rand(const char *name)
 	uint32_t i_sum = 0;
 	const uint32_t sum = 0xc253698c;
 
-	MWC_SEED();
+	STRESS_MWC_SEED();
 	for (i = 0; i < 16384; i++)
-		i_sum += mwc32();
+		i_sum += stress_mwc32();
 
 	if ((g_opt_flags & OPT_FLAGS_VERIFY) && (i_sum != sum))
 		pr_fail("%s: rand error detected, failed sum of "
@@ -411,8 +421,8 @@ static void HOT OPTIMIZE3 stress_cpu_rand48(const char *name)
 		d += drand48();
 		l += lrand48();
 	}
-	double_put(d);
-	uint64_put(l);
+	stress_double_put(d);
+	stress_uint64_put(l);
 }
 
 /*
@@ -467,8 +477,8 @@ static void HOT OPTIMIZE3 TARGET_CLONES stress_cpu_phi(const char *name)
 	int i;
 
 	/* Pick any two starting points */
-	a = mwc64() % 99;
-	b = mwc64() % 99;
+	a = stress_mwc64() % 99;
+	b = stress_mwc64() % 99;
 
 	/* Iterate until we approach overflow */
 	for (i = 0; (i < 64) && !((a | b) & mask); i++) {
@@ -487,6 +497,32 @@ static void HOT OPTIMIZE3 TARGET_CLONES stress_cpu_phi(const char *name)
 			name);
 }
 
+/*
+ *  stress_cpu_apery()
+ *      compute Apéry's constant
+ */
+static void HOT OPTIMIZE3 stress_cpu_apery(const char *name)
+{
+	uint32_t n;
+	long double a = 0.0, a_;
+	const long double precision = 1.0e-14L;
+
+	(void)name;
+
+	for (n = 1; n < 100000; n++) {
+		long double n3 = (long double)n;
+
+		a_ = a;
+		n3 = n3 * n3 * n3;
+		a += (1.0L / n3);
+		if (fabsl(a - a_) < precision)
+			break;
+	}
+	if (fabsl(a - a_) > precision)
+		pr_fail("%s: Apéry's const not accurate enough\n", name);
+}
+
+
 #if defined(HAVE_COMPLEX_H) &&		\
     defined(HAVE_COMPLEX) &&		\
     defined(__STDC_IEC_559_COMPLEX__) &&\
@@ -571,7 +607,7 @@ static void random_buffer(uint8_t *data, const size_t len)
 	size_t i;
 
 	for (i = 0; i < len / 4; i++) {
-		uint32_t v = mwc32();
+		uint32_t v = stress_mwc32();
 
 		*data++ = v;
 		v >>= 8;
@@ -614,7 +650,7 @@ static void stress_cpu_hash_generic(
 	size_t i;
 	uint32_t i_sum = 0;
 
-	MWC_SEED();
+	STRESS_MWC_SEED();
 	random_buffer((uint8_t *)buffer, sizeof(buffer));
 	/* Make it ASCII range ' '..'_' */
 	for (i = 0; i < sizeof(buffer); i++)
@@ -640,7 +676,7 @@ static void stress_cpu_jenkin(const char *name)
 	uint32_t i_sum = 0;
 	const uint32_t sum = 0x96673680;
 
-	MWC_SEED();
+	STRESS_MWC_SEED();
 	random_buffer(buffer, sizeof(buffer));
 	for (i = 0; i < sizeof(buffer); i++)
 		i_sum += stress_hash_jenkin(buffer, sizeof(buffer));
@@ -765,10 +801,10 @@ static void HOT OPTIMIZE3 TARGET_CLONES stress_cpu_idct(const char *name)
 		b <<= 2;		\
 		a |= 1;			\
 		b |= 3;			\
-		a *= mwc32();		\
-		b ^= mwc32();		\
-		a += mwc32();		\
-		b -= mwc32();		\
+		a *= stress_mwc32();	\
+		b ^= stress_mwc32();	\
+		a += stress_mwc32();	\
+		b -= stress_mwc32();	\
 		a /= 7;			\
 		b /= 9;			\
 		a |= (c2);		\
@@ -794,9 +830,9 @@ static void HOT OPTIMIZE3 TARGET_CLONES stress_cpu_int ## _sz(const char *name)\
 	register _type a, b;					\
 	int i;							\
 								\
-	MWC_SEED();						\
-	a = mwc32();						\
-	b = mwc32();						\
+	STRESS_MWC_SEED();					\
+	a = stress_mwc32();					\
+	b = stress_mwc32();					\
 								\
 	for (i = 0; i < 1000; i++) {				\
 		int_ops(a, b, c1, c2, c3)			\
@@ -863,7 +899,8 @@ stress_cpu_int(uint8_t, 8, \
 static void HOT OPTIMIZE3 TARGET_CLONES stress_cpu_ ## _name(const char *name)\
 {							\
 	int i;						\
-	_type a = 0.18728L, b = mwc32(), c = mwc32(), d;\
+	_type a = 0.18728L, b = stress_mwc32(), 	\
+	      c = stress_mwc32(), d;			\
 							\
 	(void)name;					\
 							\
@@ -871,7 +908,7 @@ static void HOT OPTIMIZE3 TARGET_CLONES stress_cpu_ ## _name(const char *name)\
 		float_ops(_type, a, b, c, d,		\
 			_sin, _cos);			\
 	}						\
-	double_put(a + b + c + d);			\
+	stress_double_put(a + b + c + d);		\
 }
 
 stress_cpu_fp(float, float, sinf, cosf)
@@ -911,21 +948,21 @@ stress_cpu_fp(__float128, float128, sinl, cosl)
  */
 #define stress_cpu_complex(_type, _ltype, _name, _csin, _ccos)	\
 static void HOT OPTIMIZE3 TARGET_CLONES stress_cpu_ ## _name(const char *name)\
-{							\
-	int i;						\
-	_type cI = I;					\
-	_type a = FP(0.18728, _ltype) + 		\
-		cI * FP(0.2762, _ltype),		\
-		b = mwc32() - cI * FP(0.11121, _ltype),\
-		c = mwc32() + cI * mwc32(), d;		\
-							\
-	(void)name;					\
-							\
-	for (i = 0; i < 1000; i++) {			\
-		float_ops(_type, a, b, c, d,		\
-			_csin, _ccos);			\
-	}						\
-	double_put(a + b + c + d);			\
+{								\
+	int i;							\
+	_type cI = I;						\
+	_type a = FP(0.18728, _ltype) + 			\
+		cI * FP(0.2762, _ltype),			\
+		b = stress_mwc32() - cI * FP(0.11121, _ltype),	\
+		c = stress_mwc32() + cI * stress_mwc32(), d;	\
+								\
+	(void)name;						\
+								\
+	for (i = 0; i < 1000; i++) {				\
+		float_ops(_type, a, b, c, d,			\
+			_csin, _ccos);				\
+	}							\
+	stress_double_put(a + b + c + d);			\
 }
 
 stress_cpu_complex(complex float, f, complex_float, csinf, ccosf)
@@ -961,12 +998,12 @@ stress_cpu_complex(complex long double, l, complex_long_double, csinl, ccosl)
 		int_a |= 1;					\
 		flt_d = flt_d + flt_b + (_ftype)_sin(flt_a);	\
 		int_b |= 3;					\
-		int_a *= mwc32();				\
+		int_a *= stress_mwc32();			\
 		flt_a = (flt_b + flt_c) / flt_c;		\
-		int_b ^= mwc32();				\
-		int_a += mwc32();				\
+		int_b ^= stress_mwc32();			\
+		int_a += stress_mwc32();			\
 		flt_b = flt_b * flt_c;				\
-		int_b -= mwc32();				\
+		int_b -= stress_mwc32();			\
 		int_a /= 7;					\
 		flt_c = flt_c + (_ftype)1.0L;			\
 		int_b /= 9;					\
@@ -995,12 +1032,12 @@ static void HOT OPTIMIZE3 TARGET_CLONES stress_cpu_int ## _sz ## _ ## _name(cons
 	const _inttype c1 = _c1 & mask;				\
 	const _inttype c2 = _c2 & mask;				\
 	const _inttype c3 = _c3 & mask;				\
-	_ftype flt_a = 0.18728L, flt_b = mwc32(),		\
-		flt_c = mwc32(), flt_d;				\
+	_ftype flt_a = 0.18728L, flt_b = stress_mwc32(),	\
+		flt_c = stress_mwc32(), flt_d;			\
 								\
-	MWC_SEED();						\
-	int_a = mwc32();					\
-	int_b = mwc32();					\
+	STRESS_MWC_SEED();					\
+	int_a = stress_mwc32();					\
+	int_b = stress_mwc32();					\
 								\
 	for (i = 0; i < 1000; i++) {				\
 		int_float_ops(_ftype, flt_a, flt_b, flt_c, flt_d,\
@@ -1012,7 +1049,7 @@ static void HOT OPTIMIZE3 TARGET_CLONES stress_cpu_int ## _sz ## _ ## _name(cons
 			"failed int" # _sz "" # _ftype		\
 			" math operations\n", name);		\
 								\
-	double_put(flt_a + flt_b + flt_c + flt_d);		\
+	stress_double_put(flt_a + flt_b + flt_c + flt_d);	\
 }
 
 stress_cpu_int_fp(uint32_t, 32, float, float,
@@ -1080,7 +1117,7 @@ stress_cpu_int_fp(__uint128_t, 128, _Decimal128, decimal128,
 static void HOT OPTIMIZE3 TARGET_CLONES stress_cpu_rgb(const char *name)
 {
 	int i;
-	uint32_t rgb = mwc32() & 0xffffff;
+	uint32_t rgb = stress_mwc32() & 0xffffff;
 	uint8_t r = rgb >> 16;
 	uint8_t g = rgb >> 8;
 	uint8_t b = rgb;
@@ -1105,7 +1142,7 @@ static void HOT OPTIMIZE3 TARGET_CLONES stress_cpu_rgb(const char *name)
 		r += 1;
 		g += 2;
 		b += 3;
-		uint64_put(r + g + b);
+		stress_uint64_put(r + g + b);
 	}
 }
 
@@ -1127,8 +1164,8 @@ static void HOT OPTIMIZE3 TARGET_CLONES stress_cpu_matrix_prod(const char *name)
 
 	for (i = 0; i < MATRIX_PROD_SIZE; i++) {
 		for (j = 0; j < MATRIX_PROD_SIZE; j++) {
-			a[i][j] = (long double)mwc32() * v;
-			b[i][j] = (long double)mwc32() * v;
+			a[i][j] = (long double)stress_mwc32() * v;
+			b[i][j] = (long double)stress_mwc32() * v;
 			r[i][j] = 0.0L;
 		}
 	}
@@ -1144,7 +1181,7 @@ static void HOT OPTIMIZE3 TARGET_CLONES stress_cpu_matrix_prod(const char *name)
 	for (i = 0; i < MATRIX_PROD_SIZE; i++)
 		for (j = 0; j < MATRIX_PROD_SIZE; j++)
 			sum += r[i][j];
-	double_put(sum);
+	stress_double_put(sum);
 }
 
 /*
@@ -1200,7 +1237,7 @@ static void HOT OPTIMIZE3 stress_cpu_psi(const char *name)
 				"than expected\n", name);
 	}
 
-	double_put(psi);
+	stress_double_put(psi);
 }
 
 /*
@@ -1232,7 +1269,7 @@ static void HOT OPTIMIZE3 TARGET_CLONES stress_cpu_ln2(const char *name)
 		pr_fail("%s: calculation of ln(2) took more "
 			"iterations than expected\n", name);
 
-	double_put(ln2);
+	stress_double_put(ln2);
 }
 
 /*
@@ -1287,7 +1324,7 @@ static void HOT stress_cpu_explog(const char *name)
 		v = a;			\
 	else				\
 		v = b;			\
-	uint64_put(next + i);		\
+	stress_uint64_put(next + i);	\
 
 /*
  *   stress_cpu_jmp
@@ -1368,7 +1405,7 @@ static void stress_cpu_crc16(const char *name)
 
 	random_buffer(buffer, sizeof(buffer));
 	for (i = 0; i < sizeof(buffer); i++)
-		uint64_put(ccitt_crc16(buffer, i));
+		stress_uint64_put(ccitt_crc16(buffer, i));
 }
 
 #if defined(HAVE_COMPLEX_H) &&		\
@@ -1406,7 +1443,7 @@ static void stress_cpu_zeta(const char *name)
 	(void)name;
 
 	for (i = 2; i < 11; i++)
-		double_put(zeta((double complex)i, precision));
+		stress_double_put(zeta((double complex)i, precision));
 }
 #endif
 
@@ -1426,7 +1463,7 @@ static void HOT OPTIMIZE3 stress_cpu_gamma(const char *name)
 		k += 1.0L;
 	} while (k < 1e6 && fabsl(_gamma - gammaold) > precision);
 
-	double_put(_gamma);
+	stress_double_put(_gamma);
 
 	if (g_opt_flags & OPT_FLAGS_VERIFY) {
 		if (fabsl(_gamma - GAMMA) > 1.0e-5L)
@@ -1457,7 +1494,7 @@ static void HOT OPTIMIZE3 stress_cpu_correlate(const char *name)
 
 	/* Generate some random data */
 	for (i = 0; i < CORRELATE_DATA_LEN; i++) {
-		data[i] = mwc64();
+		data[i] = stress_mwc64();
 		data_average += data[i];
 	}
 	data_average /= (double)CORRELATE_DATA_LEN;
@@ -1470,7 +1507,7 @@ static void HOT OPTIMIZE3 stress_cpu_correlate(const char *name)
 				   (data[j] - data_average);
 		}
 		corr[i] /= (double)CORRELATE_LEN;
-		double_put(corr[i]);
+		stress_double_put(corr[i]);
 	}
 }
 
@@ -1612,7 +1649,141 @@ static void stress_cpu_hanoi(const char *name)
 		pr_fail("%s: number of hanoi moves different from "
 			"the expected number\n", name);
 
-	uint64_put(n);
+	stress_uint64_put(n);
+}
+
+/*
+ *  stress_floatconversion
+ *	exercise conversion to/from different floating point values
+ */
+static void TARGET_CLONES stress_cpu_floatconversion(const char *name)
+{
+	float f_sum = 0.0;
+	double d_sum = 0.0;
+	long double ld_sum = 0.0;
+	register uint32_t i, j_sum = 0;
+
+	(void)name;
+
+	for (i = 0; i < 65536; i++) {
+		float f;
+		double d;
+		long double ld;
+
+		f = (float)i;
+		d = (double)f;
+		ld = (long double)d;
+
+		f_sum += f;
+		d_sum += d;
+		ld_sum += ld;
+		j_sum += (uint32_t)ld;
+
+		f = (float)(double)i;
+		f_sum += f;
+		f = (float)(long double)i;
+		f_sum += f;
+		f = (float)(double)(long double)i;
+		f_sum += f;
+		f = (float)(long double)(double)i;
+		f_sum += f;
+
+		d = (double)(long double)f;
+		d_sum += d;
+		d = (double)(float)f;
+		d_sum += d;
+		d = (double)(long double)(float)f;
+		d_sum += d;
+		d = (double)(float)(long double)f;
+		d_sum += d;
+
+		ld = (long double)(float)d;
+		ld_sum += ld;
+		ld = (long double)(double)d;
+		ld_sum += ld;
+		ld = (long double)(float)(double)d;
+		ld_sum += ld;
+		ld = (long double)(double)(float)d;
+		ld_sum += ld;
+	}
+	stress_long_double_put(ld_sum);
+	stress_double_put(d_sum);
+	stress_float_put(f_sum);
+	stress_uint32_put(j_sum);
+}
+
+/*
+ *  stress_intconversion
+ *	exercise conversion to/from different int values
+ */
+static void stress_cpu_intconversion(const char *name)
+{
+	int16_t i16_sum = stress_mwc16();
+	int32_t i32_sum = stress_mwc32();
+	int64_t i64_sum = stress_mwc64();
+
+	register uint32_t i;
+
+	(void)name;
+
+	for (i = 0; i < 65536; i++) {
+		int16_t i16;
+		int32_t i32;
+		int64_t	i64;
+
+		i16 = (int16_t)i;
+		i32 = (int32_t)i;
+		i64 = (int64_t)i;
+
+		i16_sum += i16;
+		i32_sum += i32;
+		i64_sum += i64;
+
+		i16 = -(int16_t)(uint32_t)-(int64_t)(uint64_t)i64_sum;
+		i16_sum -= i16;
+		i32 = -(int16_t)(uint32_t)-(int64_t)(uint64_t)i16_sum;
+		i32_sum -= i32;
+		i64 = -(int16_t)(uint32_t)-(int64_t)(uint64_t)i32_sum;
+		i64_sum -= i64;
+
+		i16 = -(int16_t)(uint64_t)-(int32_t)(uint64_t)i64_sum;
+		i16_sum += i16;
+		i32 = -(int16_t)(uint64_t)-(int32_t)(uint64_t)i16_sum;
+		i32_sum += i32;
+		i64 = -(int16_t)(uint64_t)-(int32_t)(uint64_t)i32_sum;
+		i64_sum += i64;
+
+		i16 = -(int32_t)(uint16_t)-(int64_t)(uint64_t)i64_sum;
+		i16_sum -= i16;
+		i32 = -(int32_t)(uint16_t)-(int64_t)(uint64_t)i16_sum;
+		i32_sum -= i32;
+		i64 = -(int32_t)(uint16_t)-(int64_t)(uint64_t)i32_sum;
+		i64_sum -= i64;
+
+		i16 = -(int32_t)(uint64_t)-(int16_t)(uint64_t)i64_sum;
+		i16_sum += i16;
+		i32 = -(int32_t)(uint64_t)-(int16_t)(uint64_t)i16_sum;
+		i32_sum += i32;
+		i64 = -(int32_t)(uint64_t)-(int16_t)(uint64_t)i32_sum;
+		i64_sum += i64;
+
+		i16 = -(int64_t)(uint16_t)-(int32_t)(uint64_t)i64_sum;
+		i16_sum -= i16;
+		i32 = -(int64_t)(uint16_t)-(int32_t)(uint64_t)i16_sum;
+		i32_sum -= i32;
+		i64 = (int64_t)(uint16_t)-(int32_t)(uint64_t)i32_sum;
+		i64_sum -= i64;
+
+		i16 = -(int64_t)(uint32_t)-(int16_t)(uint64_t)i64_sum;
+		i16_sum += i16;
+		i32 = -(int64_t)(uint32_t)-(int16_t)(uint64_t)i16_sum;
+		i32_sum += i32;
+		i64 = -(int64_t)(uint32_t)-(int16_t)(uint64_t)i32_sum;
+		i64_sum += i64;
+	}
+	stress_uint16_put(i16_sum);
+	stress_uint32_put(i32_sum);
+	stress_uint64_put(i64_sum);
 }
 
 /*
@@ -1695,7 +1866,7 @@ static void HOT OPTIMIZE3 stress_cpu_pi(const char *name)
 				"as good as expected\n", name);
 	}
 
-	double_put(pi);
+	stress_double_put(pi);
 }
 
 /*
@@ -1726,7 +1897,7 @@ static void HOT OPTIMIZE3 stress_cpu_omega(const char *name)
 				"not as good as expected\n", name);
 	}
 
-	double_put(omega);
+	stress_double_put(omega);
 }
 
 #define HAMMING(G, i, nybble, code) 			\
@@ -1839,10 +2010,10 @@ static ptrdiff_t stress_cpu_callfunc_func(
  */
 static void stress_cpu_callfunc(const char *name)
 {
-	uint64_t	u64arg = mwc64();
-	uint32_t	u32arg = mwc32();
-	uint16_t	u16arg = mwc16();
-	uint8_t		u8arg  = mwc8();
+	uint64_t	u64arg = stress_mwc64();
+	uint32_t	u32arg = stress_mwc32();
+	uint16_t	u16arg = stress_mwc16();
+	uint8_t		u8arg  = stress_mwc8();
 	ptrdiff_t	ret;
 
 	(void)name;
@@ -1851,7 +2022,7 @@ static void stress_cpu_callfunc(const char *name)
 		u64arg, u32arg, u16arg, u8arg,
 		&u64arg, &u32arg, &u16arg, &u8arg);
 
-	uint64_put((uint64_t)ret);
+	stress_uint64_put((uint64_t)ret);
 }
 
 
@@ -1875,7 +2046,10 @@ static void stress_cpu_parity(const char *name)
 	for (i = 0; i < 1000; i++, val++) {
 		register uint32_t parity, p;
 		uint32_t v;
-		uint8_t *ptr;
+		union {
+			uint32_t v32;
+			uint8_t  v8[4];
+		} u;
 
 		/*
 		 * Naive way
@@ -1948,8 +2122,8 @@ static void stress_cpu_parity(const char *name)
 		 * https://graphics.stanford.edu/~seander/bithacks.html
 		 * Variation #2
 		 */
-		ptr = (uint8_t *)&val;
-		p = stress_cpu_parity_table[ptr[0] ^ ptr[1] ^ ptr[2] ^ ptr[3]];
+		u.v32 = val;
+		p = stress_cpu_parity_table[u.v8[0] ^ u.v8[1] ^ u.v8[2] ^ u.v8[3]];
 		if ((g_opt_flags & OPT_FLAGS_VERIFY) && (p != parity))
 			pr_fail("%s: parity error detected, using the "
 				"lookup method, variation 1\n",  name);
@@ -1972,7 +2146,7 @@ static void TARGET_CLONES stress_cpu_dither(const char *name)
 	 */
 	for (y = 0; y < STRESS_CPU_DITHER_Y; y += 8) {
 		for (x = 0; x < STRESS_CPU_DITHER_X; x ++) {
-			uint64_t v = mwc64();
+			uint64_t v = stress_mwc64();
 
 			pixels[x][y + 0] = v;
 			v >>= 8;
@@ -2038,7 +2212,7 @@ static void TARGET_CLONES stress_cpu_div64(const char *name)
 
 	for (i = 0, j = 0x7fffffffffffULL; i < max; i += di, j -= dj) {
 		register uint64_t r = i / j;
-		uint64_put(r);
+		stress_uint64_put(r);
 		k++;
 	}
 }
@@ -2048,7 +2222,7 @@ static void TARGET_CLONES stress_cpu_div64(const char *name)
  *	get CPU id info, x86 only
  */
 #if defined(HAVE_CPUID_H) &&	\
-    defined(STRESS_X86) &&	\
+    defined(STRESS_ARCH_X86) &&	\
     defined(HAVE_CPUID) &&	\
     NEED_GNUC(4,6,0)
 static void TARGET_CLONES stress_cpu_cpuid(const char *name)
@@ -2062,41 +2236,41 @@ static void TARGET_CLONES stress_cpu_cpuid(const char *name)
 
 		/*  Highest Function Parameter and Manufacturer ID */
 		__cpuid(0x00, eax, ebx, ecx, edx);
-		uint32_put(eax);
+		stress_uint32_put(eax);
 
 		/* Processor Info and Feature Bits */
 		__cpuid(0x01, eax, ebx, ecx, edx);
-		uint32_put(eax);
+		stress_uint32_put(eax);
 
 		/*  Cache and TLB Descriptor information */
 		__cpuid(0x02, eax, ebx, ecx, edx);
-		uint32_put(eax);
+		stress_uint32_put(eax);
 
 		/* Processor Serial Number */
 		__cpuid(0x03, eax, ebx, ecx, edx);
-		uint32_put(eax);
+		stress_uint32_put(eax);
 
 		/* Intel thread/core and cache topology */
 		__cpuid(0x04, eax, ebx, ecx, edx);
-		uint32_put(eax);
+		stress_uint32_put(eax);
 		__cpuid(0x0b, eax, ebx, ecx, edx);
-		uint32_put(eax);
+		stress_uint32_put(eax);
 
 		/* Get highest extended function index */
 		__cpuid(0x80000000, eax, ebx, ecx, edx);
-		uint32_put(eax);
+		stress_uint32_put(eax);
 
 		/* Extended processor info */
 		__cpuid(0x80000001, eax, ebx, ecx, edx);
-		uint32_put(eax);
+		stress_uint32_put(eax);
 
 		/* Processor brand string */
 		__cpuid(0x80000002, eax, ebx, ecx, edx);
-		uint32_put(eax);
+		stress_uint32_put(eax);
 		__cpuid(0x80000003, eax, ebx, ecx, edx);
-		uint32_put(eax);
+		stress_uint32_put(eax);
 		__cpuid(0x80000004, eax, ebx, ecx, edx);
-		uint32_put(eax);
+		stress_uint32_put(eax);
 
 		/* L1 Cache and TLB Identifiers */
 		__cpuid(0x80000005, eax, ebx, ecx, edx);
@@ -2175,6 +2349,7 @@ static void TARGET_CLONES stress_cpu_union(const char *name)
 		u.bits16.b15 ^= 0xbeef;
 		u.bits64.b9++;
 		u.bits64.b10 *= 5;
+		u.u32 += 1;
 	}
 }
 
@@ -2196,7 +2371,8 @@ static uint32_t queens_try(
 	register uint32_t poss = ~(left_diag | cols | right_diag) & all;
 
 	while (poss) {
-		register uint32_t bit = poss & -poss;
+		register uint32_t inv = -poss;
+		register uint32_t bit = poss & inv;
 		register uint32_t new_cols = cols | bit;
 
 		poss -= bit;
@@ -2278,7 +2454,7 @@ static void stress_cpu_stats(const char *name)
 	const double inverse_n = 1.0 / (double)STATS_MAX;
 
 	for (i = 0; i < STATS_MAX; i++)
-		data[i] = ((double)(mwc32() + 1)) / 4294967296.0;
+		data[i] = ((double)(stress_mwc32() + 1)) / 4294967296.0;
 
 	min = max = data[0];
 
@@ -2314,10 +2490,10 @@ static void stress_cpu_stats(const char *name)
 	/* Standard Deviation */
 	stddev = sqrt(stddev);
 
-	double_put(am);
-	double_put(gm);
-	double_put(hm);
-	double_put(stddev);
+	stress_double_put(am);
+	stress_double_put(gm);
+	stress_double_put(hm);
+	stress_double_put(stddev);
 
 	if (min > hm)
 		pr_fail("%s: stats: minimum %f > harmonic mean %f\n",
@@ -2353,6 +2529,7 @@ static const stress_cpu_method_info_t cpu_methods[] = {
 	{ "all",		stress_cpu_all },	/* Special "all test */
 
 	{ "ackermann",		stress_cpu_ackermann },
+	{ "apery",		stress_cpu_apery },
 	{ "bitops",		stress_cpu_bitops },
 	{ "callfunc",		stress_cpu_callfunc },
 #if defined(HAVE_COMPLEX_H) &&		\
@@ -2366,7 +2543,7 @@ static const stress_cpu_method_info_t cpu_methods[] = {
 	{ "collatz",		stress_cpu_collatz },
 	{ "correlate",		stress_cpu_correlate },
 #if defined(HAVE_CPUID_H) &&	\
-    defined(STRESS_X86) &&	\
+    defined(STRESS_ARCH_X86) &&	\
     defined(HAVE_CPUID) &&	\
     NEED_GNUC(4,6,0)
 	{ "cpuid",		stress_cpu_cpuid },
@@ -2408,6 +2585,7 @@ static const stress_cpu_method_info_t cpu_methods[] = {
 #if defined(HAVE_FLOAT128) && !defined(__clang__)
 	{ "float128",		stress_cpu_float128 },
 #endif
+	{ "floatconversion",	stress_cpu_floatconversion },
 	{ "fnv1a",		stress_cpu_fnv1a },
 	{ "gamma",		stress_cpu_gamma },
 	{ "gcd",		stress_cpu_gcd },
@@ -2443,6 +2621,7 @@ static const stress_cpu_method_info_t cpu_methods[] = {
 	{ "int32float",		stress_cpu_int32_float },
 	{ "int32double",	stress_cpu_int32_double },
 	{ "int32longdouble",	stress_cpu_int32_longdouble },
+	{ "intconversion",	stress_cpu_intconversion },
 	{ "jenkin",		stress_cpu_jenkin },
 	{ "jmp",		stress_cpu_jmp },
 	{ "ln2",		stress_cpu_ln2 },
@@ -2486,7 +2665,7 @@ static int stress_set_cpu_method(const char *name)
 
 	for (info = cpu_methods; info->func; info++) {
 		if (!strcmp(info->name, name)) {
-			set_setting("cpu-method", TYPE_ID_UINTPTR_T, &info);
+			stress_set_setting("cpu-method", TYPE_ID_UINTPTR_T, &info);
 			return 0;
 		}
 	}
@@ -2504,7 +2683,7 @@ static int stress_set_cpu_method(const char *name)
  *  stress_cpu()
  *	stress CPU by doing floating point math ops
  */
-static int HOT OPTIMIZE3 stress_cpu(const args_t *args)
+static int HOT OPTIMIZE3 stress_cpu(const stress_args_t *args)
 {
 	double bias;
 	const stress_cpu_method_info_t *cpu_method = &cpu_methods[0];
@@ -2512,9 +2691,9 @@ static int HOT OPTIMIZE3 stress_cpu(const args_t *args)
 	int32_t cpu_load = 100;
 	int32_t cpu_load_slice = -64;
 
-	(void)get_setting("cpu-load", &cpu_load);
-	(void)get_setting("cpu-load-slice", &cpu_load_slice);
-	(void)get_setting("cpu-method", &cpu_method);
+	(void)stress_get_setting("cpu-load", &cpu_load);
+	(void)stress_get_setting("cpu-load-slice", &cpu_load_slice);
+	(void)stress_get_setting("cpu-method", &cpu_method);
 
 	func = cpu_method->func;
 
@@ -2564,7 +2743,7 @@ static int HOT OPTIMIZE3 stress_cpu(const args_t *args)
 			t2 = stress_time_now();
 		} else if (cpu_load_slice == 0) {
 			/* == 0, random time slices */
-			double slice_end = t1 + (((double)mwc16()) / 131072.0);
+			double slice_end = t1 + (((double)stress_mwc16()) / 131072.0);
 			do {
 				(void)func(args->name);
 				t2 = stress_time_now();
@@ -2643,7 +2822,7 @@ static void stress_cpu_set_default(void)
 	stress_set_cpu_method("all");
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_cpu_load,		stress_set_cpu_load },
 	{ OPT_cpu_load_slice,	stress_set_cpu_load_slice },
 	{ OPT_cpu_method,	stress_set_cpu_method },
