@@ -27,7 +27,7 @@
 #undef _XOPEN_SOURCE
 #define _XOPEN_SOURCE	600
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"crypt N",	"start N workers performing password encryption" },
 	{ NULL,	"crypt-ops N",	"stop after N bogo crypt operations" },
 	{ NULL,	NULL,		NULL }
@@ -41,7 +41,7 @@ static const help_t help[] = {
  *	crypt a password with given seed and id
  */
 static int stress_crypt_id(
-	const args_t *args,
+	const stress_args_t *args,
 	const char id,
 	const char *method,
 	const char *passwd,
@@ -68,7 +68,7 @@ static int stress_crypt_id(
  *  stress_crypt()
  *	stress libc crypt
  */
-static int stress_crypt(const args_t *args)
+static int stress_crypt(const stress_args_t *args)
 {
 	do {
 		static const char seedchars[] =
@@ -79,13 +79,13 @@ static int stress_crypt(const args_t *args)
 		uint64_t seed[2];
 		size_t i;
 
-		seed[0] = mwc64();
-		seed[1] = mwc64();
+		seed[0] = stress_mwc64();
+		seed[1] = stress_mwc64();
 
 		for (i = 0; i < 8; i++)
 			salt[i + 3] = seedchars[(seed[i / 5] >> (i % 5) * 6) & 0x3f];
 		for (i = 0; i < sizeof(passwd) - 1; i++)
-			passwd[i] = seedchars[mwc32() % sizeof(seedchars)];
+			passwd[i] = seedchars[stress_mwc32() % sizeof(seedchars)];
 		passwd[i] = '\0';
 
 		if (stress_crypt_id(args, '1', "MD5", passwd, salt) < 0)
