@@ -48,14 +48,14 @@ typedef struct {
 	double		std_dev;	/* standard deviation */
 } stress_rt_stats_t;
 
-typedef int (*stress_cyclic_func)(const args_t *args, stress_rt_stats_t *rt_stats, uint64_t cyclic_sleep);
+typedef int (*stress_cyclic_func)(const stress_args_t *args, stress_rt_stats_t *rt_stats, uint64_t cyclic_sleep);
 
 typedef struct {
 	const char 		 *name;
 	const stress_cyclic_func func;
 } stress_cyclic_method_info_t;
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"cyclic N",		"start N cyclic real time benchmark stressors" },
 	{ NULL,	"cyclic-ops N",		"stop after N cyclic timing cycles" },
 	{ NULL,	"cyclic-method M",	"specify cyclic method M, default is clock_ns" },
@@ -84,10 +84,10 @@ static int stress_set_cyclic_sleep(const char *opt)
 {
 	uint64_t cyclic_sleep;
 
-	cyclic_sleep = get_uint64(opt);
-        check_range("cyclic-sleep", cyclic_sleep,
+	cyclic_sleep = stress_get_uint64(opt);
+        stress_check_range("cyclic-sleep", cyclic_sleep,
                 1, STRESS_NANOSEC);
-        return set_setting("cyclic-sleep", TYPE_ID_UINT64, &cyclic_sleep);
+        return stress_set_setting("cyclic-sleep", TYPE_ID_UINT64, &cyclic_sleep);
 }
 
 static int stress_set_cyclic_policy(const char *opt)
@@ -96,7 +96,7 @@ static int stress_set_cyclic_policy(const char *opt)
 
 	for (policy = 0; policy < num_policies; policy++) {
 		if (!strcmp(opt, policies[policy].opt_name)) {
-			set_setting("cyclic-policy", TYPE_ID_SIZE_T, &policy);
+			stress_set_setting("cyclic-policy", TYPE_ID_SIZE_T, &policy);
 			return 0;
 		}
 	}
@@ -112,18 +112,18 @@ static int stress_set_cyclic_prio(const char *opt)
 {
 	int32_t cyclic_prio;
 
-	cyclic_prio = get_int32(opt);
-        check_range("cyclic-prio", cyclic_prio, 1, 100);
-        return set_setting("cyclic-prio", TYPE_ID_INT32, &cyclic_prio);
+	cyclic_prio = stress_get_int32(opt);
+        stress_check_range("cyclic-prio", cyclic_prio, 1, 100);
+        return stress_set_setting("cyclic-prio", TYPE_ID_INT32, &cyclic_prio);
 }
 
 static int stress_set_cyclic_dist(const char *opt)
 {
 	uint64_t cyclic_dist;
 
-	cyclic_dist = get_uint64(opt);
-        check_range("cyclic-dist", cyclic_dist, 1, 10000000);
-        return set_setting("cyclic-dist", TYPE_ID_UINT64, &cyclic_dist);
+	cyclic_dist = stress_get_uint64(opt);
+        stress_check_range("cyclic-dist", cyclic_dist, 1, 10000000);
+        return stress_set_setting("cyclic-dist", TYPE_ID_UINT64, &cyclic_dist);
 }
 
 static void stress_cyclic_stats(
@@ -151,7 +151,7 @@ static void stress_cyclic_stats(
  *	measure latencies with clock_nanosleep
  */
 static int stress_cyclic_clock_nanosleep(
-	const args_t *args,
+	const stress_args_t *args,
 	stress_rt_stats_t *rt_stats,
 	const uint64_t cyclic_sleep)
 {
@@ -178,7 +178,7 @@ static int stress_cyclic_clock_nanosleep(
  *	measure latencies with posix nanosleep
  */
 static int stress_cyclic_posix_nanosleep(
-	const args_t *args,
+	const stress_args_t *args,
 	stress_rt_stats_t *rt_stats,
 	const uint64_t cyclic_sleep)
 {
@@ -204,7 +204,7 @@ static int stress_cyclic_posix_nanosleep(
  *	measure latencies of heavy polling the clock
  */
 static int stress_cyclic_poll(
-	const args_t *args,
+	const stress_args_t *args,
 	stress_rt_stats_t *rt_stats,
 	const uint64_t cyclic_sleep)
 {
@@ -249,7 +249,7 @@ static int stress_cyclic_poll(
  *	measure latencies with pselect sleep
  */
 static int stress_cyclic_pselect(
-	const args_t *args,
+	const stress_args_t *args,
 	stress_rt_stats_t *rt_stats,
 	const uint64_t cyclic_sleep)
 {
@@ -287,7 +287,7 @@ static void MLOCKED_TEXT stress_cyclic_itimer_handler(int sig)
  *	measure latencies with itimers
  */
 static int stress_cyclic_itimer(
-	const args_t *args,
+	const stress_args_t *args,
 	stress_rt_stats_t *rt_stats,
 	const uint64_t cyclic_sleep)
 {
@@ -347,7 +347,7 @@ restore:
  *	measure latencies with usleep
  */
 static int stress_cyclic_usleep(
-	const args_t *args,
+	const stress_args_t *args,
 	stress_rt_stats_t *rt_stats,
 	const uint64_t cyclic_sleep)
 {
@@ -494,7 +494,7 @@ static int stress_set_cyclic_method(const char *name)
 
 	for (info = cyclic_methods; info->func; info++) {
 		if (!strcmp(info->name, name)) {
-			set_setting("cyclic-method", TYPE_ID_UINTPTR_T, &info);
+			stress_set_setting("cyclic-method", TYPE_ID_UINTPTR_T, &info);
 			return 0;
 		}
 	}
@@ -582,7 +582,7 @@ static int stress_cyclic_supported(void)
         return 0;
 }
 
-static int stress_cyclic(const args_t *args)
+static int stress_cyclic(const stress_args_t *args)
 {
 	const stress_cyclic_method_info_t *cyclic_method = &cyclic_methods[0];
 	const uint32_t num_instances = args->num_instances;
@@ -602,11 +602,11 @@ static int stress_cyclic(const args_t *args)
 	stress_cyclic_func func;
 
 	timeout  = g_opt_timeout;
-	(void)get_setting("cyclic-sleep", &cyclic_sleep);
-	(void)get_setting("cyclic-prio", &cyclic_prio);
-	(void)get_setting("cyclic-policy", &cyclic_policy);
-	(void)get_setting("cyclic-dist", &cyclic_dist);
-	(void)get_setting("cyclic-method", &cyclic_method);
+	(void)stress_get_setting("cyclic-sleep", &cyclic_sleep);
+	(void)stress_get_setting("cyclic-prio", &cyclic_prio);
+	(void)stress_get_setting("cyclic-policy", &cyclic_policy);
+	(void)stress_get_setting("cyclic-dist", &cyclic_dist);
+	(void)stress_get_setting("cyclic-method", &cyclic_method);
 
 	func = cyclic_method->func;
 	policy = policies[cyclic_policy].policy;
@@ -841,7 +841,7 @@ tidy:
 	return EXIT_SUCCESS;
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_cyclic_dist,	stress_set_cyclic_dist },
 	{ OPT_cyclic_method,	stress_set_cyclic_method },
 	{ OPT_cyclic_policy,	stress_set_cyclic_policy },
