@@ -35,7 +35,7 @@ typedef struct {
 	int	   opt;
 } stress_dccp_opts_t;
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"dccp N",		"start N workers exercising network DCCP I/O" },
 	{ NULL,	"dccp-domain D",	"specify DCCP domain, default is ipv4" },
 	{ NULL,	"dccp-ops N",		"stop after N DCCP  bogo operations" },
@@ -65,7 +65,7 @@ static int stress_set_dccp_opts(const char *opt)
 		if (!strcmp(opt, dccp_options[i].optname)) {
 			int dccp_opt = dccp_options[i].opt;
 
-			set_setting("dccp-opts", TYPE_ID_INT, &dccp_opt);
+			stress_set_setting("dccp-opts", TYPE_ID_INT, &dccp_opt);
 			return 0;
 		}
 	}
@@ -89,7 +89,7 @@ static int stress_set_dccp_port(const char *opt)
 	stress_set_net_port("dccp-port", opt,
 		MIN_DCCP_PORT, MAX_DCCP_PORT - STRESS_PROCS_MAX,
 		&dccp_port);
-	return set_setting("dccp-port", TYPE_ID_INT, &dccp_port);
+	return stress_set_setting("dccp-port", TYPE_ID_INT, &dccp_port);
 }
 
 /*
@@ -102,11 +102,11 @@ static int stress_set_dccp_domain(const char *name)
 
 	ret = stress_set_net_domain(DOMAIN_INET | DOMAIN_INET6,
 				"dccp-domain", name, &dccp_domain);
-	set_setting("dccp-domain", TYPE_ID_INT, &dccp_domain);
+	stress_set_setting("dccp-domain", TYPE_ID_INT, &dccp_domain);
 	return ret;
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_dccp_domain,	stress_set_dccp_domain },
 	{ OPT_dccp_opts,	stress_set_dccp_opts },
 	{ OPT_dccp_port,	stress_set_dccp_port },
@@ -120,7 +120,7 @@ static const opt_set_func_t opt_set_funcs[] = {
  *	client reader
  */
 static void stress_dccp_client(
-	const args_t *args,
+	const stress_args_t *args,
 	const pid_t ppid,
 	const int dccp_port,
 	const int dccp_domain)
@@ -202,7 +202,7 @@ retry:
  *	server writer
  */
 static int stress_dccp_server(
-	const args_t *args,
+	const stress_args_t *args,
 	const pid_t pid,
 	const pid_t ppid,
 	const int dccp_port,
@@ -376,16 +376,16 @@ die:
  *  stress_dccp
  *	stress by heavy dccp  I/O
  */
-static int stress_dccp(const args_t *args)
+static int stress_dccp(const stress_args_t *args)
 {
 	pid_t pid, ppid = getppid();
 	int dccp_port = DEFAULT_DCCP_PORT;
 	int dccp_domain = AF_INET;
 	int dccp_opts = DCCP_OPT_SEND;
 
-	(void)get_setting("dccp-port", &dccp_port);
-	(void)get_setting("dccp-domain", &dccp_domain);
-	(void)get_setting("dccp-opts", &dccp_opts);
+	(void)stress_get_setting("dccp-port", &dccp_port);
+	(void)stress_get_setting("dccp-domain", &dccp_domain);
+	(void)stress_get_setting("dccp-opts", &dccp_opts);
 
 	pr_dbg("%s: process [%d] using socket port %d\n",
 		args->name, (int)args->pid, dccp_port + args->instance);
