@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"dev-shm N",	"start N /dev/shm file and mmap stressors" },
 	{ NULL,	"dev-shm-ops N","stop after N /dev/shm bogo ops" },
 	{ NULL,	NULL,		NULL }
@@ -38,7 +38,7 @@ static const help_t help[] = {
  *	to it once we hit the largest file size allowed.
  */
 static inline int stress_dev_shm_child(
-	const args_t *args,
+	const stress_args_t *args,
 	const int fd)
 {
 	int rc = EXIT_SUCCESS;
@@ -94,7 +94,7 @@ static inline int stress_dev_shm_child(
 
 				/* Touch all pages with random data */
 				for (ptr = addr; ptr < end; ptr += words) {
-					*ptr = mwc32();
+					*ptr = stress_mwc32();
 				}
 				(void)msync(addr, sz, MS_INVALIDATE);
 				(void)munmap(addr, sz);
@@ -115,7 +115,7 @@ static inline int stress_dev_shm_child(
  *  stress_dev_shm()
  *	stress /dev/shm
  */
-static int stress_dev_shm(const args_t *args)
+static int stress_dev_shm(const stress_args_t *args)
 {
 	int fd, rc = EXIT_SUCCESS;
 	char path[PATH_MAX];
@@ -140,7 +140,7 @@ static int stress_dev_shm(const args_t *args)
 	}
 
 	(void)snprintf(path, sizeof(path), "/dev/shm/stress-dev-shm-%d-%d-%" PRIu32,
-		args->instance, getpid(), mwc32());
+		args->instance, getpid(), stress_mwc32());
 	fd = open(path, O_CREAT | O_EXCL | O_RDWR, S_IRUSR | S_IWUSR);
 	if (fd < 0) {
 		pr_inf("%s: cannot create %s, errno=%d (%s)\n",
@@ -178,7 +178,7 @@ fork_again:
 			if (WIFSIGNALED(status)) {
 				if ((WTERMSIG(status) == SIGKILL) ||
 				    (WTERMSIG(status) == SIGKILL)) {
-					log_system_mem_info();
+					stress_log_system_mem_info();
 					pr_dbg("%s: assuming killed by OOM killer, "
 						"restarting again (instance %d)\n",
 						args->name, args->instance);
