@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"dev N",	"start N device entry thrashing stressors" },
 	{ NULL,	"dev-ops N",	"stop after N device thrashing bogo ops" },
 	{ NULL,	NULL,		NULL }
@@ -370,6 +370,27 @@ static void stress_dev_tty(
 		(void)ret;
 	}
 #endif
+
+#if defined(TCOOFF) && defined(TCOON)
+	{
+		ret = ioctl(fd, TCOOFF, 0);
+		if (ret == 0)
+			ret = ioctl(fd, TCOON, 0);
+		(void)ret;
+	}
+#endif
+
+#if defined(TCIOFF) && defined(TCION)
+	{
+		ret = ioctl(fd, TCIOFF, 0);
+		if (ret == 0)
+			ret = ioctl(fd, TCION, 0);
+		(void)ret;
+	}
+#endif
+
+	/* Modem */
+
 	/* Modem */
 #if defined(TIOCGSOFTCAR)
 	{
@@ -830,7 +851,7 @@ static void stress_dev_mem_mmap_linux(const int fd, const bool read_page)
 
 		/* Try seeking */
 		off = lseek(fd, (off_t)0, SEEK_SET);
-#if defined(STRESS_X86)
+#if defined(STRESS_ARCH_X86)
 		if (off == 0) {
 			char buffer[page_size];
 			ssize_t ret;
@@ -925,7 +946,7 @@ static void stress_dev_hpet_linux(
 }
 #endif
 
-#if defined(__linux__) && defined(STRESS_X86)
+#if defined(__linux__) && defined(STRESS_ARCH_X86)
 static void stress_dev_port_linux(
 	const char *name,
 	const int fd,
@@ -1123,7 +1144,7 @@ static const stress_dev_func_t dev_funcs[] = {
 	DEV_FUNC("/dev/kmsg",	stress_dev_kmsg_linux),
 	DEV_FUNC("/dev/nvram",	stress_dev_nvram_linux),
 #endif
-#if defined(__linux__) && defined(STRESS_X86)
+#if defined(__linux__) && defined(STRESS_ARCH_X86)
 	DEV_FUNC("/dev/port",	stress_dev_port_linux),
 #endif
 #if defined(HAVE_LINUX_HPET_H)
@@ -1138,7 +1159,7 @@ static const stress_dev_func_t dev_funcs[] = {
  *	exercise a dev entry
  */
 static inline void stress_dev_rw(
-	const args_t *args,
+	const stress_args_t *args,
 	int32_t loops)
 {
 	int fd, ret;
@@ -1345,9 +1366,8 @@ next:
 static void *stress_dev_thread(void *arg)
 {
 	static void *nowt = NULL;
-	uint8_t stack[SIGSTKSZ + STACK_ALIGNMENT];
-	const pthread_args_t *pa = (pthread_args_t *)arg;
-	const args_t *args = pa->args;
+	const stress_pthread_args_t *pa = (stress_pthread_args_t *)arg;
+	const stress_args_t *args = pa->args;
 
 	/*
 	 *  Block all signals, let controlling thread
@@ -1355,16 +1375,6 @@ static void *stress_dev_thread(void *arg)
 	 */
 	(void)sigprocmask(SIG_BLOCK, &set, NULL);
 
-	/*
-	 *  According to POSIX.1 a thread should have
-	 *  a distinct alternative signal stack.
-	 *  However, we block signals in this thread
-	 *  so this is probably just totally unncessary.
-	 */
-	(void)memset(stack, 0, sizeof(stack));
-	if (stress_sigaltstack(stack, SIGSTKSZ) < 0)
-		return &nowt;
-
 	while (keep_stressing_flag())
 		stress_dev_rw(args, -1);
 
@@ -1376,7 +1386,7 @@ static void *stress_dev_thread(void *arg)
  *	read directory
  */
 static void stress_dev_dir(
-	const args_t *args,
+	const stress_args_t *args,
 	const char *path,
 	const bool recurse,
 	const int depth,
@@ -1492,12 +1502,12 @@ done:
  *  stress_dev
  *	stress reading all of /dev
  */
-static int stress_dev(const args_t *args)
+static int stress_dev(const stress_args_t *args)
 {
 	pthread_t pthreads[MAX_DEV_THREADS];
 	int ret[MAX_DEV_THREADS], rc = EXIT_SUCCESS;
 	uid_t euid = geteuid();
-	pthread_args_t pa;
+	stress_pthread_args_t pa;
 
 	dev_path = "/dev/null";
 	pa.args = args;
@@ -1565,7 +1575,7 @@ again:
 
 			/* Make sure this is killable by OOM killer */
 			stress_set_oom_adjustment(args->name, true);
-			mixup = mwc32();
+			mixup = stress_mwc32();
 
 			for (i = 0; i < MAX_DEV_THREADS; i++) {
 				ret[i] = pthread_create(&pthreads[i], NULL,
