@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"dir N",	"start N directory thrashing stressors" },
 	{ NULL,	"dir-ops N",	"stop after N directory bogo operations" },
 	{ NULL,	"dir-dirs N",	"select number of directories to exercise dir on" },
@@ -39,10 +39,10 @@ static int stress_set_dir_dirs(const char *opt)
 {
 	uint64_t dir_dirs;
 
-	dir_dirs = get_uint64(opt);
-	check_range("dir-dirs", dir_dirs,
+	dir_dirs = stress_get_uint64(opt);
+	stress_check_range("dir-dirs", dir_dirs,
 		MIN_DIR_DIRS, MAX_DIR_DIRS);
-	return set_setting("dir-dirs", TYPE_ID_UINT64, &dir_dirs);
+	return stress_set_setting("dir-dirs", TYPE_ID_UINT64, &dir_dirs);
 }
 
 #if defined(__DragonFly__)
@@ -80,7 +80,7 @@ static void stress_dir_sync(const char *path)
  *	read all dentries
  */
 static void stress_dir_read(
-	const args_t *args,
+	const stress_args_t *args,
 	const char *path)
 {
 	DIR *dp;
@@ -105,7 +105,7 @@ static void stress_dir_read(
  *	remove all dentries
  */
 static void stress_dir_tidy(
-	const args_t *args,
+	const stress_args_t *args,
 	const uint64_t n)
 {
 	uint64_t i;
@@ -124,7 +124,7 @@ static void stress_dir_tidy(
  *  stress_dir
  *	stress directory mkdir and rmdir
  */
-static int stress_dir(const args_t *args)
+static int stress_dir(const stress_args_t *args)
 {
 	int ret;
 	uint64_t dir_dirs = DEFAULT_DIR_DIRS;
@@ -132,7 +132,7 @@ static int stress_dir(const args_t *args)
 
 	stress_temp_dir(pathname, sizeof(pathname), args->name, args->pid, args->instance);
 
-	(void)get_setting("dir-dirs", &dir_dirs);
+	(void)stress_get_setting("dir-dirs", &dir_dirs);
 
 	ret = stress_temp_dir_mk_args(args);
 	if (ret < 0)
@@ -179,7 +179,7 @@ abort:
 	return ret;
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_dir_dirs,	stress_set_dir_dirs },
 	{ 0,		NULL }
 };
