@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"dirdeep N",		"start N directory depth stressors" },
 	{ NULL,	"dirdeep-ops N",	"stop after N directory depth bogo operations" },
 	{ NULL,	"dirdeep-dirs N",	"create N directories per level" },
@@ -40,10 +40,10 @@ static int stress_set_dirdeep_dirs(const char *opt)
 {
 	uint32_t dirdeep_dirs;
 
-	dirdeep_dirs = get_uint32(opt);
+	dirdeep_dirs = stress_get_uint32(opt);
 
-	check_range("dirdeep-dirs", dirdeep_dirs, 1, 10);
-	return set_setting("dirdeep-dirs", TYPE_ID_UINT32, &dirdeep_dirs);
+	stress_check_range("dirdeep-dirs", dirdeep_dirs, 1, 10);
+	return stress_set_setting("dirdeep-dirs", TYPE_ID_UINT32, &dirdeep_dirs);
 }
 
 /*
@@ -55,9 +55,9 @@ static int stress_set_dirdeep_inodes(const char *opt)
 	uint64_t inodes = stress_get_filesystem_available_inodes();
 	uint64_t dirdeep_inodes;
 
-	dirdeep_inodes = get_uint64_percent(opt, 1, inodes,
+	dirdeep_inodes = stress_get_uint64_percent(opt, 1, inodes,
 		"Cannot determine number of available free inodes");
-	return set_setting("dirdeep-inodes", TYPE_ID_UINT64, &dirdeep_inodes);
+	return stress_set_setting("dirdeep-inodes", TYPE_ID_UINT64, &dirdeep_inodes);
 }
 
 /*
@@ -92,7 +92,7 @@ static void stress_dirdeep_sync(const char *path)
  *	dirdeep_dir number of subtress per level.
  */
 static void stress_dirdeep_make(
-	const args_t *args,
+	const stress_args_t *args,
 	const char *linkpath,
 	char *const path,
 	const size_t len,
@@ -169,7 +169,7 @@ static void stress_dirdeep_make(
  *	exercise files and directories in the tree
  */
 static void stress_dir_exercise(
-	const args_t *args,
+	const stress_args_t *args,
 	char *const path,
 	const size_t len,
 	const size_t path_len)
@@ -209,7 +209,7 @@ static void stress_dir_exercise(
 			/* This will update atime only */
 			fd = open(path, O_RDONLY);
 			if (fd >= 0) {
-				const uint16_t rnd = mwc16();
+				const uint16_t rnd = stress_mwc16();
 #if defined(HAVE_FUTIMENS)
 				int ret = futimens(fd, timespec);
 				(void)ret;
@@ -243,7 +243,7 @@ static void stress_dir_exercise(
  *	clean up all files and directories in the tree
  */
 static void stress_dir_tidy(
-	const args_t *args,
+	const stress_args_t *args,
 	char *const path,
 	const size_t len,
 	const size_t path_len)
@@ -284,7 +284,7 @@ static void stress_dir_tidy(
  *  stress_dir
  *	stress deep recursive directory mkdir and rmdir
  */
-static int stress_dirdeep(const args_t *args)
+static int stress_dirdeep(const stress_args_t *args)
 {
 	int ret = EXIT_SUCCESS;
 	char path[PATH_MAX + 16];
@@ -297,8 +297,8 @@ static int stress_dirdeep(const args_t *args)
 	uint64_t inodes_target_free;
 	uint64_t min_inodes_free = ~0ULL;
 
-        (void)get_setting("dirdeep-dirs", &dirdeep_dirs);
-        (void)get_setting("dirdeep-inodes", &dirdeep_inodes);
+        (void)stress_get_setting("dirdeep-dirs", &dirdeep_dirs);
+        (void)stress_get_setting("dirdeep-inodes", &dirdeep_inodes);
 
 	inodes_target_free = (inodes_avail > dirdeep_inodes) ?
 		inodes_avail - dirdeep_inodes : 0;
@@ -333,7 +333,7 @@ static int stress_dirdeep(const args_t *args)
 	return ret;
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_dirdeep_dirs,	stress_set_dirdeep_dirs },
 	{ OPT_dirdeep_inodes,	stress_set_dirdeep_inodes },
 	{ 0,			NULL }
