@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"dup N",	"start N workers exercising dup/close" },
 	{ NULL,	"dup-ops N",	"stop after N dup/close bogo operations" },
 	{ NULL,	NULL,		NULL }
@@ -34,7 +34,7 @@ static const help_t help[] = {
  *  stress_dup()
  *	stress system by rapid dup/close calls
  */
-static int stress_dup(const args_t *args)
+static int stress_dup(const stress_args_t *args)
 {
 	static int fds[STRESS_FD_MAX];
 	size_t max_fd = stress_get_file_limit();
@@ -62,7 +62,7 @@ static int stress_dup(const args_t *args)
 			if (fds[n] < 0)
 				break;
 #if defined(HAVE_DUP3)
-			if (do_dup3 && mwc1()) {
+			if (do_dup3 && stress_mwc1()) {
 				int fd;
 
 				fd = shim_dup3(fds[0], fds[n], O_CLOEXEC);
