@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"dynlib N",	"start N workers exercising dlopen/dlclose" },
 	{ NULL,	"dynlib-ops N",	"stop after N dlopen/dlclose bogo operations" },
 	{ NULL,	NULL,		NULL }
@@ -111,7 +111,7 @@ static void MLOCKED_TEXT stress_segvhandler(int signum)
  *  stress_dynlib()
  *	stress that does lots of not a lot
  */
-static int stress_dynlib(const args_t *args)
+static int stress_dynlib(const stress_args_t *args)
 {
 	const size_t n = SIZEOF_ARRAY(libnames);
 	void *handles[n];
@@ -134,9 +134,9 @@ static int stress_dynlib(const args_t *args)
 		for (i = 0; i < n; i++) {
 			int flags;
 
-			flags = mwc1() ? RTLD_LAZY : RTLD_NOW;
+			flags = stress_mwc1() ? RTLD_LAZY : RTLD_NOW;
 #if defined(RTLD_GLOBAL) && defined(RTLD_LOCAL)
-			flags |= mwc1() ? RTLD_GLOBAL : RTLD_LOCAL;
+			flags |= stress_mwc1() ? RTLD_GLOBAL : RTLD_LOCAL;
 #endif
 			handles[i] = dlopen(libnames[i].library, flags);
 			(void)dlerror();
@@ -154,7 +154,7 @@ static int stress_dynlib(const args_t *args)
 				 * will perfom tidy up if not
 				 */
 				if (ptr)
-					uint8_put(*ptr);
+					stress_uint8_put(*ptr);
 			}
 		}
 tidy:
