@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"enosys N",	"start N workers that call non-existent system calls" },
 	{ NULL,	"enosys-ops N",	"stop after N enosys bogo operations" },
 	{ NULL,	NULL,		NULL }
@@ -40,6 +40,14 @@ static const help_t help[] = {
 #define MAX_SYSCALL	(2048)		/* Guess */
 #endif
 
+#if defined(__linux__) &&       \
+    (defined(__x86_64__) || defined(__x86_64)) && \
+    defined(HAVE_CPUID_H) &&    \
+    defined(HAVE_CPUID) &&      \
+    NEED_GNUC(4,6,0)
+#define STRESS_EXERCISE_X86_SYSCALL
+#endif
+
 typedef struct hash_syscall {
 	struct hash_syscall *next;
 	long	number;
@@ -47,14 +55,67 @@ typedef struct hash_syscall {
 
 static stress_hash_syscall_t *hash_syscall_table[HASH_SYSCALL_SIZE];
 
-PRAGMA_PUSH
-PRAGMA_WARN_OFF
+#if defined(STRESS_EXERCISE_X86_SYSCALL)
+static bool stress_x86syscall_available;
+
+static bool stress_check_x86syscall(void)
+{
+	uint32_t eax, ebx, ecx, edx;
+
+	/* Intel CPU? */
+	if (!stress_cpu_is_x86())
+		return false;
+	/* ..and supports syscall? */
+	__cpuid(0x80000001, eax, ebx, ecx, edx);
+	if (!(edx & (1ULL << 11)))
+		return false;
+        return true;
+}
+
+/*
+ *  x86_64_syscall6()
+ *      syscall 6 arg wrapper
+ */
+static inline long x86_64_syscall6(long number, long arg1, long arg2,
+				   long arg3, long arg4, long arg5,
+				   long arg6)
+{
+	long ret;
+	unsigned long _arg1 = arg1;
+	unsigned long _arg2 = arg2;
+	unsigned long _arg3 = arg3;
+	unsigned long _arg4 = arg4;
+	unsigned long _arg5 = arg5;
+	unsigned long _arg6 = arg6;
+
+	register long __arg1 asm ("rdi") = _arg1;
+	register long __arg2 asm ("rsi") = _arg2;
+	register long __arg3 asm ("rdx") = _arg3;
+	register long __arg4 asm ("r10") = _arg4;
+	register long __arg5 asm ("r8") = _arg5;
+	register long __arg6 asm ("r9") = _arg6;
+
+	asm volatile ("syscall\n\t"
+                        : "=a" (ret)
+                        : "0" (number), "r" (__arg1), "r" (__arg2), "r" (__arg3),
+			  "r" (__arg4), "r" (__arg5), "r" (__arg6)
+                        : "memory", "cc", "r11", "cx");
+        if (ret < 0) {
+                errno = ret;
+                ret = -1;
+        }
+        return ret;
+}
+#endif
+
+STRESS_PRAGMA_PUSH
+STRESS_PRAGMA_WARN_OFF
 static inline long syscall7(long number, long arg1, long arg2,
 			    long arg3, long arg4, long arg5,
 			    long arg6, long arg7)
 {
 	int ret;
-	pid_t pid = getpid();
+	const pid_t pid = getpid();
 
 	ret = syscall(number, arg1, arg2, arg3, arg4, arg5, arg6, arg7);
 
@@ -64,7 +125,35 @@ static inline long syscall7(long number, long arg1, long arg2,
 	}
 	return ret;
 }
-PRAGMA_POP
+STRESS_PRAGMA_POP
+
+static void exercise_syscall(
+	const stress_args_t *args,
+	long number, long arg1, long arg2,
+	long arg3, long arg4, long arg5,
+	long arg6, long arg7)
+{
+	int ret;
+	bool enosys = false;
+
+	if (!keep_stressing())
+		_exit(EXIT_SUCCESS);
+
+	ret = syscall7(number, arg1, arg2, arg3, arg4, arg5, arg6, arg7);
+	if ((ret < 0) && (errno != ENOSYS))
+		enosys = true;
+
+#if defined(STRESS_EXERCISE_X86_SYSCALL)
+	if (stress_x86syscall_available) {
+		ret = x86_64_syscall6(number, arg1, arg2, arg3, arg4, arg5, arg6);
+		if ((ret < 0) && (errno != ENOSYS))
+			enosys = true;
+	}
+#endif
+
+	if (enosys)
+		_exit(errno);
+}
 
 static const int syscall_ignore[] = {
 #if defined(SYS_reboot)
@@ -1020,8 +1109,8 @@ static const long skip_syscalls[] = {
 #if defined(SYS_sched_getscheduler)
 	SYS_sched_getscheduler,
 #endif
-#if defined(SYS_sched_rr_get_interval)
-	SYS_sched_rr_get_interval,
+#if defined(SYS_sched_rr_stress_get_interval)
+	SYS_sched_rr_stress_get_interval,
 #endif
 #if defined(SYS_sched_setaffinity)
 	SYS_sched_setaffinity,
@@ -2495,8 +2584,8 @@ static const long skip_syscalls[] = {
 #if defined(__NR_sched_getscheduler)
 	__NR_sched_getscheduler,
 #endif
-#if defined(__NR_sched_rr_get_interval)
-	__NR_sched_rr_get_interval,
+#if defined(__NR_sched_rr_stress_get_interval)
+	__NR_sched_rr_stress_get_interval,
 #endif
 #if defined(__NR_sched_setaffinity)
 	__NR_sched_setaffinity,
@@ -3042,7 +3131,7 @@ static void MLOCKED_TEXT stress_badhandler(int signum)
  *  Call a system call in a child context so we don't clobber
  *  the parent
  */
-static inline int stress_do_syscall(const args_t *args, const long number)
+static inline int stress_do_syscall(const stress_args_t *args, const long number)
 {
 	pid_t pid;
 	int rc = 0;
@@ -3057,7 +3146,6 @@ static inline int stress_do_syscall(const args_t *args, const long number)
 		_exit(EXIT_NO_RESOURCE);
 	} else if (pid == 0) {
 		struct itimerval it;
-		int ret;
 		size_t i;
 		unsigned long arg;
 		char buffer[1024];
@@ -3095,50 +3183,30 @@ static inline int stress_do_syscall(const args_t *args, const long number)
 		/*
 		 *  Try various ENOSYS calls
 		 */
-		if (!keep_stressing())
-			_exit(EXIT_SUCCESS);
-		ret = syscall7(number, -1, -1, -1, -1, -1, -1, -1);
-		if ((ret < 0) && (errno != ENOSYS))
-			_exit(errno);
-
-		if (!keep_stressing())
-			_exit(EXIT_SUCCESS);
-		ret = syscall7(number, 0, 0, 0, 0, 0, 0, 0);
-		if ((ret < 0) && (errno != ENOSYS))
-			_exit(errno);
-
-		if (!keep_stressing())
-			_exit(EXIT_SUCCESS);
-		ret = syscall7(number, 1, 1, 1, 1, 1, 1, 1);
-		if ((ret < 0) && (errno != ENOSYS))
-			_exit(errno);
+		exercise_syscall(args, number, -1, -1, -1, -1, -1, -1, -1);
+		exercise_syscall(args, number, 0, 0, 0, 0, 0, 0, 0);
+		exercise_syscall(args, number, 1, 1, 1, 1, 1, 1, 1);
 
 		for (arg = 2; arg;) {
-			if (!keep_stressing())
-				_exit(EXIT_SUCCESS);
-			ret = syscall7(number, arg, arg, arg,
+			exercise_syscall(args, number, arg, arg, arg,
 				      arg, arg, arg, arg);
-			if ((ret < 0) && (errno != ENOSYS))
-				_exit(errno);
 			arg <<= 1;
-			ret = syscall7(number, arg - 1, arg - 1, arg - 1,
+			exercise_syscall(args, number, arg - 1, arg - 1, arg - 1,
 				      arg - 1, arg - 1, arg - 1, arg - 1);
-			if ((ret < 0) && (errno != ENOSYS))
-				_exit(errno);
 		}
 
-		if (!keep_stressing())
-			_exit(EXIT_SUCCESS);
-		ret = syscall7(number, mwc64(), mwc64(), mwc64(),
-			      mwc64(), mwc64(), mwc64(), mwc64());
-		if ((ret < 0) && (errno != ENOSYS))
-			_exit(errno);
+		exercise_syscall(args, number,
+			stress_mwc64(), stress_mwc64(),
+			stress_mwc64(), stress_mwc64(),
+			stress_mwc64(), stress_mwc64(),
+			stress_mwc64());
 
-		ret = syscall7(number, (long)buffer, (long)buffer,
-			       (long)buffer, (long)buffer,
-			       (long)buffer, (long)buffer,
-			       (long)buffer);
-		_exit(ret < 0 ? errno : 0);
+		exercise_syscall(args, number,
+			(long)buffer, (long)buffer,
+			(long)buffer, (long)buffer,
+			(long)buffer, (long)buffer,
+			(long)buffer);
+		_exit(0);
 	} else {
 		int ret, status;
 
@@ -3165,10 +3233,14 @@ static inline int stress_do_syscall(const args_t *args, const long number)
  *  stress_enosys
  *	stress system calls
  */
-static int stress_enosys(const args_t *args)
+static int stress_enosys(const stress_args_t *args)
 {
 	pid_t pid;
 
+#if defined(STRESS_EXERCISE_X86_SYSCALL)
+	stress_x86syscall_available = stress_check_x86syscall();
+#endif
+
 again:
 	if (!keep_stressing())
 		return EXIT_SUCCESS;
@@ -3198,14 +3270,14 @@ again:
 			/* If we got killed by OOM killer, re-start */
 			if (WTERMSIG(status) == SIGKILL) {
 				if (g_opt_flags & OPT_FLAGS_OOMABLE) {
-					log_system_mem_info();
+					stress_log_system_mem_info();
 					pr_dbg("%s: assuming killed by OOM "
 						"killer, bailing out "
 						"(instance %d)\n",
 						args->name, args->instance);
 					_exit(0);
 				} else {
-					log_system_mem_info();
+					stress_log_system_mem_info();
 					pr_dbg("%s: assuming killed by OOM "
 						"killer, restarting again "
 						"(instance %d)\n",
@@ -3247,16 +3319,16 @@ again:
 			for (j = 0; j < 1024; j++) {
 				if (!keep_stressing())
 					goto finish;
-				stress_do_syscall(args, mwc8() & mask);
+				stress_do_syscall(args, stress_mwc8() & mask);
 				if (!keep_stressing())
 					goto finish;
-				stress_do_syscall(args, mwc16() & mask);
+				stress_do_syscall(args, stress_mwc16() & mask);
 				if (!keep_stressing())
 					goto finish;
-				stress_do_syscall(args, mwc32() & mask);
+				stress_do_syscall(args, stress_mwc32() & mask);
 				if (!keep_stressing())
 					goto finish;
-				stress_do_syscall(args, mwc64() & mask);
+				stress_do_syscall(args, stress_mwc64() & mask);
 			}
 
 			/* Various bit masks */
