@@ -24,13 +24,13 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"env N",	"start N workers setting enironment vars" },
 	{ NULL,	"env-ops N",	"stop after N env bogo operations" },
 	{ NULL,	NULL,		NULL }
 };
 
-static int stress_env_child(const args_t *args, void *context)
+static int stress_env_child(const stress_args_t *args, void *context)
 {
 	const size_t page_size = args->page_size;
 	uint64_t i = 0;
@@ -79,7 +79,7 @@ static int stress_env_child(const args_t *args, void *context)
 		char name[64];
 		char tmp;
 		int ret;
-		const size_t sz = 1 + (mwc32() % (arg_max - 2));
+		const size_t sz = 1 + (stress_mwc32() % (arg_max - 2));
 
 		snprintf(name, sizeof(name), "STRESS_ENV_%" PRIx64, i);
 		/*
@@ -119,7 +119,7 @@ reap:
  *  stress_env()
  *	stress environment variables
  */
-static int stress_env(const args_t *args)
+static int stress_env(const stress_args_t *args)
 {
 	return stress_oomable_child(args, NULL, stress_env_child, STRESS_OOMABLE_DROP_CAP);
 }
