@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"epoll N",	  "start N workers doing epoll handled socket activity" },
 	{ NULL,	"epoll-ops N",	  "stop after N epoll bogo operations" },
 	{ NULL,	"epoll-port P",	  "use socket ports P upwards" },
@@ -43,7 +43,7 @@ static const help_t help[] = {
     NEED_GLIBC(2,3,2)
 
 typedef void (stress_epoll_func_t)(
-	const args_t *args,
+	const stress_args_t *args,
 	const int child,
 	const pid_t ppid,
 	const int epoll_port,
@@ -67,7 +67,7 @@ static int stress_set_epoll_port(const char *opt)
 		MIN_EPOLL_PORT,
 		MAX_EPOLL_PORT - (STRESS_PROCS_MAX * MAX_SERVERS),
 		&epoll_port);
-	return set_setting("epoll-port", TYPE_ID_INT, &epoll_port);
+	return stress_set_setting("epoll-port", TYPE_ID_INT, &epoll_port);
 }
 
 /*
@@ -80,7 +80,7 @@ static int stress_set_epoll_domain(const char *name)
 
 	ret = stress_set_net_domain(DOMAIN_ALL, "epoll-domain",
 		name, &epoll_domain);
-	set_setting("epoll-domain", TYPE_ID_INT, &epoll_domain);
+	stress_set_setting("epoll-domain", TYPE_ID_INT, &epoll_domain);
 
 	switch (epoll_domain) {
 	case AF_INET:
@@ -95,7 +95,7 @@ static int stress_set_epoll_domain(const char *name)
 	return ret;
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_epoll_domain,	stress_set_epoll_domain },
 	{ OPT_epoll_port,	stress_set_epoll_port },
 	{ 0,			NULL }
@@ -134,7 +134,7 @@ static void MLOCKED_TEXT epoll_timer_handler(int sig)
  *	spawn a process
  */
 static pid_t epoll_spawn(
-	const args_t *args,
+	const stress_args_t *args,
 	stress_epoll_func_t func,
 	const int child,
 	const pid_t ppid,
@@ -221,7 +221,7 @@ static int epoll_ctl_add(const int efd, const int fd)
  *	fd's to epoll event list
  */
 static int epoll_notification(
-	const args_t *args,
+	const stress_args_t *args,
 	const int efd,
 	const int sfd)
 {
@@ -268,7 +268,7 @@ static int epoll_notification(
  *	send a relatively short message
  */
 static int epoll_client(
-	const args_t *args,
+	const stress_args_t *args,
 	const pid_t ppid,
 	const int epoll_port,
 	const int epoll_domain)
@@ -397,7 +397,7 @@ retry:
  *	wait on connections and read data
  */
 static void epoll_server(
-	const args_t *args,
+	const stress_args_t *args,
 	const int child,
 	const pid_t ppid,
 	const int epoll_port,
@@ -451,7 +451,7 @@ static void epoll_server(
 	 *  or the other to get more test coverage
 	 */
 #if defined(HAVE_EPOLL_CREATE1)
-	if (mwc1()) {
+	if (stress_mwc1()) {
 		efd = epoll_create1(0);	/* flag version */
 		if (efd < 0) {
 			pr_fail_err("epoll_create1");
@@ -501,7 +501,7 @@ static void epoll_server(
 		 * to break out if keep_stressing_flag has been changed.
 		 * Note: epoll_wait maps to epoll_pwait in glibc, ho hum.
 		 */
-		if (mwc1()) {
+		if (stress_mwc1()) {
 			n = epoll_wait(efd, events, MAX_EPOLL_EVENTS, 100);
 		} else {
 			n = epoll_pwait(efd, events, MAX_EPOLL_EVENTS, 100, &sigmask);
@@ -561,15 +561,15 @@ die:
  *  stress_epoll
  *	stress by heavy socket I/O
  */
-static int stress_epoll(const args_t *args)
+static int stress_epoll(const stress_args_t *args)
 {
 	pid_t pids[MAX_SERVERS], ppid = getppid();
 	int i, rc = EXIT_SUCCESS;
 	int epoll_port = DEFAULT_EPOLL_PORT;
 	int epoll_domain = AF_UNIX;
 
-	(void)get_setting("epoll-port", &epoll_port);
-	(void)get_setting("epoll-domain", &epoll_domain);
+	(void)stress_get_setting("epoll-port", &epoll_port);
+	(void)stress_get_setting("epoll-domain", &epoll_domain);
 
 	if (max_servers == 1) {
 		pr_dbg("%s: process [%d] using socket port %d\n",
