@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"eventfd N",	 "start N workers stressing eventfd read/writes" },
 	{ NULL,	"eventfd-ops N", "stop eventfd workers after N bogo operations" },
 	{ NULL, "eventfs-nonblock", "poll with non-blocking I/O on eventfd fd" },
@@ -36,10 +36,10 @@ static int stress_set_eventfd_nonblock(const char *opt)
 	bool eventfd_nonblock = true;
 
 	(void)opt;
-	return set_setting("eventfd-nonblock", TYPE_ID_BOOL, &eventfd_nonblock);
+	return stress_set_setting("eventfd-nonblock", TYPE_ID_BOOL, &eventfd_nonblock);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_eventfd_nonblock,	stress_set_eventfd_nonblock },
         { 0,			NULL }
 };
@@ -52,14 +52,14 @@ static const opt_set_func_t opt_set_funcs[] = {
  *  stress_eventfd
  *	stress eventfd read/writes
  */
-static int stress_eventfd(const args_t *args)
+static int stress_eventfd(const stress_args_t *args)
 {
 	pid_t pid;
 	int fd1, fd2, rc;
 	int flags = 0;
 	bool eventfd_nonblock = false;
 
-	(void)get_setting("eventfd-nonblock", &eventfd_nonblock);
+	(void)stress_get_setting("eventfd-nonblock", &eventfd_nonblock);
 
 #if defined(EFD_CLOEXEC)
 	flags |= EFD_CLOEXEC;
@@ -150,7 +150,24 @@ exit_child:
 
 		do {
 			uint64_t val = 1;
-			int ret;
+			int ret, procfd;
+			char path[PATH_MAX];
+
+			(void)snprintf(path, sizeof(path), "/proc/self/fdinfo/%d",
+				stress_mwc1() ? fd1 : fd2);
+			/*
+			 *  Accessing /proc/self/fdinfo/[fd1|fd2] will exercise
+			 *  eventfd-count and eventfd-id proc interfaces.
+			 */
+			procfd = open(path, O_RDONLY);
+			if (procfd >= 0) {
+				char buffer[4096];
+				ssize_t n;
+
+				n = read(procfd, buffer, sizeof(buffer));
+				(void)n;
+				(void)close(procfd);
+			}
 
 			for (;;) {
 				if (!keep_stressing_flag())
