@@ -28,7 +28,7 @@
  *   exec* family of args to pass
  */
 typedef struct {
-	const args_t *args;
+	const stress_args_t *args;
 	const char *path;
 	char **argv_new;
 	char **env_new;
@@ -38,7 +38,7 @@ typedef struct {
 	int which;
 } stress_exec_args_t;
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"exec N",	"start N workers spinning on fork() and exec()" },
 	{ NULL,	"exec-ops N",	"stop after N exec bogo operations" },
 	{ NULL,	"exec-max P",	"create P workers per iteration, default is 1" },
@@ -53,13 +53,13 @@ static int stress_set_exec_max(const char *opt)
 {
 	uint64_t exec_max;
 
-	exec_max = get_uint64(opt);
-	check_range("exec-max", exec_max,
+	exec_max = stress_get_uint64(opt);
+	stress_check_range("exec-max", exec_max,
 		MIN_EXECS, MAX_EXECS);
-	return set_setting("exec-max", TYPE_ID_INT64, &exec_max);
+	return stress_set_setting("exec-max", TYPE_ID_INT64, &exec_max);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_exec_max,	stress_set_exec_max },
 	{ 0,		NULL }
 };
@@ -167,7 +167,7 @@ static inline int stress_do_exec(stress_exec_args_t *ea)
 	int ret_dummy = EINVAL;
 	pthread_t pthread_exec, pthread_dummy;
 
-	if ((mwc8() & 3) == 0) {
+	if ((stress_mwc8() & 3) == 0) {
 		ret_dummy = pthread_create(&pthread_dummy, NULL, stress_exec_dummy_pthread, (void *)ea);
 
 		ret = pthread_create(&pthread_exec, NULL, stress_exec_from_pthread, (void*)ea);
@@ -206,7 +206,7 @@ static inline int stress_do_exec(stress_exec_args_t *ea)
  *  stress_exec()
  *	stress by forking and exec'ing
  */
-static int stress_exec(const args_t *args)
+static int stress_exec(const stress_args_t *args)
 {
 	static pid_t pids[MAX_FORKS];
 	char path[PATH_MAX + 1];
@@ -221,7 +221,7 @@ static int stress_exec(const args_t *args)
 	char *argv_new[] = { NULL, "--exec-exit", NULL };
 	char *env_new[] = { NULL };
 
-	(void)get_setting("exec-max", &exec_max);
+	(void)stress_get_setting("exec-max", &exec_max);
 
 	/*
 	 *  Determine our own self as the executable, e.g. run stress-ng
@@ -239,7 +239,7 @@ static int stress_exec(const args_t *args)
 	if (ret < 0)
 		return exit_status(-ret);
 	(void)stress_temp_filename_args(args,
-		filename, sizeof(filename), mwc32());
+		filename, sizeof(filename), stress_mwc32());
 
 #if defined(HAVE_EXECVEAT)
 	fdexec = open(path, O_PATH);
@@ -256,14 +256,14 @@ static int stress_exec(const args_t *args)
 		(void)memset(pids, 0, sizeof(pids));
 
 		for (i = 0; i < exec_max; i++) {
-			(void)mwc8();		/* force new random number */
+			(void)stress_mwc8();		/* force new random number */
 
 			pids[i] = fork();
 
 			if (pids[i] == 0) {
 				int fd_out, fd_in, fd = -1;
-				const int which = mwc8() % 3;
-				int exec_garbage = mwc1();
+				const int which = stress_mwc8() % 3;
+				int exec_garbage = stress_mwc1();
 				stress_exec_args_t exec_args;
 
 				(void)setpgid(0, g_pgrp);
@@ -302,7 +302,7 @@ static int stress_exec(const args_t *args)
 					}
 
 					stress_strnrnd(buffer, sizeof(buffer));
-					if (mwc1()) {
+					if (stress_mwc1()) {
 						buffer[0] = '#';
 						buffer[1] = '!';
 					}
