@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"fallocate N",		"start N workers fallocating 16MB files" },
 	{ NULL,	"fallocate-ops N",	"stop after N fallocate bogo operations" },
 	{ NULL,	"fallocate-bytes N",	"specify size of file to allocate" },
@@ -35,13 +35,13 @@ static int stress_set_fallocate_bytes(const char *opt)
 {
 	off_t fallocate_bytes;
 
-	fallocate_bytes = (off_t)get_uint64_byte_filesystem(opt, 1);
-	check_range_bytes("fallocate-bytes", fallocate_bytes,
+	fallocate_bytes = (off_t)stress_get_uint64_byte_filesystem(opt, 1);
+	stress_check_range_bytes("fallocate-bytes", fallocate_bytes,
 		MIN_FALLOCATE_BYTES, MAX_FALLOCATE_BYTES);
-	return set_setting("fallocate-bytes", TYPE_ID_OFF_T, &fallocate_bytes);
+	return stress_set_setting("fallocate-bytes", TYPE_ID_OFF_T, &fallocate_bytes);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_fallocate_bytes,	stress_set_fallocate_bytes },
 	{ 0,			NULL }
 };
@@ -71,14 +71,14 @@ static const int modes[] = {
  *  stress_fallocate
  *	stress I/O via fallocate and ftruncate
  */
-static int stress_fallocate(const args_t *args)
+static int stress_fallocate(const stress_args_t *args)
 {
 	int fd, ret;
 	char filename[PATH_MAX];
 	uint64_t ftrunc_errs = 0;
 	off_t fallocate_bytes = DEFAULT_FALLOCATE_BYTES;
 
-	if (!get_setting("fallocate-bytes", &fallocate_bytes)) {
+	if (!stress_get_setting("fallocate-bytes", &fallocate_bytes)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			fallocate_bytes = MAXIMIZED_FILE_SIZE;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -93,7 +93,7 @@ static int stress_fallocate(const args_t *args)
 		return exit_status(-ret);
 
 	(void)stress_temp_filename_args(args,
-		filename, sizeof(filename), mwc32());
+		filename, sizeof(filename), stress_mwc32());
 	if ((fd = open(filename, O_CREAT | O_RDWR, S_IRUSR | S_IWUSR)) < 0) {
 		ret = exit_status(errno);
 		pr_fail_err("open");
@@ -160,8 +160,8 @@ static int stress_fallocate(const args_t *args)
 			(void)shim_fsync(fd);
 
 			for (i = 0; i < 64; i++) {
-				off_t offset = (mwc64() % fallocate_bytes) & ~0xfff;
-				int j = (mwc32() >> 8) % SIZEOF_ARRAY(modes);
+				off_t offset = (stress_mwc64() % fallocate_bytes) & ~0xfff;
+				int j = (stress_mwc32() >> 8) % SIZEOF_ARRAY(modes);
 
 				(void)shim_fallocate(fd, modes[j], offset, 64 * KB);
 				if (!keep_stressing_flag())
