@@ -27,7 +27,7 @@
 static sigjmp_buf jmp_env;
 static volatile bool do_jmp = true;
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"fault N",	"start N workers producing page faults" },
 	{ NULL,	"fault-ops N",	"stop after N page fault bogo operations" },
 	{ NULL,	NULL,		NULL }
@@ -49,7 +49,7 @@ static void MLOCKED_TEXT stress_segvhandler(int signum)
  *  stress_fault()
  *	stress min and max page faulting
  */
-static int stress_fault(const args_t *args)
+static int stress_fault(const stress_args_t *args)
 {
 #if !defined(__HAIKU__)
 	struct rusage usage;
@@ -67,7 +67,7 @@ static int stress_fault(const args_t *args)
 		return exit_status(-ret);
 
 	(void)stress_temp_filename_args(args,
-		filename, sizeof(filename), mwc32());
+		filename, sizeof(filename), stress_mwc32());
 	i = 0;
 
 	if (stress_sighandler(args->name, SIGSEGV, stress_segvhandler, NULL) < 0)
@@ -181,7 +181,7 @@ next:
 				ptr = (uint8_t *)mmap(mapto, page_size, PROT_READ,
 					MAP_ANONYMOUS | MAP_SHARED, -1, 0);
 				if (ptr != MAP_FAILED) {
-					uint8_put(*ptr);
+					stress_uint8_put(*ptr);
 					(void)munmap((void *)ptr, page_size);
 				}
 			}
