@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"fcntl N",	"start N workers exercising fcntl commands" },
 	{ NULL,	"fcntl-ops N",	"stop after N fcntl bogo operations" },
 	{ NULL,	NULL,		NULL }
@@ -56,7 +56,7 @@ static const help_t help[] = {
  *  check_return()
  *	sanity check fcntl() return for errors
  */
-static void check_return(const args_t *args, const int ret, const char *cmd)
+static void check_return(const stress_args_t *args, const int ret, const char *cmd)
 {
 	if (ret < 0) {
 		if ((errno != EINVAL) &&
@@ -75,7 +75,7 @@ static void check_return(const args_t *args, const int ret, const char *cmd)
 /*
  *  do_fcntl()
  */
-static int do_fcntl(const args_t *args, const int fd)
+static int do_fcntl(const stress_args_t *args, const int fd)
 {
 #if defined(F_DUPFD)
 	{
@@ -274,8 +274,9 @@ static int do_fcntl(const args_t *args, const int fd)
 #if defined(F_GETOWNER_UIDS)
 	{
 		int ret;
+		uid_t uids[2];
 
-		ret = fcntl(fd, F_GETOWNER_UIDS);
+		ret = fcntl(fd, F_GETOWNER_UIDS, uids);
 		check_return(args, ret, "F_GETOWNER_UIDS");
 	}
 #endif
@@ -299,8 +300,8 @@ static int do_fcntl(const args_t *args, const int fd)
 #endif
 		int ret;
 		off_t lret;
-		const off_t len = (mwc16() + 1) & 0x7fff;
-		const off_t start = mwc16() & 0x7fff;
+		const off_t len = (stress_mwc16() + 1) & 0x7fff;
+		const off_t start = stress_mwc16() & 0x7fff;
 
 		if (ftruncate(fd, 65536) < 0) {
 			pr_fail_err("ftruncate");
@@ -435,8 +436,8 @@ lock_abort:	{ /* Nowt */ }
 		struct flock f;
 #endif
 		int ret;
-		const off_t len = (mwc16() + 1) & 0x7fff;
-		const off_t start = mwc16() & 0x7fff;
+		const off_t len = (stress_mwc16() + 1) & 0x7fff;
+		const off_t start = stress_mwc16() & 0x7fff;
 
 		if (ftruncate(fd, 65536) < 0) {
 			pr_fail_err("ftruncate");
@@ -559,7 +560,7 @@ ofd_lock_abort:	{ /* Nowt */ }
  *  stress_fcntl
  *	stress various fcntl calls
  */
-static int stress_fcntl(const args_t *args)
+static int stress_fcntl(const stress_args_t *args)
 {
 	const pid_t ppid = getppid();
 	int fd, rc = EXIT_FAILURE, retries = 0;
