@@ -26,7 +26,7 @@
 
 #define MAX_FIEMAP_PROCS	(4)		/* Number of FIEMAP stressors */
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"fiemap N",	  "start N workers exercising the FIEMAP ioctl" },
 	{ NULL,	"fiemap-ops N",	  "stop after N FIEMAP ioctl bogo operations" },
 	{ NULL,	"fiemap-bytes N", "specify size of file to fiemap" },
@@ -37,13 +37,13 @@ static int stress_set_fiemap_bytes(const char *opt)
 {
 	uint64_t fiemap_bytes;
 
-	fiemap_bytes = get_uint64_byte_filesystem(opt, 1);
-	check_range_bytes("fiemap-bytes", fiemap_bytes,
+	fiemap_bytes = stress_get_uint64_byte_filesystem(opt, 1);
+	stress_check_range_bytes("fiemap-bytes", fiemap_bytes,
 		MIN_FIEMAP_SIZE, MAX_FIEMAP_SIZE);
-	return set_setting("fiemap-bytes", TYPE_ID_UINT64, &fiemap_bytes);
+	return stress_set_setting("fiemap-bytes", TYPE_ID_UINT64, &fiemap_bytes);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_fiemap_bytes,	stress_set_fiemap_bytes },
 	{ 0,			NULL }
 };
@@ -59,7 +59,7 @@ static const opt_set_func_t opt_set_funcs[] = {
  *	extents in the file
  */
 static int stress_fiemap_writer(
-	const args_t *args,
+	const stress_args_t *args,
 	const int fd,
 	const uint64_t fiemap_bytes,
 	uint64_t *counters)
@@ -80,7 +80,7 @@ static int stress_fiemap_writer(
 		size_t i;
 		counter = 0;
 
-		offset = (mwc64() % len) & ~0x1fff;
+		offset = (stress_mwc64() % len) & ~0x1fff;
 		if (lseek(fd, (off_t)offset, SEEK_SET) < 0)
 			break;
 		if (!keep_stressing())
@@ -98,7 +98,7 @@ static int stress_fiemap_writer(
 		if (!punch_hole)
 			continue;
 
-		offset = mwc64() % len;
+		offset = stress_mwc64() % len;
 		if (shim_fallocate(fd, FALLOC_FL_PUNCH_HOLE |
 				  FALLOC_FL_KEEP_SIZE, offset, 8192) < 0) {
 			if (errno == EOPNOTSUPP)
@@ -121,7 +121,7 @@ tidy:
  *  stress_fiemap_ioctl()
  *	exercise the FIEMAP ioctl
  */
-static void stress_fiemap_ioctl(const args_t *args, int fd)
+static void stress_fiemap_ioctl(const stress_args_t *args, int fd)
 {
 	uint32_t c = 0;
 	do {
@@ -195,7 +195,7 @@ static void stress_fiemap_ioctl(const args_t *args, int fd)
  *	helper to spawn off fiemap stressor
  */
 static inline pid_t stress_fiemap_spawn(
-	const args_t *args,
+	const stress_args_t *args,
 	const int fd)
 {
 	pid_t pid;
@@ -217,7 +217,7 @@ static inline pid_t stress_fiemap_spawn(
  *  stress_fiemap
  *	stress fiemap IOCTL
  */
-static int stress_fiemap(const args_t *args)
+static int stress_fiemap(const stress_args_t *args)
 {
 	pid_t pids[MAX_FIEMAP_PROCS];
 	int ret, fd, rc = EXIT_FAILURE, status;
@@ -230,7 +230,7 @@ static int stress_fiemap(const args_t *args)
 	uint64_t fiemap_bytes = DEFAULT_FIEMAP_SIZE;
 	struct fiemap fiemap;
 
-	if (!get_setting("fiemap-bytes", &fiemap_bytes)) {
+	if (!stress_get_setting("fiemap-bytes", &fiemap_bytes)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			fiemap_bytes = MAXIMIZED_FILE_SIZE;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -257,7 +257,7 @@ static int stress_fiemap(const args_t *args)
 	}
 
 	(void)stress_temp_filename_args(args,
-		filename, sizeof(filename), mwc32());
+		filename, sizeof(filename), stress_mwc32());
 	if ((fd = open(filename, O_CREAT | O_RDWR, S_IRUSR | S_IWUSR)) < 0) {
 		rc = exit_status(errno);
 		pr_fail_err("open");
@@ -281,7 +281,7 @@ static int stress_fiemap(const args_t *args)
 		uint64_t proc_max_ops = ops_per_proc +
 			((n == 0) ? ops_remaining : 0);
 
-		const args_t new_args = {
+		const stress_args_t new_args = {
 			.counter = &counters[n],
 			.name = args->name,
 			.max_ops = proc_max_ops,
