@@ -28,7 +28,7 @@
 static const uint64_t wrap_mask = 0xffff000000000000ULL;
 #endif
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"fifo N",	  "start N workers exercising fifo I/O" },
 	{ NULL,	"fifo-ops N",	  "stop after N fifo bogo operations" },
 	{ NULL,	"fifo-readers N", "number of fifo reader stessors to start" },
@@ -39,13 +39,13 @@ static int stress_set_fifo_readers(const char *opt)
 {
 	uint64_t fifo_readers;
 
-	fifo_readers = get_uint64(opt);
-	check_range("fifo-readers", fifo_readers,
+	fifo_readers = stress_get_uint64(opt);
+	stress_check_range("fifo-readers", fifo_readers,
 		MIN_FIFO_READERS, MAX_FIFO_READERS);
-	return set_setting("fifo-readers", TYPE_ID_UINT64, &fifo_readers);
+	return stress_set_setting("fifo-readers", TYPE_ID_UINT64, &fifo_readers);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_fifo_readers,	stress_set_fifo_readers },
 	{ 0,			NULL }
 };
@@ -56,8 +56,8 @@ static const opt_set_func_t opt_set_funcs[] = {
  *	spawn a process
  */
 static pid_t fifo_spawn(
-	const args_t *args,
-	void (*func)(const args_t *args, const char *name, const char *fifoname),
+	const stress_args_t *args,
+	void (*func)(const stress_args_t *args, const char *name, const char *fifoname),
 	const char *name,
 	const char *fifoname)
 {
@@ -82,7 +82,7 @@ static pid_t fifo_spawn(
  *	read fifo
  */
 static void stress_fifo_reader(
-	const args_t *args,
+	const stress_args_t *args,
 	const char *name,
 	const char *fifoname)
 {
@@ -155,7 +155,7 @@ redo:
  *  stress_fifo
  *	stress by heavy fifo I/O
  */
-static int stress_fifo(const args_t *args)
+static int stress_fifo(const stress_args_t *args)
 {
 	pid_t pids[MAX_FIFO_READERS];
 	int fd;
@@ -164,7 +164,7 @@ static int stress_fifo(const args_t *args)
 	uint64_t fifo_readers = DEFAULT_FIFO_READERS;
 	int rc;
 
-	if (!get_setting("fifo-readers", &fifo_readers)) {
+	if (!stress_get_setting("fifo-readers", &fifo_readers)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			fifo_readers = MAX_FIFO_READERS;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -176,7 +176,7 @@ static int stress_fifo(const args_t *args)
 		return exit_status(-rc);
 
 	(void)stress_temp_filename_args(args,
-		fifoname, sizeof(fifoname), mwc32());
+		fifoname, sizeof(fifoname), stress_mwc32());
 
 	if (mkfifo(fifoname, S_IRUSR | S_IWUSR) < 0) {
 		rc = exit_status(errno);
