@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"file-ioctl N",		"start N workers exercising file specific ioctls" },
 	{ NULL,	"file-ioctl-ops N",	"stop after N file ioctl bogo operations" },
 	{ NULL,	NULL,			NULL }
@@ -33,7 +33,7 @@ static const help_t help[] = {
 #if (defined(FIONBIO) && defined(O_NONBLOCK)) || \
     (defined(FIOASYNC) && defined(O_ASYNC))
 static void check_flag(
-	const args_t *args,
+	const stress_args_t *args,
 	const char *ioctl_name,
 	const int fd,
 	const int flag,
@@ -70,7 +70,7 @@ static void check_flag(
  *  stress_file_ioctl
  *	stress file ioctls
  */
-static int stress_file_ioctl(const args_t *args)
+static int stress_file_ioctl(const stress_args_t *args)
 {
 	char filename[PATH_MAX];
 	int ret, fd;
@@ -78,7 +78,7 @@ static int stress_file_ioctl(const args_t *args)
 	int dfd;
 #endif
 	const off_t file_sz = 8192;
-	uint32_t rnd = mwc32();
+	uint32_t rnd = stress_mwc32();
 
 	ret = stress_temp_dir_mk_args(args);
 	if (ret < 0)
