@@ -40,7 +40,7 @@ static const stress_filename_opts_t filename_opts[] = {
 	{ -1,				NULL }
 };
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"filename N",		"start N workers exercising filenames" },
 	{ NULL,	"filename-ops N",	"stop after N filename bogo operations" },
 	{ NULL,	"filename-opts opt",	"specify allowed filename options" },
@@ -66,7 +66,7 @@ static int stress_set_filename_opts(const char *opt)
 	for (i = 0; filename_opts[i].opt_text; i++) {
 		if (!strcmp(opt, filename_opts[i].opt_text)) {
 			uint8_t filename_opt = filename_opts[i].opt;
-			set_setting("filename-opts", TYPE_ID_UINT8, &filename_opt);
+			stress_set_setting("filename-opts", TYPE_ID_UINT8, &filename_opt);
 			return 0;
 		}
 	}
@@ -83,7 +83,7 @@ static int stress_set_filename_opts(const char *opt)
  *	determine allowed filename chars by probing
  */
 static int stress_filename_probe(
-	const args_t *args,
+	const stress_args_t *args,
 	char *filename,
 	char *ptr,
 	size_t *chars_allowed)
@@ -218,7 +218,7 @@ static void stress_filename_generate_random(
 	size_t i;
 
 	for (i = 0; i < sz_max; i++) {
-		const int j = mwc32() % chars_allowed;
+		const int j = stress_mwc32() % chars_allowed;
 		filename[i] = allowed[j];
 	}
 	if (*filename == '.')
@@ -233,7 +233,7 @@ static void stress_filename_generate_random(
  *	should_pass = false - expect it to fail (name too long)
  */
 static void stress_filename_test(
-	const args_t *args,
+	const stress_args_t *args,
 	const char *filename,
 	const size_t sz_max,
 	const bool should_pass)
@@ -257,7 +257,7 @@ static void stress_filename_test(
  *  stress_filename()
  *	stress filename sizes etc
  */
-static int stress_filename(const args_t *args)
+static int stress_filename(const stress_args_t *args)
 {
 	int ret, rc = EXIT_FAILURE;
 	size_t sz_left, sz_max;
@@ -275,7 +275,7 @@ static int stress_filename(const args_t *args)
 	uint8_t filename_opt = STRESS_FILENAME_PROBE;
 #endif
 
-	(void)get_setting("filename-opts", &filename_opt);
+	(void)stress_get_setting("filename-opts", &filename_opt);
 
 	stress_temp_dir_args(args, pathname, sizeof(pathname));
 	if (mkdir(pathname, S_IRWXU) < 0) {
@@ -380,14 +380,14 @@ again:
 			/* If we got killed by OOM killer, re-start */
 			if (WTERMSIG(status) == SIGKILL) {
 				if (g_opt_flags & OPT_FLAGS_OOMABLE) {
-					log_system_mem_info();
+					stress_log_system_mem_info();
 					pr_dbg("%s: assuming killed by OOM "
 						"killer, bailing out "
 						"(instance %d)\n",
 						args->name, args->instance);
 					_exit(0);
 				} else {
-					log_system_mem_info();
+					stress_log_system_mem_info();
 					pr_dbg("%s: assuming killed by OOM "
 						"killer, restarting again "
 						"(instance %d)\n",
@@ -409,7 +409,7 @@ again:
 		sz = 1;
 		do {
 			const char ch = allowed[i];
-			const size_t rnd_sz = 1 + (mwc32() % sz_max);
+			const size_t rnd_sz = 1 + (stress_mwc32() % sz_max);
 
 			i++;
 			if (i >= chars_allowed)
@@ -466,7 +466,7 @@ tidy_dir:
 	return rc;
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_filename_opts,	stress_set_filename_opts },
 	{ 0,			NULL }
 };
