@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"flock N",	"start N workers locking a single file" },
 	{ NULL,	"flock-ops N",	"stop after N flock bogo operations" },
 	{ NULL,	NULL,		NULL }
@@ -36,7 +36,7 @@ static const help_t help[] = {
 
 #define MAX_FLOCK_STRESSORS	(3)
 
-static void stress_flock_child(const args_t *args, const int fd)
+static void stress_flock_child(const stress_args_t *args, const int fd)
 {
 	bool cont;
 
@@ -93,7 +93,7 @@ static void stress_flock_child(const args_t *args, const int fd)
  *  stress_flock
  *	stress file locking
  */
-static int stress_flock(const args_t *args)
+static int stress_flock(const stress_args_t *args)
 {
 	int fd, ret, rc = EXIT_FAILURE;
 	size_t i;
@@ -105,7 +105,7 @@ static int stress_flock(const args_t *args)
 		return exit_status(-ret);
 
 	(void)stress_temp_filename_args(args,
-		filename, sizeof(filename), mwc32());
+		filename, sizeof(filename), stress_mwc32());
 	fd = open(filename, O_CREAT | O_RDWR, S_IRUSR | S_IWUSR);
 	if (fd < 0) {
 		pr_err("%s: failed to create %s: errno=%d (%s)\n",
