@@ -24,14 +24,14 @@
  */
 #include "stress-ng.h"
 
-static const help_t fork_help[] = {
+static const stress_help_t fork_help[] = {
 	{ "f N","fork N",	"start N workers spinning on fork() and exit()" },
 	{ NULL,	"fork-ops N",	"stop after N fork bogo operations" },
 	{ NULL,	"fork-max P",	"create P workers per iteration, default is 1" },
 	{ NULL,	NULL,		NULL }
 };
 
-static const help_t vfork_help[] = {
+static const stress_help_t vfork_help[] = {
 	{ NULL,	"vfork N",	"start N workers spinning on vfork() and exit()" },
 	{ NULL,	"vfork-ops N",	"stop after N vfork bogo operations" },
 	{ NULL,	"vfork-max P",	"create P processes per iteration, default is 1" },
@@ -46,10 +46,10 @@ static int stress_set_fork_max(const char *opt)
 {
 	uint32_t fork_max;
 
-	fork_max = get_uint32(opt);
-	check_range("fork-max", fork_max,
+	fork_max = stress_get_uint32(opt);
+	stress_check_range("fork-max", fork_max,
 		MIN_FORKS, MAX_FORKS);
-	return set_setting("fork-max", TYPE_ID_UINT32, &fork_max);
+	return stress_set_setting("fork-max", TYPE_ID_UINT32, &fork_max);
 }
 
 /*
@@ -60,10 +60,10 @@ static int stress_set_vfork_max(const char *opt)
 {
 	uint32_t vfork_max;
 
-	vfork_max = get_uint32(opt);
-	check_range("vfork-max", vfork_max,
+	vfork_max = stress_get_uint32(opt);
+	stress_check_range("vfork-max", vfork_max,
 		MIN_VFORKS, MAX_VFORKS);
-	return set_setting("vfork-max", TYPE_ID_UINT32, &vfork_max);
+	return stress_set_setting("vfork-max", TYPE_ID_UINT32, &vfork_max);
 }
 
 /*
@@ -72,7 +72,7 @@ static int stress_set_vfork_max(const char *opt)
  *	fork function fork_fn (fork or vfork)
  */
 static int stress_fork_fn(
-	const args_t *args,
+	const stress_args_t *args,
 	pid_t (*fork_fn)(void),
 	const char *fork_fn_name,
 	const uint32_t fork_max)
@@ -152,11 +152,11 @@ static int stress_fork_fn(
  *  stress_fork()
  *	stress by forking and exiting
  */
-static int stress_fork(const args_t *args)
+static int stress_fork(const stress_args_t *args)
 {
 	uint32_t fork_max = DEFAULT_FORKS;
 
-	if (!get_setting("fork-max", &fork_max)) {
+	if (!stress_get_setting("fork-max", &fork_max)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			fork_max = MAX_FORKS;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -171,13 +171,13 @@ static int stress_fork(const args_t *args)
  *  stress_vfork()
  *	stress by vforking and exiting
  */
-PRAGMA_PUSH
-PRAGMA_WARN_OFF
-static int stress_vfork(const args_t *args)
+STRESS_PRAGMA_PUSH
+STRESS_PRAGMA_WARN_OFF
+static int stress_vfork(const stress_args_t *args)
 {
 	uint32_t vfork_max = DEFAULT_VFORKS;
 
-	if (!get_setting("vfork-max", &vfork_max)) {
+	if (!stress_get_setting("vfork-max", &vfork_max)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			vfork_max = MAX_VFORKS;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -186,14 +186,14 @@ static int stress_vfork(const args_t *args)
 
 	return stress_fork_fn(args, vfork, "vfork", vfork_max);
 }
-PRAGMA_POP
+STRESS_PRAGMA_POP
 
-static const opt_set_func_t fork_opt_set_funcs[] = {
+static const stress_opt_set_func_t fork_opt_set_funcs[] = {
 	{ OPT_fork_max,		stress_set_fork_max },
 	{ 0,			NULL }
 };
 
-static const opt_set_func_t vfork_opt_set_funcs[] = {
+static const stress_opt_set_func_t vfork_opt_set_funcs[] = {
 	{ OPT_vfork_max,	stress_set_vfork_max },
 	{ 0,			NULL }
 };
