@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"fp-error N",	  "start N workers exercising floating point errors" },
 	{ NULL,	"fp-error-ops N", "stop after N fp-error bogo operations" },
 	{ NULL,	NULL,		  NULL }
@@ -65,7 +65,7 @@ static inline bool stress_double_same(
 }
 
 static void stress_fp_check(
-	const args_t *args,
+	const stress_args_t *args,
 	const char *expr,
 	const double val,
 	const double val_expected,
@@ -104,7 +104,7 @@ static void stress_fp_check(
  *  stress_fp_error()
  *	stress floating point error handling
  */
-static int stress_fp_error(const args_t *args)
+static int stress_fp_error(const stress_args_t *args)
 {
 	do {
 		volatile double d1, d2;
