@@ -30,7 +30,7 @@
 static volatile bool keep_running;
 static sigset_t set;
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"fstat N",	  "start N workers exercising fstat on files" },
 	{ NULL,	"fstat-ops N",	  "stop after N fstat bogo operations" },
 	{ NULL,	"fstat-dir path", "fstat files in the specified directory" },
@@ -58,14 +58,14 @@ typedef struct stat_info {
 
 /* Thread context information */
 typedef struct ctxt {
-	const args_t 	*args;		/* Stressor args */
+	const stress_args_t 	*args;		/* Stressor args */
 	stress_stat_info_t *si;		/* path stat information */
 	const uid_t	euid;		/* euid of process */
 } stress_ctxt_t;
 
 static int stress_set_fstat_dir(const char *opt)
 {
-	return set_setting("fstat-dir", TYPE_ID_STR, opt);
+	return stress_set_setting("fstat-dir", TYPE_ID_STR, opt);
 }
 
 /*
@@ -144,7 +144,6 @@ static void stress_fstat_helper(const stress_ctxt_t *ctxt)
 static void *stress_fstat_thread(void *ctxt_ptr)
 {
 	static void *nowt = NULL;
-	uint8_t stack[SIGSTKSZ + STACK_ALIGNMENT];
 	const stress_ctxt_t *ctxt = (const stress_ctxt_t *)ctxt_ptr;
 
 	/*
@@ -155,16 +154,6 @@ static void *stress_fstat_thread(void *ctxt_ptr)
 	(void)sigprocmask(SIG_BLOCK, &set, NULL);
 #endif
 
-	/*
-	 *  According to POSIX.1 a thread should have
-	 *  a distinct alternative signal stack.
-	 *  However, we block signals in this thread
-	 *  so this is probably just totally unncessary.
-	 */
-	(void)memset(stack, 0, sizeof(stack));
-	if (stress_sigaltstack(stack, SIGSTKSZ) < 0)
-		return &nowt;
-
 	while (keep_running && keep_stressing_flag()) {
 		size_t i;
 
@@ -184,7 +173,7 @@ static void *stress_fstat_thread(void *ctxt_ptr)
  *  stress_fstat_threads()
  *	create a bunch of threads to thrash a file
  */
-static void stress_fstat_threads(const args_t *args, stress_stat_info_t *si, const uid_t euid)
+static void stress_fstat_threads(const stress_args_t *args, stress_stat_info_t *si, const uid_t euid)
 {
 	size_t i;
 #if defined(HAVE_LIB_PTHREAD)
@@ -226,7 +215,7 @@ static void stress_fstat_threads(const args_t *args, stress_stat_info_t *si, con
  *  stress_fstat()
  *	stress system with fstat
  */
-static int stress_fstat(const args_t *args)
+static int stress_fstat(const stress_args_t *args)
 {
 	stress_stat_info_t *si;
 	static stress_stat_info_t *stat_info;
@@ -237,7 +226,7 @@ static int stress_fstat(const args_t *args)
 	DIR *dp;
 	char *fstat_dir = "/dev";
 
-	(void)get_setting("fstat-dir", &fstat_dir);
+	(void)stress_get_setting("fstat-dir", &fstat_dir);
 
 	if (stress_sighandler(args->name, SIGALRM, handle_fstat_sigalrm, NULL) < 0)
 		return EXIT_FAILURE;
@@ -309,7 +298,7 @@ free_cache:
 	return ret;
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_fstat_dir,	stress_set_fstat_dir },
 	{ 0,			NULL }
 };
