@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"full N",	"start N workers exercising /dev/full" },
 	{ NULL, "full-ops N",	"stop after N /dev/full bogo I/O operations" },
 	{ NULL,	NULL,		NULL }
@@ -47,7 +47,7 @@ static const stress_whences_t whences[] = {
  *  stress_full
  *	stress /dev/full
  */
-static int stress_full(const args_t *args)
+static int stress_full(const stress_args_t *args)
 {
 	do {
 		ssize_t ret;
@@ -109,8 +109,8 @@ try_read:
 		/*
 		 *  Seeks will always succeed
 		 */
-		w = mwc32() % 3;
-		offset = (off_t)mwc64();
+		w = stress_mwc32() % 3;
+		offset = (off_t)stress_mwc64();
 		ret = lseek(fd, offset, whences[w].whence);
 		if (ret < 0) {
 			pr_fail("%s: lseek(fd, %jd, %s)\n",
