@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-typedef void (*stress_funccall_func)(const args_t *argse);
+typedef void (*stress_funccall_func)(const stress_args_t *argse);
 
 typedef struct {
 	const char              *name;  /* human readable form of stressor */
@@ -33,19 +33,21 @@ typedef struct {
 
 static const stress_funccall_method_info_t funccall_methods[];
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"funccall N",		"start N workers exercising 1 to 9 arg functions" },
 	{ NULL,	"funccall-ops N",	"stop after N function call bogo operations" },
 	{ NULL,	"funccall-method M",	"select function call method M" },
 	{ NULL,	NULL,			NULL }
 };
 
-#define uint8_t_put	uint8_put
-#define uint16_t_put	uint16_put
-#define uint32_t_put	uint32_put
-#define uint64_t_put	uint64_put
-#define __uint128_t_put	uint128_put
-#define stress_long_double_t_put long_double_put
+#define uint8_t_put	stress_uint8_put
+#define uint16_t_put	stress_uint16_put
+#define uint32_t_put	stress_uint32_put
+#define uint64_t_put	stress_uint64_put
+#define __uint128_t_put	stress_uint128_put
+#define float_put	stress_float_put
+#define double_put	stress_double_put
+#define stress_long_double_t_put stress_long_double_put
 
 typedef long double 	stress_long_double_t;
 
@@ -723,9 +725,9 @@ stress_funcdeep_9(__float128)
 #endif
 
 #define stress_funccall_type(type, rndfunc)				\
-static void NOINLINE stress_funccall_ ## type(const args_t *args);	\
+static void NOINLINE stress_funccall_ ## type(const stress_args_t *args);	\
 									\
-static void NOINLINE stress_funccall_ ## type(const args_t *args)	\
+static void NOINLINE stress_funccall_ ## type(const stress_args_t *args)	\
 {									\
 	register int ii;						\
 	type a, b, c, d, e, f, g, h, i;					\
@@ -782,30 +784,30 @@ static void NOINLINE stress_funccall_ ## type(const args_t *args)	\
 	} while (keep_stressing());					\
 }
 
-stress_funccall_type(uint8_t, mwc8)
-stress_funccall_type(uint16_t, mwc16)
-stress_funccall_type(uint32_t, mwc32)
-stress_funccall_type(uint64_t, mwc64)
+stress_funccall_type(uint8_t, stress_mwc8)
+stress_funccall_type(uint16_t, stress_mwc16)
+stress_funccall_type(uint32_t, stress_mwc32)
+stress_funccall_type(uint64_t, stress_mwc64)
 #if defined(HAVE_INT128_T)
-stress_funccall_type(__uint128_t, mwc64)
+stress_funccall_type(__uint128_t, stress_mwc64)
 #endif
-stress_funccall_type(float, (float)mwc64)
-stress_funccall_type(double, (double)mwc64)
-stress_funccall_type(stress_long_double_t, (long double)mwc64)
+stress_funccall_type(float, (float)stress_mwc64)
+stress_funccall_type(double, (double)stress_mwc64)
+stress_funccall_type(stress_long_double_t, (long double)stress_mwc64)
 #if defined(HAVE_FLOAT_DECIMAL32) && !defined(__clang__)
-stress_funccall_type(_Decimal32, (_Decimal32)mwc64)
+stress_funccall_type(_Decimal32, (_Decimal32)stress_mwc64)
 #endif
 #if defined(HAVE_FLOAT_DECIMAL64) && !defined(__clang__)
-stress_funccall_type(_Decimal64, (_Decimal64)mwc64)
+stress_funccall_type(_Decimal64, (_Decimal64)stress_mwc64)
 #endif
 #if defined(HAVE_FLOAT_DECIMAL128) && !defined(__clang__)
-stress_funccall_type(_Decimal128, (_Decimal128)mwc64)
+stress_funccall_type(_Decimal128, (_Decimal128)stress_mwc64)
 #endif
 #if defined(HAVE_FLOAT80) && !defined(__clang__)
-stress_funccall_type(__float80, (__float80)mwc64)
+stress_funccall_type(__float80, (__float80)stress_mwc64)
 #endif
 #if defined(HAVE_FLOAT128) && !defined(__clang__)
-stress_funccall_type(__float128, (__float128)mwc64)
+stress_funccall_type(__float128, (__float128)stress_mwc64)
 #endif
 
 /*
@@ -850,7 +852,7 @@ static int stress_set_funccall_method(const char *name)
 
 	for (info = funccall_methods; info->func; info++) {
 		if (!strcmp(info->name, name)) {
-			set_setting("funccall-method", TYPE_ID_UINTPTR_T, &info);
+			stress_set_setting("funccall-method", TYPE_ID_UINTPTR_T, &info);
 			return 0;
 		}
 	}
@@ -868,11 +870,11 @@ static int stress_set_funccall_method(const char *name)
  *  stress_funccall()
  *	stress various argument sized function calls
  */
-static int stress_funccall(const args_t *args)
+static int stress_funccall(const stress_args_t *args)
 {
         const stress_funccall_method_info_t *funccall_method = &funccall_methods[3];
 
-        (void)get_setting("funccall-method", &funccall_method);
+        (void)stress_get_setting("funccall-method", &funccall_method);
 
         funccall_method->func(args);
 
@@ -885,7 +887,7 @@ static void stress_funccall_set_default(void)
 	stress_set_funccall_method("uint64");
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_funccall_method,	stress_set_funccall_method },
 	{ 0,			NULL }
 };
