@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-typedef void (*stress_funcret_func)(const args_t *argse);
+typedef void (*stress_funcret_func)(const stress_args_t *argse);
 
 typedef struct {
 	const char              *name;  /* human readable form of stressor */
@@ -33,7 +33,7 @@ typedef struct {
 
 static const stress_funcret_method_info_t funcret_methods[];
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"funcret N",		"start N workers exercising function return copying" },
 	{ NULL,	"funcret-ops N",	"stop after N function return bogo operations" },
 	{ NULL,	"funcret-method M",	"select method of exercising a function return type" },
@@ -168,16 +168,16 @@ stress_funcret_deep1(stress_uint64x128_t)
 stress_funcret_deeper1(stress_uint64x128_t)
 
 #define stress_funcret_type(type)					\
-static void NOINLINE stress_funcret_ ## type(const args_t *args);	\
+static void NOINLINE stress_funcret_ ## type(const stress_args_t *args);	\
 									\
-static void NOINLINE stress_funcret_ ## type(const args_t *args)	\
+static void NOINLINE stress_funcret_ ## type(const stress_args_t *args)	\
 {									\
 	register size_t i;						\
 	type a;								\
 	uint8_t data[sizeof(a)];					\
 									\
 	for (i = 0; i < sizeof(data); i++) 				\
-		data[i] = mwc8();					\
+		data[i] = stress_mwc8();				\
 	(void)memcpy(&a, data, sizeof(a));				\
 									\
 	do {								\
@@ -267,7 +267,7 @@ static int stress_set_funcret_method(const char *name)
 
 	for (info = funcret_methods; info->func; info++) {
 		if (!strcmp(info->name, name)) {
-			set_setting("funcret-method", TYPE_ID_UINTPTR_T, &info);
+			stress_set_setting("funcret-method", TYPE_ID_UINTPTR_T, &info);
 			return 0;
 		}
 	}
@@ -285,11 +285,11 @@ static int stress_set_funcret_method(const char *name)
  *  stress_funcret()
  *	stress various argument sized function calls
  */
-static int stress_funcret(const args_t *args)
+static int stress_funcret(const stress_args_t *args)
 {
         const stress_funcret_method_info_t *funcret_method = &funcret_methods[3];
 
-        (void)get_setting("funcret-method", &funcret_method);
+        (void)stress_get_setting("funcret-method", &funcret_method);
 
         funcret_method->func(args);
 
@@ -301,7 +301,7 @@ static void stress_funcret_set_default(void)
 	stress_set_funcret_method("uint64");
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_funcret_method,	stress_set_funcret_method },
 	{ 0,			NULL }
 };
