@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"futex N",	"start N workers exercising a fast mutex" },
 	{ NULL,	"futex-ops N",	"stop after N fast mutex bogo operations" },
 	{ NULL,	NULL,		NULL }
@@ -41,7 +41,7 @@ static const help_t help[] = {
  * 	efficiently use futex, but to stress the futex system call
  *	by rapidly calling it on wait and wakes
  */
-static int stress_futex(const args_t *args)
+static int stress_futex(const stress_args_t *args)
 {
 	uint64_t *timeout = &g_shared->futex.timeout[args->instance];
 	uint32_t *futex = &g_shared->futex.futex[args->instance];
