@@ -33,7 +33,7 @@
 
 #define GIDS_MAX 	(1024)
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"get N",	"start N workers exercising the get*() system calls" },
 	{ NULL,	"get-ops N",	"stop after N get bogo operations" },
 	{ NULL, NULL,		NULL }
@@ -123,7 +123,7 @@ static const int priorities[] = {
  *  stress on get*() calls
  *	stress system by rapid get*() system calls
  */
-static int stress_get(const args_t *args)
+static int stress_get(const stress_args_t *args)
 {
 	const bool verify = (g_opt_flags & OPT_FLAGS_VERIFY);
 #if defined(HAVE_SYS_TIMEX_H)
