@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"getdent N",	 "start N workers reading directories using getdents" },
 	{ NULL,	"getdent-ops N", "stop after N getdents bogo operations" },
 	{ NULL,	NULL,		 NULL }
@@ -35,7 +35,7 @@ static const help_t help[] = {
 #define BUF_SIZE	(256 * 1024)
 
 typedef int (stress_getdents_func)(
-	const args_t *args,
+	const stress_args_t *args,
 	const char *path,
 	const bool recurse,
 	const int depth,
@@ -58,7 +58,7 @@ static stress_getdents_func * getdents_funcs[] = {
 };
 
 static inline int stress_getdents_rand(
-	const args_t *args,
+	const stress_args_t *args,
 	const char *path,
 	const bool recurse,
 	const int depth,
@@ -66,7 +66,7 @@ static inline int stress_getdents_rand(
 {
 	int ret = -ENOSYS;
 	const size_t n = SIZEOF_ARRAY(getdents_funcs);
-	size_t i, j = mwc32() % n;
+	size_t i, j = stress_mwc32() % n;
 
 	for (i = 0; i < n; i++) {
 		stress_getdents_func *func = getdents_funcs[j];
@@ -93,7 +93,7 @@ static inline int stress_getdents_rand(
  *	read directory via the old 32 bit interface
  */
 static int stress_getdents_dir(
-	const args_t *args,
+	const stress_args_t *args,
 	const char *path,
 	const bool recurse,
 	const int depth,
@@ -110,7 +110,7 @@ static int stress_getdents_dir(
 	if (fd < 0)
 		return 0;
 
-	buf_sz = ((mwc32() % BUF_SIZE) + page_size) & ~(page_size - 1);
+	buf_sz = ((stress_mwc32() % BUF_SIZE) + page_size) & ~(page_size - 1);
 	buf = malloc(buf_sz);
 	if (!buf)
 		goto exit_close;
@@ -163,7 +163,7 @@ exit_close:
  *	read directory via the 64 bit interface
  */
 static int stress_getdents64_dir(
-	const args_t *args,
+	const stress_args_t *args,
 	const char *path,
 	const bool recurse,
 	const int depth,
@@ -180,7 +180,7 @@ static int stress_getdents64_dir(
 	if (fd < 0)
 		return 0;
 
-	buf_sz = ((mwc32() % BUF_SIZE) + page_size) & ~(page_size - 1);
+	buf_sz = ((stress_mwc32() % BUF_SIZE) + page_size) & ~(page_size - 1);
 	buf = malloc(buf_sz);
 	if (!buf)
 		goto exit_close;
@@ -230,7 +230,7 @@ exit_close:
  *  stress_getdent
  *	stress reading directories
  */
-static int stress_getdent(const args_t *args)
+static int stress_getdent(const stress_args_t *args)
 {
 	const size_t page_size = args->page_size;
 
