@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"getrandom N",	   "start N workers fetching random data via getrandom()" },
 	{ NULL,	"getrandom-ops N", "stop after N getrandom bogo operations" },
 	{ NULL, NULL,		   NULL }
@@ -62,7 +62,7 @@ static int stress_getrandom_supported(void)
  *  stress_getrandom
  *	stress reading random values using getrandom()
  */
-static int stress_getrandom(const args_t *args)
+static int stress_getrandom(const stress_args_t *args)
 {
 	do {
 		char buffer[RANDOM_BUFFER_SIZE];
