@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"handle N",	"start N workers exercising name_to_handle_at" },
 	{ NULL,	"handle-ops N",	"stop after N handle bogo operations" },
 	{ NULL,	NULL,		NULL }
@@ -56,7 +56,7 @@ static void free_mount_info(const int mounts)
 		free(mount_info[i].mount_path);
 }
 
-static int get_mount_info(const args_t *args)
+static int get_mount_info(const stress_args_t *args)
 {
 	FILE *fp;
 	int mounts = 0;
@@ -103,7 +103,7 @@ static int get_mount_info(const args_t *args)
  *	stress system by rapid open/close calls via
  *	name_to_handle_at and open_by_handle_at
  */
-static int stress_handle(const args_t *args)
+static int stress_handle(const stress_args_t *args)
 {
 	int mounts;
 	pid_t pid;
@@ -142,14 +142,14 @@ again:
 			/* If we got killed by OOM killer, re-start */
 			if (WTERMSIG(status) == SIGKILL) {
 				if (g_opt_flags & OPT_FLAGS_OOMABLE) {
-					log_system_mem_info();
+					stress_log_system_mem_info();
 					pr_dbg("%s: assuming killed by OOM "
 						"killer, bailing out "
 						"(instance %d)\n",
 						args->name, args->instance);
 					_exit(0);
 				} else {
-					log_system_mem_info();
+					stress_log_system_mem_info();
 					pr_dbg("%s: assuming killed by OOM "
 						"killer, restarting again "
 						"(instance %d)\n",
