@@ -66,7 +66,7 @@ typedef struct {
 	const int oflag;	/* open O_* flags */
 } stress_hdd_opts_t;
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ "d N","hdd N",		"start N workers spinning on write()/unlink()" },
 	{ NULL,	"hdd-ops N",		"stop after N hdd bogo operations" },
 	{ NULL,	"hdd-bytes N",		"write N bytes per hdd worker (default is 1GB)" },
@@ -141,20 +141,20 @@ static int stress_set_hdd_bytes(const char *opt)
 {
 	uint64_t hdd_bytes;
 
-	hdd_bytes = get_uint64_byte_filesystem(opt, 1);
-	check_range_bytes("hdd-bytes", hdd_bytes,
+	hdd_bytes = stress_get_uint64_byte_filesystem(opt, 1);
+	stress_check_range_bytes("hdd-bytes", hdd_bytes,
 		MIN_HDD_BYTES, MAX_HDD_BYTES);
-	return set_setting("hdd-bytes", TYPE_ID_UINT64, &hdd_bytes);
+	return stress_set_setting("hdd-bytes", TYPE_ID_UINT64, &hdd_bytes);
 }
 
 static int stress_set_hdd_write_size(const char *opt)
 {
 	uint64_t hdd_write_size;
 
-	hdd_write_size = get_uint64_byte(opt);
-	check_range_bytes("hdd-write-size", hdd_write_size,
+	hdd_write_size = stress_get_uint64_byte(opt);
+	stress_check_range_bytes("hdd-write-size", hdd_write_size,
 		MIN_HDD_WRITE_SIZE, MAX_HDD_WRITE_SIZE);
-	return set_setting("hdd-write-size", TYPE_ID_UINT64, &hdd_write_size);
+	return stress_set_setting("hdd-write-size", TYPE_ID_UINT64, &hdd_write_size);
 }
 
 /*
@@ -298,9 +298,9 @@ static int stress_set_hdd_opts(const char *opts)
 		}
 	}
 
-	set_setting("hdd-flags", TYPE_ID_INT, &hdd_flags);
-	set_setting("hdd-oflags", TYPE_ID_INT, &hdd_oflags);
-	set_setting("hdd-opts-set", TYPE_ID_BOOL, &opts_set);
+	stress_set_setting("hdd-flags", TYPE_ID_INT, &hdd_flags);
+	stress_set_setting("hdd-oflags", TYPE_ID_INT, &hdd_oflags);
+	stress_set_setting("hdd-opts-set", TYPE_ID_BOOL, &opts_set);
 	free(str);
 
 	return 0;
@@ -310,7 +310,7 @@ static int stress_set_hdd_opts(const char *opts)
  *  stress_hdd_advise()
  *	set posix_fadvise options
  */
-static int stress_hdd_advise(const args_t *args, const int fd, const int flags)
+static int stress_hdd_advise(const stress_args_t *args, const int fd, const int flags)
 {
 #if (defined(POSIX_FADV_SEQ) || defined(POSIX_FADV_RANDOM) || \
     defined(POSIX_FADV_NOREUSE) || defined(POSIX_FADV_WILLNEED) || \
@@ -339,7 +339,7 @@ static int stress_hdd_advise(const args_t *args, const int fd, const int flags)
  *  stress_hdd
  *	stress I/O via writes
  */
-static int stress_hdd(const args_t *args)
+static int stress_hdd(const stress_args_t *args)
 {
 	uint8_t *buf = NULL;
 	void *alloc_buf;
@@ -354,14 +354,14 @@ static int stress_hdd(const args_t *args)
 	int flags, fadvise_flags;
 	bool opts_set = false;
 
-	(void)get_setting("hdd-flags", &hdd_flags);
-	(void)get_setting("hdd-oflags", &hdd_oflags);
-	(void)get_setting("hdd-opts-set", &opts_set);
+	(void)stress_get_setting("hdd-flags", &hdd_flags);
+	(void)stress_get_setting("hdd-oflags", &hdd_oflags);
+	(void)stress_get_setting("hdd-opts-set", &opts_set);
 
 	flags = O_CREAT | O_RDWR | O_TRUNC | hdd_oflags;
 	fadvise_flags = hdd_flags & HDD_OPT_FADV_MASK;
 
-	if (!get_setting("hdd-bytes", &hdd_bytes)) {
+	if (!stress_get_setting("hdd-bytes", &hdd_bytes)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			hdd_bytes = MAXIMIZED_FILE_SIZE;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -372,7 +372,7 @@ static int stress_hdd(const args_t *args)
 	if (hdd_bytes < MIN_HDD_WRITE_SIZE)
 		hdd_bytes = MIN_HDD_WRITE_SIZE;
 
-	if (!get_setting("hdd-write-size", &hdd_write_size)) {
+	if (!stress_get_setting("hdd-write-size", &hdd_write_size)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			hdd_write_size = MAX_HDD_WRITE_SIZE;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -445,7 +445,7 @@ static int stress_hdd(const args_t *args)
 	stress_strnrnd((char *)buf, hdd_write_size);
 
 	(void)stress_temp_filename_args(args,
-		filename, sizeof(filename), mwc32());
+		filename, sizeof(filename), stress_mwc32());
 	do {
 		int fd;
 		struct stat statbuf;
@@ -474,7 +474,7 @@ static int stress_hdd(const args_t *args)
 		}
 
 		/* Exercise ftruncate or truncate */
-		if (mwc1()) {
+		if (stress_mwc1()) {
 			if (ftruncate(fd, (off_t)0) < 0) {
 				pr_fail_err("ftruncate");
 				(void)close(fd);
@@ -506,7 +506,7 @@ static int stress_hdd(const args_t *args)
 
 				off_t offset = (i == 0) ?
 					hdd_bytes :
-					(mwc64() % hdd_bytes) & ~511;
+					(stress_mwc64() % hdd_bytes) & ~511;
 
 				if (lseek(fd, offset, SEEK_SET) < 0) {
 					pr_fail_err("lseek");
@@ -643,7 +643,7 @@ seq_rd_retry:
 
 			for (i = 0; i < hdd_read_size; i += hdd_write_size) {
 				off_t offset = (hdd_bytes > hdd_write_size) ?
-					(mwc64() % (hdd_bytes - hdd_write_size)) & ~511 : 0;
+					(stress_mwc64() % (hdd_bytes - hdd_write_size)) & ~511 : 0;
 
 				if (lseek(fd, offset, SEEK_SET) < 0) {
 					pr_fail_err("lseek");
@@ -705,7 +705,7 @@ finish:
 	return rc;
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_hdd_bytes,	stress_set_hdd_bytes },
 	{ OPT_hdd_opts,		stress_set_hdd_opts },
 	{ OPT_hdd_write_size,	stress_set_hdd_write_size },
