@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"hrtimers N",	  "start N workers that exercise high resolution timers" },
 	{ NULL,	"hrtimers-ops N", "stop after N bogo high-res timer bogo operations" },
 	{ NULL,	NULL,		  NULL }
@@ -48,7 +48,7 @@ static double start;
 static void stress_hrtimers_set(struct itimerspec *timer)
 {
 	timer->it_value.tv_sec = 0;
-	timer->it_value.tv_nsec = (mwc64() % 50000) + 1;
+	timer->it_value.tv_nsec = (stress_mwc64() % 50000) + 1;
 	timer->it_interval.tv_sec = timer->it_value.tv_sec;
 	timer->it_interval.tv_nsec = timer->it_value.tv_nsec;
 }
@@ -99,7 +99,7 @@ cancel:
  *  stress_hrtimer_process
  *	stress timer child process
  */
-static int stress_hrtimer_process(const args_t *args, uint64_t *counter)
+static int stress_hrtimer_process(const stress_args_t *args, uint64_t *counter)
 {
 	struct sigevent sev;
 	struct itimerspec timer;
@@ -145,7 +145,7 @@ static int stress_hrtimer_process(const args_t *args, uint64_t *counter)
 	return EXIT_SUCCESS;
 }
 
-static int stress_hrtimers(const args_t *args)
+static int stress_hrtimers(const stress_args_t *args)
 {
 	pid_t pids[PROCS_MAX];
 	const size_t page_size = args->page_size;
