@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"hsearch N",	  "start N workers that exercise a hash table search" },
 	{ NULL,	"hsearch-ops N",  "stop after N hash search bogo operations" },
 	{ NULL,	"hsearch-size N", "number of integers to insert into hash table" },
@@ -39,24 +39,24 @@ static int stress_set_hsearch_size(const char *opt)
 {
 	uint64_t hsearch_size;
 
-	hsearch_size = get_uint64(opt);
-	check_range("hsearch-size", hsearch_size,
+	hsearch_size = stress_get_uint64(opt);
+	stress_check_range("hsearch-size", hsearch_size,
 		MIN_TSEARCH_SIZE, MAX_TSEARCH_SIZE);
-	return set_setting("hsearch-size", TYPE_ID_UINT64, &hsearch_size);
+	return stress_set_setting("hsearch-size", TYPE_ID_UINT64, &hsearch_size);
 }
 
 /*
  *  stress_hsearch()
  *	stress hsearch
  */
-static int stress_hsearch(const args_t *args)
+static int stress_hsearch(const stress_args_t *args)
 {
 	uint64_t hsearch_size = DEFAULT_HSEARCH_SIZE;
 	size_t i, max;
 	int ret = EXIT_FAILURE;
 	char **keys;
 
-	if (!get_setting("hsearch-size", &hsearch_size)) {
+	if (!stress_get_setting("hsearch-size", &hsearch_size)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			hsearch_size = MAX_HSEARCH_SIZE;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -141,7 +141,7 @@ free_hash:
 	return ret;
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_hsearch_size,	stress_set_hsearch_size },
 	{ 0,			NULL }
 };
