@@ -26,7 +26,7 @@
 
 static const char *bitmap_file = "/sys/kernel/mm/page_idle/bitmap";
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"idle-page N",	   "start N idle page scanning workers" },
 	{ NULL,	"idle-page-ops N", "stop after N idle page scan bogo operations" },
 	{ NULL, NULL,		   NULL }
@@ -68,7 +68,7 @@ static int stress_idle_page_supported(void)
  *  stress_idle_page
  *	stress kernel logging interface
  */
-static int stress_idle_page(const args_t *args)
+static int stress_idle_page(const stress_args_t *args)
 {
 	int fd;
 	off_t posn = 0, last_posn = 0xfffffffffffffff8ULL;
