@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"inode-flags N",	"start N workers exercising various inode flags" },
 	{ NULL,	"inode-flags-ops N",	"stop inode-flags workers after N bogo operations" },
 	{ NULL,	NULL,			NULL }
@@ -53,7 +53,7 @@ static shim_pthread_spinlock_t spinlock;
  *	try and toggle an inode flag on/off
  */
 static void stress_inode_flags_ioctl(
-	const args_t *args,
+	const stress_args_t *args,
 	const int fd,
 	const int flag)
 {
@@ -98,7 +98,7 @@ static inline void stress_inode_flags_ioctl_sane(const int fd)
  *	than fail.
  */
 static int stress_inode_flags_stressor(
-	const args_t *args,
+	const stress_args_t *args,
 	stress_data_t *data)
 {
 	while (keep_running && keep_stressing()) {
@@ -170,8 +170,7 @@ static int stress_inode_flags_stressor(
 static void *stress_inode_flags_thread(void *arg)
 {
 	static void *nowt = NULL;
-	uint8_t stack[SIGSTKSZ + STACK_ALIGNMENT];
-	pthread_args_t *pa = (pthread_args_t *)arg;
+	stress_pthread_args_t *pa = (stress_pthread_args_t *)arg;
 
 	/*
 	 *  Block all signals, let controlling thread
@@ -179,16 +178,6 @@ static void *stress_inode_flags_thread(void *arg)
 	 */
 	(void)sigprocmask(SIG_BLOCK, &set, NULL);
 
-	/*
-	 *  According to POSIX.1 a thread should have
-	 *  a distinct alternative signal stack.
-	 *  However, we block signals in this thread
-	 *  so this is probably just totally unncessary.
-	 */
-	(void)memset(stack, 0, sizeof(stack));
-	if (stress_sigaltstack(stack, SIGSTKSZ) < 0)
-		return &nowt;
-
 	pa->pthread_ret = stress_inode_flags_stressor(pa->args, pa->data);
 
 	return &nowt;
@@ -199,12 +188,12 @@ static void *stress_inode_flags_thread(void *arg)
  *  stress_inode_flags
  *	stress reading all of /dev
  */
-static int stress_inode_flags(const args_t *args)
+static int stress_inode_flags(const stress_args_t *args)
 {
 	size_t i;
 	pthread_t pthreads[MAX_INODE_FLAG_THREADS];
 	int rc, ret[MAX_INODE_FLAG_THREADS];
-	pthread_args_t pa[MAX_INODE_FLAG_THREADS];
+	stress_pthread_args_t pa[MAX_INODE_FLAG_THREADS];
 	stress_data_t data;
 	char tmp[PATH_MAX], file_name[PATH_MAX];
 	char *dir_name;
@@ -219,7 +208,7 @@ static int stress_inode_flags(const args_t *args)
 	if (rc < 0)
 		return exit_status(-rc);
 	(void)stress_temp_filename_args(args,
-		file_name, sizeof(file_name), mwc32());
+		file_name, sizeof(file_name), stress_mwc32());
 
 	shim_strlcpy(tmp, file_name, sizeof(tmp));
 	dir_name = dirname(tmp);
