@@ -26,7 +26,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"inotify N",	 "start N workers exercising inotify events" },
 	{ NULL,	"inotify-ops N", "stop inotify workers after N bogo operations" },
 	{ NULL, NULL,		 NULL }
@@ -43,8 +43,8 @@ static const help_t help[] = {
 #define TIME_OUT	(10)	/* Secs for inotify to report back */
 #define BUF_SIZE	(4096)
 
-typedef int (*stress_inotify_helper)(const args_t *args, const char *path, const void *private);
-typedef void (*stress_inotify_func)(const args_t *args, const char *path);
+typedef int (*stress_inotify_helper)(const stress_args_t *args, const char *path, const void *private);
+typedef void (*stress_inotify_func)(const stress_args_t *args, const char *path);
 
 typedef struct {
 	const stress_inotify_func func;
@@ -57,7 +57,7 @@ typedef struct {
  *	required inotify event flags 'flags'.
  */
 static void inotify_exercise(
-	const args_t *args,	/* Stressor args */
+	const stress_args_t *args,	/* Stressor args */
 	const char *filename,	/* Filename in test */
 	const char *watchname,	/* File or directory to watch using inotify */
 	const char *matchname,	/* Filename we expect inotify event to report */
@@ -183,7 +183,7 @@ cleanup:
  *  rm_file()
  *	remove a file
  */
-static int rm_file(const args_t *args, const char *path)
+static int rm_file(const stress_args_t *args, const char *path)
 {
 	if ((unlink(path) < 0) && errno != ENOENT) {
 		pr_err("%s: cannot remove file %s: errno=%d (%s)\n",
@@ -197,7 +197,7 @@ static int rm_file(const args_t *args, const char *path)
  *  rm_dir()
  *	clean files in directory and directory
  */
-static int rm_dir(const args_t *args, const char *path)
+static int rm_dir(const stress_args_t *args, const char *path)
 {
 	DIR *dp;
 	int ret;
@@ -228,7 +228,7 @@ static int rm_dir(const args_t *args, const char *path)
  *  mk_dir()
  *	make a directory
  */
-static int mk_dir(const args_t *args, const char *path)
+static int mk_dir(const stress_args_t *args, const char *path)
 {
 	if (mkdir(path, DIR_FLAGS) < 0) {
 		pr_err("%s: cannot mkdir %s: errno=%d (%s)\n",
@@ -255,7 +255,7 @@ static inline void mk_filename(
  *  mk_file()
  *	create file of length len bytes
  */
-static int mk_file(const args_t *args, const char *filename, const size_t len)
+static int mk_file(const stress_args_t *args, const char *filename, const size_t len)
 {
 	int fd;
 	size_t sz = len;
@@ -293,7 +293,7 @@ static int mk_file(const args_t *args, const char *filename, const size_t len)
 
 #if defined(IN_ATTRIB)
 static int inotify_attrib_helper(
-	const args_t *args,
+	const stress_args_t *args,
 	const char *path,
 	const void *signum)
 {
@@ -306,7 +306,7 @@ static int inotify_attrib_helper(
 	return 0;
 }
 
-static void inotify_attrib_file(const args_t *args, const char *path)
+static void inotify_attrib_file(const stress_args_t *args, const char *path)
 {
 	char filepath[PATH_MAX];
 
@@ -322,7 +322,7 @@ static void inotify_attrib_file(const args_t *args, const char *path)
 
 #if defined(IN_ACCESS)
 static int inotify_access_helper(
-	const args_t *args,
+	const stress_args_t *args,
 	const char *path,
 	const void *signum)
 {
@@ -350,7 +350,7 @@ do_access:
 	return rc;
 }
 
-static void inotify_access_file(const args_t *args, const char *path)
+static void inotify_access_file(const stress_args_t *args, const char *path)
 {
 	char filepath[PATH_MAX];
 
@@ -366,7 +366,7 @@ static void inotify_access_file(const args_t *args, const char *path)
 
 #if defined(IN_MODIFY)
 static int inotify_modify_helper(
-	const args_t *args,
+	const stress_args_t *args,
 	const char *path,
 	const void *signum)
 {
@@ -396,7 +396,7 @@ remove:
 	return rc;
 }
 
-static void inotify_modify_file(const args_t *args, const char *path)
+static void inotify_modify_file(const stress_args_t *args, const char *path)
 {
 	char filepath[PATH_MAX];
 
@@ -408,7 +408,7 @@ static void inotify_modify_file(const args_t *args, const char *path)
 
 #if defined(IN_CREATE)
 static int inotify_creat_helper(
-	const args_t *args,
+	const stress_args_t *args,
 	const char *path,
 	const void *signum)
 {
@@ -423,7 +423,7 @@ static int inotify_creat_helper(
 	return 0;
 }
 
-static void inotify_creat_file(const args_t *args, const char *path)
+static void inotify_creat_file(const stress_args_t *args, const char *path)
 {
 	char filepath[PATH_MAX];
 
@@ -436,7 +436,7 @@ static void inotify_creat_file(const args_t *args, const char *path)
 
 #if defined(IN_OPEN)
 static int inotify_open_helper(
-	const args_t *args,
+	const stress_args_t *args,
 	const char *path,
 	const void *signum)
 {
@@ -452,7 +452,7 @@ static int inotify_open_helper(
 	return 0;
 }
 
-static void inotify_open_file(const args_t *args, const char *path)
+static void inotify_open_file(const stress_args_t *args, const char *path)
 {
 	char filepath[PATH_MAX];
 
@@ -467,7 +467,7 @@ static void inotify_open_file(const args_t *args, const char *path)
 
 #if defined(IN_DELETE)
 static int inotify_delete_helper(
-	const args_t *args,
+	const stress_args_t *args,
 	const char *path,
 	const void *signum)
 {
@@ -476,7 +476,7 @@ static int inotify_delete_helper(
 	return rm_file(args, path);
 }
 
-static void inotify_delete_file(const args_t *args, const char *path)
+static void inotify_delete_file(const stress_args_t *args, const char *path)
 {
 	char filepath[PATH_MAX];
 
@@ -492,7 +492,7 @@ static void inotify_delete_file(const args_t *args, const char *path)
 
 #if defined(IN_DELETE_SELF)
 static int inotify_delete_self_helper(
-	const args_t *args,
+	const stress_args_t *args,
 	const char *path,
 	const void *signum)
 {
@@ -501,7 +501,7 @@ static int inotify_delete_self_helper(
 	return rm_dir(args, path);
 }
 
-static void inotify_delete_self(const args_t *args, const char *path)
+static void inotify_delete_self(const stress_args_t *args, const char *path)
 {
 	char filepath[PATH_MAX];
 
@@ -517,7 +517,7 @@ static void inotify_delete_self(const args_t *args, const char *path)
 
 #if defined(IN_MOVE_SELF)
 static int inotify_move_self_helper(
-	const args_t *args,
+	const stress_args_t *args,
 	const char *oldpath,
 	const void *private)
 {
@@ -532,7 +532,7 @@ static int inotify_move_self_helper(
 }
 #endif
 
-static void inotify_move_self(const args_t *args, const char *path)
+static void inotify_move_self(const stress_args_t *args, const char *path)
 {
 	char filepath[PATH_MAX], newpath[PATH_MAX];
 
@@ -549,7 +549,7 @@ static void inotify_move_self(const args_t *args, const char *path)
 
 #if defined(IN_MOVED_TO)
 static int inotify_moved_to_helper(
-	const args_t *args,
+	const stress_args_t *args,
 	const char *newpath,
 	const void *private)
 {
@@ -563,7 +563,7 @@ static int inotify_moved_to_helper(
 	return 0;
 }
 
-static void inotify_moved_to(const args_t *args, const char *path)
+static void inotify_moved_to(const stress_args_t *args, const char *path)
 {
 	char olddir[PATH_MAX - 16], oldfile[PATH_MAX], newfile[PATH_MAX];
 
@@ -585,7 +585,7 @@ static void inotify_moved_to(const args_t *args, const char *path)
 
 #if defined(IN_MOVED_FROM)
 static int inotify_moved_from_helper(
-	const args_t *args,
+	const stress_args_t *args,
 	const char *oldpath,
 	const void *private)
 {
@@ -599,7 +599,7 @@ static int inotify_moved_from_helper(
 	return 0;
 }
 
-static void inotify_moved_from(const args_t *args, const char *path)
+static void inotify_moved_from(const stress_args_t *args, const char *path)
 {
 	char oldfile[PATH_MAX], newdir[PATH_MAX - 16], newfile[PATH_MAX];
 
@@ -621,7 +621,7 @@ static void inotify_moved_from(const args_t *args, const char *path)
 
 #if defined(IN_CLOSE_WRITE)
 static int inotify_close_write_helper(
-	const args_t *args,
+	const stress_args_t *args,
 	const char *path,
 	const void *fdptr)
 {
@@ -632,7 +632,7 @@ static int inotify_close_write_helper(
 	return 0;
 }
 
-static void inotify_close_write_file(const args_t *args, const char *path)
+static void inotify_close_write_file(const stress_args_t *args, const char *path)
 {
 	char filepath[PATH_MAX];
 	int fd;
@@ -656,7 +656,7 @@ static void inotify_close_write_file(const args_t *args, const char *path)
 
 #if defined(IN_CLOSE_NOWRITE)
 static int inotify_close_nowrite_helper(
-	const args_t *args,
+	const stress_args_t *args,
 	const char *path,
 	const void *fdptr)
 {
@@ -667,7 +667,7 @@ static int inotify_close_nowrite_helper(
 	return 0;
 }
 
-static void inotify_close_nowrite_file(const args_t *args, const char *path)
+static void inotify_close_nowrite_file(const stress_args_t *args, const char *path)
 {
 	char filepath[PATH_MAX];
 	int fd;
@@ -734,7 +734,7 @@ static const stress_inotify_t inotify_stressors[] = {
  *  stress_inotify()
  *	stress inotify
  */
-static int stress_inotify(const args_t *args)
+static int stress_inotify(const stress_args_t *args)
 {
 	char pathname[PATH_MAX - 16];
 	int ret, i;
