@@ -24,9 +24,9 @@
  */
 #include "stress-ng.h"
 
-typedef void (*stress_iomix_func)(const args_t *args, const int fd, const off_t iomix_bytes);
+typedef void (*stress_iomix_func)(const stress_args_t *args, const int fd, const off_t iomix_bytes);
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"iomix N",	 "start N workers that have a mix of I/O operations" },
 	{ NULL,	"iomix-bytes N", "write N bytes per iomix worker (default is 1GB)" },
 	{ NULL,	"iomix-ops N",	 "stop iomix workers after N iomix bogo operations" },
@@ -37,10 +37,10 @@ static int stress_set_iomix_bytes(const char *opt)
 {
 	off_t iomix_bytes;
 
-	iomix_bytes = (off_t)get_uint64_byte_filesystem(opt, 1);
-	check_range_bytes("iomix-bytes", iomix_bytes,
+	iomix_bytes = (off_t)stress_get_uint64_byte_filesystem(opt, 1);
+	stress_check_range_bytes("iomix-bytes", iomix_bytes,
 		MIN_IOMIX_BYTES, MAX_IOMIX_BYTES);
-	return set_setting("iomix-bytes", TYPE_ID_OFF_T, &iomix_bytes);
+	return stress_set_setting("iomix-bytes", TYPE_ID_OFF_T, &iomix_bytes);
 }
 
 /*
@@ -48,17 +48,17 @@ static int stress_set_iomix_bytes(const char *opt)
  *	bursty sequential writes
  */
 static void stress_iomix_wr_seq_bursts(
-	const args_t *args,
+	const stress_args_t *args,
 	const int fd,
 	const off_t iomix_bytes)
 {
 	do {
 		off_t ret, posn;
-		const int n = mwc8();
+		const int n = stress_mwc8();
 		int i;
 		struct timeval tv;
 
-		posn = mwc64() % iomix_bytes;
+		posn = stress_mwc64() % iomix_bytes;
 		ret = lseek(fd, posn, SEEK_SET);
 		if (ret < 0) {
 			pr_fail_err("seek");
@@ -67,7 +67,7 @@ static void stress_iomix_wr_seq_bursts(
 		for (i = 0; (i < n) && (posn < iomix_bytes); i++) {
 			char buffer[512];
 			ssize_t rc;
-			const size_t len = 1 + (mwc32() & (sizeof(buffer) - 1));
+			const size_t len = 1 + (stress_mwc32() & (sizeof(buffer) - 1));
 
 			stress_strnrnd(buffer, len);
 
@@ -84,7 +84,7 @@ static void stress_iomix_wr_seq_bursts(
 			inc_counter(args);
 		}
 		tv.tv_sec = 0;
-		tv.tv_usec = mwc32() % 1000000;
+		tv.tv_usec = stress_mwc32() % 1000000;
 		(void)select(0, NULL, NULL, NULL, &tv);
 	} while (keep_stressing());
 }
@@ -94,22 +94,22 @@ static void stress_iomix_wr_seq_bursts(
  *	bursty random writes
  */
 static void stress_iomix_wr_rnd_bursts(
-	const args_t *args,
+	const stress_args_t *args,
 	const int fd,
 	const off_t iomix_bytes)
 {
 	do {
-		const int n = mwc8();
+		const int n = stress_mwc8();
 		int i;
 		struct timeval tv;
 
 		for (i = 0; i < n; i++) {
 			char buffer[512];
 			ssize_t rc;
-			const size_t len = 1 + (mwc32() & (sizeof(buffer) - 1));
+			const size_t len = 1 + (stress_mwc32() & (sizeof(buffer) - 1));
 			off_t ret, posn;
 
-			posn = mwc64() % iomix_bytes;
+			posn = stress_mwc64() % iomix_bytes;
 			ret = lseek(fd, posn, SEEK_SET);
 			if (ret < 0) {
 				pr_fail_err("seek");
@@ -128,8 +128,8 @@ static void stress_iomix_wr_rnd_bursts(
 				return;
 			inc_counter(args);
 		}
-		tv.tv_sec = mwc32() % 2;
-		tv.tv_usec = mwc32() % 1000000;
+		tv.tv_sec = stress_mwc32() % 2;
+		tv.tv_usec = stress_mwc32() % 1000000;
 		(void)select(0, NULL, NULL, NULL, &tv);
 
 	} while (keep_stressing());
@@ -140,7 +140,7 @@ static void stress_iomix_wr_rnd_bursts(
  *	slow sequential writes
  */
 static void stress_iomix_wr_seq_slow(
-	const args_t *args,
+	const stress_args_t *args,
 	const int fd,
 	const off_t iomix_bytes)
 {
@@ -155,7 +155,7 @@ static void stress_iomix_wr_seq_slow(
 		while (posn < iomix_bytes) {
 			char buffer[512];
 			ssize_t rc;
-			const size_t len = 1 + (mwc32() & (sizeof(buffer) - 1));
+			const size_t len = 1 + (stress_mwc32() & (sizeof(buffer) - 1));
 
 			stress_strnrnd(buffer, len);
 
@@ -180,17 +180,17 @@ static void stress_iomix_wr_seq_slow(
  *	bursty sequential reads
  */
 static void stress_iomix_rd_seq_bursts(
-	const args_t *args,
+	const stress_args_t *args,
 	const int fd,
 	const off_t iomix_bytes)
 {
 	do {
 		off_t ret, posn;
-		const int n = mwc8();
+		const int n = stress_mwc8();
 		int i;
 		struct timeval tv;
 
-		posn = mwc64() % iomix_bytes;
+		posn = stress_mwc64() % iomix_bytes;
 		ret = lseek(fd, posn, SEEK_SET);
 		if (ret < 0) {
 			pr_fail_err("seek");
@@ -202,7 +202,7 @@ static void stress_iomix_rd_seq_bursts(
 		for (i = 0; (i < n) && (posn < iomix_bytes); i++) {
 			char buffer[512];
 			ssize_t rc;
-			const size_t len = 1 + (mwc32() & (sizeof(buffer) - 1));
+			const size_t len = 1 + (stress_mwc32() & (sizeof(buffer) - 1));
 
 			rc = read(fd, buffer, len);
 			if (rc < 0) {
@@ -215,7 +215,7 @@ static void stress_iomix_rd_seq_bursts(
 			inc_counter(args);
 		}
 		tv.tv_sec = 0;
-		tv.tv_usec = mwc32() % 1000000;
+		tv.tv_usec = stress_mwc32() % 1000000;
 		(void)select(0, NULL, NULL, NULL, &tv);
 	} while (keep_stressing());
 }
@@ -225,22 +225,22 @@ static void stress_iomix_rd_seq_bursts(
  *	bursty random reads
  */
 static void stress_iomix_rd_rnd_bursts(
-	const args_t *args,
+	const stress_args_t *args,
 	const int fd,
 	const off_t iomix_bytes)
 {
 	do {
-		const int n = mwc8();
+		const int n = stress_mwc8();
 		int i;
 		struct timeval tv;
 
 		for (i = 0; i < n; i++) {
 			char buffer[512];
 			ssize_t rc;
-			const size_t len = 1 + (mwc32() & (sizeof(buffer) - 1));
+			const size_t len = 1 + (stress_mwc32() & (sizeof(buffer) - 1));
 			off_t ret, posn;
 
-			posn = mwc64() % iomix_bytes;
+			posn = stress_mwc64() % iomix_bytes;
 #if defined(HAVE_POSIX_FADVISE)
 			(void)posix_fadvise(fd, posn, len, POSIX_FADV_RANDOM);
 #endif
@@ -259,8 +259,8 @@ static void stress_iomix_rd_rnd_bursts(
 				return;
 			inc_counter(args);
 		}
-		tv.tv_sec = mwc32() % 3;
-		tv.tv_usec = mwc32() % 1000000;
+		tv.tv_sec = stress_mwc32() % 3;
+		tv.tv_usec = stress_mwc32() % 1000000;
 		(void)select(0, NULL, NULL, NULL, &tv);
 	} while (keep_stressing());
 }
@@ -270,7 +270,7 @@ static void stress_iomix_rd_rnd_bursts(
  *	slow sequential reads
  */
 static void stress_iomix_rd_seq_slow(
-	const args_t *args,
+	const stress_args_t *args,
 	const int fd,
 	const off_t iomix_bytes)
 {
@@ -285,7 +285,7 @@ static void stress_iomix_rd_seq_slow(
 		while (posn < iomix_bytes) {
 			char buffer[512];
 			ssize_t rc;
-			const size_t len = 1 + (mwc32() & (sizeof(buffer) - 1));
+			const size_t len = 1 + (stress_mwc32() & (sizeof(buffer) - 1));
 
 #if defined(HAVE_POSIX_FADVISE)
 			(void)posix_fadvise(fd, posn, len, POSIX_FADV_SEQUENTIAL);
@@ -309,7 +309,7 @@ static void stress_iomix_rd_seq_slow(
  *	file syncs
  */
 static void stress_iomix_sync(
-	const args_t *args,
+	const stress_args_t *args,
 	const int fd,
 	const off_t iomix_bytes)
 {
@@ -320,8 +320,8 @@ static void stress_iomix_sync(
 		if (!keep_stressing())
 			break;
 		inc_counter(args);
-		tv.tv_sec = mwc32() % 4;
-		tv.tv_usec = mwc32() % 1000000;
+		tv.tv_sec = stress_mwc32() % 4;
+		tv.tv_usec = stress_mwc32() % 1000000;
 		(void)select(0, NULL, NULL, NULL, &tv);
 		if (!keep_stressing())
 			break;
@@ -330,19 +330,19 @@ static void stress_iomix_sync(
 		(void)shim_fdatasync(fd);
 		if (!keep_stressing())
 			break;
-		tv.tv_sec = mwc32() % 4;
-		tv.tv_usec = mwc32() % 1000000;
+		tv.tv_sec = stress_mwc32() % 4;
+		tv.tv_usec = stress_mwc32() % 1000000;
 		(void)select(0, NULL, NULL, NULL, &tv);
 		if (!keep_stressing())
 			break;
 #endif
 #if defined(HAVE_SYNC_FILE_RANGE) &&	\
     defined(SYNC_FILE_RANGE_WRITE)
-		(void)sync_file_range(fd, mwc64() % iomix_bytes, 65536, SYNC_FILE_RANGE_WRITE);
+		(void)sync_file_range(fd, stress_mwc64() % iomix_bytes, 65536, SYNC_FILE_RANGE_WRITE);
 		if (!keep_stressing())
 			break;
-		tv.tv_sec = mwc32() % 4;
-		tv.tv_usec = mwc32() % 1000000;
+		tv.tv_sec = stress_mwc32() % 4;
+		tv.tv_usec = stress_mwc32() % 1000000;
 		(void)select(0, NULL, NULL, NULL, &tv);
 #else
 		(void)iomix_bytes;
@@ -356,12 +356,12 @@ static void stress_iomix_sync(
  *	bad fadvise hints
  */
 static void stress_iomix_bad_advise(
-	const args_t *args,
+	const stress_args_t *args,
 	const int fd,
 	const off_t iomix_bytes)
 {
 	do {
-		off_t posn = mwc64() % iomix_bytes;
+		off_t posn = stress_mwc64() % iomix_bytes;
 
 		(void)posix_fadvise(fd, posn, 65536, POSIX_FADV_DONTNEED);
 		(void)shim_usleep(100000);
@@ -374,7 +374,7 @@ static void stress_iomix_bad_advise(
  *	random memory mapped read/writes
  */
 static void stress_iomix_rd_wr_mmap(
-	const args_t *args,
+	const stress_args_t *args,
 	const int fd,
 	const off_t iomix_bytes)
 {
@@ -389,7 +389,7 @@ static void stress_iomix_rd_wr_mmap(
 
 	do {
 		for (i = 0; i < SIZEOF_ARRAY(mmaps); i++) {
-			off_t posn = (mwc64() % iomix_bytes) & ~(page_size - 1);
+			off_t posn = (stress_mwc64() % iomix_bytes) & ~(page_size - 1);
 			mmaps[i] = mmap(NULL, page_size,
 					PROT_READ | PROT_WRITE, flags, fd, posn);
 		}
@@ -402,11 +402,11 @@ static void stress_iomix_rd_wr_mmap(
 				/* Force page data to be read */
 				for (j = 0; j < page_size; j++)
 					sum += buffer[j];
-				uint64_put(sum);
+				stress_uint64_put(sum);
 
 				stress_strnrnd(mmaps[i], page_size);
 				(void)shim_msync(mmaps[i], page_size,
-					mwc1() ? MS_ASYNC : MS_SYNC);
+					stress_mwc1() ? MS_ASYNC : MS_SYNC);
 			}
 		}
 		(void)shim_usleep(100000);
@@ -422,7 +422,7 @@ static void stress_iomix_rd_wr_mmap(
  *	lots of small 1 byte writes
  */
 static void stress_iomix_wr_bytes(
-	const args_t *args,
+	const stress_args_t *args,
 	const int fd,
 	const off_t iomix_bytes)
 {
@@ -435,7 +435,7 @@ static void stress_iomix_wr_bytes(
 			return;
 		}
 		while (posn < iomix_bytes) {
-			char buffer[1] = { (mwc8() % 26) + 'A' };
+			char buffer[1] = { (stress_mwc8() % 26) + 'A' };
 			ssize_t rc;
 
 			rc = write(fd, buffer, sizeof(buffer));
@@ -458,7 +458,7 @@ static void stress_iomix_wr_bytes(
  *	lots of small 1 byte reads
  */
 static void stress_iomix_rd_bytes(
-	const args_t *args,
+	const stress_args_t *args,
 	const int fd,
 	const off_t iomix_bytes)
 {
@@ -509,7 +509,7 @@ static void stress_iomix_rd_bytes(
  *	attempt to set and unset a file based inode flag
  */
 static void stress_iomix_inode_ioctl(
-	const args_t *args,
+	const stress_args_t *args,
 	const int fd,
 	const int flag,
 	bool *ok)
@@ -544,7 +544,7 @@ static void stress_iomix_inode_ioctl(
  *	twiddle various inode flags
  */
 static void stress_iomix_inode_flags(
-	const args_t *args,
+	const stress_args_t *args,
 	const int fd,
 	const off_t iomix_bytes)
 {
@@ -598,7 +598,7 @@ static void stress_iomix_inode_flags(
  *	occasional file cache dropping
  */
 static void stress_iomix_drop_caches(
-	const args_t *args,
+	const stress_args_t *args,
 	const int fd,
 	const off_t iomix_bytes)
 {
@@ -654,7 +654,7 @@ static stress_iomix_func iomix_funcs[] = {
  *  stress_iomix
  *	stress I/O via random mix of io ops
  */
-static int stress_iomix(const args_t *args)
+static int stress_iomix(const stress_args_t *args)
 {
 	int fd, ret;
 	char filename[PATH_MAX];
@@ -673,7 +673,7 @@ static int stress_iomix(const args_t *args)
 		return EXIT_NO_RESOURCE;
 	}
 
-	if (!get_setting("iomix-bytes", &iomix_bytes)) {
+	if (!stress_get_setting("iomix-bytes", &iomix_bytes)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			iomix_bytes = MAXIMIZED_FILE_SIZE;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -692,7 +692,7 @@ static int stress_iomix(const args_t *args)
 	}
 
 	(void)stress_temp_filename_args(args,
-		filename, sizeof(filename), mwc32());
+		filename, sizeof(filename), stress_mwc32());
 	if ((fd = open(filename, O_CREAT | O_RDWR | O_SYNC, S_IRUSR | S_IWUSR)) < 0) {
 		ret = exit_status(errno);
 		pr_fail_err("open");
@@ -719,7 +719,7 @@ static int stress_iomix(const args_t *args)
 	(void)memset(counters, 0, sz);
 
 	for (i = 0; i < SIZEOF_ARRAY(iomix_funcs); i++) {
-		const args_t tmp_args = {
+		const stress_args_t tmp_args = {
 			.counter = &counters[i],
 			.name = args->name,
 			.max_ops = args->max_ops,
@@ -780,7 +780,7 @@ unmap:
 	return ret;
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_iomix_bytes,	stress_set_iomix_bytes },
 	{ 0,			NULL }
 };
