@@ -40,7 +40,7 @@ static const stress_ioport_opts_t ioport_opts[] = {
 	{ "inout",	IOPORT_OPT_IN | IOPORT_OPT_OUT },
 };
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"ioport N",	"start N workers exercising port I/O" },
 	{ NULL,	"ioport-ops N",	"stop ioport workers after N port bogo operations" },
 	{ NULL,	NULL,		NULL }
@@ -54,7 +54,7 @@ static int stress_set_ioport_opts(const char *opts)
 		if (!strcmp(opts, ioport_opts[i].opt)) {
 			uint32_t flag = ioport_opts[i].flag;
 
-			set_setting("ioport-opts", TYPE_ID_UINT32, &flag);
+			stress_set_setting("ioport-opts", TYPE_ID_UINT32, &flag);
 			return 0;
 		}
 	}
@@ -68,12 +68,12 @@ static int stress_set_ioport_opts(const char *opts)
 	return -1;
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_ioport_opts,	stress_set_ioport_opts },
 	{ 0,			NULL }
 };
 
-#if defined(STRESS_X86) && 	\
+#if defined(STRESS_ARCH_X86) && 	\
     defined(HAVE_IOPORT) &&	\
     defined(HAVE_SYS_IO_H)
 
@@ -105,13 +105,13 @@ static int stress_ioport_supported(void)
  *  stress_ioport()
  *	stress performs I/O port I/O transactions
  */
-static int stress_ioport(const args_t *args)
+static int stress_ioport(const stress_args_t *args)
 {
 	int ret;
 	uint32_t flag = 0;
 	unsigned char v;
 
-	(void)get_setting("ioport-opts", &flag);
+	(void)stress_get_setting("ioport-opts", &flag);
 	if (!flag)
 		flag = IOPORT_OPT_IN | IOPORT_OPT_OUT;
 
