@@ -26,7 +26,7 @@
 
 #define MAX_MNTS	(256)
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ "i N", "io N",	"start N workers spinning on sync()" },
 	{ NULL,	 "io-ops N",	"stop sync I/O after N io bogo operations" },
 	{ NULL,	 NULL,		NULL }
@@ -36,7 +36,7 @@ static const help_t help[] = {
  *  stress on sync()
  *	stress system by IO sync calls
  */
-static int stress_io(const args_t *args)
+static int stress_io(const stress_args_t *args)
 {
 #if defined(HAVE_SYNCFS)
 	int i, fd, n_mnts;
