@@ -29,7 +29,7 @@ static uint64_t max_ops;
 static double rate_us;
 static double start;
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"itimer N",	"start N workers exercising interval timers" },
 	{ NULL,	"itimer-ops N",	"stop after N interval timer bogo operations" },
 	{ NULL,	"itimer-rand",	"enable random interval timer frequency" },
@@ -44,10 +44,10 @@ static int stress_set_itimer_freq(const char *opt)
 {
 	uint64_t itimer_freq;
 
-	itimer_freq = get_uint64(opt);
-	check_range("itimer-freq", itimer_freq,
+	itimer_freq = stress_get_uint64(opt);
+	stress_check_range("itimer-freq", itimer_freq,
 		MIN_TIMER_FREQ, MAX_TIMER_FREQ);
-	return set_setting("itimer-freq", TYPE_ID_UINT64, &itimer_freq);
+	return stress_set_setting("itimer-freq", TYPE_ID_UINT64, &itimer_freq);
 }
 
 static int stress_set_itimer_rand(const char *opt)
@@ -55,7 +55,7 @@ static int stress_set_itimer_rand(const char *opt)
 	bool itimer_rand = true;
 
 	(void)opt;
-	return set_setting("itimer-rand", TYPE_ID_BOOL, &itimer_rand);
+	return stress_set_setting("itimer-rand", TYPE_ID_BOOL, &itimer_rand);
 }
 
 /*
@@ -67,11 +67,11 @@ static void stress_itimer_set(struct itimerval *timer)
 	double rate;
 	bool itimer_rand = false;
 
-	(void)get_setting("itimer-rand", &itimer_rand);
+	(void)stress_get_setting("itimer-rand", &itimer_rand);
 
 	if (itimer_rand) {
 		/* Mix in some random variation */
-		double r = ((double)(mwc32() % 10000) - 5000.0) / 40000.0;
+		double r = ((double)(stress_mwc32() % 10000) - 5000.0) / 40000.0;
 		rate = rate_us + (rate_us * r);
 	} else {
 		rate = rate_us;
@@ -135,7 +135,7 @@ cancel:
  *  stress_itimer
  *	stress itimer
  */
-static int stress_itimer(const args_t *args)
+static int stress_itimer(const stress_args_t *args)
 {
 	struct itimerval timer;
 	sigset_t mask;
@@ -148,7 +148,7 @@ static int stress_itimer(const args_t *args)
 	max_ops = args->max_ops;
 	start = stress_time_now();
 
-	if (!get_setting("itimer-freq", &itimer_freq)) {
+	if (!stress_get_setting("itimer-freq", &itimer_freq)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			itimer_freq = MAX_ITIMER_FREQ;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -183,7 +183,7 @@ static int stress_itimer(const args_t *args)
 	return EXIT_SUCCESS;
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_itimer_freq,	stress_set_itimer_freq },
 	{ OPT_itimer_rand,	stress_set_itimer_rand },
 	{ 0,			NULL }
