@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"judy N",	"start N workers that exercise a judy array search" },
 	{ NULL,	"judy-ops N",	"stop after N judy array search bogo operations" },
 	{ NULL,	"judy-size N",	"number of 32 bit integers to insert into judy array" },
@@ -39,13 +39,13 @@ static int stress_set_judy_size(const char *opt)
 {
 	uint64_t judy_size;
 
-	judy_size = get_uint64(opt);
-	check_range("judy-size", judy_size,
+	judy_size = stress_get_uint64(opt);
+	stress_check_range("judy-size", judy_size,
 		MIN_JUDY_SIZE, MAX_JUDY_SIZE);
-	return set_setting("judy-size", TYPE_ID_UINT64, &judy_size);
+	return stress_set_setting("judy-size", TYPE_ID_UINT64, &judy_size);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_judy_size,	stress_set_judy_size },
 	{ 0,			NULL }
 };
@@ -65,13 +65,13 @@ static inline Word_t gen_index(const Word_t index)
  *  stress_judy()
  *	stress judy
  */
-static int stress_judy(const args_t *args)
+static int stress_judy(const stress_args_t *args)
 {
 	uint64_t judy_size = DEFAULT_JUDY_SIZE;
 	size_t n;
 	Word_t i, j;
 
-	if (!get_setting("judy-size", &judy_size)) {
+	if (!stress_get_setting("judy-size", &judy_size)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			judy_size = MAX_JUDY_SIZE;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -89,7 +89,7 @@ static int stress_judy(const args_t *args)
 			Word_t idx = gen_index(i);
 
 			JLI(pvalue, PJLArray, idx);
-			if (pvalue == PJERR) {
+			if ((pvalue == NULL) || (pvalue == PJERR)) {
 				pr_err("%s: cannot allocate new "
 					"judy node\n", args->name);
 				for (j = 0; j < n; j++) {
