@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"kcmp N",	"start N workers exercising kcmp" },
 	{ NULL,	"kcmp-ops N",	"stop after N kcmp bogo operations" },
 	{ NULL, NULL,		NULL }
@@ -95,7 +95,7 @@ struct kcmp_epoll_slot {
  *  stress_kcmp
  *	stress sys_kcmp
  */
-static int stress_kcmp(const args_t *args)
+static int stress_kcmp(const stress_args_t *args)
 {
 	pid_t pid1;
 	int fd1;
