@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"key N",	"start N workers exercising key operations" },
 	{ NULL,	"key-ops N",	"stop after N key bogo operations" },
 	{ NULL,	NULL,		NULL }
@@ -79,7 +79,7 @@ static key_serial_t sys_request_key(
  *  stress_key
  *	stress key operations
  */
-static int stress_key(const args_t *args)
+static int stress_key(const stress_args_t *args)
 {
 	key_serial_t keys[MAX_KEYS];
 	pid_t ppid = getppid();
@@ -187,7 +187,7 @@ static int stress_key(const args_t *args)
 			(void)sys_keyctl(KEYCTL_SETPERM, keys[i], KEY_USR_ALL);
 #endif
 #if defined(KEYCTL_REVOKE)
-			if (mwc1())
+			if (stress_mwc1())
 				(void)sys_keyctl(KEYCTL_REVOKE, keys[i]);
 #endif
 #if defined(KEYCTL_INVALIDATE)
