@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
  	{ NULL,	"kill N",	"start N workers killing with SIGUSR1" },
 	{ NULL,	"kill-ops N",	"stop after N kill bogo operations" },
 	{ NULL,	NULL,		NULL }
@@ -34,7 +34,7 @@ static const help_t help[] = {
  *  stress on sched_kill()
  *	stress system by rapid kills
  */
-static int stress_kill(const args_t *args)
+static int stress_kill(const stress_args_t *args)
 {
 	uint64_t udelay = 5000;
 
