@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"klog N",	"start N workers exercising kernel syslog interface" },
 	{ NULL,	"klog-ops N",	"stop after N klog bogo operations" },
 	{ NULL,	NULL,		NULL }
@@ -48,7 +48,7 @@ static const help_t help[] = {
  *  stress_klog
  *	stress kernel logging interface
  */
-static int stress_klog(const args_t *args)
+static int stress_klog(const stress_args_t *args)
 {
 	char *buffer;
 	ssize_t len;
@@ -78,7 +78,7 @@ static int stress_klog(const args_t *args)
 	}
 
 	do {
-		int ret, buflen = (mwc32() % len) + 1;
+		int ret, buflen = (stress_mwc32() % len) + 1;
 
 		ret = shim_klogctl(SYSLOG_ACTION_READ_ALL, buffer, buflen);
 		if (ret < 0)
