@@ -28,7 +28,7 @@
 static uint64_t lease_sigio;
 #endif
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"lease N",	    "start N workers holding and breaking a lease" },
 	{ NULL,	"lease-ops N",	    "stop after N lease bogo operations" },
 	{ NULL,	"lease-breakers N", "number of lease breaking workers to start" },
@@ -39,13 +39,13 @@ static int stress_set_lease_breakers(const char *opt)
 {
 	uint64_t lease_breakers;
 
-	lease_breakers = get_uint64(opt);
-	check_range("lease-breakers", lease_breakers,
+	lease_breakers = stress_get_uint64(opt);
+	stress_check_range("lease-breakers", lease_breakers,
 		MIN_LEASE_BREAKERS, MAX_LEASE_BREAKERS);
-	return set_setting("lease-breakers", TYPE_ID_UINT64, &lease_breakers);
+	return stress_set_setting("lease-breakers", TYPE_ID_UINT64, &lease_breakers);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_lease_breakers,	stress_set_lease_breakers },
 	{ 0,			NULL }
 };
@@ -68,7 +68,7 @@ static void MLOCKED_TEXT stress_lease_handler(int signum)
  *	spawn a process
  */
 static pid_t stress_lease_spawn(
-	const args_t *args,
+	const stress_args_t *args,
 	const char *filename)
 {
 	pid_t pid;
@@ -109,14 +109,14 @@ again:
  *  stress_lease
  *	stress by fcntl lease activity
  */
-static int stress_lease(const args_t *args)
+static int stress_lease(const stress_args_t *args)
 {
 	char filename[PATH_MAX];
 	int ret, fd, status;
 	pid_t l_pids[MAX_LEASE_BREAKERS];
 	uint64_t i, lease_breakers = DEFAULT_LEASE_BREAKERS;
 
-	if (!get_setting("lease-breakers", &lease_breakers)) {
+	if (!stress_get_setting("lease-breakers", &lease_breakers)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			lease_breakers = MAX_LEASE_BREAKERS;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -132,7 +132,7 @@ static int stress_lease(const args_t *args)
 	if (ret < 0)
 		return exit_status(-ret);
 	(void)stress_temp_filename_args(args,
-		filename, sizeof(filename), mwc32());
+		filename, sizeof(filename), stress_mwc32());
 
 	fd = creat(filename, S_IRUSR | S_IWUSR);
 	if (fd < 0) {
