@@ -24,14 +24,14 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"lockbus N",	 "start N workers locking a memory increment" },
 	{ NULL,	"lockbus-ops N", "stop after N lockbus bogo operations" },
 	{ NULL, NULL,		 NULL }
 };
 
-#if (((defined(__GNUC__) || defined(__clang__)) && defined(STRESS_X86)) || \
-    (defined(__GNUC__) && NEED_GNUC(4,7,0) && defined(STRESS_ARM)))
+#if (((defined(__GNUC__) || defined(__clang__)) && defined(STRESS_ARCH_X86)) || \
+    (defined(__GNUC__) && NEED_GNUC(4,7,0) && defined(STRESS_ARCH_ARM)))
 
 #define BUFFER_SIZE	(1024 * 1024 * 16)
 #define CHUNK_SIZE	(64 * 4)
@@ -68,7 +68,7 @@ static const help_t help[] = {
 	LOCK(ptr)			\
 	LOCK(ptr)
 
-#if defined(STRESS_X86)
+#if defined(STRESS_ARCH_X86)
 static sigjmp_buf jmp_env;
 static bool do_splitlock;
 
@@ -86,11 +86,11 @@ static void MLOCKED_TEXT stress_sigbus_handler(int signum)
  *  stress_lockbus()
  *      stress memory with lock and increment
  */
-static int stress_lockbus(const args_t *args)
+static int stress_lockbus(const stress_args_t *args)
 {
 	uint32_t *buffer;
 	int flags = MAP_ANONYMOUS | MAP_SHARED;
-#if defined(STRESS_X86)
+#if defined(STRESS_ARCH_X86)
 	uint32_t *splitlock_ptr1, *splitlock_ptr2;
 
 	if (stress_sighandler(args->name, SIGBUS, stress_sigbus_handler, NULL) < 0)
@@ -107,7 +107,7 @@ static int stress_lockbus(const args_t *args)
 		return rc;
 	}
 
-#if defined(STRESS_X86)
+#if defined(STRESS_ARCH_X86)
 	/* Split lock on a page boundary */
 	splitlock_ptr1 = (uint32_t *)(((uint8_t *)buffer) + args->page_size - (sizeof(uint32_t) >> 1));
 	/* Split lock on a cache boundary */
@@ -118,8 +118,8 @@ static int stress_lockbus(const args_t *args)
 #endif
 
 	do {
-		uint32_t *ptr0 = buffer + ((mwc32() % (BUFFER_SIZE - CHUNK_SIZE)) >> 2);
-#if defined(STRESS_X86)
+		uint32_t *ptr0 = buffer + ((stress_mwc32() % (BUFFER_SIZE - CHUNK_SIZE)) >> 2);
+#if defined(STRESS_ARCH_X86)
 		uint32_t *ptr1 = do_splitlock ? splitlock_ptr1 : ptr0;
 		uint32_t *ptr2 = do_splitlock ? splitlock_ptr2 : ptr0;
 #else
@@ -144,7 +144,7 @@ static int stress_lockbus(const args_t *args)
 		inc_counter(args);
 	} while (keep_stressing());
 
-#if defined(STRESS_X86)
+#if defined(STRESS_ARCH_X86)
 done:
 #endif
 	(void)munmap((void *)buffer, BUFFER_SIZE);
