@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"lockf N",	  "start N workers locking a single file via lockf" },
 	{ NULL,	"lockf-ops N",	  "stop after N lockf bogo operations" },
 	{ NULL, "lockf-nonblock", "don't block if lock cannot be obtained, re-try" },
@@ -57,10 +57,10 @@ static int stress_lockf_set_nonblock(const char *opt)
 	bool lockf_nonblock = true;
 
 	(void)opt;
-	return set_setting("lockf-nonblock", TYPE_ID_BOOL, &lockf_nonblock);
+	return stress_set_setting("lockf-nonblock", TYPE_ID_BOOL, &lockf_nonblock);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_lockf_nonblock,   stress_lockf_set_nonblock },
 	{ 0,			NULL }
 };
@@ -146,7 +146,7 @@ static void stress_lockf_info_free(void)
  *  stress_lockf_unlock()
  *	pop oldest lock record off list and unlock it
  */
-static int stress_lockf_unlock(const args_t *args, const int fd)
+static int stress_lockf_unlock(const stress_args_t *args, const int fd)
 {
 	/* Pop one off list */
 	if (!lockf_infos.head)
@@ -170,15 +170,15 @@ static int stress_lockf_unlock(const args_t *args, const int fd)
  *	hammer lock/unlock to create some file lock contention
  */
 static int stress_lockf_contention(
-	const args_t *args,
+	const stress_args_t *args,
 	const int fd)
 {
 	bool lockf_nonblock = false;
 	int lockf_cmd;
 
-	(void)get_setting("lockf-nonblock", &lockf_nonblock);
+	(void)stress_get_setting("lockf-nonblock", &lockf_nonblock);
 	lockf_cmd = lockf_nonblock ?  F_TLOCK : F_LOCK;
-	mwc_reseed();
+	stress_mwc_reseed();
 
 	do {
 		off_t offset;
@@ -189,7 +189,7 @@ static int stress_lockf_contention(
 			if (stress_lockf_unlock(args, fd) < 0)
 				return -1;
 
-		offset = mwc64() % (LOCK_FILE_SIZE - LOCK_SIZE);
+		offset = stress_mwc64() % (LOCK_FILE_SIZE - LOCK_SIZE);
 		if (lseek(fd, offset, SEEK_SET) < 0) {
 			pr_fail_err("lseek");
 			return -1;
@@ -218,7 +218,7 @@ static int stress_lockf_contention(
  *  stress_lockf
  *	stress file locking via lockf()
  */
-static int stress_lockf(const args_t *args)
+static int stress_lockf(const stress_args_t *args)
 {
 	int fd, ret = EXIT_FAILURE;
 	pid_t cpid = -1;
@@ -249,7 +249,7 @@ static int stress_lockf(const args_t *args)
 	 *  stress flock processes
 	 */
 	(void)stress_temp_filename_args(args,
-		filename, sizeof(filename), mwc32());
+		filename, sizeof(filename), stress_mwc32());
 
 	if ((fd = open(filename, O_CREAT | O_RDWR, S_IRUSR | S_IWUSR)) < 0) {
 		ret = exit_status(errno);
