@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL, "lockofd N",	 "start N workers using open file description locking" },
 	{ NULL, "lockofd-ops N", "stop after N lockofd bogo operations" },
 	{ NULL, NULL,		 NULL }
@@ -132,7 +132,7 @@ static void stress_lockofd_info_free(void)
  *  stress_lockofd_unlock()
  *	pop oldest lock record off list and unlock it
  */
-static int stress_lockofd_unlock(const args_t *args, const int fd)
+static int stress_lockofd_unlock(const stress_args_t *args, const int fd)
 {
 	struct flock f;
 
@@ -160,10 +160,10 @@ static int stress_lockofd_unlock(const args_t *args, const int fd)
  *	hammer advisory lock/unlock to create some file lock contention
  */
 static int stress_lockofd_contention(
-	const args_t *args,
+	const stress_args_t *args,
 	const int fd)
 {
-	mwc_reseed();
+	stress_mwc_reseed();
 
 	do {
 		off_t offset;
@@ -176,8 +176,8 @@ static int stress_lockofd_contention(
 			if (stress_lockofd_unlock(args, fd) < 0)
 				return -1;
 
-		len  = (mwc16() + 1) & 0xfff;
-		offset = mwc64() % (LOCK_FILE_SIZE - len);
+		len  = (stress_mwc16() + 1) & 0xfff;
+		offset = stress_mwc64() % (LOCK_FILE_SIZE - len);
 
 		f.l_type = F_WRLCK;
 		f.l_whence = SEEK_SET;
@@ -209,7 +209,7 @@ static int stress_lockofd_contention(
  *  stress_lockofd
  *	stress file locking via advisory locking
  */
-static int stress_lockofd(const args_t *args)
+static int stress_lockofd(const stress_args_t *args)
 {
 	int fd, ret = EXIT_FAILURE;
 	pid_t cpid = -1;
@@ -240,7 +240,7 @@ static int stress_lockofd(const args_t *args)
 	 *  stress flock processes
 	 */
 	(void)stress_temp_filename_args(args,
-		filename, sizeof(filename), mwc32());
+		filename, sizeof(filename), stress_mwc32());
 
 	if ((fd = open(filename, O_CREAT | O_RDWR, S_IRUSR | S_IWUSR)) < 0) {
 		ret = exit_status(errno);
