@@ -26,7 +26,7 @@
 
 static jmp_buf buf;
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"longjmp N",	 "start N workers exercising setjmp/longjmp" },
 	{ NULL,	"longjmp-ops N", "stop after N longjmp bogo operations" },
 	{ NULL,	NULL,		 NULL }
@@ -43,7 +43,7 @@ static void OPTIMIZE1 NOINLINE NORETURN stress_longjmp_func(void)
  *  stress_jmp()
  *	stress system by setjmp/longjmp calls
  */
-static int OPTIMIZE1 stress_longjmp(const args_t *args)
+static int OPTIMIZE1 stress_longjmp(const stress_args_t *args)
 {
 	int ret;
 
