@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"loop N",	"start N workers exercising loopback devices" },
 	{ NULL,	"loop-ops N",	"stop after N bogo loopback operations" },
 	{ NULL,	NULL,		NULL }
@@ -55,7 +55,7 @@ static int stress_loop_supported(void)
  *  stress_loop()
  *	stress loopback device
  */
-static int stress_loop(const args_t *args)
+static int stress_loop(const stress_args_t *args)
 {
 	int ret, backing_fd, rc = EXIT_FAILURE;
 	char backing_file[PATH_MAX];
@@ -66,7 +66,7 @@ static int stress_loop(const args_t *args)
 		return exit_status(-ret);
 
 	(void)stress_temp_filename_args(args,
-		backing_file, sizeof(backing_file), mwc32());
+		backing_file, sizeof(backing_file), stress_mwc32());
 
 	if ((backing_fd = open(backing_file, O_RDWR | O_CREAT, S_IRUSR | S_IWUSR)) < 0) {
 		pr_fail_err("open");
@@ -147,7 +147,7 @@ static int stress_loop(const args_t *args)
 #if defined(LOOP_SET_STATUS)
 		ret = ioctl(loop_dev, LOOP_SET_STATUS, &info);
 		(void)ret;
-		switch (mwc1()) {
+		switch (stress_mwc1()) {
 		case 0:
 			info.lo_encrypt_type = LO_CRYPT_NONE;
 			info.lo_encrypt_key_size = 0;
@@ -198,7 +198,7 @@ static int stress_loop(const args_t *args)
 		 *  produce kernel warnings but should not break the
 		 *  kernel.
 		 */
-		blk_size = (unsigned long)blk_sizes[mwc8() % SIZEOF_ARRAY(blk_sizes)];
+		blk_size = (unsigned long)blk_sizes[stress_mwc8() % SIZEOF_ARRAY(blk_sizes)];
 		ret = ioctl(loop_dev, LOOP_SET_BLOCK_SIZE, blk_size);
 		(void)ret;
 #endif
