@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"malloc N",		"start N workers exercising malloc/realloc/free" },
 	{ NULL,	"malloc-bytes N",	"allocate up to N bytes per allocation" },
 	{ NULL,	"malloc-max N",		"keep up to N allocations at a time" },
@@ -37,30 +37,30 @@ static int stress_set_malloc_bytes(const char *opt)
 {
 	size_t malloc_bytes;
 
-	malloc_bytes = (size_t)get_uint64_byte_memory(opt, 1);
-	check_range_bytes("malloc-bytes", malloc_bytes,
+	malloc_bytes = (size_t)stress_get_uint64_byte_memory(opt, 1);
+	stress_check_range_bytes("malloc-bytes", malloc_bytes,
 		MIN_MALLOC_BYTES, MAX_MEM_LIMIT);
-	return set_setting("malloc-bytes", TYPE_ID_SIZE_T, &malloc_bytes);
+	return stress_set_setting("malloc-bytes", TYPE_ID_SIZE_T, &malloc_bytes);
 }
 
 static int stress_set_malloc_max(const char *opt)
 {
 	size_t malloc_max;
 
-	malloc_max = (size_t)get_uint64_byte(opt);
-	check_range("malloc-max", malloc_max,
+	malloc_max = (size_t)stress_get_uint64_byte(opt);
+	stress_check_range("malloc-max", malloc_max,
 		MIN_MALLOC_MAX, MAX_MALLOC_MAX);
-	return set_setting("malloc-max", TYPE_ID_SIZE_T, &malloc_max);
+	return stress_set_setting("malloc-max", TYPE_ID_SIZE_T, &malloc_max);
 }
 
 static int stress_set_malloc_threshold(const char *opt)
 {
 	size_t malloc_threshold;
 
-	malloc_threshold = (size_t)get_uint64_byte(opt);
-	check_range("malloc-threshold", malloc_threshold,
+	malloc_threshold = (size_t)stress_get_uint64_byte(opt);
+	stress_check_range("malloc-threshold", malloc_threshold,
 		MIN_MALLOC_THRESHOLD, MAX_MALLOC_THRESHOLD);
-	return set_setting("malloc-threshold", TYPE_ID_SIZE_T, &malloc_threshold);
+	return stress_set_setting("malloc-threshold", TYPE_ID_SIZE_T, &malloc_threshold);
 }
 
 /*
@@ -70,12 +70,12 @@ static int stress_set_malloc_threshold(const char *opt)
  */
 static inline size_t stress_alloc_size(const size_t malloc_bytes)
 {
-	const size_t len = mwc64() % malloc_bytes;
+	const size_t len = stress_mwc64() % malloc_bytes;
 
 	return len ? len : 1;
 }
 
-static int stress_malloc_child(const args_t *args, void *context)
+static int stress_malloc_child(const stress_args_t *args, void *context)
 {
 	size_t j;
 	size_t malloc_bytes = DEFAULT_MALLOC_BYTES;
@@ -87,7 +87,7 @@ static int stress_malloc_child(const args_t *args, void *context)
 
 	(void)context;
 
-	if (!get_setting("malloc-bytes", &malloc_bytes)) {
+	if (!stress_get_setting("malloc-bytes", &malloc_bytes)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			malloc_bytes = MAX_32;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -98,7 +98,7 @@ static int stress_malloc_child(const args_t *args, void *context)
 	if (malloc_bytes < MIN_MALLOC_BYTES)
 		malloc_bytes = MIN_MALLOC_BYTES;
 
-	if (!get_setting("malloc-max", &malloc_max)) {
+	if (!stress_get_setting("malloc-max", &malloc_max)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			malloc_max = MAX_MALLOC_MAX;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -106,7 +106,7 @@ static int stress_malloc_child(const args_t *args, void *context)
 	}
 
 #if defined(__GNUC__) && defined(M_MMAP_THRESHOLD) && defined(HAVE_MALLOPT)
-	if (get_setting("malloc-threshold", &malloc_threshold))
+	if (stress_get_setting("malloc-threshold", &malloc_threshold))
 		(void)mallopt(M_MMAP_THRESHOLD, (int)malloc_threshold);
 #endif
 	addr = (void **)calloc(malloc_max, sizeof(void *));
@@ -117,7 +117,7 @@ static int stress_malloc_child(const args_t *args, void *context)
 	}
 
 	do {
-		const unsigned int rnd = mwc32();
+		const unsigned int rnd = stress_mwc32();
 		const unsigned int i = rnd % malloc_max;
 		const unsigned int action = (rnd >> 12) & 1;
 		const unsigned int do_calloc = (rnd >> 14) & 0x1f;
@@ -182,12 +182,12 @@ abort:
  *	stress malloc by performing a mix of
  *	allocation and frees
  */
-static int stress_malloc(const args_t *args)
+static int stress_malloc(const stress_args_t *args)
 {
 	return stress_oomable_child(args, NULL, stress_malloc_child, STRESS_OOMABLE_NORMAL);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_malloc_threshold,	stress_set_malloc_threshold },
 	{ OPT_malloc_max,	stress_set_malloc_max },
 	{ OPT_malloc_bytes,	stress_set_malloc_bytes },
