@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"matrix-3d N",		"start N workers exercising 3D matrix operations" },
 	{ NULL,	"matrix-3d-ops N",	"stop after N 3D maxtrix bogo operations" },
 	{ NULL,	"matrix-3d-method M",	"specify 3D matrix stress method M, default is all" },
@@ -58,10 +58,10 @@ static int stress_set_matrix_3d_size(const char *opt)
 {
 	size_t matrix_3d_size;
 
-	matrix_3d_size = get_uint64(opt);
-	check_range("matrix-3d-size", matrix_3d_size,
+	matrix_3d_size = stress_get_uint64(opt);
+	stress_check_range("matrix-3d-size", matrix_3d_size,
 		MIN_MATRIX3D_SIZE, MAX_MATRIX3D_SIZE);
-	return set_setting("matrix-3d-size", TYPE_ID_SIZE_T, &matrix_3d_size);
+	return stress_set_setting("matrix-3d-size", TYPE_ID_SIZE_T, &matrix_3d_size);
 }
 
 static int stress_set_matrix_3d_zyx(const char *opt)
@@ -70,7 +70,7 @@ static int stress_set_matrix_3d_zyx(const char *opt)
 
         (void)opt;
 
-        return set_setting("matrix-3d-zyx", TYPE_ID_SIZE_T, &matrix_3d_zyx);
+        return stress_set_setting("matrix-3d-zyx", TYPE_ID_SIZE_T, &matrix_3d_zyx);
 }
 
 /*
@@ -444,7 +444,7 @@ static void OPTIMIZE3 TARGET_CLONES stress_matrix_3d_xyz_frobenius(
 				return;
 		}
 	}
-	double_put(sum);
+	stress_double_put(sum);
 }
 
 /*
@@ -476,7 +476,7 @@ static void OPTIMIZE3 TARGET_CLONES stress_matrix_3d_zyx_frobenius(
 				return;
 		}
 	}
-	double_put(sum);
+	stress_double_put(sum);
 }
 
 /*
@@ -834,7 +834,7 @@ static const stress_matrix_3d_method_info_t *stress_get_matrix_3d_method(
 
 	for (info = matrix_3d_methods; info->name; info++) {
 		if (!strcmp(info->name, name)) {
-			set_setting("matrix-3d-method", TYPE_ID_STR, name);
+			stress_set_setting("matrix-3d-method", TYPE_ID_STR, name);
 			return info;
 		}
 	}
@@ -861,7 +861,7 @@ static int stress_set_matrix_3d_method(const char *name)
 
 	info = stress_get_matrix_3d_method(name);
 	if (info) {
-		set_setting("matrix-3d-method", TYPE_ID_STR, name);
+		stress_set_setting("matrix-3d-method", TYPE_ID_STR, name);
 		return 0;
 	}
 	stress_matrix_3d_method_error();
@@ -877,7 +877,7 @@ static inline size_t round_up(size_t page_size, size_t n)
 }
 
 static inline int stress_matrix_3d_exercise(
-	const args_t *args,
+	const stress_args_t *args,
 	const stress_matrix_3d_func func,
 	const size_t n)
 {
@@ -922,8 +922,8 @@ static inline int stress_matrix_3d_exercise(
 			register size_t k;
 
 			for (k = 0; k < n; k++) {
-				a[i][j][k] = (stress_matrix_3d_type_t)mwc64() * v;
-				b[i][j][k] = (stress_matrix_3d_type_t)mwc64() * v;
+				a[i][j][k] = (stress_matrix_3d_type_t)stress_mwc64() * v;
+				b[i][j][k] = (stress_matrix_3d_type_t)stress_mwc64() * v;
 				r[i][j][k] = 0.0;
 			}
 		}
@@ -939,11 +939,11 @@ static inline int stress_matrix_3d_exercise(
 
 	ret = EXIT_SUCCESS;
 
-	munmap((void *)r, matrix_3d_size);
+	(void)munmap((void *)r, matrix_3d_size);
 tidy_b:
-	munmap((void *)b, matrix_3d_size);
+	(void)munmap((void *)b, matrix_3d_size);
 tidy_a:
-	munmap((void *)a, matrix_3d_size);
+	(void)munmap((void *)a, matrix_3d_size);
 tidy_ret:
 	return ret;
 }
@@ -952,7 +952,7 @@ tidy_ret:
  *  stress_matrix()
  *	stress CPU by doing floating point math ops
  */
-static int stress_matrix(const args_t *args)
+static int stress_matrix(const stress_args_t *args)
 {
 	char *matrix_3d_method_name;
 	const stress_matrix_3d_method_info_t *matrix_3d_method;
@@ -960,8 +960,8 @@ static int stress_matrix(const args_t *args)
 	size_t matrix_3d_size = 128;
 	size_t matrix_3d_yx = 0;
 
-	(void)get_setting("matrix-3d-method", &matrix_3d_method_name);
-	(void)get_setting("matrix-3d-zyx", &matrix_3d_yx);
+	(void)stress_get_setting("matrix-3d-method", &matrix_3d_method_name);
+	(void)stress_get_setting("matrix-3d-zyx", &matrix_3d_yx);
 
 	matrix_3d_method = stress_get_matrix_3d_method(matrix_3d_method_name);
 	if (!matrix_3d_method) {
@@ -975,7 +975,7 @@ static int stress_matrix(const args_t *args)
 		pr_dbg("%s using method '%s' (%s)\n", args->name, matrix_3d_method->name,
 			matrix_3d_yx ? "z by y by x" : "x by y by z");
 
-	if (!get_setting("matrix-3d-size", &matrix_3d_size)) {
+	if (!stress_get_setting("matrix-3d-size", &matrix_3d_size)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			matrix_3d_size = MAX_MATRIX_SIZE;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -990,7 +990,7 @@ static void stress_matrix_3d_set_default(void)
 	stress_set_matrix_3d_method("all");
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_matrix_3d_method,	stress_set_matrix_3d_method },
 	{ OPT_matrix_3d_size,	stress_set_matrix_3d_size },
 	{ OPT_matrix_3d_zyx,	stress_set_matrix_3d_zyx },
