@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"matrix N",		"start N workers exercising matrix operations" },
 	{ NULL,	"matrix-ops N",		"stop after N maxtrix bogo operations" },
 	{ NULL,	"matrix-method M",	"specify matrix stress method M, default is all" },
@@ -57,10 +57,10 @@ static int stress_set_matrix_size(const char *opt)
 {
 	size_t matrix_size;
 
-	matrix_size = get_uint64(opt);
-	check_range("matrix-size", matrix_size,
+	matrix_size = stress_get_uint64(opt);
+	stress_check_range("matrix-size", matrix_size,
 		MIN_MATRIX_SIZE, MAX_MATRIX_SIZE);
-	return set_setting("matrix-size", TYPE_ID_SIZE_T, &matrix_size);
+	return stress_set_setting("matrix-size", TYPE_ID_SIZE_T, &matrix_size);
 }
 
 static int stress_set_matrix_yx(const char *opt)
@@ -69,7 +69,7 @@ static int stress_set_matrix_yx(const char *opt)
 
 	(void)opt;
 
-	return set_setting("matrix-yx", TYPE_ID_SIZE_T, &matrix_yx);
+	return stress_set_setting("matrix-yx", TYPE_ID_SIZE_T, &matrix_yx);
 }
 
 /*
@@ -445,7 +445,7 @@ static void OPTIMIZE3 TARGET_CLONES stress_matrix_xy_frobenius(
 		if (UNLIKELY(!keep_stressing_flag()))
 			return;
 	}
-	double_put(sum);
+	stress_double_put(sum);
 }
 
 /*
@@ -473,7 +473,7 @@ static void OPTIMIZE3 TARGET_CLONES stress_matrix_yx_frobenius(
 		if (UNLIKELY(!keep_stressing_flag()))
 			return;
 	}
-	double_put(sum);
+	stress_double_put(sum);
 }
 
 /*
@@ -852,7 +852,7 @@ static const stress_matrix_method_info_t *stress_get_matrix_method(
 
 	for (info = matrix_methods; info->name; info++) {
 		if (!strcmp(info->name, name)) {
-			set_setting("matrix-method", TYPE_ID_STR, name);
+			stress_set_setting("matrix-method", TYPE_ID_STR, name);
 			return info;
 		}
 	}
@@ -879,7 +879,7 @@ static int stress_set_matrix_method(const char *name)
 
 	info = stress_get_matrix_method(name);
 	if (info) {
-		set_setting("matrix-method", TYPE_ID_STR, name);
+		stress_set_setting("matrix-method", TYPE_ID_STR, name);
 		return 0;
 	}
 	stress_matrix_method_error();
@@ -895,7 +895,7 @@ static inline size_t round_up(size_t page_size, size_t n)
 }
 
 static inline int stress_matrix_exercise(
-	const args_t *args,
+	const stress_args_t *args,
 	const stress_matrix_func func,
 	const size_t n)
 {
@@ -937,8 +937,8 @@ static inline int stress_matrix_exercise(
 		register size_t j;
 
 		for (j = 0; j < n; j++) {
-			a[i][j] = (stress_matrix_type_t)mwc64() * v;
-			b[i][j] = (stress_matrix_type_t)mwc64() * v;
+			a[i][j] = (stress_matrix_type_t)stress_mwc64() * v;
+			b[i][j] = (stress_matrix_type_t)stress_mwc64() * v;
 			r[i][j] = 0.0;
 		}
 	}
@@ -953,11 +953,11 @@ static inline int stress_matrix_exercise(
 
 	ret = EXIT_SUCCESS;
 
-	munmap((void *)r, matrix_size);
+	(void)munmap((void *)r, matrix_size);
 tidy_b:
-	munmap((void *)b, matrix_size);
+	(void)munmap((void *)b, matrix_size);
 tidy_a:
-	munmap((void *)a, matrix_size);
+	(void)munmap((void *)a, matrix_size);
 tidy_ret:
 	return ret;
 }
@@ -966,7 +966,7 @@ tidy_ret:
  *  stress_matrix()
  *	stress CPU by doing floating point math ops
  */
-static int stress_matrix(const args_t *args)
+static int stress_matrix(const stress_args_t *args)
 {
 	char *matrix_method_name;
 	const stress_matrix_method_info_t *matrix_method;
@@ -974,8 +974,8 @@ static int stress_matrix(const args_t *args)
 	size_t matrix_size = 128;
 	size_t matrix_yx = 0;
 
-	(void)get_setting("matrix-method", &matrix_method_name);
-	(void)get_setting("matrix-yx", &matrix_yx);
+	(void)stress_get_setting("matrix-method", &matrix_method_name);
+	(void)stress_get_setting("matrix-yx", &matrix_yx);
 
 	matrix_method = stress_get_matrix_method(matrix_method_name);
 	if (!matrix_method) {
@@ -989,7 +989,7 @@ static int stress_matrix(const args_t *args)
 		pr_dbg("%s using method '%s' (%s)\n", args->name, matrix_method->name,
 			matrix_yx ? "y by x" : "x by y");
 
-	if (!get_setting("matrix-size", &matrix_size)) {
+	if (!stress_get_setting("matrix-size", &matrix_size)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			matrix_size = MAX_MATRIX_SIZE;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -1004,7 +1004,7 @@ static void stress_matrix_set_default(void)
 	stress_set_matrix_method("all");
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_matrix_method,	stress_set_matrix_method },
 	{ OPT_matrix_size,	stress_set_matrix_size },
 	{ OPT_matrix_yx,	stress_set_matrix_yx },
