@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"membarrier N",		"start N workers performing membarrier system calls" },
 	{ NULL,	"membarrier-ops N",	"stop after N membarrier bogo operations" },
 	{ NULL,	NULL,			NULL }
@@ -53,7 +53,7 @@ enum membarrier_cmd {
 
 #endif
 
-static int stress_membarrier_exercise(const args_t *args)
+static int stress_membarrier_exercise(const stress_args_t *args)
 {
 	int ret;
 	unsigned int i, mask;
@@ -76,8 +76,7 @@ static int stress_membarrier_exercise(const args_t *args)
 static void *stress_membarrier_thread(void *parg)
 {
 	static void *nowt = NULL;
-	uint8_t stack[SIGSTKSZ + STACK_ALIGNMENT];
-	const args_t *args = ((pthread_args_t *)parg)->args;
+	const stress_args_t *args = ((stress_pthread_args_t *)parg)->args;
 
 	/*
 	 *  Block all signals, let controlling thread
@@ -85,16 +84,6 @@ static void *stress_membarrier_thread(void *parg)
 	 */
 	(void)sigprocmask(SIG_BLOCK, &set, NULL);
 
-	/*
-	 *  According to POSIX.1 a thread should have
-	 *  a distinct alternative signal stack.
-	 *  However, we block signals in this thread
-	 *  so this is probably just totally unncessary.
-	 */
-	(void)memset(stack, 0, sizeof(stack));
-	if (stress_sigaltstack(stack, SIGSTKSZ) < 0)
-		return &nowt;
-
 	while (keep_running && keep_stressing_flag()) {
 		if (stress_membarrier_exercise(args) < 0)
 			break;
@@ -107,13 +96,13 @@ static void *stress_membarrier_thread(void *parg)
  *  stress on membarrier()
  *	stress system by IO sync calls
  */
-static int stress_membarrier(const args_t *args)
+static int stress_membarrier(const stress_args_t *args)
 {
 	int ret;
 	pthread_t pthreads[MAX_MEMBARRIER_THREADS];
 	size_t i;
 	int pthread_ret[MAX_MEMBARRIER_THREADS];
-	pthread_args_t pargs = { args, NULL, 0 };
+	stress_pthread_args_t pargs = { args, NULL, 0 };
 
 	ret = shim_membarrier(MEMBARRIER_CMD_QUERY, 0);
 	if (ret < 0) {
