@@ -26,7 +26,7 @@
 
 #define ALIGN_SIZE	(64)
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"memcpy N",	   "start N workers performing memory copies" },
 	{ NULL,	"memcpy-ops N",	   "stop after N memcpy bogo operations" },
 	{ NULL,	"memcpy-method M", "set memcpy method (M = all, libc, builtin, naive)" },
@@ -191,7 +191,7 @@ static int stress_set_memcpy_method(const char *name)
 
 	for (info = stress_memcpy_methods; info->func; info++) {
 		if (!strcmp(info->name, name)) {
-			set_setting("memcpy-method", TYPE_ID_UINTPTR_T, &info);
+			stress_set_setting("memcpy-method", TYPE_ID_UINTPTR_T, &info);
 			return 0;
 		}
 	}
@@ -214,7 +214,7 @@ static void stress_memcpy_set_default(void)
  *  stress_memcpy()
  *	stress memory copies
  */
-static int stress_memcpy(const args_t *args)
+static int stress_memcpy(const stress_args_t *args)
 {
 	static stress_buffer_t b;
 	uint8_t *b_str = g_shared->str_shared;
@@ -222,7 +222,7 @@ static int stress_memcpy(const args_t *args)
 	uint8_t *aligned_buf = stress_align_address(b.buffer, ALIGN_SIZE);
 	const stress_memcpy_method_info_t *memcpy_method = &stress_memcpy_methods[1];
 
-	(void)get_setting("memcpy-method", &memcpy_method);
+	(void)stress_get_setting("memcpy-method", &memcpy_method);
 
 	stress_strnrnd((char *)aligned_buf, ALIGN_SIZE);
 
@@ -234,7 +234,7 @@ static int stress_memcpy(const args_t *args)
 	return EXIT_SUCCESS;
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_memcpy_method,	stress_set_memcpy_method },
 	{ 0,			NULL }
 };
