@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"memfd N",	 "start N workers allocating memory with memfd_create" },
 	{ NULL,	"memfd-bytes N", "allocate N bytes for each stress iteration" },
 	{ NULL,	"memfd-fds N",	 "number of memory fds to open per stressors" },
@@ -40,10 +40,10 @@ static int stress_set_memfd_bytes(const char *opt)
 {
 	size_t memfd_bytes;
 
-	memfd_bytes = (size_t)get_uint64_byte_memory(opt, 1);
-	check_range_bytes("memfd-bytes", memfd_bytes,
+	memfd_bytes = (size_t)stress_get_uint64_byte_memory(opt, 1);
+	stress_check_range_bytes("memfd-bytes", memfd_bytes,
 		MIN_MEMFD_BYTES, MAX_MEM_LIMIT);
-	return set_setting("memfd-bytes", TYPE_ID_SIZE_T, &memfd_bytes);
+	return stress_set_setting("memfd-bytes", TYPE_ID_SIZE_T, &memfd_bytes);
 }
 
 /*
@@ -54,13 +54,13 @@ static int stress_set_memfd_fds(const char *opt)
 {
 	uint32_t memfd_fds;
 
-	memfd_fds = (uint32_t)get_uint64(opt);
-	check_range("memfd-fds", memfd_fds,
+	memfd_fds = (uint32_t)stress_get_uint64(opt);
+	stress_check_range("memfd-fds", memfd_fds,
 		MIN_MEMFD_FDS, MAX_MEMFD_FDS);
-	return set_setting("memfd-fds", TYPE_ID_UINT32, &memfd_fds);
+	return stress_set_setting("memfd-fds", TYPE_ID_UINT32, &memfd_fds);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_memfd_bytes,	stress_set_memfd_bytes },
 	{ OPT_memfd_fds,	stress_set_memfd_fds },
 	{ 0,			NULL }
@@ -71,7 +71,7 @@ static const opt_set_func_t opt_set_funcs[] = {
 /*
  *  Create allocations using memfd_create, ftruncate and mmap
  */
-static int stress_memfd_child(const args_t *args, void *context)
+static int stress_memfd_child(const stress_args_t *args, void *context)
 {
 	int *fds;
 	void **maps;
@@ -84,7 +84,7 @@ static int stress_memfd_child(const args_t *args, void *context)
 
 	(void)context;
 
-	if (!get_setting("memfd-bytes", &memfd_bytes)) {
+	if (!stress_get_setting("memfd-bytes", &memfd_bytes)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			memfd_bytes = MAX_32;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -94,7 +94,7 @@ static int stress_memfd_child(const args_t *args, void *context)
 	if (memfd_bytes < MIN_MEMFD_BYTES)
 		memfd_bytes = MIN_MEMFD_BYTES;
 
-	(void)get_setting("memfd-fds", &memfd_fds);
+	(void)stress_get_setting("memfd-fds", &memfd_fds);
 
 	size = memfd_bytes / memfd_fds;
 
@@ -183,7 +183,7 @@ static int stress_memfd_child(const args_t *args, void *context)
 			/*
 			 *  ..and punch a hole
 			 */
-			whence = (mwc32() % size) & ~(page_size - 1);
+			whence = (stress_mwc32() % size) & ~(page_size - 1);
 			ret = shim_fallocate(fds[i], FALLOC_FL_PUNCH_HOLE |
 				FALLOC_FL_KEEP_SIZE, whence, page_size);
 			(void)ret;
@@ -249,7 +249,7 @@ clean:
  *  stress_memfd()
  *	stress memfd
  */
-static int stress_memfd(const args_t *args)
+static int stress_memfd(const stress_args_t *args)
 {
 	return stress_oomable_child(args, NULL, stress_memfd_child, STRESS_OOMABLE_NORMAL);
 }
