@@ -29,7 +29,7 @@ typedef struct {
 	bool timeout;
 } stress_mem_info_t;
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"memhotplug N",	"start N workers that exercise memory hotplug" },
 	{ NULL,	"memhotplug-ops N",	"stop after N memory hotplug operations" },
 	{ NULL,	NULL,		NULL }
@@ -152,7 +152,7 @@ static void stress_memhotplug_mem_online(stress_mem_info_t *mem_info)
  *  stress_memhotplug()
  *	stress the linux memory hotplug subsystem
  */
-static int stress_memhotplug(const args_t *args)
+static int stress_memhotplug(const stress_args_t *args)
 {
 	DIR *dir;
         struct dirent *d;
@@ -186,6 +186,7 @@ static int stress_memhotplug(const args_t *args)
 	mem_info = calloc(n, sizeof(*mem_info));
 	if (!mem_info) {
 		pr_inf("%s: out of memory\n", args->name);
+		(void)closedir(dir);
 		return EXIT_NO_RESOURCE;
 	}
 
