@@ -26,7 +26,7 @@
 
 #define STRESS_NANOSEC		(1000000000)
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"memrate N",		"start N workers exercised memory read/writes" },
 	{ NULL,	"memrate-ops N",	"stop after N memrate bogo operations" },
 	{ NULL,	"memrate-bytes N",	"size of memory buffer being exercised" },
@@ -58,30 +58,30 @@ static int stress_set_memrate_bytes(const char *opt)
 {
 	uint64_t memrate_bytes;
 
-	memrate_bytes = get_uint64_byte(opt);
-	check_range_bytes("memrate-bytes", memrate_bytes,
+	memrate_bytes = stress_get_uint64_byte(opt);
+	stress_check_range_bytes("memrate-bytes", memrate_bytes,
 		MIN_MEMRATE_BYTES, MAX_MEMRATE_BYTES);
-	return set_setting("memrate-bytes", TYPE_ID_UINT64, &memrate_bytes);
+	return stress_set_setting("memrate-bytes", TYPE_ID_UINT64, &memrate_bytes);
 }
 
 static int stress_set_memrate_rd_mbs(const char *opt)
 {
 	uint64_t memrate_rd_mbs;
 
-	memrate_rd_mbs = get_uint64(opt);
-	check_range_bytes("memrate-rd-mbs", memrate_rd_mbs,
+	memrate_rd_mbs = stress_get_uint64(opt);
+	stress_check_range_bytes("memrate-rd-mbs", memrate_rd_mbs,
 		1, 1000000);
-	return set_setting("memrate-rd-mbs", TYPE_ID_UINT64, &memrate_rd_mbs);
+	return stress_set_setting("memrate-rd-mbs", TYPE_ID_UINT64, &memrate_rd_mbs);
 }
 
 static int stress_set_memrate_wr_mbs(const char *opt)
 {
 	uint64_t memrate_wr_mbs;
 
-	memrate_wr_mbs = get_uint64(opt);
-	check_range_bytes("memrate-wr-mbs", memrate_wr_mbs,
+	memrate_wr_mbs = stress_get_uint64(opt);
+	stress_check_range_bytes("memrate-wr-mbs", memrate_wr_mbs,
 		1, 1000000);
-	return set_setting("memrate-wr-mbs", TYPE_ID_UINT64, &memrate_wr_mbs);
+	return stress_set_setting("memrate-wr-mbs", TYPE_ID_UINT64, &memrate_wr_mbs);
 }
 
 #define STRESS_MEMRATE_READ(size)				\
@@ -214,10 +214,10 @@ static void OPTIMIZE3 stress_memrate_init_data(
 	register volatile uint32_t *ptr;
 
 	for (ptr = start; ptr < (uint32_t *)end; ptr++)
-		*ptr = mwc32();
+		*ptr = stress_mwc32();
 }
 
-static inline void *stress_memrate_mmap(const args_t *args, uint64_t sz)
+static inline void *stress_memrate_mmap(const stress_args_t *args, uint64_t sz)
 {
 	void *ptr;
 
@@ -240,7 +240,7 @@ static inline void *stress_memrate_mmap(const args_t *args, uint64_t sz)
 #if defined(HAVE_MADVISE)
 		int ret, advice = MADV_NORMAL;
 
-		(void)get_setting("memrate-madvise", &advice);
+		(void)stress_get_setting("memrate-madvise", &advice);
 
 		ret = madvise(ptr, sz, advice);
 		(void)ret;
@@ -249,7 +249,7 @@ static inline void *stress_memrate_mmap(const args_t *args, uint64_t sz)
 	return ptr;
 }
 
-static int stress_memrate_child(const args_t *args, void *ctxt)
+static int stress_memrate_child(const stress_args_t *args, void *ctxt)
 {
 	const stress_memrate_context_t *context = (stress_memrate_context_t *)ctxt;
 	void *buffer, *buffer_end;
@@ -289,7 +289,7 @@ static int stress_memrate_child(const args_t *args, void *ctxt)
  *  stress_memrate()
  *	stress cache/memory/CPU with memrate stressors
  */
-static int stress_memrate(const args_t *args)
+static int stress_memrate(const stress_args_t *args)
 {
 	int rc;
 	size_t i, stats_size;
@@ -300,9 +300,9 @@ static int stress_memrate(const args_t *args)
 	context.memrate_rd_mbs = ~0;
 	context.memrate_wr_mbs = ~0;
 
-	(void)get_setting("memrate-bytes", &context.memrate_bytes);
-	(void)get_setting("memrate-rd-mbs", &context.memrate_rd_mbs);
-	(void)get_setting("memrate-wr-mbs", &context.memrate_wr_mbs);
+	(void)stress_get_setting("memrate-bytes", &context.memrate_bytes);
+	(void)stress_get_setting("memrate-rd-mbs", &context.memrate_rd_mbs);
+	(void)stress_get_setting("memrate-wr-mbs", &context.memrate_wr_mbs);
 
 	stats_size = memrate_items * sizeof(stress_memrate_stats_t);
 	stats_size = (stats_size + args->page_size - 1) & ~(args->page_size - 1);
@@ -337,7 +337,7 @@ static int stress_memrate(const args_t *args)
 	return rc;
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_memrate_bytes,	stress_set_memrate_bytes },
 	{ OPT_memrate_rd_mbs,	stress_set_memrate_rd_mbs },
 	{ OPT_memrate_wr_mbs,	stress_set_memrate_wr_mbs },
