@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"memthrash N",		"start N workers thrashing a 16MB memory buffer" },
 	{ NULL,	"memthrash-ops N",	"stop after N memthrash bogo operations" },
 	{ NULL,	"memthrash-method M",	"specify memthrash method M, default is all" },
@@ -38,7 +38,7 @@ static const help_t help[] = {
 #define MATRIX_SIZE		(1 << MATRIX_SIZE_MAX_SHIFT)
 #define MEM_SIZE		(MATRIX_SIZE * MATRIX_SIZE)
 
-typedef void (*stress_memthrash_func_t)(const args_t *args, size_t mem_size);
+typedef void (*stress_memthrash_func_t)(const stress_args_t *args, size_t mem_size);
 
 typedef struct {
 	const char		*name;	/* human readable form of stressor */
@@ -56,8 +56,8 @@ static void *mem;
 static volatile bool thread_terminate;
 static sigset_t set;
 
-#if (((defined(__GNUC__) || defined(__clang__)) && defined(STRESS_X86)) || \
-    (defined(__GNUC__) && NEED_GNUC(4,7,0) && defined(STRESS_ARM)))
+#if (((defined(__GNUC__) || defined(__clang__)) && defined(STRESS_ARCH_X86)) || \
+    (defined(__GNUC__) && NEED_GNUC(4,7,0) && defined(STRESS_ARCH_ARM)))
 #if defined(__GNUC__) && NEED_GNUC(4,7,0)
 #define MEM_LOCK(ptr)	 __atomic_add_fetch(ptr, 1, __ATOMIC_SEQ_CST);
 #else
@@ -70,34 +70,34 @@ static inline HOT OPTIMIZE3 void stress_memthrash_random_chunk(
 	const size_t mem_size)
 {
 	uint32_t i;
-	const uint32_t max = mwc16();
+	const uint32_t max = stress_mwc16();
 	size_t chunks = mem_size / chunk_size;
 
 	if (chunks < 1)
 		chunks = 1;
 
 	for (i = 0; !thread_terminate && (i < max); i++) {
-		const size_t chunk = mwc32() % chunks;
+		const size_t chunk = stress_mwc32() % chunks;
 		const size_t offset = chunk * chunk_size;
 		void *ptr = (void *)(((uint8_t *)mem) + offset);
-		
+
 #if defined(__GNUC__)
-		(void)__builtin_memset(ptr, mwc8(), chunk_size);
+		(void)__builtin_memset(ptr, stress_mwc8(), chunk_size);
 #else
-		(void)memset(ptr, mwc8(), chunk_size);
+		(void)memset(ptr, stress_mwc8(), chunk_size);
 #endif
 	}
 }
 
 static void HOT OPTIMIZE3 stress_memthrash_random_chunkpage(
-	const args_t *args,
+	const stress_args_t *args,
 	const size_t mem_size)
 {
 	stress_memthrash_random_chunk(args->page_size, mem_size);
 }
 
 static void HOT OPTIMIZE3 stress_memthrash_random_chunk256(
-	const args_t *args,
+	const stress_args_t *args,
 	const size_t mem_size)
 {
 	(void)args;
@@ -106,7 +106,7 @@ static void HOT OPTIMIZE3 stress_memthrash_random_chunk256(
 }
 
 static void HOT OPTIMIZE3 stress_memthrash_random_chunk64(
-	const args_t *args,
+	const stress_args_t *args,
 	const size_t mem_size)
 {
 	(void)args;
@@ -115,7 +115,7 @@ static void HOT OPTIMIZE3 stress_memthrash_random_chunk64(
 }
 
 static void HOT OPTIMIZE3 stress_memthrash_random_chunk8(
-	const args_t *args,
+	const stress_args_t *args,
 	const size_t mem_size)
 {
 	(void)args;
@@ -124,7 +124,7 @@ static void HOT OPTIMIZE3 stress_memthrash_random_chunk8(
 }
 
 static void HOT OPTIMIZE3 stress_memthrash_random_chunk1(
-	const args_t *args,
+	const stress_args_t *args,
 	const size_t mem_size)
 {
 	(void)args;
@@ -133,20 +133,20 @@ static void HOT OPTIMIZE3 stress_memthrash_random_chunk1(
 }
 
 static void stress_memthrash_memset(
-	const args_t *args,
+	const stress_args_t *args,
 	const size_t mem_size)
 {
 	(void)args;
 
 #if defined(__GNUC__)
-	(void)__builtin_memset((void *)mem, mwc8(), mem_size);
+	(void)__builtin_memset((void *)mem, stress_mwc8(), mem_size);
 #else
-	(void)memset((void *)mem, mwc8(), mem_size);
+	(void)memset((void *)mem, stress_mwc8(), mem_size);
 #endif
 }
 
 static void HOT OPTIMIZE3 stress_memthrash_flip_mem(
-	const args_t *args,
+	const stress_args_t *args,
 	const size_t mem_size)
 {
 	(void)args;
@@ -161,12 +161,12 @@ static void HOT OPTIMIZE3 stress_memthrash_flip_mem(
 }
 
 static void HOT OPTIMIZE3 stress_memthrash_swap(
-	const args_t *args,
+	const stress_args_t *args,
 	const size_t mem_size)
 {
 	size_t i;
-	register size_t offset1 = mwc32() % mem_size;
-	register size_t offset2 = mwc32() % mem_size;
+	register size_t offset1 = stress_mwc32() % mem_size;
+	register size_t offset2 = stress_mwc32() % mem_size;
 	uint8_t *mem_u8 = (uint8_t *)mem;
 
 	(void)args;
@@ -188,7 +188,7 @@ static void HOT OPTIMIZE3 stress_memthrash_swap(
 }
 
 static void HOT OPTIMIZE3 stress_memthrash_matrix(
-	const args_t *args,
+	const stress_args_t *args,
 	const size_t mem_size)
 {
 	(void)args;
@@ -197,7 +197,7 @@ static void HOT OPTIMIZE3 stress_memthrash_matrix(
 	size_t i, j;
 	volatile uint8_t *vmem = mem;
 
-	for (i = 0; !thread_terminate && (i < MATRIX_SIZE); i+= ((mwc8() & 0xf) + 1)) {
+	for (i = 0; !thread_terminate && (i < MATRIX_SIZE); i+= ((stress_mwc8() & 0xf) + 1)) {
 		for (j = 0; j < MATRIX_SIZE; j+= 16) {
 			size_t i1 = (i * MATRIX_SIZE) + j;
 			size_t i2 = (j * MATRIX_SIZE) + i;
@@ -211,16 +211,16 @@ static void HOT OPTIMIZE3 stress_memthrash_matrix(
 }
 
 static void HOT OPTIMIZE3 stress_memthrash_prefetch(
-	const args_t *args,
+	const stress_args_t *args,
 	const size_t mem_size)
 {
 	uint32_t i;
-	const uint32_t max = mwc16();
+	const uint32_t max = stress_mwc16();
 
 	(void)args;
 
 	for (i = 0; !thread_terminate && (i < max); i++) {
-		size_t offset = mwc32() % mem_size;
+		size_t offset = stress_mwc32() % mem_size;
 		uint8_t *const ptr = ((uint8_t *)mem) + offset;
 		volatile uint8_t *const vptr = ptr;
 
@@ -231,45 +231,45 @@ static void HOT OPTIMIZE3 stress_memthrash_prefetch(
 }
 
 static void HOT OPTIMIZE3 stress_memthrash_flush(
-	const args_t *args,
+	const stress_args_t *args,
 	const size_t mem_size)
 {
 	uint32_t i;
-	const uint32_t max = mwc16();
+	const uint32_t max = stress_mwc16();
 
 	(void)args;
 
 	for (i = 0; !thread_terminate && (i < max); i++) {
-		size_t offset = mwc32() % mem_size;
+		size_t offset = stress_mwc32() % mem_size;
 		uint8_t *const ptr = ((uint8_t *)mem) + offset;
 		volatile uint8_t *const vptr = ptr;
 
 		*vptr = i & 0xff;
-		clflush(ptr);
+		shim_clflush(ptr);
 	}
 }
 
 static void HOT OPTIMIZE3 stress_memthrash_mfence(
-	const args_t *args,
+	const stress_args_t *args,
 	const size_t mem_size)
 {
 	uint32_t i;
-	const uint32_t max = mwc16();
+	const uint32_t max = stress_mwc16();
 
 	(void)args;
 
 	for (i = 0; !thread_terminate && (i < max); i++) {
-		size_t offset = mwc32() % mem_size;
+		size_t offset = stress_mwc32() % mem_size;
 		volatile uint8_t *ptr = ((uint8_t *)mem) + offset;
 
 		*ptr = i & 0xff;
-		mfence();
+		shim_mfence();
 	}
 }
 
 #if defined(MEM_LOCK)
 static void HOT OPTIMIZE3 stress_memthrash_lock(
-	const args_t *args,
+	const stress_args_t *args,
 	const size_t mem_size)
 {
 	uint32_t i;
@@ -277,7 +277,7 @@ static void HOT OPTIMIZE3 stress_memthrash_lock(
 	(void)args;
 
 	for (i = 0; !thread_terminate && (i < 64); i++) {
-		size_t offset = mwc32() % mem_size;
+		size_t offset = stress_mwc32() % mem_size;
 		volatile uint8_t *ptr = ((uint8_t *)mem) + offset;
 
 		MEM_LOCK(ptr);
@@ -286,11 +286,11 @@ static void HOT OPTIMIZE3 stress_memthrash_lock(
 #endif
 
 static void HOT OPTIMIZE3 stress_memthrash_spinread(
-	const args_t *args,
+	const stress_args_t *args,
 	const size_t mem_size)
 {
 	uint32_t i;
-	const size_t offset = mwc32() % mem_size;
+	const size_t offset = stress_mwc32() % mem_size;
 	volatile uint32_t *ptr = (uint32_t *)(((uint8_t *)mem) + offset);
 
 	(void)args;
@@ -309,11 +309,11 @@ static void HOT OPTIMIZE3 stress_memthrash_spinread(
 }
 
 static void HOT OPTIMIZE3 stress_memthrash_spinwrite(
-	const args_t *args,
+	const stress_args_t *args,
 	const size_t mem_size)
 {
 	uint32_t i;
-	const size_t offset = mwc32() % mem_size;
+	const size_t offset = stress_mwc32() % mem_size;
 	volatile uint32_t *ptr = (uint32_t *)(((uint8_t *)mem) + offset);
 
 	(void)args;
@@ -332,8 +332,8 @@ static void HOT OPTIMIZE3 stress_memthrash_spinwrite(
 }
 
 
-static void stress_memthrash_all(const args_t *args, size_t mem_size);
-static void stress_memthrash_random(const args_t *args, size_t mem_size);
+static void stress_memthrash_all(const stress_args_t *args, size_t mem_size);
+static void stress_memthrash_random(const stress_args_t *args, size_t mem_size);
 
 static const stress_memthrash_method_info_t memthrash_methods[] = {
 	{ "all",	stress_memthrash_all },		/* MUST always be first! */
@@ -358,7 +358,7 @@ static const stress_memthrash_method_info_t memthrash_methods[] = {
 	{ "swap",	stress_memthrash_swap }
 };
 
-static void stress_memthrash_all(const args_t *args, size_t mem_size)
+static void stress_memthrash_all(const stress_args_t *args, size_t mem_size)
 {
 	static size_t i = 1;
 	const double t = stress_time_now();
@@ -372,11 +372,11 @@ static void stress_memthrash_all(const args_t *args, size_t mem_size)
 		i = 1;
 }
 
-static void stress_memthrash_random(const args_t *args, size_t mem_size)
+static void stress_memthrash_random(const stress_args_t *args, size_t mem_size)
 {
 	/* loop until we find a good candidate */
 	for (;;) {
-		size_t i = mwc8() % SIZEOF_ARRAY(memthrash_methods);
+		size_t i = stress_mwc8() % SIZEOF_ARRAY(memthrash_methods);
 		const stress_memthrash_func_t func = (stress_memthrash_func_t)memthrash_methods[i].func;
 
 		/* Don't run stress_memthrash_random/all to avoid recursion */
@@ -399,7 +399,7 @@ static int stress_set_memthrash_method(const char *name)
 	for (i = 0; i < SIZEOF_ARRAY(memthrash_methods); i++) {
 		const stress_memthrash_method_info_t *info = &memthrash_methods[i];
 		if (!strcmp(memthrash_methods[i].name, name)) {
-			set_setting("memthrash-method", TYPE_ID_UINTPTR_T, &info);
+			stress_set_setting("memthrash-method", TYPE_ID_UINTPTR_T, &info);
 			return 0;
 		}
 	}
@@ -419,10 +419,9 @@ static int stress_set_memthrash_method(const char *name)
  */
 static void *stress_memthrash_func(void *arg)
 {
-	uint8_t stack[SIGSTKSZ + STACK_ALIGNMENT];
 	static void *nowt = NULL;
-	const pthread_args_t *parg = (pthread_args_t *)arg;
-	const args_t *args = parg->args;
+	const stress_pthread_args_t *parg = (stress_pthread_args_t *)arg;
+	const stress_args_t *args = parg->args;
 	const stress_memthrash_func_t func = (stress_memthrash_func_t)parg->data;
 
 	/*
@@ -431,16 +430,6 @@ static void *stress_memthrash_func(void *arg)
 	 */
 	(void)sigprocmask(SIG_BLOCK, &set, NULL);
 
-	/*
-	 *  According to POSIX.1 a thread should have
-	 *  a distinct alternative signal stack.
-	 *  However, we block signals in this thread
-	 *  so this is probably just totally unncessary.
-	 */
-	(void)memset(stack, 0, sizeof(stack));
-	if (stress_sigaltstack(stack, SIGSTKSZ) < 0)
-		goto die;
-
 	while (!thread_terminate && keep_stressing()) {
 		size_t j;
 
@@ -460,7 +449,6 @@ static void *stress_memthrash_func(void *arg)
 
 	/* Wait parent up, all done! */
 	(void)kill(args->pid, SIGALRM);
-die:
 	return &nowt;
 }
 
@@ -495,14 +483,14 @@ static inline char *plural(uint32_t n)
 	return n > 1 ? "s" : "";
 }
 
-static int stress_memthrash_child(const args_t *args, void *ctxt)
+static int stress_memthrash_child(const stress_args_t *args, void *ctxt)
 {
 	stress_memthrash_context_t *context = (stress_memthrash_context_t *)ctxt;
 	const uint32_t max_threads = context->max_threads;
 	uint32_t i;
 	pthread_t pthreads[max_threads];
 	int ret[max_threads];
-	pthread_args_t pargs;
+	stress_pthread_args_t pargs;
 
 	int flags = MAP_PRIVATE | MAP_ANONYMOUS;
 #if defined(MAP_POPULATE)
@@ -569,7 +557,7 @@ reap_mem:
  *  stress_memthrash()
  *	stress by creating pthreads
  */
-static int stress_memthrash(const args_t *args)
+static int stress_memthrash(const stress_args_t *args)
 {
 	stress_memthrash_context_t context;
 
@@ -577,7 +565,7 @@ static int stress_memthrash(const args_t *args)
 	context.max_threads = stress_memthrash_max(args->num_instances, context.total_cpus);
 	context.memthrash_method = &memthrash_methods[0];
 
-	(void)get_setting("memthrash-method", &context.memthrash_method);
+	(void)stress_get_setting("memthrash-method", &context.memthrash_method);
 
 	pr_dbg("%s: using method '%s'\n", args->name, context.memthrash_method->name);
 	if (args->instance == 0) {
@@ -598,7 +586,7 @@ static int stress_memthrash(const args_t *args)
 	return stress_oomable_child(args, &context, stress_memthrash_child, STRESS_OOMABLE_NORMAL);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_memthrash_method,	stress_set_memthrash_method },
 	{ 0,			NULL }
 };
@@ -619,7 +607,7 @@ static int stress_set_memthrash_method(const char *name)
 	return 0;
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_memthrash_method,	stress_set_memthrash_method },
 	{ 0,			NULL }
 };
