@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"mergesort N",		"start N workers merge sorting 32 bit random integers" },
 	{ NULL,	"mergesort-ops N",	"stop after N merge sort bogo operations" },
 	{ NULL,	"mergesort-size N",	"number of 32 bit integers to sort" },
@@ -44,13 +44,13 @@ static int stress_set_mergesort_size(const char *opt)
 {
 	uint64_t mergesort_size;
 
-	mergesort_size = get_uint64(opt);
-	check_range("mergesort-size", mergesort_size,
+	mergesort_size = stress_get_uint64(opt);
+	stress_check_range("mergesort-size", mergesort_size,
 		MIN_MERGESORT_SIZE, MAX_MERGESORT_SIZE);
-	return set_setting("mergesort-size", TYPE_ID_UINT64, &mergesort_size);
+	return stress_set_setting("mergesort-size", TYPE_ID_UINT64, &mergesort_size);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_mergesort_integers,	stress_set_mergesort_size },
 	{ 0,				NULL }
 };
@@ -105,7 +105,7 @@ static int stress_mergesort_cmp_2(const void *p1, const void *p2)
  */
 static int stress_mergesort_cmp_3(const void *p1, const void *p2)
 {
-	int r = ((int)mwc8() % 3) - 1;
+	int r = ((int)stress_mwc8() % 3) - 1;
 
 	(void)p1;
 	(void)p2;
@@ -117,7 +117,7 @@ static int stress_mergesort_cmp_3(const void *p1, const void *p2)
  *  stress_mergesort()
  *	stress mergesort
  */
-static int stress_mergesort(const args_t *args)
+static int stress_mergesort(const stress_args_t *args)
 {
 	uint64_t mergesort_size = DEFAULT_MERGESORT_SIZE;
 	int32_t *data, *ptr;
@@ -125,7 +125,7 @@ static int stress_mergesort(const args_t *args)
 	struct sigaction old_action;
 	int ret;
 
-	if (!get_setting("mergesort-size", &mergesort_size)) {
+	if (!stress_get_setting("mergesort-size", &mergesort_size)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			mergesort_size = MAX_MERGESORT_SIZE;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -156,7 +156,7 @@ static int stress_mergesort(const args_t *args)
 
 	/* This is expensive, do it once */
 	for (ptr = data, i = 0; i < n; i++)
-		*ptr++ = mwc32();
+		*ptr++ = stress_mwc32();
 
 	do {
 		/* Sort "random" data */
