@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"mincore N",	  "start N workers exercising mincore" },
 	{ NULL,	"mincore-ops N",  "stop after N mincore bogo operations" },
 	{ NULL,	"mincore-random", "randomly select pages rather than linear scan" },
@@ -36,10 +36,10 @@ static int stress_set_mincore_rand(const char *opt)
 	bool mincore_rand = true;
 
 	(void)opt;
-	return set_setting("mincore-rand", TYPE_ID_BOOL, &mincore_rand);
+	return stress_set_setting("mincore-rand", TYPE_ID_BOOL, &mincore_rand);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_mincore_rand,     stress_set_mincore_rand },
 	{ 0,			NULL }
 };
@@ -52,14 +52,14 @@ static const opt_set_func_t opt_set_funcs[] = {
  *  stress_mincore()
  *	stress mincore system call
  */
-static int stress_mincore(const args_t *args)
+static int stress_mincore(const stress_args_t *args)
 {
 	uint8_t *addr = 0, *prev_addr = 0;
 	const size_t page_size = args->page_size;
 	const ptrdiff_t mask = ~(page_size - 1);
 	bool mincore_rand = false;
 
-	(void)get_setting("mincore-rand", &mincore_rand);
+	(void)stress_get_setting("mincore-rand", &mincore_rand);
 
 	do {
 		int i;
@@ -94,7 +94,7 @@ redo: 			errno = 0;
 				addr = (uint8_t *)(ptrdiff_t)
 					(((ptrdiff_t)addr >> 1) & mask);
 				if (addr == prev_addr)
-					addr = (uint8_t *)((ptrdiff_t)(mwc64() & mask));
+					addr = (uint8_t *)((ptrdiff_t)(stress_mwc64() & mask));
 				prev_addr = addr;
 			}
 			else
