@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"mknod N",	"start N workers that exercise mknod" },
 	{ NULL,	"mknod-ops N",	"stop after N mknod bogo operations" },
 	{ NULL,	NULL,		NULL }
@@ -49,7 +49,7 @@ static const int modes[] = {
  *	remove all files
  */
 static void stress_mknod_tidy(
-	const args_t *args,
+	const stress_args_t *args,
 	const uint64_t n)
 {
 	uint64_t i;
@@ -68,7 +68,7 @@ static void stress_mknod_tidy(
  *  stress_mknod
  *	stress mknod creates
  */
-static int stress_mknod(const args_t *args)
+static int stress_mknod(const stress_args_t *args)
 {
 	const size_t num_nodes = SIZEOF_ARRAY(modes);
 	int ret;
@@ -88,7 +88,7 @@ static int stress_mknod(const args_t *args)
 		for (i = 0; i < n; i++) {
 			char path[PATH_MAX];
 			const uint64_t gray_code = (i >> 1) ^ i;
-			int mode = modes[mwc32() % num_nodes];
+			int mode = modes[stress_mwc32() % num_nodes];
 
 			(void)stress_temp_filename_args(args,
 				path, sizeof(path), gray_code);
