@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"mlock N",	"start N workers exercising mlock/munlock" },
 	{ NULL,	"mlock-ops N",	"stop after N mlock bogo operations" },
 	{ NULL,	NULL,		NULL }
@@ -51,7 +51,7 @@ static int do_mlock(const void *addr, size_t len)
 	static bool use_mlock2 = true;
 
 	if (use_mlock2) {
-		uint32_t rnd = mwc32() >> 5;
+		uint32_t rnd = stress_mwc32() >> 5;
 		/* Randomly use mlock2 or mlock */
 		if (rnd & 1) {
 			const int flags = (rnd & 2) ?
@@ -79,7 +79,7 @@ static inline int do_mlock(const void *addr, size_t len)
 }
 #endif
 
-static int stress_mlock_child(const args_t *args, void *context)
+static int stress_mlock_child(const stress_args_t *args, void *context)
 {
 	size_t i, n;
 	uint8_t **mappings;
@@ -145,7 +145,7 @@ static int stress_mlock_child(const args_t *args, void *context)
 			 *  Attempt a bogos munlock, ignore failure
 			 */
 			(void)shim_munlock((void *)((uint8_t *)addr + page_size), 0);
-			munmap((void *)addr, page_size * 3);
+			(void)munmap((void *)addr, page_size * 3);
 		}
 #if defined(HAVE_MLOCKALL)
 #if defined(MCL_CURRENT)
@@ -172,7 +172,7 @@ static int stress_mlock_child(const args_t *args, void *context)
 		(void)shim_munlockall();
 #endif
 		for (i = 0; i < n;  i++)
-			munmap((void *)mappings[i], page_size);
+			(void)munmap((void *)mappings[i], page_size);
 	} while (keep_stressing());
 
 	free(mappings);
@@ -184,7 +184,7 @@ static int stress_mlock_child(const args_t *args, void *context)
  *  stress_mlock()
  *	stress mlock with pages being locked/unlocked
  */
-static int stress_mlock(const args_t *args)
+static int stress_mlock(const stress_args_t *args)
 {
 	return stress_oomable_child(args, NULL, stress_mlock_child, STRESS_OOMABLE_NORMAL);
 }
