@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"mmap N",	 "start N workers stressing mmap and munmap" },
 	{ NULL,	"mmap-ops N",	 "stop after N mmap bogo operations" },
 	{ NULL,	"mmap-async",	 "using asynchronous msyncs for file based mmap" },
@@ -91,6 +91,26 @@ static const int mmap_flags[] = {
 #endif
 #if defined(MAP_DENYWRITE)
 	MAP_DENYWRITE,
+#endif
+/* OpenBSD */
+#if defined(MAP_HASSEMAPHORE)
+	 MAP_HASSEMAPHORE,
+#endif
+/* OpenBSD */
+#if defined(MAP_INHERIT)
+	MAP_INHERIT,
+#endif
+/* FreeBSD */
+#if defined(MAP_NOCORE)
+	MAP_NOCORE,
+#endif
+/* FreeBSD */
+#if defined(MAP_NOSYNC)
+	MAP_NOSYNC,
+#endif
+/* FreeBSD */
+#if defined(MAP_PREFAULT_READ)
+	MAP_PREFAULT_READ,
 #endif
 	0
 };
@@ -99,10 +119,10 @@ static int stress_set_mmap_bytes(const char *opt)
 {
 	size_t mmap_bytes;
 
-	mmap_bytes = (size_t)get_uint64_byte_memory(opt, 1);
-	check_range_bytes("mmap-bytes", mmap_bytes,
+	mmap_bytes = (size_t)stress_get_uint64_byte_memory(opt, 1);
+	stress_check_range_bytes("mmap-bytes", mmap_bytes,
 		MIN_MMAP_BYTES, MAX_MEM_LIMIT);
-	return set_setting("mmap-bytes", TYPE_ID_SIZE_T, &mmap_bytes);
+	return stress_set_setting("mmap-bytes", TYPE_ID_SIZE_T, &mmap_bytes);
 }
 
 static int stress_set_mmap_mprotect(const char *opt)
@@ -110,7 +130,7 @@ static int stress_set_mmap_mprotect(const char *opt)
 	bool mmap_mprotect = true;
 
 	(void)opt;
-	return set_setting("mmap-mprotect", TYPE_ID_BOOL, &mmap_mprotect);
+	return stress_set_setting("mmap-mprotect", TYPE_ID_BOOL, &mmap_mprotect);
 }
 
 static int stress_set_mmap_file(const char *opt)
@@ -118,7 +138,7 @@ static int stress_set_mmap_file(const char *opt)
 	bool mmap_file = true;
 
 	(void)opt;
-	return set_setting("mmap-file", TYPE_ID_BOOL, &mmap_file);
+	return stress_set_setting("mmap-file", TYPE_ID_BOOL, &mmap_file);
 }
 
 static int stress_set_mmap_async(const char *opt)
@@ -126,7 +146,7 @@ static int stress_set_mmap_async(const char *opt)
 	bool mmap_async = true;
 
 	(void)opt;
-	return set_setting("mmap-async", TYPE_ID_BOOL, &mmap_async);
+	return stress_set_setting("mmap-async", TYPE_ID_BOOL, &mmap_async);
 }
 
 static int stress_set_mmap_osync(const char *opt)
@@ -134,7 +154,7 @@ static int stress_set_mmap_osync(const char *opt)
 	bool mmap_osync = true;
 
 	(void)opt;
-	return set_setting("mmap-osync", TYPE_ID_BOOL, &mmap_osync);
+	return stress_set_setting("mmap-osync", TYPE_ID_BOOL, &mmap_osync);
 }
 
 static int stress_set_mmap_odirect(const char *opt)
@@ -142,7 +162,7 @@ static int stress_set_mmap_odirect(const char *opt)
 	bool mmap_odirect = true;
 
 	(void)opt;
-	return set_setting("mmap-odirect", TYPE_ID_BOOL, &mmap_odirect);
+	return stress_set_setting("mmap-odirect", TYPE_ID_BOOL, &mmap_odirect);
 }
 
 /*
@@ -177,7 +197,7 @@ static void stress_mmap_mprotect(
 #endif
 }
 
-static int stress_mmap_child(const args_t *args, void *ctxt)
+static int stress_mmap_child(const stress_args_t *args, void *ctxt)
 {
 	stress_mmap_context_t *context = (stress_mmap_context_t *)ctxt;
 	const size_t page_size = args->page_size;
@@ -205,7 +225,7 @@ static int stress_mmap_child(const args_t *args, void *ctxt)
 
 	do {
 		size_t n;
-		const int rnd = mwc32() % SIZEOF_ARRAY(mmap_flags);
+		const int rnd = stress_mwc32() % SIZEOF_ARRAY(mmap_flags);
 		int rnd_flag = mmap_flags[rnd];
 		uint8_t *buf = NULL;
 
@@ -308,7 +328,7 @@ retry:
 		 */
 		(void)stress_mincore_touch_pages(buf, context->mmap_bytes);
 		for (n = pages4k; n; ) {
-			uint64_t j, i = mwc64() % pages4k;
+			uint64_t j, i = stress_mwc64() % pages4k;
 			for (j = 0; j < n; j++) {
 				uint64_t page = (i + j) % pages4k;
 				if (mapped[page] == PAGE_MAPPED) {
@@ -330,7 +350,7 @@ retry:
 		 *  Step #2, map them back in random order
 		 */
 		for (n = pages4k; n; ) {
-			uint64_t j, i = mwc64() % pages4k;
+			uint64_t j, i = stress_mwc64() % pages4k;
 
 			for (j = 0; j < n; j++) {
 				uint64_t page = (i + j) % pages4k;
@@ -345,7 +365,7 @@ retry:
 					 * track of failed mappings too
 					 */
 #if defined(MAP_FIXED_NOREPLACE)
-					if (mwc1())
+					if (stress_mwc1())
 						fixed_flags = MAP_FIXED_NOREPLACE;
 #endif
 					mappings[page] = (uint8_t *)mmap((void *)mappings[page],
@@ -407,7 +427,7 @@ cleanup:
  *  stress_mmap()
  *	stress mmap
  */
-static int stress_mmap(const args_t *args)
+static int stress_mmap(const stress_args_t *args)
 {
 	const size_t page_size = args->page_size;
 	char filename[PATH_MAX];
@@ -426,16 +446,16 @@ static int stress_mmap(const args_t *args)
 	context.flags |= MAP_POPULATE;
 #endif
 
-	(void)get_setting("mmap-async", &context.mmap_async);
-	(void)get_setting("mmap-file", &context.mmap_file);
-	(void)get_setting("mmap-mprotect", &context.mmap_mprotect);
-	(void)get_setting("mmap-osync", &mmap_osync);
-	(void)get_setting("mmap-odirect", &mmap_odirect);
+	(void)stress_get_setting("mmap-async", &context.mmap_async);
+	(void)stress_get_setting("mmap-file", &context.mmap_file);
+	(void)stress_get_setting("mmap-mprotect", &context.mmap_mprotect);
+	(void)stress_get_setting("mmap-osync", &mmap_osync);
+	(void)stress_get_setting("mmap-odirect", &mmap_odirect);
 
 	if (mmap_osync || mmap_odirect)
 		context.mmap_file = true;
 
-	if (!get_setting("mmap-bytes", &context.mmap_bytes)) {
+	if (!stress_get_setting("mmap-bytes", &context.mmap_bytes)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			context.mmap_bytes = MAX_32;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -457,7 +477,7 @@ static int stress_mmap(const args_t *args)
 			return exit_status(-rc);
 
 		(void)stress_temp_filename_args(args,
-			filename, sizeof(filename), mwc32());
+			filename, sizeof(filename), stress_mwc32());
 
 		if (mmap_odirect) {
 #if defined(O_DIRECT)
@@ -523,7 +543,7 @@ redo:
 	return ret;
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_mmap_async,	stress_set_mmap_async },
 	{ OPT_mmap_bytes,	stress_set_mmap_bytes },
 	{ OPT_mmap_file,	stress_set_mmap_file },
