@@ -26,7 +26,7 @@
 
 static volatile bool page_fault = false;
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"mmapaddr N",	  "start N workers stressing mmap with random addresses" },
 	{ NULL,	"mmapaddr-ops N", "stop after N mmapaddr bogo operations" },
 	{ NULL,	NULL,		  NULL }
@@ -43,7 +43,7 @@ static void stress_fault_handler(int signum)
  *  stress_mmapaddr_check()
  *	perform some quick sanity checks to see if page is mapped OK
  */
-static int stress_mmapaddr_check(const args_t *args, uint8_t *map_addr)
+static int stress_mmapaddr_check(const stress_args_t *args, uint8_t *map_addr)
 {
 	unsigned char vec[1];
 	volatile uint8_t val;
@@ -80,7 +80,7 @@ static int stress_mmapaddr_check(const args_t *args, uint8_t *map_addr)
  *	try to find an unmapp'd address
  */
 static void *stress_mmapaddr_get_addr(
-	const args_t *args,
+	const stress_args_t *args,
 	const uintptr_t mask,
 	const size_t page_size)
 {
@@ -91,7 +91,7 @@ static void *stress_mmapaddr_get_addr(
 		int ret;
 
 		vec[0] = 0;
-		addr = (void *)(intptr_t)(mwc64() & mask);
+		addr = (void *)(intptr_t)(stress_mwc64() & mask);
 		ret = shim_mincore(addr, page_size, vec);
 		if (ret == 0) {
 			addr = NULL;
@@ -112,7 +112,7 @@ static void *stress_mmapaddr_get_addr(
 	return addr;
 }
 
-static int stress_mmapaddr_child(const args_t *args, void *context)
+static int stress_mmapaddr_child(const stress_args_t *args, void *context)
 {
 	const size_t page_size = args->page_size;
 	const uintptr_t page_mask = ~(page_size - 1);
@@ -123,7 +123,7 @@ static int stress_mmapaddr_child(const args_t *args, void *context)
 	do {
 		uint8_t *addr, *map_addr, *remap_addr;
 		int flags;
-		uint8_t rnd = mwc8();
+		uint8_t rnd = stress_mwc8();
 #if defined(MAP_POPULATE)
 		const int mmap_flags = MAP_POPULATE | MAP_PRIVATE | MAP_ANONYMOUS;
 #else
@@ -191,7 +191,7 @@ unmap:
  *  stress_mmapaddr()
  *	stress mmap with randomly chosen addresses
  */
-static int stress_mmapaddr(const args_t *args)
+static int stress_mmapaddr(const stress_args_t *args)
 {
 	if (stress_sighandler(args->name, SIGSEGV, stress_fault_handler, NULL) < 0)
 		return EXIT_FAILURE;
