@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"mmapfixed N",		"start N workers stressing mmap with fixed mappings" },
 	{ NULL,	"mmapfixed-ops N",	"stop after N mmapfixed bogo operations" },
 	{ NULL,	NULL,			NULL }
@@ -51,7 +51,7 @@ static void MLOCKED_TEXT stress_sigsegv_handler(int signum)
 	_exit(0);
 }
 
-static int stress_mmapfixed_child(const args_t *args, void *context)
+static int stress_mmapfixed_child(const stress_args_t *args, void *context)
 {
 	const size_t page_size = args->page_size;
 	uintptr_t addr = MMAP_TOP;
@@ -66,24 +66,24 @@ static int stress_mmapfixed_child(const args_t *args, void *context)
 	do {
 		uint8_t *buf;
 		int flags = MAP_FIXED | MAP_ANONYMOUS;
-		size_t  sz = page_size * (1 + (mwc8() % 7));
+		size_t  sz = page_size * (1 + (stress_mwc8() % 7));
 
 #if defined(MAP_SHARED) && defined(MAP_PRIVATE)
-		flags |= mwc1() ? MAP_SHARED : MAP_PRIVATE;
+		flags |= stress_mwc1() ? MAP_SHARED : MAP_PRIVATE;
 #endif
 #if defined(MAP_LOCKED)
-		flags |= mwc1() ? MAP_LOCKED : 0;
+		flags |= stress_mwc1() ? MAP_LOCKED : 0;
 #endif
 #if defined(MAP_NORESERVE)
-		flags |= mwc1() ? MAP_NORESERVE : 0;
+		flags |= stress_mwc1() ? MAP_NORESERVE : 0;
 #endif
 #if defined(MAP_POPULATE)
-		flags |= mwc1() ? MAP_POPULATE : 0;
+		flags |= stress_mwc1() ? MAP_POPULATE : 0;
 #endif
 #if defined(MAP_FIXED_NOREPLACE)
 		/* 4.17 Linux flag */
 		flags &= ~MAP_FIXED;
-		flags |= mwc1() ? MAP_FIXED : MAP_FIXED_NOREPLACE;
+		flags |= stress_mwc1() ? MAP_FIXED : MAP_FIXED_NOREPLACE;
 #endif
 
 		if (!keep_stressing_flag())
@@ -126,7 +126,7 @@ next:
  *  stress_mmapfixed()
  *	stress mmap at fixed hinted addresses
  */
-static int stress_mmapfixed(const args_t *args)
+static int stress_mmapfixed(const stress_args_t *args)
 {
 	return stress_oomable_child(args, NULL, stress_mmapfixed_child, STRESS_OOMABLE_NORMAL);
 }
