@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"mmapfork N",	  "start N workers stressing many forked mmaps/munmaps" },
 	{ NULL,	"mmapfork-ops N", "stop after N mmapfork bogo operations" },
 	{ NULL,	NULL,		  NULL }
@@ -70,38 +70,81 @@ static void __strlcat(char *dst, char *src, size_t *n)
 	*n -= ln;
 }
 
+/*
+ *  should_terminate()
+ *	check that parent hasn't been OOM'd or it is time to die
+ */
+static inline bool should_terminate(const stress_args_t *args, const pid_t ppid)
+{
+	if ((kill(ppid, 0) < 0) && (errno == ESRCH))
+		return true;
+	return !keep_stressing();
+}
+
+#if defined(MADV_WIPEONFORK)
+/*
+ *  stress_memory_is_not_zero()
+ *	return true if memory is non-zero
+ */
+static bool stress_memory_is_not_zero(uint8_t *ptr, const size_t size)
+{
+	size_t i;
+
+	for (i = 0; i < size; i++)
+		if (ptr[i])
+			return true;
+	return false;
+}
+#endif
+
 /*
  *  stress_mmapfork()
  *	stress mappings + fork VM subystem
  */
-static int stress_mmapfork(const args_t *args)
+static int stress_mmapfork(const stress_args_t *args)
 {
 	pid_t pids[MAX_PIDS];
 	struct sysinfo info;
 	void *ptr;
 	uint64_t segv_count = 0;
 	int8_t segv_reasons = 0;
+#if defined(MADV_WIPEONFORK)
+	uint8_t *wipe_ptr;
+	const size_t wipe_size = args->page_size;
+	bool wipe_ok = false;
+#endif
+
+#if defined(MADV_WIPEONFORK)
+	/*
+	 *  Setup a page that should be wiped if MADV_WIPEONFORK works
+	 */
+	wipe_ptr = mmap(NULL, wipe_size, PROT_READ | PROT_WRITE,
+		MAP_PRIVATE | MAP_ANONYMOUS, -1, 0);
+	if (wipe_ptr != MAP_FAILED) {
+		(void)memset(wipe_ptr, 0xff, wipe_size);
+		if (shim_madvise(wipe_ptr, wipe_size, MADV_WIPEONFORK) == 0)
+			wipe_ok = true;
+	}
+#endif
 
 	do {
-		size_t i, n, len;
+		size_t i, len;
 
-		(void)memset(pids, 0, sizeof(pids));
+		for (i = 0; i < MAX_PIDS; i++)
+			pids[i] = -1;
 
-		for (n = 0; n < MAX_PIDS; n++) {
-retry:			if (!keep_stressing_flag())
+		for (i = 0; i < MAX_PIDS; i++) {
+			if (!keep_stressing())
 				goto reap;
 
-			pids[n] = fork();
-			if (pids[n] < 0) {
-				/* Out of resources for fork, re-do, ugh */
-				if ((errno == EAGAIN) || (errno == ENOMEM)) {
-					(void)shim_usleep(10000);
-					goto retry;
-				}
+			pids[i] = fork();
+			/* Out of resources for fork?, do a reap */
+			if (pids[i] < 0)
 				break;
-			}
-			if (pids[n] == 0) {
+			if (pids[i] == 0) {
 				/* Child */
+				const pid_t ppid = getppid();
+
 				(void)setpgid(0, g_pgrp);
 				stress_parent_died_alarm();
 
@@ -112,38 +155,64 @@ retry:			if (!keep_stressing_flag())
 					pr_fail_err("sysinfo");
 					_exit(_EXIT_FAILURE);
 				}
+#if defined(MADV_WIPEONFORK)
+				if (wipe_ok && (wipe_ptr != MAP_FAILED) &&
+				    stress_memory_is_not_zero(wipe_ptr, wipe_size)) {
+					pr_fail("%s: madvise MADV_WIPEONFORK didn't wipe page %p\n",
+						args->name, wipe_ptr);
+					_exit(_EXIT_FAILURE);
+				}
+#endif
 
 				len = ((size_t)info.freeram / (args->num_instances * MAX_PIDS)) / 2;
 				segv_ret = _EXIT_SEGV_MMAP;
 				ptr = mmap(NULL, len, PROT_READ | PROT_WRITE,
 					MAP_POPULATE | MAP_SHARED | MAP_ANONYMOUS, -1, 0);
 				if (ptr != MAP_FAILED) {
+					if (should_terminate(args, ppid))
+						_exit(EXIT_SUCCESS);
 					segv_ret = _EXIT_SEGV_MADV_WILLNEED;
 					(void)shim_madvise(ptr, len, MADV_WILLNEED);
 
+					if (should_terminate(args, ppid))
+						_exit(EXIT_SUCCESS);
 					segv_ret = _EXIT_SEGV_MEMSET;
 					(void)memset(ptr, 0, len);
 
+					if (should_terminate(args, ppid))
+						_exit(EXIT_SUCCESS);
 					segv_ret = _EXIT_SEGV_MADV_DONTNEED;
 					(void)shim_madvise(ptr, len, MADV_DONTNEED);
 
+					if (should_terminate(args, ppid))
+						_exit(EXIT_SUCCESS);
 					segv_ret = _EXIT_SEGV_MUNMAP;
 					(void)munmap(ptr, len);
 				}
 				_exit(EXIT_SUCCESS);
 			}
-			(void)setpgid(pids[n], g_pgrp);
+			(void)setpgid(pids[i], g_pgrp);
 		}
-reap:
-		for (i = 0; i < n; i++) {
+
+		/*
+		 *  Wait for children to terminate
+		 */
+		for (i = 0; i < MAX_PIDS; i++) {
 			int status;
 
+			if (UNLIKELY(pids[i] < 0))
+				continue;
+
 			if (shim_waitpid(pids[i], &status, 0) < 0) {
 				if (errno != EINTR) {
 					pr_err("%s: waitpid errno=%d (%s)\n",
 						args->name, errno, strerror(errno));
+				} else {
+					/* Probably an SIGARLM, force reap */
+					goto reap;
 				}
 			} else {
+				pids[i] = -1;
 				if (WIFEXITED(status)) {
 					int masked = WEXITSTATUS(status) & _EXIT_MASK;
 
@@ -154,9 +223,26 @@ reap:
 				}
 			}
 		}
+reap:
+		/*
+		 *  Force child death and reap
+		 */
+		for (i = 0; i < MAX_PIDS; i++) {
+			int status;
+
+			if (UNLIKELY(pids[i] < 0))
+				continue;
+			(void)kill(pids[i], SIGKILL);
+			(void)shim_waitpid(pids[i], &status, 0);
+		}
 		inc_counter(args);
 	} while (keep_stressing());
 
+#if defined(MADV_WIPEONFORK)
+	if (wipe_ptr != MAP_FAILED)
+		munmap(wipe_ptr, wipe_size);
+#endif
+
 	if (segv_count) {
 		char buffer[1024];
 		size_t n = sizeof(buffer) - 1;
