@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"mq N",		"start N workers passing messages using POSIX messages" },
 	{ NULL,	"mq-ops N",	"stop mq workers after N bogo messages" },
 	{ NULL,	"mq-size N",	"specify the size of the POSIX message queue" },
@@ -36,13 +36,13 @@ static int stress_set_mq_size(const char *opt)
 	uint64_t sz;
 	int mq_size;
 
-	sz = get_uint64(opt);
-	check_range("mq-size", sz, MIN_MQ_SIZE, MAX_MQ_SIZE);
+	sz = stress_get_uint64(opt);
+	stress_check_range("mq-size", sz, MIN_MQ_SIZE, MAX_MQ_SIZE);
 	mq_size = (int)sz;
-	return set_setting("mq-size", TYPE_ID_INT, &mq_size);
+	return stress_set_setting("mq-size", TYPE_ID_INT, &mq_size);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_mq_size,	stress_set_mq_size },
 	{ 0,		NULL }
 };
@@ -66,7 +66,7 @@ static void stress_mq_notify_func(union sigval s)
  *  stress_mq
  *	stress POSIX message queues
  */
-static int stress_mq(const args_t *args)
+static int stress_mq(const stress_args_t *args)
 {
 	pid_t pid;
 	mqd_t mq = -1;
@@ -78,7 +78,7 @@ static int stress_mq(const args_t *args)
 	time_t time_start;
 	struct timespec abs_timeout;
 
-	if (!get_setting("mq-size", &mq_size)) {
+	if (!stress_get_setting("mq-size", &mq_size)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			mq_size = MAX_MQ_SIZE;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -216,16 +216,17 @@ again:
 				}
 				if (prio >= PRIOS_MAX) {
 					pr_fail("%s: mq_receive: unexpected priority %u, expected 0..%d\n",
-						args->name, prio, PRIO_MAX - 1);
-				}
-				if (g_opt_flags & OPT_FLAGS_VERIFY) {
-					if (msg.value != values[prio]) {
-						pr_fail("%s: mq_receive: expected message "
-							"containing 0x%" PRIx64
-							" but received 0x%" PRIx64 " instead\n",
-							args->name, values[prio], msg.value);
+						args->name, prio, PRIOS_MAX - 1);
+				} else {
+					if (g_opt_flags & OPT_FLAGS_VERIFY) {
+						if (msg.value != values[prio]) {
+							pr_fail("%s: mq_receive: expected message "
+								"containing 0x%" PRIx64
+								" but received 0x%" PRIx64 " instead\n",
+								args->name, values[prio], msg.value);
+						}
+						values[prio]++;
 					}
-					values[prio]++;
 				}
 			}
 			_exit(EXIT_SUCCESS);
@@ -244,7 +245,7 @@ again:
 
 		do {
 			int ret;
-			unsigned int prio = mwc8() % PRIOS_MAX;
+			unsigned int prio = stress_mwc8() % PRIOS_MAX;
 
 			const uint64_t timed = (msg.value & 1);
 
