@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"mremap N",	  "start N workers stressing mremap" },
 	{ NULL,	"mremap-ops N",	  "stop after N mremap bogo operations" },
 	{ NULL,	"mremap-bytes N", "mremap N bytes maximum for each stress iteration" },
@@ -35,13 +35,13 @@ static int stress_set_mremap_bytes(const char *opt)
 {
 	size_t mremap_bytes;
 
-	mremap_bytes = (size_t)get_uint64_byte_memory(opt, 1);
-	check_range_bytes("mremap-bytes", mremap_bytes,
+	mremap_bytes = (size_t)stress_get_uint64_byte_memory(opt, 1);
+	stress_check_range_bytes("mremap-bytes", mremap_bytes,
 		MIN_MREMAP_BYTES, MAX_MEM_LIMIT);
-	return set_setting("mremap-bytes", TYPE_ID_SIZE_T, &mremap_bytes);
+	return stress_set_setting("mremap-bytes", TYPE_ID_SIZE_T, &mremap_bytes);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_mremap_bytes,	stress_set_mremap_bytes },
 	{ 0,			NULL }
 };
@@ -80,7 +80,7 @@ static inline void *rand_mremap_addr(const size_t sz, int flags)
  *	try and remap old size to new size
  */
 static int try_remap(
-	const args_t *args,
+	const stress_args_t *args,
 	uint8_t **buf,
 	const size_t old_sz,
 	const size_t new_sz)
@@ -94,7 +94,7 @@ static int try_remap(
 #endif
 
 #if defined(MREMAP_FIXED) && defined(MREMAP_MAYMOVE)
-	flags = maymove | (mwc32() & MREMAP_FIXED);
+	flags = maymove | (stress_mwc32() & MREMAP_FIXED);
 #else
 	flags = maymove;
 #endif
@@ -145,7 +145,7 @@ static int try_remap(
 	return -1;
 }
 
-static int stress_mremap_child(const args_t *args, void *context)
+static int stress_mremap_child(const stress_args_t *args, void *context)
 {
 	size_t new_sz, sz, mremap_bytes = DEFAULT_MREMAP_BYTES;
 	int flags = MAP_PRIVATE | MAP_ANONYMOUS;
@@ -156,7 +156,7 @@ static int stress_mremap_child(const args_t *args, void *context)
 #endif
 	(void)context;
 
-	if (!get_setting("mremap-bytes", &mremap_bytes)) {
+	if (!stress_get_setting("mremap-bytes", &mremap_bytes)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			mremap_bytes = MAX_32;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -243,7 +243,7 @@ static int stress_mremap_child(const args_t *args, void *context)
  *  stress_mremap()
  *	stress mmap
  */
-static int stress_mremap(const args_t *args)
+static int stress_mremap(const stress_args_t *args)
 {
 	return stress_oomable_child(args, NULL, stress_mremap_child, STRESS_OOMABLE_NORMAL);
 }
