@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"msg N",	"start N workers stressing System V messages" },
 	{ NULL,	"msg-ops N",	"stop msg workers after N bogo messages" },
 	{ NULL, "msg-types N",	"enable N different message types" },
@@ -34,12 +34,12 @@ static const help_t help[] = {
 static int stress_set_msg_types(const char *opt) {
         int32_t msg_types;
 
-        msg_types = get_int32(opt);
-        check_range("msg-types", msg_types, 0, 100);
-        return set_setting("msg-types", TYPE_ID_INT32, &msg_types);
+        msg_types = stress_get_int32(opt);
+        stress_check_range("msg-types", msg_types, 0, 100);
+        return stress_set_setting("msg-types", TYPE_ID_INT32, &msg_types);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
         { OPT_msg_types,	stress_set_msg_types },
         { 0,                    NULL },
 };
@@ -53,7 +53,7 @@ typedef struct {
 	uint32_t value;
 } stress_msg_t;
 
-static int stress_msg_get_stats(const args_t *args, const int msgq_id)
+static int stress_msg_get_stats(const stress_args_t *args, const int msgq_id)
 {
 	struct msqid_ds buf;
 
@@ -67,7 +67,7 @@ static int stress_msg_get_stats(const args_t *args, const int msgq_id)
 	 * select random msgq index numbers, we may hit
 	 * some that are in use. Ignore failures
 	 */
-	(void)msgctl(mwc8() % (msgq_id + 1), MSG_STAT_ANY, &buf);
+	(void)msgctl(stress_mwc8() % (msgq_id + 1), MSG_STAT_ANY, &buf);
 #endif
 
 #if defined(IPC_INFO) &&	\
@@ -126,7 +126,7 @@ static void stress_msg_get_procinfo(bool *get_procinfo)
  *  stress_msg
  *	stress by message queues
  */
-static int stress_msg(const args_t *args)
+static int stress_msg(const stress_args_t *args)
 {
 	pid_t pid;
 	int msgq_id;
@@ -135,7 +135,7 @@ static int stress_msg(const args_t *args)
 	bool get_procinfo = true;
 #endif
 
-	(void)get_setting("msg-types", &msg_types);
+	(void)stress_get_setting("msg-types", &msg_types);
 
 	msgq_id = msgget(IPC_PRIVATE, S_IRUSR | S_IWUSR | IPC_CREAT | IPC_EXCL);
 	if (msgq_id < 0) {
@@ -205,7 +205,7 @@ again:
 		msg.value = 0;
 
 		do {
-			msg.mtype = (msg_types) ? (mwc8() % msg_types) + 1 : 1;
+			msg.mtype = (msg_types) ? (stress_mwc8() % msg_types) + 1 : 1;
 			if (msgsnd(msgq_id, &msg, sizeof(msg.value), 0) < 0) {
 				if (errno != EINTR)
 					pr_fail_dbg("msgsnd");
