@@ -29,7 +29,7 @@ static sigjmp_buf jmp_env;
 static uint64_t sigbus_count;
 #endif
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"msync N",	 "start N workers syncing mmap'd data with msync" },
 	{ NULL,	"msync-ops N",	 "stop msync workers after N bogo msyncs" },
 	{ NULL,	"msync-bytes N", "size of file and memory mapped region to msync" },
@@ -40,13 +40,13 @@ static int stress_set_msync_bytes(const char *opt)
 {
 	size_t msync_bytes;
 
-	msync_bytes = (size_t)get_uint64_byte_memory(opt, 1);
-	check_range_bytes("msync-bytes", msync_bytes,
+	msync_bytes = (size_t)stress_get_uint64_byte_memory(opt, 1);
+	stress_check_range_bytes("msync-bytes", msync_bytes,
 		MIN_MSYNC_BYTES, MAX_MEM_LIMIT);
-	return set_setting("msync-bytes", TYPE_ID_SIZE_T, &msync_bytes);
+	return stress_set_setting("msync-bytes", TYPE_ID_SIZE_T, &msync_bytes);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_msync_bytes,	stress_set_msync_bytes },
 	{ 0,			NULL }
 };
@@ -87,7 +87,7 @@ static void MLOCKED_TEXT stress_sigbus_handler(int signum)
  *  stress_msync()
  *	stress msync
  */
-static int stress_msync(const args_t *args)
+static int stress_msync(const stress_args_t *args)
 {
 	uint8_t *buf = NULL;
 	const size_t page_size = args->page_size;
@@ -108,7 +108,7 @@ static int stress_msync(const args_t *args)
 	if (stress_sighandler(args->name, SIGBUS, stress_sigbus_handler, NULL) < 0)
 		return EXIT_FAILURE;
 
-	if (!get_setting("msync-bytes", &msync_bytes)) {
+	if (!stress_get_setting("msync-bytes", &msync_bytes)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			msync_bytes = MAXIMIZED_FILE_SIZE;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -131,7 +131,7 @@ static int stress_msync(const args_t *args)
 		return exit_status(-rc);
 
 	(void)stress_temp_filename_args(args,
-		filename, sizeof(filename), mwc32());
+		filename, sizeof(filename), stress_mwc32());
 
 	if ((fd = open(filename, O_CREAT | O_RDWR, S_IRUSR | S_IWUSR)) < 0) {
 		rc = exit_status(errno);
@@ -173,8 +173,8 @@ static int stress_msync(const args_t *args)
 		/*
 		 *  Change data in memory, msync to disk
 		 */
-		offset = (mwc64() % (sz - page_size)) & ~(page_size - 1);
-		val = mwc8();
+		offset = (stress_mwc64() % (sz - page_size)) & ~(page_size - 1);
+		val = stress_mwc8();
 
 		(void)memset(buf + offset, val, page_size);
 		ret = shim_msync(buf + offset, page_size, MS_SYNC);
@@ -208,8 +208,8 @@ do_invalidate:
 		/*
 		 *  Now change data on disc, msync invalidate
 		 */
-		offset = (mwc64() % (sz - page_size)) & ~(page_size - 1);
-		val = mwc8();
+		offset = (stress_mwc64() % (sz - page_size)) & ~(page_size - 1);
+		val = stress_mwc8();
 
 		(void)memset(buf + offset, val, page_size);
 
