@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"netlink-task N",	"start N workers exercising netlink tasks events" },
 	{ NULL,	"netlink-task-ops N",	"stop netlink-task workers after N bogo events" },
 	{ NULL,	NULL,			NULL }
@@ -73,7 +73,7 @@ static int stress_netlink_task_supported(void)
  *	send a netlink cmd
  */
 static int stress_netlink_sendcmd(
-	const args_t *args,
+	const stress_args_t *args,
 	const int sock,
 	const uint16_t nlmsg_type,
 	const uint16_t nlmsg_pid,
@@ -133,7 +133,7 @@ static int stress_netlink_sendcmd(
  *	switches are incrementing over time.
  */
 static void stress_parse_payload(
-	const args_t *args,
+	const stress_args_t *args,
 	struct nlattr *na,
 	const pid_t pid,
 	uint64_t *nivcsw)
@@ -177,7 +177,7 @@ static void stress_parse_payload(
  *	monitor parent's activity using taskstats info
  */
 static int stress_netlink_taskstats_monitor(
-	const args_t *args,
+	const stress_args_t *args,
 	const int sock,
 	const pid_t pid,
 	const uint16_t id,
@@ -225,7 +225,7 @@ static int stress_netlink_taskstats_monitor(
  *  stress_netlink_task()
  *	stress netlink task events
  */
-static int stress_netlink_task(const args_t *args)
+static int stress_netlink_task(const stress_args_t *args)
 {
 	int ret, sock = -1;
 	ssize_t len;
@@ -259,7 +259,7 @@ static int stress_netlink_task(const args_t *args)
 	}
 
 	ret = stress_netlink_sendcmd(args, sock, GENL_ID_CTRL, pid, CTRL_CMD_GETFAMILY,
-		CTRL_ATTR_FAMILY_NAME, (void *)name, sizeof(name));
+		CTRL_ATTR_FAMILY_NAME, (const void *)name, sizeof(name));
 	if (ret < 0) {
 		pr_err("%s: sendto CTRL_CMD_GETFAMILY failed: %d (%s)\n",
 			args->name, errno, strerror(errno));
