@@ -30,8 +30,8 @@ typedef struct {
 } stress_opt_flag_t;
 
 /* Per stressor process information */
-static proc_info_t *procs_head, *procs_tail;
-proc_info_t *g_proc_current;
+static stress_proc_info_t *procs_head, *procs_tail;
+stress_proc_info_t *g_proc_current;
 
 /* Various option settings and flags */
 static volatile bool wait_flag = true;		/* false = exit run wait loop */
@@ -46,9 +46,9 @@ volatile bool g_keep_stressing_flag = true;	/* false to exit stressor */
 volatile bool g_caught_sigint = false;		/* true if stopped by SIGINT */
 pid_t g_pgrp;					/* process group leader */
 const char *g_app_name = "stress-ng";		/* Name of application */
-shared_t *g_shared;				/* shared memory */
+stress_shared_t *g_shared;			/* shared memory */
 jmp_buf g_error_env;				/* parsing error env */
-put_val_t g_put_val;				/* sync data to somewhere */
+stress_put_val_t g_put_val;			/* sync data to somewhere */
 bool g_unsupported = false;			/* true if stressors are unsupported */
 
 /*
@@ -179,7 +179,7 @@ STRESS_ASSERT(SIZEOF_ARRAY(stressors) != STRESS_MAX)
 /*
  *  Different stress classes
  */
-static const class_info_t classes[] = {
+static const stress_class_info_t classes[] = {
 	{ CLASS_CPU_CACHE,	"cpu-cache" },
 	{ CLASS_CPU,		"cpu" },
 	{ CLASS_DEV,		"device" },
@@ -228,6 +228,8 @@ static const struct option long_options[] = {
 	{ "bigheap-growth",1,	0,	OPT_bigheap_growth },
 	{ "bind-mount",	1,	0,	OPT_bind_mount },
 	{ "bind-mount-ops",1,	0,	OPT_bind_mount_ops },
+	{ "binderfs",	1,	0,	OPT_binderfs },
+	{ "binderfs-opts",1,	0,	OPT_binderfs_ops },
 	{ "branch",	1,	0,	OPT_branch },
 	{ "branch-ops",	1,	0,	OPT_branch_ops },
 	{ "brk",	1,	0,	OPT_brk },
@@ -247,6 +249,8 @@ static const struct option long_options[] = {
 	{ "cache-no-affinity",0,0,	OPT_cache_no_affinity },
 	{ "cap",	1,	0, 	OPT_cap },
 	{ "cap-ops",	1,	0, 	OPT_cap_ops },
+	{ "chattr",	1,	0, 	OPT_chattr },
+	{ "chattr-ops",	1,	0,	OPT_chattr_ops },
 	{ "chdir",	1,	0, 	OPT_chdir },
 	{ "chdir-ops",	1,	0, 	OPT_chdir_ops },
 	{ "chdir-dirs",	1,	0,	OPT_chdir_dirs },
@@ -626,6 +630,8 @@ static const struct option long_options[] = {
 	{ "readahead",	1,	0,	OPT_readahead },
 	{ "readahead-ops",1,	0,	OPT_readahead_ops },
 	{ "readahead-bytes",1,	0,	OPT_readahead_bytes },
+	{ "reboot",	1,	0,	OPT_reboot },
+	{ "reboot-ops",	1,	0,	OPT_reboot_ops },
 	{ "remap",	1,	0,	OPT_remap },
 	{ "remap-ops",	1,	0,	OPT_remap_ops },
 	{ "rename",	1,	0,	OPT_rename },
@@ -699,6 +705,9 @@ static const struct option long_options[] = {
 	{ "sigsegv-ops",1,	0,	OPT_sigsegv_ops },
 	{ "sigsuspend",	1,	0,	OPT_sigsuspend},
 	{ "sigsuspend-ops",1,	0,	OPT_sigsuspend_ops},
+	{ "skiplist",	1,	0,	OPT_skiplist },
+	{ "skiplist-ops",1,	0,	OPT_skiplist_ops },
+	{ "skiplist-size",1,	0,	OPT_skiplist_size },
 	{ "sleep",	1,	0,	OPT_sleep },
 	{ "sleep-ops",	1,	0,	OPT_sleep_ops },
 	{ "sleep-max",	1,	0,	OPT_sleep_max },
@@ -709,6 +718,8 @@ static const struct option long_options[] = {
 	{ "sock-opts",	1,	0,	OPT_sock_opts },
 	{ "sock-port",	1,	0,	OPT_sock_port },
 	{ "sock-type",	1,	0,	OPT_sock_type },
+	{ "sockabuse",	1,	0,	OPT_sockabuse },
+	{ "sockabuse-ops",1,	0,	OPT_sockabuse_ops },
 	{ "sockdiag",	1,	0,	OPT_sockdiag },
 	{ "sockdiag-ops",1,	0,	OPT_sockdiag_ops },
 	{ "sockfd",	1,	0,	OPT_sockfd },
@@ -879,7 +890,7 @@ static const struct option long_options[] = {
 /*
  *  Generic help options
  */
-static const help_t help_generic[] = {
+static const stress_help_t help_generic[] = {
 	{ NULL,		"abort",		"abort all stressors if any stressor fails" },
 	{ NULL,		"aggressive",		"enable all aggressive options" },
 	{ "a N",	"all N",		"start N workers of each stress test" },
@@ -961,7 +972,7 @@ static inline int32_t stressor_name_find(const char *name)
  *  remove_proc()
  *	remove proc from proc list
  */
-static void remove_proc(proc_info_t *pi)
+static void remove_proc(stress_proc_info_t *pi)
 {
 	if (procs_head == pi) {
 		procs_head = pi->next;
@@ -1051,12 +1062,12 @@ static int stress_exclude(void)
 {
 	char *str, *token, *opt_exclude;
 
-	if (!get_setting("exclude", &opt_exclude))
+	if (!stress_get_setting("exclude", &opt_exclude))
 		return 0;
 
 	for (str = opt_exclude; (token = strtok(str, ",")) != NULL; str = NULL) {
 		stress_id_t id;
-		proc_info_t *pi = procs_head;
+		stress_proc_info_t *pi = procs_head;
 		uint32_t i = stressor_name_find(token);
 
 		if (!stressors[i].name) {
@@ -1067,7 +1078,7 @@ static int stress_exclude(void)
 		id = stressors[i].id;
 
 		while (pi) {
-			proc_info_t *next = pi->next;
+			stress_proc_info_t *next = pi->next;
 
 			if (pi->stressor->id == id)
 				remove_proc(pi);
@@ -1176,7 +1187,7 @@ static void version(void)
  *  usage_help()
  *	show generic help information
  */
-static void usage_help(const help_t help_info[])
+static void usage_help(const stress_help_t help_info[])
 {
 	size_t i;
 
@@ -1235,7 +1246,7 @@ static void usage(void)
 		"--fork 4 --timeout 10s\n\n"
 		"Note: Sizes can be suffixed with B,K,M,G and times with "
 		"s,m,h,d,y\n", g_app_name);
-	free_settings();
+	stress_free_settings();
 	exit(EXIT_SUCCESS);
 }
 
@@ -1285,7 +1296,7 @@ static void kill_procs(const int sig)
 {
 	static int count = 0;
 	int signum = sig;
-	proc_info_t *pi;
+	stress_proc_info_t *pi;
 
 	/* multiple calls will always fallback to SIGKILL */
 	count++;
@@ -1335,11 +1346,11 @@ static char *str_exitstatus(const int status)
  * 	wait for procs
  */
 static void MLOCKED_TEXT wait_procs(
-	proc_info_t *procs_list,
+	stress_proc_info_t *procs_list,
 	bool *success,
 	bool *resource_success)
 {
-	proc_info_t *pi;
+	stress_proc_info_t *pi;
 
 	if (g_opt_flags & OPT_FLAGS_IGNITE_CPU)
 		stress_ignite_cpu_start();
@@ -1361,6 +1372,7 @@ static void MLOCKED_TEXT wait_procs(
 
 		while (wait_flag) {
 			const int32_t cpus = stress_get_processors_configured();
+			bool procs_alive = false;
 
 			/*
 			 *  If we can't get the mask, then don't do
@@ -1371,6 +1383,8 @@ static void MLOCKED_TEXT wait_procs(
 			if (!CPU_COUNT(&proc_mask))	/* Highly unlikely */
 				goto do_wait;
 
+			(void)shim_usleep(usec_sleep);
+
 			for (pi = procs_list; pi; pi = pi->next) {
 				int32_t j;
 
@@ -1379,9 +1393,15 @@ static void MLOCKED_TEXT wait_procs(
 					if (pid) {
 						cpu_set_t mask;
 						int32_t cpu_num;
+						int status, ret;
+
+						ret = waitpid(pid, &status, WNOHANG);
+						if ((ret < 0) && (errno == ESRCH))
+							continue;
+						procs_alive = true;
 
 						do {
-							cpu_num = mwc32() % cpus;
+							cpu_num = stress_mwc32() % cpus;
 						} while (!(CPU_ISSET(cpu_num, &proc_mask)));
 
 						CPU_ZERO(&mask);
@@ -1391,7 +1411,8 @@ static void MLOCKED_TEXT wait_procs(
 					}
 				}
 			}
-			(void)shim_usleep(usec_sleep);
+			if (!procs_alive)
+				break;
 			cpu++;
 		}
 	}
@@ -1521,9 +1542,9 @@ static void MLOCKED_TEXT handle_terminate(int signum)
  *  get_proc()
  *	return nth proc from list
  */
-static proc_info_t *get_nth_proc(const uint32_t n)
+static stress_proc_info_t *get_nth_proc(const uint32_t n)
 {
-	proc_info_t *pi = procs_head;
+	stress_proc_info_t *pi = procs_head;
 	uint32_t i;
 
 	for (i = 0; pi && (i < n); i++)
@@ -1539,7 +1560,7 @@ static proc_info_t *get_nth_proc(const uint32_t n)
 static uint32_t get_num_procs(void)
 {
 	uint32_t n = 0;
-	proc_info_t *pi;
+	stress_proc_info_t *pi;
 
 	for (pi = procs_head; pi; pi = pi->next)
 		n++;
@@ -1553,10 +1574,10 @@ static uint32_t get_num_procs(void)
  */
 static void free_procs(void)
 {
-	proc_info_t *pi = procs_head;
+	stress_proc_info_t *pi = procs_head;
 
 	while (pi) {
-		proc_info_t *next = pi->next;
+		stress_proc_info_t *next = pi->next;
 
 		free(pi->pids);
 		free(pi->stats);
@@ -1573,10 +1594,10 @@ static void free_procs(void)
  *  get_total_num_procs()
  *	deterimine number of runnable procs from list
  */
-static uint32_t get_total_num_procs(proc_info_t *procs_list)
+static uint32_t get_total_num_procs(stress_proc_info_t *procs_list)
 {
 	uint32_t total_num_procs = 0;
-	proc_info_t *pi;
+	stress_proc_info_t *pi;
 
 	for (pi = procs_list; pi; pi = pi->next)
 		total_num_procs += pi->num_procs;
@@ -1598,7 +1619,7 @@ static void stress_child_atexit(void)
  *	kick off and run stressors
  */
 static void MLOCKED_TEXT stress_run(
-	proc_info_t *procs_list,
+	stress_proc_info_t *procs_list,
 	double *duration,
 	bool *success,
 	bool *resource_success
@@ -1626,11 +1647,11 @@ static void MLOCKED_TEXT stress_run(
 				int32_t ionice_class = UNDEFINED;
 				int32_t ionice_level = UNDEFINED;
 
-				(void)get_setting("backoff", &backoff);
-				(void)get_setting("ionice-class", &ionice_class);
-				(void)get_setting("ionice-level", &ionice_level);
+				(void)stress_get_setting("backoff", &backoff);
+				(void)stress_get_setting("ionice-class", &ionice_class);
+				(void)stress_get_setting("ionice-level", &ionice_level);
 
-				proc_stats_t *stats = g_proc_current->stats[j];
+				stress_proc_stats_t *stats = g_proc_current->stats[j];
 again:
 				if (!keep_stressing_flag())
 					break;
@@ -1659,11 +1680,11 @@ again:
 
 					if (g_opt_timeout)
 						(void)alarm(g_opt_timeout);
-					mwc_reseed();
+					stress_mwc_reseed();
 					(void)snprintf(name, sizeof(name), "%s-%s", g_app_name,
 						stress_munge_underscore(g_proc_current->stressor->name));
 					stress_set_oom_adjustment(name, false);
-					set_max_limits();
+					stress_set_max_limits();
 					stress_set_iopriority(ionice_class, ionice_level);
 					stress_set_proc_name(name);
 					(void)umask(0077);
@@ -1682,7 +1703,7 @@ again:
 						(void)stress_perf_enable(&stats->sp);
 #endif
 					if (keep_stressing_flag() && !(g_opt_flags & OPT_FLAGS_DRY_RUN)) {
-						const args_t args = {
+						const stress_args_t args = {
 							.counter = &stats->counter,
 							.name = name,
 							.max_ops = g_proc_current->bogo_ops,
@@ -1719,7 +1740,7 @@ again:
 child_exit:
 					free_procs();
 					stress_cache_free();
-					free_settings();
+					stress_free_settings();
 					if ((rc != 0) && (g_opt_flags & OPT_FLAGS_ABORT)) {
 						keep_stressing_set_flag(false);
 						wait_flag = false;
@@ -1771,7 +1792,7 @@ static int show_stressors(void)
 	ssize_t len = 0;
 	char buffer[64];
 	bool previous = false;
-	proc_info_t *pi;
+	stress_proc_info_t *pi;
 
 	for (pi = procs_head; pi; pi = pi->next) {
 		const int32_t n = pi->num_procs;
@@ -1812,7 +1833,7 @@ static void metrics_dump(
 	FILE *yaml,
 	const int32_t ticks_per_sec)
 {
-	proc_info_t *pi;
+	stress_proc_info_t *pi;
 
 	pr_inf("%-13s %9.9s %9.9s %9.9s %9.9s %12s %12s\n",
 		"stressor", "bogo ops", "real time", "usr time",
@@ -1831,7 +1852,7 @@ static void metrics_dump(
 		bool run_ok = false;
 
 		for (j = 0; j < pi->started_procs; j++) {
-			const proc_stats_t *const stats = pi->stats[j];
+			const stress_proc_stats_t *const stats = pi->stats[j];
 
 			run_ok  |= stats->run_ok;
 			c_total += stats->counter;
@@ -1964,10 +1985,10 @@ static void log_args(int argc, char **argv)
 }
 
 /*
- *  log_system_mem_info()
+ *  stress_log_system_mem_info()
  *	dump system memory info
  */
-void log_system_mem_info(void)
+void stress_log_system_mem_info(void)
 {
 #if defined(HAVE_SYS_SYSINFO_H) && \
     defined(HAVE_SYSINFO) && \
@@ -2027,7 +2048,7 @@ static inline void stress_map_shared(const size_t len)
 	void *last_page;
 #endif
 
-	g_shared = (shared_t *)mmap(NULL, sz, PROT_READ | PROT_WRITE,
+	g_shared = (stress_shared_t *)mmap(NULL, sz, PROT_READ | PROT_WRITE,
 		MAP_SHARED | MAP_ANON, -1, 0);
 	if (g_shared == MAP_FAILED) {
 		pr_err("Cannot mmap to shared memory region: errno=%d (%s)\n",
@@ -2084,11 +2105,11 @@ static inline void exclude_unsupported(void)
 
 	for (i = 0; i < SIZEOF_ARRAY(stressors); i++) {
 		if (stressors[i].info && stressors[i].info->supported) {
-			proc_info_t *pi = procs_head;
+			stress_proc_info_t *pi = procs_head;
 			stress_id_t id = stressors[i].id;
 
 			while (pi) {
-				proc_info_t *next = pi->next;
+				stress_proc_info_t *next = pi->next;
 
 				if ((pi->stressor->id == id) &&
 				    pi->num_procs &&
@@ -2109,7 +2130,7 @@ static inline void exclude_unsupported(void)
 static void set_proc_limits(void)
 {
 #if defined(RLIMIT_NPROC)
-	proc_info_t *pi;
+	stress_proc_info_t *pi;
 	struct rlimit limit;
 
 	if (getrlimit(RLIMIT_NPROC, &limit) < 0)
@@ -2138,9 +2159,9 @@ static void set_proc_limits(void)
  *	stressor.  If it does not exist, create a new one
  *	and return that. Terminate if out of memory.
  */
-static proc_info_t *find_proc_info(const stress_t *stressor)
+static stress_proc_info_t *find_proc_info(const stress_t *stressor)
 {
-	proc_info_t *pi;
+	stress_proc_info_t *pi;
 
 #if 0
 	/* Scan backwards in time to find last matching stressor */
@@ -2175,7 +2196,7 @@ static proc_info_t *find_proc_info(const stress_t *stressor)
  */
 static void stressors_init(void)
 {
-	proc_info_t *pi;
+	stress_proc_info_t *pi;
 
 	for (pi = procs_head; pi; pi = pi->next) {
 		size_t i;
@@ -2195,7 +2216,7 @@ static void stressors_init(void)
  */
 static void stressors_deinit(void)
 {
-	proc_info_t *pi;
+	stress_proc_info_t *pi;
 
 	for (pi = procs_head; pi; pi = pi->next) {
 		size_t i;
@@ -2234,10 +2255,10 @@ static inline void stressor_set_defaults(void)
 static inline void exclude_pathological(void)
 {
 	if (!(g_opt_flags & OPT_FLAGS_PATHOLOGICAL)) {
-		proc_info_t *pi = procs_head;
+		stress_proc_info_t *pi = procs_head;
 
 		while (pi) {
-			proc_info_t *next = pi->next;
+			stress_proc_info_t *next = pi->next;
 
 			if (pi->stressor->info->class & CLASS_PATHOLOGICAL) {
 				if (pi->num_procs > 0) {
@@ -2260,8 +2281,8 @@ static inline void exclude_pathological(void)
  */
 static inline void setup_stats_buffers(void)
 {
-	proc_info_t *pi;
-	proc_stats_t *stats = g_shared->stats;
+	stress_proc_info_t *pi;
+	stress_proc_stats_t *stats = g_shared->stats;
 
 	for (pi = procs_head; pi; pi = pi->next) {
 		int32_t j;
@@ -2279,7 +2300,7 @@ static inline void set_random_stressors(void)
 {
 	int32_t opt_random = 0;
 
-	(void)get_setting("random", &opt_random);
+	(void)stress_get_setting("random", &opt_random);
 
 	if (g_opt_flags & OPT_FLAGS_RANDOM) {
 		int32_t n = opt_random;
@@ -2292,14 +2313,17 @@ static inline void set_random_stressors(void)
 			exit(EXIT_FAILURE);
 		}
 
-		if (!n_procs)
-			n_procs = 1;
+		if (!n_procs) {
+			(void)fprintf(stderr,
+				"No stressors are available, unable to continue\n");
+			exit(EXIT_FAILURE);
+		}
 
 		/* create n randomly chosen stressors */
 		while (n > 0) {
-			int32_t rnd = mwc32() % ((opt_random >> 5) + 2);
-			int32_t i = mwc32() % n_procs;
-			proc_info_t *pi = get_nth_proc(i);
+			int32_t rnd = stress_mwc32() % ((opt_random >> 5) + 2);
+			int32_t i = stress_mwc32() % n_procs;
+			stress_proc_info_t *pi = get_nth_proc(i);
 
 			if (!pi)
 				continue;
@@ -2325,7 +2349,7 @@ static void enable_all_stressors(const uint32_t instances)
 		return;
 
 	for (i = 0; i < STRESS_MAX; i++) {
-		proc_info_t *pi = find_proc_info(&stressors[i]);
+		stress_proc_info_t *pi = find_proc_info(&stressors[i]);
 
 		if (!pi) {
 			(void)fprintf(stderr, "Cannot allocate stressor state info\n");
@@ -2351,7 +2375,7 @@ static void enable_classes(const uint32_t class)
 
 	for (i = 0; stressors[i].id != STRESS_MAX; i++) {
 		if (stressors[i].info->class & class) {
-			proc_info_t *pi = find_proc_info(&stressors[i]);
+			stress_proc_info_t *pi = find_proc_info(&stressors[i]);
 
 			if (g_opt_flags & OPT_FLAGS_SEQUENTIAL)
 				pi->num_procs = g_opt_sequential;
@@ -2363,10 +2387,10 @@ static void enable_classes(const uint32_t class)
 
 
 /*
- *  parse_opts
+ *  stress_parse_opts
  *	parse argv[] and set stress-ng options accordingly
  */
-int parse_opts(int argc, char **argv, const bool jobmode)
+int stress_parse_opts(int argc, char **argv, const bool jobmode)
 {
 	optind = 0;
 
@@ -2389,24 +2413,24 @@ next_opt:
 		for (i = 0; stressors[i].id != STRESS_MAX; i++) {
 			if (stressors[i].short_getopt == c) {
 				const char *name = opt_name(c);
-				proc_info_t *pi = find_proc_info(&stressors[i]);
+				stress_proc_info_t *pi = find_proc_info(&stressors[i]);
 				g_proc_current = pi;
 
 				g_opt_flags |= OPT_FLAGS_SET;
-				pi->num_procs = get_int32(optarg);
+				pi->num_procs = stress_get_int32(optarg);
 				stress_get_processors(&pi->num_procs);
-				check_value(name, pi->num_procs);
+				stress_check_value(name, pi->num_procs);
 
 				goto next_opt;
 			}
 			if (stressors[i].op == (stress_op_t)c) {
 				uint64_t bogo_ops;
 
-				bogo_ops = get_uint64(optarg);
-				check_range(opt_name(c), bogo_ops,
+				bogo_ops = stress_get_uint64(optarg);
+				stress_check_range(opt_name(c), bogo_ops,
 					MIN_OPS, MAX_OPS);
 				/* We don't need to set this, but it may be useful */
-				set_setting(opt_name(c), TYPE_ID_UINT64, &bogo_ops);
+				stress_set_setting(opt_name(c), TYPE_ID_UINT64, &bogo_ops);
 				if (g_proc_current)
 					g_proc_current->bogo_ops = bogo_ops;
 				goto next_opt;
@@ -2436,13 +2460,13 @@ next_opt:
 		switch (c) {
 		case OPT_all:
 			g_opt_flags |= OPT_FLAGS_ALL;
-			g_opt_parallel = get_int32(optarg);
+			g_opt_parallel = stress_get_int32(optarg);
 			stress_get_processors(&g_opt_parallel);
-			check_value("all", g_opt_parallel);
+			stress_check_value("all", g_opt_parallel);
 			break;
 		case OPT_backoff:
-			i64 = (int64_t)get_uint64(optarg);
-			set_setting_global("backoff", TYPE_ID_INT64, &i64);
+			i64 = (int64_t)stress_get_uint64(optarg);
+			stress_set_setting_global("backoff", TYPE_ID_INT64, &i64);
 			break;
 		case OPT_cache_level:
 			/*
@@ -2452,11 +2476,11 @@ next_opt:
 			i16 = atoi(optarg);
 			if ((i16 <= 0) || (i16 > 3))
 				i16 = DEFAULT_CACHE_LEVEL;
-			set_setting("cache-level", TYPE_ID_INT16, &i16);
+			stress_set_setting("cache-level", TYPE_ID_INT16, &i16);
 			break;
 		case OPT_cache_ways:
-			u32 = get_uint32(optarg);
-			set_setting("cache-ways", TYPE_ID_UINT32, &u32);
+			u32 = stress_get_uint32(optarg);
+			stress_set_setting("cache-ways", TYPE_ID_UINT32, &u32);
 			break;
 		case OPT_class:
 			ret = get_class(optarg, &u32);
@@ -2465,29 +2489,29 @@ next_opt:
 			else if (ret > 0)
 				exit(EXIT_SUCCESS);
 			else {
-				set_setting("class", TYPE_ID_UINT32, &u32);
+				stress_set_setting("class", TYPE_ID_UINT32, &u32);
 				enable_classes(u32);
 			}
 			break;
 		case OPT_exclude:
-			set_setting_global("exclude", TYPE_ID_STR, (void *)optarg);
+			stress_set_setting_global("exclude", TYPE_ID_STR, (void *)optarg);
 			break;
 		case OPT_help:
 			usage();
 			break;
 		case OPT_ionice_class:
 			i32 = stress_get_opt_ionice_class(optarg);
-			set_setting("ionice-class", TYPE_ID_INT32, &i32);
+			stress_set_setting("ionice-class", TYPE_ID_INT32, &i32);
 			break;
 		case OPT_ionice_level:
-			i32 = get_int32(optarg);
-			set_setting("ionice-level", TYPE_ID_INT32, &i32);
+			i32 = stress_get_int32(optarg);
+			stress_set_setting("ionice-level", TYPE_ID_INT32, &i32);
 			break;
 		case OPT_job:
-			set_setting_global("job", TYPE_ID_STR, (void *)optarg);
+			stress_set_setting_global("job", TYPE_ID_STR, (void *)optarg);
 			break;
 		case OPT_log_file:
-			set_setting_global("log-file", TYPE_ID_STR, (void *)optarg);
+			stress_set_setting_global("log-file", TYPE_ID_STR, (void *)optarg);
 			break;
 		case OPT_no_madvise:
 			g_opt_flags &= ~OPT_FLAGS_MMAP_MADVISE;
@@ -2503,24 +2527,24 @@ next_opt:
 			break;
 		case OPT_random:
 			g_opt_flags |= OPT_FLAGS_RANDOM;
-			i32 = get_int32(optarg);
-			check_value("random", i32);
+			i32 = stress_get_int32(optarg);
 			stress_get_processors(&i32);
-			set_setting("random", TYPE_ID_INT32, &i32);
+			stress_check_value("random", i32);
+			stress_set_setting("random", TYPE_ID_INT32, &i32);
 			break;
 		case OPT_sched:
 			i32 = stress_get_opt_sched(optarg);
-			set_setting_global("sched", TYPE_ID_INT32, &i32);
+			stress_set_setting_global("sched", TYPE_ID_INT32, &i32);
 			break;
 		case OPT_sched_prio:
-			i32 = get_int32(optarg);
-			set_setting_global("sched-prio", TYPE_ID_INT32, &i32);
+			i32 = stress_get_int32(optarg);
+			stress_set_setting_global("sched-prio", TYPE_ID_INT32, &i32);
 			break;
 		case OPT_sequential:
 			g_opt_flags |= OPT_FLAGS_SEQUENTIAL;
-			g_opt_sequential = get_int32(optarg);
+			g_opt_sequential = stress_get_int32(optarg);
 			stress_get_processors(&g_opt_sequential);
-			check_range("sequential", g_opt_sequential,
+			stress_check_range("sequential", g_opt_sequential,
 				MIN_SEQUENTIAL, MAX_SEQUENTIAL);
 			break;
 		case OPT_stressors:
@@ -2535,7 +2559,7 @@ next_opt:
 				exit(EXIT_FAILURE);
 			break;
 		case OPT_timeout:
-			g_opt_timeout = get_uint64_time(optarg);
+			g_opt_timeout = stress_get_uint64_time(optarg);
 			break;
 		case OPT_timer_slack:
 			(void)stress_set_timer_slack_ns(optarg);
@@ -2544,7 +2568,7 @@ next_opt:
 			version();
 			exit(EXIT_SUCCESS);
 		case OPT_yaml:
-			set_setting_global("yaml", TYPE_ID_STR, (void *)optarg);
+			stress_set_setting_global("yaml", TYPE_ID_STR, (void *)optarg);
 			break;
 		default:
 			if (!jobmode)
@@ -2559,7 +2583,7 @@ next_opt:
  *  alloc_proc_resources()
  *	allocate array of pids based on n pids required
  */
-static void alloc_proc_resources(pid_t **pids, proc_stats_t ***stats, size_t n)
+static void alloc_proc_resources(pid_t **pids, stress_proc_stats_t ***stats, size_t n)
 {
 	*pids = calloc(n, sizeof(pid_t));
 	if (!*pids) {
@@ -2568,7 +2592,7 @@ static void alloc_proc_resources(pid_t **pids, proc_stats_t ***stats, size_t n)
 		exit(EXIT_FAILURE);
 	}
 
-	*stats = calloc(n, sizeof(proc_stats_t *));
+	*stats = calloc(n, sizeof(stress_proc_stats_t *));
 	if (!*stats) {
 		pr_err("cannot allocate stats list\n");
 		free(*pids);
@@ -2598,7 +2622,7 @@ static void set_default_timeout(const uint64_t timeout)
  */
 static void stress_setup_sequential(const uint32_t class)
 {
-	proc_info_t *pi;
+	stress_proc_info_t *pi;
 
 	set_default_timeout(60);
 
@@ -2615,7 +2639,7 @@ static void stress_setup_sequential(const uint32_t class)
  */
 static void stress_setup_parallel(const uint32_t class)
 {
-	proc_info_t *pi;
+	stress_proc_info_t *pi;
 
 	set_default_timeout(DEFAULT_TIMEOUT);
 
@@ -2642,13 +2666,13 @@ static inline void stress_run_sequential(
 	bool *success,
 	bool *resource_success)
 {
-	proc_info_t *pi;
+	stress_proc_info_t *pi;
 
 	/*
 	 *  Step through each stressor one by one
 	 */
 	for (pi = procs_head; pi && keep_stressing_flag(); pi = pi->next) {
-		proc_info_t *next = pi->next;
+		stress_proc_info_t *next = pi->next;
 
 		pi->next = NULL;
 		stress_run(pi, duration, success, resource_success);
@@ -2723,7 +2747,7 @@ int main(int argc, char **argv, char **envp)
 
 	procs_head = NULL;
 	procs_tail = NULL;
-	mwc_reseed();
+	stress_mwc_reseed();
 
 	(void)stress_get_pagesize();
 	stressor_set_defaults();
@@ -2743,14 +2767,14 @@ int main(int argc, char **argv, char **envp)
 		exit(EXIT_FAILURE);
 	}
 
-	ret = parse_opts(argc, argv, false);
+	ret = stress_parse_opts(argc, argv, false);
 	if (ret != EXIT_SUCCESS)
 		exit(ret);
 	/*
 	 *  Load in job file options
 	 */
-	(void)get_setting("job", &job_filename);
-	if (parse_jobfile(argc, argv, job_filename) < 0)
+	(void)stress_get_setting("job", &job_filename);
+	if (stress_parse_jobfile(argc, argv, job_filename) < 0)
 		exit(EXIT_FAILURE);
 
 	/*
@@ -2771,7 +2795,7 @@ int main(int argc, char **argv, char **envp)
 			"options together\n");
 		exit(EXIT_FAILURE);
 	}
-	(void)get_setting("class", &class);
+	(void)stress_get_setting("class", &class);
 
 	if (class &&
 	    !(g_opt_flags & (OPT_FLAGS_SEQUENTIAL | OPT_FLAGS_ALL))) {
@@ -2783,18 +2807,23 @@ int main(int argc, char **argv, char **envp)
 	/*
 	 *  Setup logging
 	 */
-	if (get_setting("log-file", &log_filename))
+	if (stress_get_setting("log-file", &log_filename))
 		pr_openlog(log_filename);
 	shim_openlog("stress-ng", 0, LOG_USER);
 	log_args(argc, argv);
 	log_system_info();
-	log_system_mem_info();
+	stress_log_system_mem_info();
 
 	pr_dbg("%" PRId32 " processor%s online, %" PRId32
 		" processor%s configured\n",
 		cpus_online, cpus_online == 1 ? "" : "s",
 		cpus_configured, cpus_configured == 1 ? "" : "s");
 
+	/*
+	 *  For random mode the stressors must be available
+	 */
+	if (g_opt_flags & OPT_FLAGS_RANDOM)
+		enable_all_stressors(0);
 	/*
 	 *  These two options enable all the stressors
 	 */
@@ -2834,12 +2863,12 @@ int main(int argc, char **argv, char **envp)
 	/*
 	 *  Get various user defined settings
 	 */
-	(void)get_setting("sched", &sched);
-	(void)get_setting("sched-prio", &sched_prio);
+	(void)stress_get_setting("sched", &sched);
+	(void)stress_get_setting("sched-prio", &sched_prio);
 	if (stress_set_sched(getpid(), sched, sched_prio, false) < 0)
 		exit(EXIT_FAILURE);
-	(void)get_setting("ionice-class", &ionice_class);
-	(void)get_setting("ionice-level", &ionice_level);
+	(void)stress_get_setting("ionice-class", &ionice_class);
+	(void)stress_get_setting("ionice-level", &ionice_level);
 	stress_set_iopriority(ionice_class, ionice_level);
 
 	stress_mlock_executable();
@@ -2899,7 +2928,7 @@ int main(int argc, char **argv, char **envp)
 	 *  Allocate shared memory segment for shared data
 	 *  across all the child stressors
 	 */
-	len = sizeof(shared_t) + (sizeof(proc_stats_t) * get_total_num_procs(procs_head));
+	len = sizeof(stress_shared_t) + (sizeof(stress_proc_stats_t) * get_total_num_procs(procs_head));
 	stress_map_shared(len);
 
 	/*
@@ -2921,9 +2950,9 @@ int main(int argc, char **argv, char **envp)
 	 *  Allocate shared cache memory
 	 */
 	g_shared->mem_cache_level = DEFAULT_CACHE_LEVEL;
-	(void)get_setting("cache-level", &g_shared->mem_cache_level);
+	(void)stress_get_setting("cache-level", &g_shared->mem_cache_level);
 	g_shared->mem_cache_ways = 0;
-	(void)get_setting("cache-ways", &g_shared->mem_cache_ways);
+	(void)stress_get_setting("cache-ways", &g_shared->mem_cache_ways);
 	if (stress_cache_alloc("cache allocate") < 0) {
 		stress_unmap_shared();
 		free_procs();
@@ -2963,7 +2992,7 @@ int main(int argc, char **argv, char **envp)
 	/*
 	 *  Save results to YAML file
 	 */
-	if (get_setting("yaml", &yaml_filename)) {
+	if (stress_get_setting("yaml", &yaml_filename)) {
 		yaml = fopen(yaml_filename, "w");
 		if (!yaml)
 			pr_err("Cannot output YAML data to %s\n", yaml_filename);
@@ -3008,7 +3037,7 @@ int main(int argc, char **argv, char **envp)
 	free_procs();
 	stress_cache_free();
 	stress_unmap_shared();
-	free_settings();
+	stress_free_settings();
 
 	/*
 	 *  Close logs
