@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"nice N",	"start N workers that randomly re-adjust nice levels" },
 	{ NULL,	"nice-ops N",	"stop after N nice bogo operations" },
 	{ NULL,	NULL,		NULL }
@@ -35,7 +35,7 @@ static const help_t help[] = {
 static void stress_nice_delay(void)
 {
 	double start = stress_time_now();
-	double delay = 0.01 + (double)mwc16() / 3276800.0;
+	double delay = 0.01 + (double)stress_mwc16() / 3276800.0;
 
 	while (stress_time_now() - start < delay)
 		(void)shim_sched_yield();
@@ -45,7 +45,7 @@ static void stress_nice_delay(void)
  *  stress on sched_nice()
  *	stress system by sched_nice
  */
-static int stress_nice(const args_t *args)
+static int stress_nice(const stress_args_t *args)
 {
 #if defined(HAVE_SETPRIORITY)
 	int max_prio, min_prio;
@@ -72,7 +72,7 @@ static int stress_nice(const args_t *args)
 
 	do {
 		pid_t pid;
-		int which = mwc1();
+		int which = stress_mwc1();
 
 		pid = fork();
 		if (pid == 0) {
