@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"nop N",	"start N workers that burn cycles with no-ops" },
 	{ NULL,	"nop-ops N",	"stop after N nop bogo no-op operations" },
 	{ NULL,	NULL,		NULL }
@@ -50,7 +50,7 @@ static const help_t help[] = {
  *  stress_nop()
  *	stress that does lots of not a lot
  */
-static int stress_nop(const args_t *args)
+static int stress_nop(const stress_args_t *args)
 {
 	do {
 		register int i = 256;
