@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"numa N",	"start N workers stressing NUMA interfaces" },
 	{ NULL,	"numa-ops N",	"stop after N NUMA bogo operations" },
 	{ NULL,	NULL,		NULL }
@@ -172,7 +172,7 @@ static int stress_numa_get_mem_nodes(stress_node_t **node_ptr,
  *  stress_numa()
  *	stress the Linux NUMA interfaces
  */
-static int stress_numa(const args_t *args)
+static int stress_numa(const stress_args_t *args)
 {
 	long numa_nodes;
 	unsigned long max_nodes;
