@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"opcode N",	   "start N workers exercising random opcodes" },
 	{ NULL,	"opcode-ops N",	   "stop after N opcode bogo operations" },
 	{ NULL,	"opcode-method M", "set opcode stress method (M = random, inc, mixed, text)" },
@@ -147,7 +147,7 @@ static void stress_opcode_random(
 	(void)op;
 
 	while (ops < ops_end)
-		*(ops++) = mwc8();
+		*(ops++) = stress_mwc8();
 }
 
 static void stress_opcode_inc(
@@ -173,7 +173,7 @@ static void stress_opcode_mixed(
 	register uint32_t *ops = (uint32_t *)ops_begin;
 
 	while (ops < (uint32_t *)ops_end) {
-		register uint32_t rnd = mwc32();
+		register uint32_t rnd = stress_mwc32();
 
 		*(ops++) = tmp;
 		*(ops++) = tmp ^ 0xffffffff;	/* Inverted */
@@ -204,12 +204,12 @@ static void stress_opcode_text(
 		return;
 	}
 
-	offset = mwc64() % (text_len - ops_len);
+	offset = stress_mwc64() % (text_len - ops_len);
 	offset &= ~(0x7ULL);
 
 	(void)memcpy(ops_begin, text_start + offset, ops_len);
 	for (ops = ops_begin; ops < ops_end; ops++) {
-		uint8_t rnd = mwc8();
+		uint8_t rnd = stress_mwc8();
 
 		/* 1 in 8 chance of random bit corruption */
 		if (rnd < 32) {
@@ -237,7 +237,7 @@ static int stress_set_opcode_method(const char *name)
 
 	for (info = stress_opcode_methods; info->func; info++) {
 		if (!strcmp(info->name, name)) {
-			set_setting("opcode-method", TYPE_ID_UINTPTR_T, &info);
+			stress_set_setting("opcode-method", TYPE_ID_UINTPTR_T, &info);
 			return 0;
 		}
 	}
@@ -255,7 +255,7 @@ static int stress_set_opcode_method(const char *name)
  *  stress_opcode
  *	stress with random opcodes
  */
-static int stress_opcode(const args_t *args)
+static int stress_opcode(const stress_args_t *args)
 {
 	const size_t page_size = args->page_size;
 	int rc;
@@ -275,7 +275,7 @@ static int stress_opcode(const args_t *args)
 	}
 #endif
 
-	(void)get_setting("opcode-method", &opcode_method);
+	(void)stress_get_setting("opcode-method", &opcode_method);
 
 	do {
 		pid_t pid;
@@ -284,7 +284,7 @@ static int stress_opcode(const args_t *args)
 		 *  Force a new random value so that child always
 		 *  gets a different random value on each fork
 		 */
-		(void)mwc32();
+		(void)stress_mwc32();
 		op += 1024;
 again:
 		if (!keep_stressing_flag())
@@ -404,7 +404,7 @@ static void stress_opcode_set_default(void)
         stress_set_opcode_method("random");
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_opcode_method,	stress_set_opcode_method },
 	{ 0,			NULL }
 };
@@ -427,7 +427,7 @@ static int stress_set_opcode_method(const char *name)
 	return -1;
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_opcode_method,	stress_set_opcode_method },
 	{ 0,			NULL }
 };
