@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"personality N",	"start N workers that change their personality" },
 	{ NULL,	"personality-ops N",	"stop after N bogo personality calls" },
 	{ NULL,	NULL,			NULL }
@@ -41,7 +41,7 @@ static const unsigned long personalities[] = {
  *  stress_personality()
  *	stress system by rapid open/close calls
  */
-static int stress_personality(const args_t *args)
+static int stress_personality(const stress_args_t *args)
 {
 	const ssize_t n = SIZEOF_ARRAY(personalities);
 	bool failed[n];
