@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"physpage N",	  "start N workers performing physical page lookup" },
 	{ NULL,	"physpage-ops N", "stop after N physical page bogo operations" },
 	{ NULL,	NULL,		  NULL }
@@ -51,7 +51,7 @@ static int stress_physpage_supported(void)
 }
 
 static int stress_virt_to_phys(
-	const args_t *args,
+	const stress_args_t *args,
 	const size_t page_size,
 	const int fd_pm,
 	const int fd_pc,
@@ -116,7 +116,7 @@ err:
  *  stress_physpage()
  *	stress physical page lookups
  */
-static int stress_physpage(const args_t *args)
+static int stress_physpage(const stress_args_t *args)
 {
 	int fd_pm, fd_pc;
 	const size_t page_size = args->page_size;
