@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"pidfd N",	"start N workers exercising pidfd system call" },
 	{ NULL,	"pidfd-ops N",	"stop after N pidfd bogo operations" },
 	{ NULL,	NULL,		NULL }
@@ -79,7 +79,7 @@ static void stress_pidfd_reap(pid_t pid, int pidfd)
  *  stress_pidfd
  *	stress signalfd reads
  */
-static int stress_pidfd(const args_t *args)
+static int stress_pidfd(const stress_args_t *args)
 {
 	while (keep_stressing()) {
 		pid_t pid;
