@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ "P N", "poll N",	"start N workers exercising zero timeout polling" },
 	{ NULL,	"poll-ops N",	"stop after N poll bogo operations" },
 	{ NULL,	NULL,		NULL }
@@ -39,7 +39,7 @@ static const help_t help[] = {
  *  pipe_read()
  *	read a pipe with some verification and checking
  */
-static int pipe_read(const args_t *args, const int fd, const int n)
+static int pipe_read(const stress_args_t *args, const int fd, const int n)
 {
 	while (keep_stressing_flag()) {
 		ssize_t ret;
@@ -75,7 +75,7 @@ static int pipe_read(const args_t *args, const int fd, const int n)
  *  stress_poll()
  *	stress system by rapid polling system calls
  */
-static int stress_poll(const args_t *args)
+static int stress_poll(const stress_args_t *args)
 {
 	int pipefds[MAX_PIPES][2];
 	int i;
@@ -116,7 +116,7 @@ again:
 			ssize_t ret;
 
 			/* Write on a randomly chosen pipe */
-			i = (mwc32() >> 8) % MAX_PIPES;
+			i = (stress_mwc32() >> 8) % MAX_PIPES;
 			(void)memset(buf, '0' + i, sizeof(buf));
 			ret = write(pipefds[i][1], buf, sizeof(buf));
 			if (ret < (ssize_t)sizeof(buf)) {
