@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"procfs N",	"start N workers reading portions of /proc" },
 	{ NULL,	"procfs-ops N",	"stop procfs workers after N bogo read operations" },
 	{ NULL,	NULL,		NULL }
@@ -82,9 +82,11 @@ static const help_t help[] = {
      defined(PR_SVE_GET_VL) ||			\
      defined(PR_SVE_SET_VL) ||			\
      defined(PR_GET_TAGGED_ADDR_CTRL) ||	\
-     defined(PR_SET_TAGGED_ADDR_CTRL)
+     defined(PR_SET_TAGGED_ADDR_CTRL) ||	\
+     defined(PR_GET_IO_FLUSHER) ||		\
+     defined(PR_SET_IO_FLUSHER)
 
-static int stress_prctl_child(const args_t *args, const pid_t mypid)
+static int stress_prctl_child(const stress_args_t *args, const pid_t mypid)
 {
 	int ret;
 
@@ -501,6 +503,18 @@ static int stress_prctl_child(const args_t *args, const pid_t mypid)
 	}
 #endif
 
+#if defined(PR_GET_IO_FLUSHER)
+	{
+		ret = prctl(PR_GET_IO_FLUSHER, 0, 0, 0, 0);
+		(void)ret;
+
+#if defined(PR_SET_IO_FLUSHER)
+		ret = prctl(PR_SET_IO_FLUSHER, ret, 0, 0, 0);
+		(void)ret;
+#endif
+	}
+#endif
+
 	(void)ret;
 
 	return 0;
@@ -510,7 +524,7 @@ static int stress_prctl_child(const args_t *args, const pid_t mypid)
  *  stress_prctl()
  *	stress seccomp
  */
-static int stress_prctl(const args_t *args)
+static int stress_prctl(const stress_args_t *args)
 {
 	do {
 		pid_t pid;
