@@ -22,7 +22,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"procfs N",	"start N workers reading portions of /proc" },
 	{ NULL,	"procfs-ops N",	"stop procfs workers after N bogo read operations" },
 	{ NULL,	NULL,		NULL }
@@ -34,7 +34,7 @@ static const help_t help[] = {
 #define MAX_PROCFS_THREADS	(4)
 
 typedef struct stress_ctxt {
-	const args_t *args;
+	const stress_args_t *args;
 	const char *path;
 	bool writeable;
 } stress_ctxt_t;
@@ -161,7 +161,7 @@ static inline void stress_proc_rw(
 		 *  Multiple randomly sized reads
 		 */
 		while (i < (4096 * PROC_BUF_SZ)) {
-			ssize_t sz = 1 + (mwc32() % sizeof(buffer));
+			ssize_t sz = 1 + (stress_mwc32() % sizeof(buffer));
 			if (!keep_stressing_flag())
 				break;
 			ret = read(fd, buffer, sz);
@@ -200,7 +200,7 @@ static inline void stress_proc_rw(
 		ptr = mmap(NULL, page_size, PROT_READ,
 			MAP_SHARED | MAP_ANONYMOUS, fd, 0);
 		if (ptr != MAP_FAILED) {
-			uint8_put(*ptr);
+			stress_uint8_put(*ptr);
 			(void)munmap(ptr, page_size);
 		}
 
@@ -298,7 +298,6 @@ next:
 static void *stress_proc_rw_thread(void *ctxt_ptr)
 {
 	static void *nowt = NULL;
-	uint8_t stack[SIGSTKSZ + STACK_ALIGNMENT];
 	stress_ctxt_t *ctxt = (stress_ctxt_t *)ctxt_ptr;
 
 	/*
@@ -307,16 +306,6 @@ static void *stress_proc_rw_thread(void *ctxt_ptr)
 	 */
 	(void)sigprocmask(SIG_BLOCK, &set, NULL);
 
-	/*
-	 *  According to POSIX.1 a thread should have
-	 *  a distinct alternative signal stack.
-	 *  However, we block signals in this thread
-	 *  so this is probably just totally unncessary.
-	 */
-	(void)memset(stack, 0, sizeof(stack));
-	if (stress_sigaltstack(stack, SIGSTKSZ) < 0)
-		return &nowt;
-
 	while (keep_stressing_flag())
 		stress_proc_rw(ctxt, -1);
 
@@ -334,7 +323,7 @@ static void stress_proc_dir(
 	const int depth)
 {
 	struct dirent **dlist;
-	const args_t *args = ctxt->args;
+	const stress_args_t *args = ctxt->args;
 	int32_t loops = args->instance < 8 ? args->instance + 1 : 8;
 	int i, n;
 
@@ -345,12 +334,7 @@ static void stress_proc_dir(
 	if (depth > 20)
 		return;
 
-#if defined(STRESS_ARM)
-	if (!strncmp(path, "/proc/bus/pci", 13))
-		return;
-#endif
-
-	mixup = mwc32();
+	mixup = stress_mwc32();
 	dlist = NULL;
 	n = scandir(path, &dlist, NULL, mixup_sort);
 	if (n <= 0)
@@ -401,7 +385,7 @@ done:
  *  stress_procfs
  *	stress reading all of /proc
  */
-static int stress_procfs(const args_t *args)
+static int stress_procfs(const stress_args_t *args)
 {
 	size_t i;
 	pthread_t pthreads[MAX_PROCFS_THREADS];
