@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"pthread N",	 "start N workers that create multiple threads" },
 	{ NULL,	"pthread-ops N", "stop pthread workers after N bogo threads created" },
 	{ NULL,	"pthread-max P", "create P threads at a time by each worker" },
@@ -33,9 +33,13 @@ static const help_t help[] = {
 
 #if defined(HAVE_LIB_PTHREAD)
 
+/* per pthread data */
 typedef struct {
-	pthread_t pthread;
-	pid_t     tid;
+	pthread_t pthread;	/* The pthread */
+	int	  ret;		/* pthread create return */
+#if defined(HAVE_PTHREAD_ATTR_SETSTACK)
+	void 	 *stack;	/* pthread stack */
+#endif
 } stress_pthread_info_t;
 
 static pthread_cond_t cond;
@@ -52,19 +56,24 @@ static int stress_set_pthread_max(const char *opt)
 {
 	uint64_t pthread_max;
 
-	pthread_max = get_uint64(opt);
-	check_range("pthread-max", pthread_max,
+	pthread_max = stress_get_uint64(opt);
+	stress_check_range("pthread-max", pthread_max,
 		MIN_PTHREAD, MAX_PTHREAD);
-	return set_setting("pthread-max", TYPE_ID_UINT64, &pthread_max);
+	return stress_set_setting("pthread-max", TYPE_ID_UINT64, &pthread_max);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_pthread_max,	stress_set_pthread_max },
 	{ 0,			NULL }
 };
 
 #if defined(HAVE_LIB_PTHREAD)
 
+/* Some systems such as GNU/HURD don't define PTHREAD_STACK_MIN */
+#if !defined(PTHREAD_STACK_MIN)
+#define PTHREAD_STACK_MIN		(16 * KB)
+#endif
+
 #if defined(HAVE_GET_ROBUST_LIST) && defined(HAVE_LINUX_FUTEX_H)
 static inline long sys_get_robust_list(int pid, struct robust_list_head **head_ptr, size_t *len_ptr)
 {
@@ -114,32 +123,18 @@ static bool keep_thread_running(void)
  */
 static void *stress_pthread_func(void *parg)
 {
-	uint8_t stack[SIGSTKSZ + STACK_ALIGNMENT];
 	static void *nowt = NULL;
 	int ret;
+#if defined(HAVE_GETTID)
 	const pid_t tid = shim_gettid();
+#else
+	const pid_t tid = 0;
+#endif
 #if defined(HAVE_GET_ROBUST_LIST) && defined(HAVE_LINUX_FUTEX_H)
 	struct robust_list_head *head;
 	size_t len;
 #endif
-	const args_t *args = ((pthread_args_t *)parg)->args;
-
-	/*
-	 *  According to POSIX.1 a thread should have
-	 *  a distinct alternative signal stack.
-	 *  However, we block signals in this thread
-	 *  so this is probably just totally unncessary.
-	 */
-	(void)memset(stack, 0, sizeof(stack));
-	if (stress_sigaltstack(stack, SIGSTKSZ) < 0)
-		goto die;
-
-#if defined(HAVE_GETTID)
-	{
-		stress_pthread_info_t *pi = ((pthread_args_t *)parg)->data;
-		pi->tid = shim_gettid();
-	}
-#endif
+	const stress_args_t *args = ((stress_pthread_args_t *)parg)->args;
 
 #if defined(HAVE_GET_ROBUST_LIST) && defined(HAVE_LINUX_FUTEX_H)
 	/*
@@ -148,7 +143,7 @@ static void *stress_pthread_func(void *parg)
 	if (sys_get_robust_list(0, &head, &len) < 0) {
 		if (errno != ENOSYS) {
 			pr_fail("%s: get_robust_list failed, tid=%d, errno=%d (%s)\n",
-				args->name, tid, errno, strerror(errno));
+				args->name, (int)tid, errno, strerror(errno));
 			goto die;
 		}
 	} else {
@@ -156,7 +151,7 @@ static void *stress_pthread_func(void *parg)
 		if (sys_set_robust_list(head, len) < 0) {
 			if (errno != ENOSYS) {
 				pr_fail("%s: set_robust_list failed, tid=%d, errno=%d (%s)\n",
-					args->name, tid, errno, strerror(errno));
+					args->name, (int)tid, errno, strerror(errno));
 				goto die;
 			}
 		}
@@ -251,14 +246,17 @@ die:
  *  stress_pthread()
  *	stress by creating pthreads
  */
-static int stress_pthread(const args_t *args)
+static int stress_pthread(const stress_args_t *args)
 {
 	bool locked = false;
 	uint64_t limited = 0, attempted = 0;
 	uint64_t pthread_max = DEFAULT_PTHREAD;
 	int ret;
-	pthread_args_t pargs = { args, NULL, 0 };
+	stress_pthread_args_t pargs = { args, NULL, 0 };
 	sigset_t set;
+#if defined(HAVE_PTHREAD_ATTR_SETSTACK)
+	const size_t stack_size = STRESS_MAXIMUM(16 * KB, PTHREAD_STACK_MIN);
+#endif
 
 	keep_running_flag = true;
 
@@ -271,7 +269,7 @@ static int stress_pthread(const args_t *args)
 	sigaddset(&set, SIGALRM);
 	sigprocmask(SIG_BLOCK, &set, NULL);
 
-	if (!get_setting("pthread-max", &pthread_max)) {
+	if (!stress_get_setting("pthread-max", &pthread_max)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			pthread_max = MAX_PTHREAD;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -309,20 +307,54 @@ static int stress_pthread(const args_t *args)
 			stop_running();
 			continue;
 		}
+		for (i = 0; i < pthread_max; i++)
+			pthreads[i].ret = -1;
+
 		for (i = 0; i < pthread_max; i++) {
+#if defined(HAVE_PTHREAD_ATTR_SETSTACK)
+			pthread_attr_t attr;
+#endif
 			pargs.data = (void *)&pthreads[i];
 
-			ret = pthread_create(&pthreads[i].pthread, NULL,
-				stress_pthread_func, (void *)&pargs);
+#if defined(HAVE_PTHREAD_ATTR_SETSTACK)
+			/*
+			 *  We mmap our own per pthread stack to ensure we
+			 *  have one available before the pthread is started
+			 *  and this allows us to exercise the pthread stack
+			 *  setting.
+			 */
+			pthreads[i].stack = mmap(NULL, stack_size, PROT_READ | PROT_WRITE,
+				MAP_PRIVATE | MAP_ANONYMOUS, -1, 0);
+			if (pthreads[i].stack == MAP_FAILED)
+				break;
+
+			ret = pthread_attr_init(&attr);
 			if (ret) {
+				pr_fail("%s: pthread_attr_init failed, errno=%d (%s)\n",
+					args->name, ret, strerror(ret));
+				stop_running();
+				break;
+			}
+			ret = pthread_attr_setstack(&attr, pthreads[i].stack, stack_size);
+			if (ret) {
+				pr_fail("%s: pthread_attr_setstack failed, errno=%d (%s)\n",
+					args->name, ret, strerror(ret));
+				stop_running();
+				break;
+			}
+#endif
+
+			pthreads[i].ret = pthread_create(&pthreads[i].pthread, NULL,
+				stress_pthread_func, (void *)&pargs);
+			if (pthreads[i].ret) {
 				/* Out of resources, don't try any more */
-				if (ret == EAGAIN) {
+				if (pthreads[i].ret == EAGAIN) {
 					limited++;
 					break;
 				}
 				/* Something really unexpected */
 				pr_fail("%s: pthread_create failed, errno=%d (%s)\n",
-					args->name, ret, strerror(ret));
+					args->name, pthreads[i].ret, strerror(ret));
 				stop_running();
 				break;
 			}
@@ -344,6 +376,11 @@ static int stress_pthread(const args_t *args)
 		for (j = 0; j < 1000; j++) {
 			bool all_running = false;
 
+			if (!keep_stressing()) {
+				stop_running();
+				goto reap;
+			}
+
 			if (!locked) {
 				ret = shim_pthread_spin_lock(&spinlock);
 				if (ret) {
@@ -382,6 +419,12 @@ reap:
 			/* fall through and unlock */
 		}
 		for (j = 0; j < i; j++) {
+#if defined(HAVE_PTHREAD_ATTR_SETSTACK)
+			if (pthreads[j].stack != MAP_FAILED)
+				(void)munmap(pthreads[j].stack, stack_size);
+#endif
+			if (pthreads[j].ret)
+				continue;
 			ret = pthread_join(pthreads[j].pthread, NULL);
 			if ((ret) && (ret != ESRCH)) {
 				pr_fail("%s: pthread_join failed (parent), errno=%d (%s)\n",
