@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"ptrace N",	"start N workers that trace a child using ptrace" },
 	{ NULL,	"ptrace-ops N",	"stop ptrace workers after N system calls are traced" },
 	{ NULL, NULL,		NULL }
@@ -36,18 +36,20 @@ static const help_t help[] = {
  *  main syscall ptrace loop
  */
 static inline bool stress_syscall_wait(
-	const args_t *args,
+	const stress_args_t *args,
 	const pid_t pid)
 {
 	while (keep_stressing_flag()) {
 		int status;
 
 		if (ptrace(PTRACE_SYSCALL, pid, 0, 0) < 0) {
-			pr_fail_dbg("ptrace");
-			return true;
+			if ((errno != ESRCH) && (errno != EPERM) && (errno != EACCES)) {
+				pr_fail_dbg("ptrace");
+				return true;
+			}
 		}
 		if (shim_waitpid(pid, &status, 0) < 0) {
-			if (errno != EINTR)
+			if ((errno != EINTR) && (errno != ECHILD))
 				pr_fail_dbg("waitpid");
 			return true;
 		}
@@ -65,7 +67,7 @@ static inline bool stress_syscall_wait(
  *  stress_ptrace()
  *	stress ptracing
  */
-static int stress_ptrace(const args_t *args)
+static int stress_ptrace(const stress_args_t *args)
 {
 	pid_t pid;
 
@@ -83,9 +85,10 @@ static int stress_ptrace(const args_t *args)
 		 * as this makes life way too complex
 		 */
 		if (ptrace(PTRACE_TRACEME) != 0) {
-			pr_fail("%s: ptrace child being traced "
-				"already, aborting\n", args->name);
-			_exit(0);
+			pr_inf("%s: child cannot be traced, "
+				"skipping stressor: errno=%d (%s)\n",
+				args->name, errno, strerror(errno));
+			_exit(EXIT_SUCCESS);
 		}
 		/* Wait for parent to start tracing me */
 		(void)kill(getpid(), SIGSTOP);
@@ -130,7 +133,7 @@ static int stress_ptrace(const args_t *args)
 		(void)setpgid(pid, g_pgrp);
 
 		if (shim_waitpid(pid, &status, 0) < 0) {
-			if (errno != EINTR) {
+			if ((errno != EINTR) && (errno != ECHILD)) {
 				pr_fail_dbg("waitpid");
 				return EXIT_FAILURE;
 			}
@@ -138,6 +141,21 @@ static int stress_ptrace(const args_t *args)
 		}
 		if (ptrace(PTRACE_SETOPTIONS, pid,
 			0, PTRACE_O_TRACESYSGOOD) < 0) {
+			pr_inf("%s: child cannot be traced, "
+				"skipping stressor: errno=%d (%s)\n",
+				args->name, errno, strerror(errno));
+			if ((errno == ESRCH) || (errno == EPERM) || (errno == EACCES)) {
+				/* Ensure child is really dead and reap */
+				(void)kill(pid, SIGKILL);
+				if (shim_waitpid(pid, &status, 0) < 0) {
+					if ((errno != EINTR) && (errno != ECHILD)) {
+						pr_fail_dbg("waitpid");
+						return EXIT_FAILURE;
+					}
+					return EXIT_SUCCESS;
+				}
+				return WEXITSTATUS(status);
+			}
 			pr_fail_dbg("ptrace");
 			return EXIT_FAILURE;
 		}
