@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"pty N",	"start N workers that exercise pseudoterminals" },
 	{ NULL,	"pty-ops N",	"stop pty workers after N pty bogo operations" },
 	{ NULL,	"pty-max N",	"attempt to open a maximum of N ptys" },
@@ -51,13 +51,13 @@ static int stress_set_pty_max(const char *opt)
 {
 	uint64_t pty_max;
 
-	pty_max = get_uint64(opt);
-	check_range("pty-max", pty_max,
+	pty_max = stress_get_uint64(opt);
+	stress_check_range("pty-max", pty_max,
 		MIN_PTYS, MAX_PTYS);
-	return set_setting("pty-max", TYPE_ID_UINT64, &pty_max);
+	return stress_set_setting("pty-max", TYPE_ID_UINT64, &pty_max);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_pty_max,	stress_set_pty_max },
 	{ 0,		NULL }
 };
@@ -70,12 +70,12 @@ static const opt_set_func_t opt_set_funcs[] = {
  *  stress_pty
  *	stress pty handling
  */
-static int stress_pty(const args_t *args)
+static int stress_pty(const stress_args_t *args)
 {
 	uint64_t pty_max = DEFAULT_PTYS;
 	stress_pty_info_t *ptys;
 
-	(void)get_setting("pty-max", &pty_max);
+	(void)stress_get_setting("pty-max", &pty_max);
 
 	ptys = calloc(pty_max, sizeof(*ptys));
 	if (!ptys) {
