@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"radixsort N",	    "start N workers radix sorting random strings" },
 	{ NULL,	"radixsort-ops N",  "stop after N radixsort bogo operations" },
 	{ NULL,	"radixsort-size N", "number of strings to sort" },
@@ -61,13 +61,13 @@ static int stress_set_radixsort_size(const char *opt)
 {
 	uint64_t radixsort_size;
 
-	radixsort_size = get_uint64(opt);
-	check_range("radixsort-size", radixsort_size,
+	radixsort_size = stress_get_uint64(opt);
+	stress_check_range("radixsort-size", radixsort_size,
 		MIN_QSORT_SIZE, MAX_QSORT_SIZE);
-	return set_setting("radixsort-size", TYPE_ID_UINT64, &radixsort_size);
+	return stress_set_setting("radixsort-size", TYPE_ID_UINT64, &radixsort_size);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_radixsort_size,	stress_set_radixsort_size },
 	{ 0,			NULL }
 };
@@ -77,7 +77,7 @@ static const opt_set_func_t opt_set_funcs[] = {
  *  stress_radixsort()
  *	stress radixsort
  */
-static int stress_radixsort(const args_t *args)
+static int stress_radixsort(const stress_args_t *args)
 {
 	uint64_t radixsort_size = DEFAULT_RADIXSORT_SIZE;
 	const unsigned char **data;
@@ -87,7 +87,7 @@ static int stress_radixsort(const args_t *args)
 	int ret;
 	unsigned char revtable[256];
 
-	if (!get_setting("radixsort-size", &radixsort_size)) {
+	if (!stress_get_setting("radixsort-size", &radixsort_size)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			radixsort_size = MAX_RADIXSORT_SIZE;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -142,7 +142,7 @@ static int stress_radixsort(const args_t *args)
 
 		/* Randomize first char */
 		for (ptr = text, i = 0; i < n; i++, ptr += STR_SIZE)
-			*ptr = 'a' + (mwc8() % 26);
+			*ptr = 'a' + (stress_mwc8() % 26);
 
 		inc_counter(args);
 	} while (keep_stressing());
