@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"ramfs N",	 "start N workers exercising ramfs mounts" },
 	{ NULL,	"ramfs-ops N",	 "stop after N bogo ramfs mount operations" },
 	{ NULL, "ramfs-bytes N", "set the ramfs size in bytes, e.g. 2M is 2MB" },
@@ -62,15 +62,15 @@ static int stress_set_ramfs_size(const char *opt)
 	const uint64_t page_size = (uint64_t)stress_get_pagesize();
 	const uint64_t page_mask = ~(page_size - 1);
 
-        ramfs_size = get_uint64_byte(opt);
-        check_range_bytes("ramfs-size", ramfs_size,
+        ramfs_size = stress_get_uint64_byte(opt);
+        stress_check_range_bytes("ramfs-size", ramfs_size,
                 1 * MB, 1 * GB);
 	if (ramfs_size & (page_size - 1)) {
 		ramfs_size &= page_mask;
 		pr_inf("ramfs: rounding ramfs-size to %" PRIu64 " x %" PRId64 "K pages\n",
 			ramfs_size / page_size, page_size >> 10);
 	}
-        return set_setting("ramfs-size", TYPE_ID_UINT64, &ramfs_size);
+        return stress_set_setting("ramfs-size", TYPE_ID_UINT64, &ramfs_size);
 }
 
 static void stress_ramfs_child_handler(int signum)
@@ -84,7 +84,7 @@ static void stress_ramfs_child_handler(int signum)
  *  stress_ramfs_umount()
  *	umount a path with retries.
  */
-static void stress_ramfs_umount(const args_t *args, const char *path)
+static void stress_ramfs_umount(const stress_args_t *args, const char *path)
 {
 	int i;
 	static const uint64_t ns = 100000000;	/* 1/10th second */
@@ -133,7 +133,7 @@ static void stress_ramfs_umount(const args_t *args, const char *path)
  *  stress_ramfs_fs_ops()
  *	exercise the ram based file system;
  */
-static int stress_ramfs_fs_ops(const args_t *args, const char *pathname)
+static int stress_ramfs_fs_ops(const stress_args_t *args, const char *pathname)
 {
 	char filename[PATH_MAX + 5];
 	char symlinkname[PATH_MAX + 5];
@@ -201,7 +201,7 @@ static int stress_ramfs_fs_ops(const args_t *args, const char *pathname)
  *	aggressively perform ramfs mounts, this can force out of memory
  *	situations
  */
-static int stress_ramfs_child(const args_t *args)
+static int stress_ramfs_child(const stress_args_t *args)
 {
 	char pathname[PATH_MAX], realpathname[PATH_MAX];
 	uint64_t ramfs_size = 2 * MB;
@@ -221,7 +221,7 @@ static int stress_ramfs_child(const args_t *args)
 	(void)setpgid(0, g_pgrp);
 	stress_parent_died_alarm();
 
-	(void)get_setting("ramfs-size", &ramfs_size);
+	(void)stress_get_setting("ramfs-size", &ramfs_size);
 
 	stress_temp_dir(pathname, sizeof(pathname), args->name, args->pid, args->instance);
 	if (mkdir(pathname, S_IRGRP | S_IWGRP) < 0) {
@@ -276,6 +276,7 @@ static int stress_ramfs_child(const args_t *args)
 				goto skip_fsopen;
 			pr_fail("%s: fsopen failed: errno=%d (%s)\n",
 				args->name, errno, strerror(errno));
+			goto skip_fsopen;
 		}
 		(void)snprintf(opt, sizeof(opt), "%" PRIu64, ramfs_size);
 		if (shim_fsconfig(fd, FSCONFIG_SET_STRING, "size", opt, 0) < 0) {
@@ -343,7 +344,7 @@ cleanup:
  *  stress_ramfs_mount()
  *      stress ramfs mounting
  */
-static int stress_ramfs_mount(const args_t *args)
+static int stress_ramfs_mount(const stress_args_t *args)
 {
 	int pid;
 
@@ -378,7 +379,7 @@ again:
 					args->instance);
 				/* If we got killed by OOM killer, re-start */
 				if (WTERMSIG(status) == SIGKILL) {
-					log_system_mem_info();
+					stress_log_system_mem_info();
 					pr_dbg("%s: assuming killed by OOM killer, "
 						"restarting again (instance %d)\n",
 						args->name, args->instance);
@@ -396,7 +397,7 @@ again:
 	return EXIT_SUCCESS;
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
         { OPT_ramfs_size,	stress_set_ramfs_size},
         { 0,                    NULL }
 };
