@@ -24,14 +24,14 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"rawdev N",	   "start N workers that read a raw device" },
 	{ NULL,	"rawdev-ops N",	   "stop after N rawdev read operations" },
 	{ NULL,	"rawdev-method M", "specify the rawdev reead method to use" },
 	{ NULL,	NULL,		   NULL }
 };
 
-typedef void (*stress_rawdev_func)(const args_t *args, const int fd,
+typedef void (*stress_rawdev_func)(const stress_args_t *args, const int fd,
 			   unsigned long blks, unsigned long blksz);
 
 #define	MIN_BLKSZ	((int)512)
@@ -96,7 +96,7 @@ static char *stress_rawdev_path(const dev_t dev)
 }
 
 static void stress_rawdev_sweep(
-	const args_t *args,
+	const stress_args_t *args,
 	const int fd,
 	unsigned long blks,
 	unsigned long blksz)
@@ -128,7 +128,7 @@ static void stress_rawdev_sweep(
 }
 
 static void stress_rawdev_wiggle(
-	const args_t *args,
+	const stress_args_t *args,
 	const int fd,
 	unsigned long blks,
 	unsigned long blksz)
@@ -155,7 +155,7 @@ static void stress_rawdev_wiggle(
 }
 
 static void stress_rawdev_ends(
-	const args_t *args,
+	const stress_args_t *args,
 	const int fd,
 	unsigned long blks,
 	unsigned long blksz)
@@ -187,7 +187,7 @@ static void stress_rawdev_ends(
 }
 
 static void stress_rawdev_random(
-	const args_t *args,
+	const stress_args_t *args,
 	const int fd,
 	unsigned long blks,
 	unsigned long blksz)
@@ -198,7 +198,7 @@ static void stress_rawdev_random(
 
 	for (i = 0; i < 256 && keep_stressing(); i++) {
 		int ret;
-		off_t offset = (off_t)blksz * (mwc64() % blks);
+		off_t offset = (off_t)blksz * (stress_mwc64() % blks);
 
 		ret = pread(fd, aligned, (size_t)blksz, offset);
 		if (ret < 0) {
@@ -210,7 +210,7 @@ static void stress_rawdev_random(
 }
 
 static void stress_rawdev_burst(
-	const args_t *args,
+	const stress_args_t *args,
 	const int fd,
 	unsigned long blks,
 	unsigned long blksz)
@@ -218,7 +218,7 @@ static void stress_rawdev_burst(
 	int i;
 	char buf[blksz << 1];
 	char *aligned = stress_align_address(buf, blksz);
-	off_t blk = (mwc64() % blks);
+	off_t blk = (stress_mwc64() % blks);
 
 	for (i = 0; i < 256 && keep_stressing(); i++) {
 		int ret;
@@ -242,7 +242,7 @@ static const stress_rawdev_method_info_t rawdev_methods[];
  *      iterate over all rawdev methods
  */
 static void stress_rawdev_all(
-	const args_t *args,
+	const stress_args_t *args,
 	const int fd,
 	unsigned long blks,
 	unsigned long blksz)
@@ -283,7 +283,7 @@ static int stress_set_rawdev_method(const char *name)
 
 	for (info = rawdev_methods; info->func; info++) {
 		if (!strcmp(info->name, name)) {
-			set_setting("rawdev-method", TYPE_ID_UINTPTR_T, &info);
+			stress_set_setting("rawdev-method", TYPE_ID_UINTPTR_T, &info);
 			return 0;
 		}
 	}
@@ -310,7 +310,7 @@ static int stress_set_rawdev_method(const char *name)
 }
 #endif
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_rawdev_method,	stress_set_rawdev_method },
 	{ 0,			NULL }
 };
@@ -319,7 +319,7 @@ static const opt_set_func_t opt_set_funcs[] = {
     defined(BLKGETSIZE) && 		\
     defined(BLKSSZGET)
 
-static int stress_rawdev(const args_t *args)
+static int stress_rawdev(const stress_args_t *args)
 {
 	int ret;
 	char path[PATH_MAX], *devpath;
@@ -332,7 +332,7 @@ static int stress_rawdev(const args_t *args)
 
 	stress_temp_dir_args(args, path, sizeof(path));
 
-	(void)get_setting("rawdev-method", &rawdev_method);
+	(void)stress_get_setting("rawdev-method", &rawdev_method);
 	func = rawdev_method->func;
 
 	fd = open(path, O_RDWR | O_CREAT, S_IRUSR | S_IWUSR);
