@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"rawsock N",		"start N workers performing raw socket send/receives " },
 	{ NULL,	"rawsock-ops N",	"stop after N raw socket bogo operations" },
 	{ NULL,	NULL,			NULL }
@@ -58,7 +58,7 @@ static int stress_rawsock_supported(void)
  *  stress_rawsock
  *	stress by heavy raw udp ops
  */
-static int stress_rawsock(const args_t *args)
+static int stress_rawsock(const stress_args_t *args)
 {
 	pid_t pid;
 	int rc = EXIT_SUCCESS;
