@@ -24,14 +24,14 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"rdrand N",	"start N workers exercising rdrand (x86 only)" },
 	{ NULL,	"rdrand-ops N",	"stop after N rdrand bogo operations" },
 	{ NULL,	NULL,		NULL }
 };
 
 #if defined(HAVE_CPUID_H) &&	\
-    defined(STRESS_X86) &&	\
+    defined(STRESS_ARCH_X86) &&	\
     defined(HAVE_CPUID) &&	\
     NEED_GNUC(4,6,0)
 
@@ -102,7 +102,7 @@ static inline uint32_t rand64(void)
 #endif
 
 
-#if defined(STRESS_PPC64) &&	\
+#if defined(STRESS_ARCH_PPC64) &&	\
     defined(HAVE_DARN)
 
 #define HAVE_RAND_CAPABILITY
@@ -186,7 +186,7 @@ static inline uint64_t rand64(void)
  *  stress_rdrand()
  *      stress Intel rdrand instruction
  */
-static int stress_rdrand(const args_t *args)
+static int stress_rdrand(const stress_args_t *args)
 {
 	if (rdrand_supported) {
 		double time_start, duration, billion_bits;
