@@ -28,7 +28,7 @@
 #define BUF_SIZE		(512)
 #define MAX_OFFSETS		(16)
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"readahead N",		"start N workers exercising file readahead" },
 	{ NULL,	"readahead-bytes N",	"size of file to readahead on (default is 1GB)" },
 	{ NULL,	"readahead-ops N",	"stop after N readahead bogo operations" },
@@ -39,13 +39,13 @@ static int stress_set_readahead_bytes(const char *opt)
 {
 	uint64_t readahead_bytes;
 
-	readahead_bytes = get_uint64_byte_filesystem(opt, 1);
-	check_range_bytes("readahead-bytes", readahead_bytes,
+	readahead_bytes = stress_get_uint64_byte_filesystem(opt, 1);
+	stress_check_range_bytes("readahead-bytes", readahead_bytes,
 		MIN_HDD_BYTES, MAX_HDD_BYTES);
-	return set_setting("readahead-bytes", TYPE_ID_UINT64, &readahead_bytes);
+	return stress_set_setting("readahead-bytes", TYPE_ID_UINT64, &readahead_bytes);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_readahead_bytes,	stress_set_readahead_bytes },
 	{ 0,			NULL }
 };
@@ -53,7 +53,7 @@ static const opt_set_func_t opt_set_funcs[] = {
 #if defined(__linux__) && NEED_GLIBC(2,3,0)
 
 static int do_readahead(
-	const args_t *args,
+	const stress_args_t *args,
 	const int fd,
 	off_t *offsets,
 	const uint64_t rounded_readahead_bytes)
@@ -61,7 +61,7 @@ static int do_readahead(
 	int i;
 
 	for (i = 0; i < MAX_OFFSETS; i++) {
-		offsets[i] = (mwc64() % (rounded_readahead_bytes - BUF_SIZE)) & ~511;
+		offsets[i] = (stress_mwc64() % (rounded_readahead_bytes - BUF_SIZE)) & ~511;
 		if (readahead(fd, offsets[i], BUF_SIZE) < 0) {
 			pr_fail_err("ftruncate");
 			return -1;
@@ -74,7 +74,7 @@ static int do_readahead(
  *  stress_readahead
  *	stress file system cache via readahead calls
  */
-static int stress_readahead(const args_t *args)
+static int stress_readahead(const stress_args_t *args)
 {
 	uint8_t *buf = NULL;
 	uint64_t rounded_readahead_bytes, i;
@@ -87,7 +87,7 @@ static int stress_readahead(const args_t *args)
 	int fd;
 	struct stat statbuf;
 
-	if (!get_setting("readahead-bytes", &readahead_bytes)) {
+	if (!stress_get_setting("readahead-bytes", &readahead_bytes)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			readahead_bytes = MAXIMIZED_FILE_SIZE;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -109,7 +109,7 @@ static int stress_readahead(const args_t *args)
 	}
 
 	(void)stress_temp_filename_args(args,
-		filename, sizeof(filename), mwc32());
+		filename, sizeof(filename), stress_mwc32());
 
 	if ((fd = open(filename, flags, S_IRUSR | S_IWUSR)) < 0) {
 		rc = exit_status(errno);
