@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"remap N",	"start N workers exercising page remappings" },
 	{ NULL,	"remap-ops N",	"stop after N remapping bogo operations" },
 	{ NULL,	NULL,		NULL }
@@ -41,7 +41,7 @@ typedef uint16_t stress_mapdata_t;
  *	check page order
  */
 static void check_order(
-	const args_t *args,
+	const stress_args_t *args,
 	const size_t stride,
 	const stress_mapdata_t *data,
 	const size_t *order,
@@ -66,7 +66,7 @@ static void check_order(
  *	remap based on given order
  */
 static int remap_order(
-	const args_t *args,
+	const stress_args_t *args,
 	const size_t stride,
 	stress_mapdata_t *data,
 	const size_t *order,
@@ -92,7 +92,7 @@ static int remap_order(
  *  stress_remap
  *	stress page remapping
  */
-static int stress_remap(const args_t *args)
+static int stress_remap(const stress_args_t *args)
 {
 	stress_mapdata_t *data;
 	const size_t page_size = args->page_size;
@@ -126,7 +126,7 @@ static int stress_remap(const args_t *args)
 		for (i = 0; i < N_PAGES; i++)
 			order[i] = i;
 		for (i = 0; i < N_PAGES; i++) {
-			size_t tmp, j = mwc32() % N_PAGES;
+			size_t tmp, j = stress_mwc32() % N_PAGES;
 
 			tmp = order[i];
 			order[i] = order[j];
