@@ -27,7 +27,7 @@
 #define RESOURCE_FORKS 	(1024)
 #define MAX_LOOPS	(1024)
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"resources N",	   "start N workers consuming system resources" },
 	{ NULL,	"resources-ops N", "stop after N resource bogo operations" },
 	{ NULL,	NULL,		   NULL }
@@ -118,7 +118,7 @@ static void *stress_pthread_func(void *ctxt)
 #endif
 
 static void NORETURN waste_resources(
-	const args_t *args,
+	const stress_args_t *args,
 	const size_t page_size,
 	const size_t pipe_size,
 	const size_t mem_slack)
@@ -238,17 +238,17 @@ static void NORETURN waste_resources(
 	            (freemem > 0) && (freemem < mem_slack))
 			break;
 
-		if ((mwc8() & 0xf) == 0) {
+		if ((stress_mwc8() & 0xf) == 0) {
 			info[i].m_malloc = calloc(1, page_size);
 			if (!keep_stressing_flag())
 				break;
 		}
-		if ((mwc8() & 0xf) == 0) {
+		if ((stress_mwc8() & 0xf) == 0) {
 			info[i].m_sbrk = shim_sbrk(page_size);
 			if (!keep_stressing_flag())
 				break;
 		}
-		if ((mwc8() & 0xf) == 0) {
+		if ((stress_mwc8() & 0xf) == 0) {
 			info[i].m_mmap_size = page_size;
 			info[i].m_mmap = mmap(NULL, info[i].m_mmap_size,
 				PROT_READ | PROT_WRITE, MAP_ANONYMOUS | MAP_PRIVATE, -1, 0);
@@ -292,8 +292,8 @@ static void NORETURN waste_resources(
 			break;
 #endif
 		info[i].fd_sock = socket(
-			domains[mwc32() % SIZEOF_ARRAY(domains)],
-			types[mwc32() % SIZEOF_ARRAY(types)], 0);
+			domains[stress_mwc32() % SIZEOF_ARRAY(domains)],
+			types[stress_mwc32() % SIZEOF_ARRAY(types)], 0);
 		if (!keep_stressing_flag())
 			break;
 
@@ -314,7 +314,7 @@ static void NORETURN waste_resources(
 		if (!keep_stressing_flag())
 			break;
 		if (info[i].fd_tmp != -1) {
-			size_t sz = page_size * mwc32();
+			size_t sz = page_size * stress_mwc32();
 
 			(void)shim_fallocate(info[i].fd_tmp, 0, 0, sz);
 #if defined(F_GETLK) &&		\
@@ -431,7 +431,7 @@ static void NORETURN waste_resources(
 #endif
 
 #if defined(HAVE_SEM_SYSV)
-		key_t sem_key = (key_t)mwc32();
+		key_t sem_key = (key_t)stress_mwc32();
 		info[i].sem_id = semget(sem_key, 1,
 			IPC_CREAT | S_IRUSR | S_IWUSR);
 		if (!keep_stressing_flag())
@@ -607,7 +607,7 @@ static void MLOCKED_TEXT kill_children(const size_t resource_forks)
  *  stress_resources()
  *	stress by forking and exiting
  */
-static int stress_resources(const args_t *args)
+static int stress_resources(const stress_args_t *args)
 {
 	const size_t page_size = args->page_size;
 	const size_t pipe_size = stress_probe_max_pipe_size();
