@@ -50,7 +50,7 @@
 #define REVIO_OPT_FDATASYNC	(0x00400000)
 #define REVIO_OPT_SYNCFS	(0x00800000)
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"revio N",	"start N workers performing reverse I/O" },
 	{ NULL,	"revio-ops N",	"stop after N revio bogo operations" },
 	{ NULL,	NULL,		NULL }
@@ -125,10 +125,10 @@ static int stress_set_revio_bytes(const char *opt)
 {
 	uint64_t revio_bytes;
 
-	revio_bytes = get_uint64_byte_filesystem(opt, 1);
-	check_range_bytes("revio-bytes", revio_bytes,
+	revio_bytes = stress_get_uint64_byte_filesystem(opt, 1);
+	stress_check_range_bytes("revio-bytes", revio_bytes,
 		MIN_REVIO_BYTES, MAX_REVIO_BYTES);
-	return set_setting("revio-bytes", TYPE_ID_UINT64, &revio_bytes);
+	return stress_set_setting("revio-bytes", TYPE_ID_UINT64, &revio_bytes);
 }
 
 /*
@@ -223,9 +223,9 @@ static int stress_set_revio_opts(const char *opts)
 		}
 	}
 
-	set_setting("revio-flags", TYPE_ID_INT, &revio_flags);
-	set_setting("revio-oflags", TYPE_ID_INT, &revio_oflags);
-	set_setting("revio-opts-set", TYPE_ID_BOOL, &opts_set);
+	stress_set_setting("revio-flags", TYPE_ID_INT, &revio_flags);
+	stress_set_setting("revio-oflags", TYPE_ID_INT, &revio_oflags);
+	stress_set_setting("revio-opts-set", TYPE_ID_BOOL, &opts_set);
 	free(str);
 
 	return 0;
@@ -235,7 +235,7 @@ static int stress_set_revio_opts(const char *opts)
  *  stress_revio_advise()
  *	set posix_fadvise options
  */
-static int stress_revio_advise(const args_t *args, const int fd, const int flags)
+static int stress_revio_advise(const stress_args_t *args, const int fd, const int flags)
 {
 #if (defined(POSIX_FADV_SEQ) || defined(POSIX_FADV_RANDOM) || \
     defined(POSIX_FADV_NOREUSE) || defined(POSIX_FADV_WILLNEED) || \
@@ -285,7 +285,7 @@ static inline size_t stress_revio_get_extents(const int fd)
  *  stress_revio
  *	stress I/O via writes in reverse
  */
-static int stress_revio(const args_t *args)
+static int stress_revio(const stress_args_t *args)
 {
 	uint8_t *buf = NULL;
 	void *alloc_buf;
@@ -301,16 +301,16 @@ static int stress_revio(const args_t *args)
 	bool opts_set = false;
 	double avg_extents = 0.0;
 
-	(void)get_setting("revio-flags", &revio_flags);
-	(void)get_setting("revio-oflags", &revio_oflags);
-	(void)get_setting("revio-opts-set", &opts_set);
+	(void)stress_get_setting("revio-flags", &revio_flags);
+	(void)stress_get_setting("revio-oflags", &revio_oflags);
+	(void)stress_get_setting("revio-opts-set", &opts_set);
 
 	revio_flags |= REVIO_OPT_O_DIRECT;	/* HACK */
 
 	flags = O_CREAT | O_RDWR | O_TRUNC | revio_oflags;
 	fadvise_flags = revio_flags & REVIO_OPT_FADV_MASK;
 
-	if (!get_setting("revio-bytes", &revio_bytes)) {
+	if (!stress_get_setting("revio-bytes", &revio_bytes)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			revio_bytes = MAXIMIZED_FILE_SIZE;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -354,7 +354,7 @@ static int stress_revio(const args_t *args)
 	stress_strnrnd((char *)buf, DEFAULT_REVIO_WRITE_SIZE);
 
 	(void)stress_temp_filename_args(args,
-		filename, sizeof(filename), mwc32());
+		filename, sizeof(filename), stress_mwc32());
 
 	do {
 		int fd;
@@ -389,7 +389,7 @@ static int stress_revio(const args_t *args)
 		}
 
 		/* Sequential Reverse Write */
-		for (i = 0; i < revio_bytes; i += DEFAULT_REVIO_WRITE_SIZE * (8 + (mwc8() & 7))) {
+		for (i = 0; i < revio_bytes; i += DEFAULT_REVIO_WRITE_SIZE * (8 + (stress_mwc8() & 7))) {
 			size_t j;
 			off_t lseek_ret, offset = revio_bytes - i;
 seq_wr_retry:
@@ -437,7 +437,7 @@ finish:
 	return rc;
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_revio_bytes,	stress_set_revio_bytes },
 	{ OPT_revio_opts,	stress_set_revio_opts },
 	{ 0,			NULL }
