@@ -27,7 +27,7 @@
 static volatile bool do_jmp = true;
 static sigjmp_buf jmp_env;
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"rmap N",	"start N workers that stress reverse mappings" },
 	{ NULL,	"rmap-ops N",	"stop after N rmap bogo operations" },
 	{ NULL,	NULL,		NULL }
@@ -85,7 +85,7 @@ static void MLOCKED_TEXT stress_rlimit_handler(int signum)
 		siglongjmp(jmp_env, 1);
 }
 
-static int stress_rlimit_child(const args_t *args, void *ctxt)
+static int stress_rlimit_child(const stress_args_t *args, void *ctxt)
 {
 	stress_rlimit_context_t *context = (stress_rlimit_context_t *)ctxt;
 
@@ -112,7 +112,7 @@ static int stress_rlimit_child(const args_t *args, void *ctxt)
 			void *oldbrk;
 			int fds[MAX_RLIMIT_NOFILE];
 
-			switch (mwc32() % 5) {
+			switch (stress_mwc32() % 5) {
 			default:
 			case 0:
 				/* Trigger an rlimit signal */
@@ -178,7 +178,7 @@ static int stress_rlimit_child(const args_t *args, void *ctxt)
  *  stress_rlimit
  *	stress by generating rlimit signals
  */
-static int stress_rlimit(const args_t *args)
+static int stress_rlimit(const stress_args_t *args)
 {
 	struct sigaction old_action_xcpu, old_action_xfsz, old_action_segv;
 	size_t i;
@@ -196,7 +196,7 @@ static int stress_rlimit(const args_t *args)
 		return EXIT_FAILURE;
 
 	(void)stress_temp_filename_args(args,
-		filename, sizeof(filename), mwc32());
+		filename, sizeof(filename), stress_mwc32());
 	if (stress_temp_dir_mk_args(args) < 0)
 		return EXIT_FAILURE;
 	if ((context.fd = creat(filename, S_IRUSR | S_IWUSR)) < 0) {
