@@ -28,7 +28,7 @@
 #define MAPPINGS_MAX		(64)
 #define MAPPING_PAGES		(16)
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"rmap N",	"start N workers that stress reverse mappings" },
 	{ NULL,	"rmap-ops N",	"stop after N rmap bogo operations" },
 	{ NULL,	NULL,		NULL }
@@ -65,14 +65,14 @@ static void stress_rmap_child(
 
 	do {
 		ssize_t i;
-		const int sync_flag = mwc8() ? MS_ASYNC : MS_SYNC;
+		const int sync_flag = stress_mwc8() ? MS_ASYNC : MS_SYNC;
 
-		switch (mwc32() & 3) {
+		switch (stress_mwc32() & 3) {
 		case 0: for (i = 0; keep_stressing_flag() && (i < MAPPINGS_MAX); i++) {
 				if (max_ops && *counter >= max_ops)
 					break;
 				if (mappings[i] != MAP_FAILED) {
-					(void)memset(mappings[i], mwc8(), sz);
+					(void)memset(mappings[i], stress_mwc8(), sz);
 					(void)shim_msync(mappings[i], sz, sync_flag);
 				}
 			}
@@ -81,17 +81,17 @@ static void stress_rmap_child(
 				if (max_ops && *counter >= max_ops)
 					break;
 				if (mappings[i] != MAP_FAILED) {
-					(void)memset(mappings[i], mwc8(), sz);
+					(void)memset(mappings[i], stress_mwc8(), sz);
 					(void)shim_msync(mappings[i], sz, sync_flag);
 				}
 			}
 			break;
 		case 2: for (i = 0; keep_stressing_flag() && (i < MAPPINGS_MAX); i++) {
-				size_t j = mwc32() % MAPPINGS_MAX;
+				size_t j = stress_mwc32() % MAPPINGS_MAX;
 				if (max_ops && *counter >= max_ops)
 					break;
 				if (mappings[j] != MAP_FAILED) {
-					(void)memset(mappings[j], mwc8(), sz);
+					(void)memset(mappings[j], stress_mwc8(), sz);
 					(void)shim_msync(mappings[j], sz, sync_flag);
 				}
 			}
@@ -116,7 +116,7 @@ static void stress_rmap_child(
  *  stress_rmap()
  *	stress mmap
  */
-static int stress_rmap(const args_t *args)
+static int stress_rmap(const stress_args_t *args)
 {
 	const size_t page_size = args->page_size;
 	const size_t sz = ((MAPPINGS_MAX - 1) + MAPPING_PAGES) * page_size;
@@ -154,7 +154,7 @@ static int stress_rmap(const args_t *args)
 		return exit_status(-rc);
 
 	(void)stress_temp_filename_args(args,
-		filename, sizeof(filename), mwc32());
+		filename, sizeof(filename), stress_mwc32());
 
 	if ((fd = open(filename, O_CREAT | O_RDWR, S_IRUSR | S_IWUSR)) < 0) {
 		rc = exit_status(errno);
