@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"rtc N",	"start N workers that exercise the RTC interfaces" },
 	{ NULL,	"rtc-ops N",	"stop after N RTC bogo operations" },
 	{ NULL,	NULL,		NULL }
@@ -47,7 +47,7 @@ static const char *interfaces[] = {
 	"offset"
 };
 
-static inline int stress_rtc_dev(const args_t *args)
+static inline int stress_rtc_dev(const stress_args_t *args)
 {
 #if defined(RTC_RD_TIME) || defined(RTC_ALM_READ) || \
     defined(RTC_WKALM_RD) || defined(RTC_IRQP_READ)
@@ -75,6 +75,11 @@ static inline int stress_rtc_dev(const args_t *args)
 			ret = -errno;
 			goto err;
 		}
+	} else {
+		int r;
+
+		r = ioctl(fd, RTC_SET_TIME, &rtc_tm);
+		(void)r;
 	}
 #endif
 
@@ -105,6 +110,11 @@ static inline int stress_rtc_dev(const args_t *args)
 			ret = -errno;
 			goto err;
 		}
+	} else {
+		int r;
+
+		r = ioctl(fd, RTC_IRQP_SET, tmp);
+		(void)r;
 	}
 #endif
 
@@ -119,6 +129,16 @@ static inline int stress_rtc_dev(const args_t *args)
 	FD_SET(fd, &rfds);
 	(void)select(fd + 1, &rfds, NULL, NULL, &timeout);
 
+#if defined(RTC_VL_READ)
+	if (ioctl(fd, RTC_VL_READ, &tmp) < 0) {
+		if (errno != ENOTTY) {
+			pr_fail_err("ioctl RTC_IRQP_READ");
+			ret = -errno;
+			goto err;
+		}
+	}
+#endif
+
 #if defined(RTC_RD_TIME) || defined(RTC_ALM_READ) || \
     defined(RTC_WKALM_RD) || defined(RTC_IRQP_READ)
 err:
@@ -128,7 +148,7 @@ err:
 	return ret;
 }
 
-static inline int stress_rtc_sys(const args_t *args)
+static inline int stress_rtc_sys(const stress_args_t *args)
 {
 	size_t i;
 	int rc = 0;
@@ -162,7 +182,7 @@ static inline int stress_rtc_sys(const args_t *args)
 	return rc;
 }
 
-static inline int stress_rtc_proc(const args_t *args)
+static inline int stress_rtc_proc(const stress_args_t *args)
 {
 	int ret;
 	char buf[4096];
@@ -182,7 +202,7 @@ static inline int stress_rtc_proc(const args_t *args)
  *  stress_rtc
  *	stress some Linux RTC ioctls and /sys/class/rtc interface
  */
-static int stress_rtc(const args_t *args)
+static int stress_rtc(const stress_args_t *args)
 {
 	do {
 		int ret;
