@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"sctp N",	 "start N workers performing SCTP send/receives " },
 	{ NULL,	"sctp-ops N",	 "stop after N SCTP bogo operations" },
 	{ NULL,	"sctp-domain D", "specify sctp domain, default is ipv4" },
@@ -54,7 +54,7 @@ static int stress_set_sctp_port(const char *opt)
 	stress_set_net_port("sctp-port", opt,
 		MIN_SCTP_PORT, MAX_SCTP_PORT - STRESS_PROCS_MAX,
 		&sctp_port);
-	return set_setting("sctp-port", TYPE_ID_INT, &sctp_port);
+	return stress_set_setting("sctp-port", TYPE_ID_INT, &sctp_port);
 }
 
 /*
@@ -67,12 +67,12 @@ static int stress_set_sctp_domain(const char *name)
 
 	ret = stress_set_net_domain(DOMAIN_INET | DOMAIN_INET6, "sctp-domain",
 				     name, &sctp_domain);
-	set_setting("sctp-domain", TYPE_ID_INT, &sctp_domain);
+	stress_set_setting("sctp-domain", TYPE_ID_INT, &sctp_domain);
 
 	return ret;
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_sctp_port,	stress_set_sctp_port },
 	{ OPT_sctp_domain,	stress_set_sctp_domain },
 	{ 0,			NULL }
@@ -142,7 +142,7 @@ static void stress_sctp_sockopts(const int fd)
  *	client reader
  */
 static void stress_sctp_client(
-	const args_t *args,
+	const stress_args_t *args,
 	const pid_t ppid,
 	const int sctp_port,
 	const int sctp_domain)
@@ -230,7 +230,7 @@ retry:
  *	server writer
  */
 static int stress_sctp_server(
-	const args_t *args,
+	const stress_args_t *args,
 	const pid_t pid,
 	const pid_t ppid,
 	const int sctp_port,
@@ -350,15 +350,15 @@ static void stress_sctp_sigpipe(int signum)
  *  stress_sctp
  *	stress SCTP by heavy SCTP network I/O
  */
-static int stress_sctp(const args_t *args)
+static int stress_sctp(const stress_args_t *args)
 {
 	pid_t pid, ppid = getppid();
 	int sctp_port = DEFAULT_SCTP_PORT;
 	int sctp_domain = AF_INET;
 	int ret = EXIT_FAILURE;
 
-	(void)get_setting("sctp-port", &sctp_port);
-	(void)get_setting("sctp-domain", &sctp_domain);
+	(void)stress_get_setting("sctp-port", &sctp_port);
+	(void)stress_get_setting("sctp-domain", &sctp_domain);
 
 	if (stress_sighandler(args->name, SIGPIPE, stress_sctp_sigpipe, NULL) < 0)
 		return EXIT_FAILURE;
