@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"seal N",	"start N workers performing fcntl SEAL commands" },
 	{ NULL,	"seal-ops N",	"stop after N SEAL bogo operations" },
 	{ NULL,	NULL,		NULL }
@@ -62,7 +62,7 @@ static const help_t help[] = {
  *  stress_seal
  *	stress file sealing
  */
-static int stress_seal(const args_t *args)
+static int stress_seal(const stress_args_t *args)
 {
 	int fd, ret;
 	int rc = EXIT_FAILURE;
@@ -75,7 +75,7 @@ static int stress_seal(const args_t *args)
 		char buf[page_size];
 
 		(void)snprintf(filename, sizeof(filename), "%s-%d-%" PRIu32 "-%" PRIu32,
-			args->name, args->pid, args->instance, mwc32());
+			args->name, args->pid, args->instance, stress_mwc32());
 
 		fd = shim_memfd_create(filename, MFD_ALLOW_SEALING);
 		if (fd < 0) {
