@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"seccomp N",	 "start N workers performing seccomp call filtering" },
 	{ NULL,	"seccomp-ops N", "stop after N seccomp bogo operations" },
 	{ NULL,	NULL,		 NULL }
@@ -173,7 +173,7 @@ static void MLOCKED_TEXT stress_sigsys(int signum)
  *  stress_seccomp_set_huge_filter()
  *	set up a huge seccomp filter, see how large we can go
  */
-static int stress_seccomp_set_huge_filter(const args_t *args)
+static int stress_seccomp_set_huge_filter(const stress_args_t *args)
 {
 	static struct sock_filter bpf_stmt =
 		BPF_STMT(BPF_RET+BPF_K, SECCOMP_RET_ALLOW);
@@ -231,7 +231,7 @@ next:
  * 	if allow_write is true.
  */
 static int stress_seccomp_set_filter(
-	const args_t *args,
+	const stress_args_t *args,
 	const bool allow_write,
 	bool do_random)
 {
@@ -248,7 +248,7 @@ static int stress_seccomp_set_filter(
 
 	if (do_random) {
 		for (i = 0; i < SIZEOF_ARRAY(filter_random); i++) {
-			struct sock_filter bpf_stmt = BPF_STMT(mwc32(), SECCOMP_RET_KILL);
+			struct sock_filter bpf_stmt = BPF_STMT(stress_mwc32(), SECCOMP_RET_KILL);
 			filter_random[i] = bpf_stmt;
 		}
 	}
@@ -297,12 +297,12 @@ redo_prctl:
  *  stress_seccomp()
  *	stress seccomp
  */
-static int stress_seccomp(const args_t *args)
+static int stress_seccomp(const stress_args_t *args)
 {
 	do {
 		pid_t pid;
-		const bool allow_write = (mwc32() % 2) != 0;
-		const bool do_random = (mwc32() % 20) != 0;
+		const bool allow_write = (stress_mwc32() % 2) != 0;
+		const bool do_random = (stress_mwc32() % 20) != 0;
 
 		pid = fork();
 		if (pid == -1) {
