@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"seek N",	"start N workers performing random seek r/w IO" },
 	{ NULL,	"seek-ops N",	"stop after N seek bogo operations" },
 	{ NULL,	"seek-punch",	"punch random holes in file to stress extents" },
@@ -36,10 +36,10 @@ static int stress_set_seek_size(const char *opt)
 {
 	uint64_t seek_size;
 
-	seek_size = get_uint64_byte(opt);
-	check_range_bytes("seek-size", seek_size,
+	seek_size = stress_get_uint64_byte(opt);
+	stress_check_range_bytes("seek-size", seek_size,
 		MIN_SEEK_SIZE, MAX_SEEK_SIZE);
-	return set_setting("seek-size", TYPE_ID_UINT64, &seek_size);
+	return stress_set_setting("seek-size", TYPE_ID_UINT64, &seek_size);
 }
 
 
@@ -48,14 +48,14 @@ static int stress_set_seek_punch(const char *opt)
 	(void)opt;
 	bool seek_punch = true;
 
-	return set_setting("seek-punch", TYPE_ID_BOOL, &seek_punch);
+	return stress_set_setting("seek-punch", TYPE_ID_BOOL, &seek_punch);
 }
 
 /*
  *  stress_seek
  *	stress I/O via random seeks and read/writes
  */
-static int stress_seek(const args_t *args)
+static int stress_seek(const stress_args_t *args)
 {
 	uint64_t len;
 	uint64_t seek_size = DEFAULT_SEEK_SIZE;
@@ -65,10 +65,10 @@ static int stress_seek(const args_t *args)
 #if defined(OPT_SEEK_PUNCH)
 	bool seek_punch = false;
 
-	(void)get_setting("seek-punch", TYPE_ID_BOOL, &seek_punch);
+	(void)stress_get_setting("seek-punch", TYPE_ID_BOOL, &seek_punch);
 #endif
 
-	if (!get_setting("seek-size", &seek_size)) {
+	if (!stress_get_setting("seek-size", &seek_size)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			seek_size = MAXIMIZED_FILE_SIZE;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -83,7 +83,7 @@ static int stress_seek(const args_t *args)
 	stress_strnrnd((char *)buf, sizeof(buf));
 
 	(void)stress_temp_filename_args(args,
-		filename, sizeof(filename), mwc32());
+		filename, sizeof(filename), stress_mwc32());
 	if ((fd = open(filename, O_CREAT | O_RDWR, S_IRUSR | S_IWUSR)) < 0) {
 		rc = exit_status(errno);
 		pr_fail_err("open");
@@ -107,7 +107,7 @@ static int stress_seek(const args_t *args)
 		uint8_t tmp[512];
 		ssize_t rwret;
 
-		offset = mwc64() % len;
+		offset = stress_mwc64() % len;
 		if (lseek(fd, (off_t)offset, SEEK_SET) < 0) {
 			pr_fail_err("lseek");
 			goto close_finish;
@@ -125,7 +125,7 @@ re_write:
 			}
 		}
 
-		offset = mwc64() % len;
+		offset = stress_mwc64() % len;
 		if (lseek(fd, (off_t)offset, SEEK_SET) < 0) {
 			pr_fail_err("lseek SEEK_SET");
 			goto close_finish;
@@ -175,7 +175,7 @@ re_read:
 		if (!seek_punch_hole)
 			continue;
 
-		offset = mwc64() % len;
+		offset = stress_mwc64() % len;
 		if (shim_fallocate(fd, FALLOC_FL_PUNCH_HOLE |
 				  FALLOC_FL_KEEP_SIZE, offset, 8192) < 0) {
 			if (errno == EOPNOTSUPP)
@@ -193,7 +193,7 @@ finish:
 	return rc;
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_seek_size,	stress_set_seek_size },
 	{ OPT_seek_punch,	stress_set_seek_punch },
 	{ 0,			NULL }
