@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"sem-sysv N",		"start N workers doing System V semaphore operations" },
 	{ NULL,	"sem-sysv-ops N",	"stop after N System V sem bogo operations" },
 	{ NULL,	"sem-sysv-procs N",	"number of processes to start per worker" },
@@ -44,13 +44,13 @@ static int stress_set_semaphore_sysv_procs(const char *opt)
 {
 	uint64_t semaphore_sysv_procs;
 
-	semaphore_sysv_procs = get_uint64(opt);
-	check_range("sem-sysv-procs", semaphore_sysv_procs,
+	semaphore_sysv_procs = stress_get_uint64(opt);
+	stress_check_range("sem-sysv-procs", semaphore_sysv_procs,
 		MIN_SEMAPHORE_PROCS, MAX_SEMAPHORE_PROCS);
-	return set_setting("sem-sysv-procs", TYPE_ID_UINT64, &semaphore_sysv_procs);
+	return stress_set_setting("sem-sysv-procs", TYPE_ID_UINT64, &semaphore_sysv_procs);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_sem_sysv_procs,	stress_set_semaphore_sysv_procs },
 	{ 0,			NULL }
 };
@@ -65,7 +65,7 @@ static void stress_semaphore_sysv_init(void)
 	int count = 0;
 
 	while (count < 100) {
-		g_shared->sem_sysv.key_id = (key_t)mwc16();
+		g_shared->sem_sysv.key_id = (key_t)stress_mwc16();
 		g_shared->sem_sysv.sem_id =
 			semget(g_shared->sem_sysv.key_id, 1,
 				IPC_CREAT | S_IRUSR | S_IWUSR);
@@ -139,7 +139,7 @@ static void stress_semaphore_sysv_get_procinfo(bool *get_procinfo)
  *  stress_semaphore_sysv_thrash()
  *	exercise the semaphore
  */
-static void stress_semaphore_sysv_thrash(const args_t *args)
+static void stress_semaphore_sysv_thrash(const stress_args_t *args)
 {
 	const int sem_id = g_shared->sem_sysv.sem_id;
 
@@ -280,7 +280,7 @@ timed_out:
  *  semaphore_sysv_spawn()
  *	spawn a process
  */
-static pid_t semaphore_sysv_spawn(const args_t *args)
+static pid_t semaphore_sysv_spawn(const stress_args_t *args)
 {
 	pid_t pid;
 
@@ -306,13 +306,13 @@ again:
  *  stress_sem_sysv()
  *	stress system by sem ops
  */
-static int stress_sem_sysv(const args_t *args)
+static int stress_sem_sysv(const stress_args_t *args)
 {
 	pid_t pids[MAX_SEMAPHORE_PROCS];
 	uint64_t i;
 	uint64_t semaphore_sysv_procs = DEFAULT_SEMAPHORE_PROCS;
 
-	if (!get_setting("sem-sysv-procs", &semaphore_sysv_procs)) {
+	if (!stress_get_setting("sem-sysv-procs", &semaphore_sysv_procs)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			semaphore_sysv_procs = MAX_SEMAPHORE_PROCS;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
