@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"sem N",	"start N workers doing semaphore operations" },
 	{ NULL,	"sem-ops N",	"stop after N semaphore bogo operations" },
 	{ NULL,	"sem-procs N",	"number of processes to start per worker" },
@@ -35,13 +35,13 @@ static int stress_set_semaphore_posix_procs(const char *opt)
 {
 	uint64_t semaphore_posix_procs;
 
-	semaphore_posix_procs = get_uint64(opt);
-	check_range("sem-procs", semaphore_posix_procs,
+	semaphore_posix_procs = stress_get_uint64(opt);
+	stress_check_range("sem-procs", semaphore_posix_procs,
 		MIN_SEMAPHORE_PROCS, MAX_SEMAPHORE_PROCS);
-	return set_setting("sem-procs", TYPE_ID_UINT64, &semaphore_posix_procs);
+	return stress_set_setting("sem-procs", TYPE_ID_UINT64, &semaphore_posix_procs);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_sem_procs,	stress_set_semaphore_posix_procs },
 	{ 0,			NULL }
 };
@@ -60,8 +60,8 @@ static int p_ret[MAX_SEMAPHORE_PROCS];
  */
 static void *semaphore_posix_thrash(void *arg)
 {
-	const pthread_args_t *p_args = arg;
-	const args_t *args = p_args->args;
+	const stress_pthread_args_t *p_args = arg;
+	const stress_args_t *args = p_args->args;
 	static void *nowt = NULL;
 
 	do {
@@ -107,7 +107,7 @@ static void *semaphore_posix_thrash(void *arg)
 				pr_fail_dbg("sem_post");
 				break;
 			}
-			if (mwc1())
+			if (stress_mwc1())
 				(void)shim_sched_yield();
 			else
 				(void)shim_usleep(0);
@@ -121,14 +121,14 @@ static void *semaphore_posix_thrash(void *arg)
  *  stress_sem()
  *	stress system by POSIX sem ops
  */
-static int stress_sem(const args_t *args)
+static int stress_sem(const stress_args_t *args)
 {
 	uint64_t semaphore_posix_procs = DEFAULT_SEMAPHORE_PROCS;
 	uint64_t i;
 	bool created = false;
-	pthread_args_t p_args;
+	stress_pthread_args_t p_args;
 
-	if (!get_setting("sem-procs", &semaphore_posix_procs)) {
+	if (!stress_get_setting("sem-procs", &semaphore_posix_procs)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			semaphore_posix_procs = MAX_SEMAPHORE_PROCS;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
