@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"sendfile N",	   "start N workers exercising sendfile" },
 	{ NULL,	"sendfile-ops N",  "stop after N bogo sendfile operations" },
 	{ NULL,	"sendfile-size N", "size of data to be sent with sendfile" },
@@ -35,13 +35,13 @@ static int stress_set_sendfile_size(const char *opt)
 {
 	int64_t sendfile_size;
 
-	sendfile_size = get_uint64_byte(opt);
-	check_range_bytes("sendfile-size", sendfile_size,
+	sendfile_size = stress_get_uint64_byte(opt);
+	stress_check_range_bytes("sendfile-size", sendfile_size,
 		MIN_SENDFILE_SIZE, MAX_SENDFILE_SIZE);
-	return set_setting("sendfile-size", TYPE_ID_UINT64, &sendfile_size);
+	return stress_set_setting("sendfile-size", TYPE_ID_UINT64, &sendfile_size);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_sendfile_size,	stress_set_sendfile_size },
 	{ 0,			NULL }
 };
@@ -53,14 +53,14 @@ static const opt_set_func_t opt_set_funcs[] = {
  *  stress_sendfile
  *	stress reading of a temp file and writing to /dev/null via sendfile
  */
-static int stress_sendfile(const args_t *args)
+static int stress_sendfile(const stress_args_t *args)
 {
 	char filename[PATH_MAX];
 	int fdin, fdout, ret, rc = EXIT_SUCCESS;
 	size_t sz;
 	int64_t sendfile_size = DEFAULT_SENDFILE_SIZE;
 
-	if (!get_setting("sendfile-size", &sendfile_size)) {
+	if (!stress_get_setting("sendfile-size", &sendfile_size)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			sendfile_size = MAX_SENDFILE_SIZE;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -73,7 +73,7 @@ static int stress_sendfile(const args_t *args)
 		return exit_status(-ret);
 
 	(void)stress_temp_filename_args(args,
-		filename, sizeof(filename), mwc32());
+		filename, sizeof(filename), stress_mwc32());
 
 	if ((fdin = open(filename, O_CREAT | O_RDWR, S_IRUSR | S_IWUSR)) < 0) {
 		rc = exit_status(errno);
