@@ -90,7 +90,7 @@ static stress_rlimit_info_t rlimits[] = {
 #endif
 };
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"set N",	"start N workers exercising the set*() system calls" },
 	{ NULL,	"set-ops N",	"stop after N set bogo operations" },
 	{ NULL,	NULL,		NULL }
@@ -100,7 +100,7 @@ static const help_t help[] = {
  *  stress on set*() calls
  *	stress system by rapid get*() system calls
  */
-static int stress_set(const args_t *args)
+static int stress_set(const stress_args_t *args)
 {
 	size_t i;
 	int ret_hostname;
