@@ -27,7 +27,7 @@
 static volatile bool do_jmp = true;
 static sigjmp_buf jmp_env;
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"shellsort N",	   "start N workers shell sorting 32 bit random integers" },
 	{ NULL,	"shellsort-ops N",  "stop after N shell sort bogo operations" },
 	{ NULL,	"shellsort-size N", "number of 32 bit integers to sort" },
@@ -42,13 +42,13 @@ static int stress_set_shellsort_size(const char *opt)
 {
 	uint64_t shellsort_size;
 
-	shellsort_size = get_uint64(opt);
-	check_range("shellsort-size", shellsort_size,
+	shellsort_size = stress_get_uint64(opt);
+	stress_check_range("shellsort-size", shellsort_size,
 		MIN_SHELLSORT_SIZE, MAX_SHELLSORT_SIZE);
-	return set_setting("shellsort-size", TYPE_ID_UINT64, &shellsort_size);
+	return stress_set_setting("shellsort-size", TYPE_ID_UINT64, &shellsort_size);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_shellsort_integers,	stress_set_shellsort_size },
 	{ 0,				NULL }
 };
@@ -163,7 +163,7 @@ static int shellsort(void *base, size_t nmemb, size_t size,
  *  stress_shellsort()
  *	stress shellsort
  */
-static int stress_shellsort(const args_t *args)
+static int stress_shellsort(const stress_args_t *args)
 {
 	uint64_t shellsort_size = DEFAULT_SHELLSORT_SIZE;
 	int32_t *data, *ptr;
@@ -171,7 +171,7 @@ static int stress_shellsort(const args_t *args)
 	struct sigaction old_action;
 	int ret;
 
-	if (!get_setting("shellsort-size", &shellsort_size)) {
+	if (!stress_get_setting("shellsort-size", &shellsort_size)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			shellsort_size = MAX_SHELLSORT_SIZE;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -200,7 +200,7 @@ static int stress_shellsort(const args_t *args)
 
 	/* This is expensive, do it once */
 	for (ptr = data, i = 0; i < n; i++) {
-		*ptr++ = mwc32();
+		*ptr++ = stress_mwc32();
 	}
 
 	do {
