@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"shm-sysv N",		"start N workers that exercise System V shared memory" },
 	{ NULL,	"shm-sysv-ops N",	"stop after N shared memory bogo operations" },
 	{ NULL,	"shm-sysv-bytes N",	"allocate and free N bytes of shared memory per loop" },
@@ -77,23 +77,23 @@ static int stress_set_shm_sysv_bytes(const char *opt)
 {
 	size_t shm_sysv_bytes;
 
-	shm_sysv_bytes = (size_t)get_uint64_byte(opt);
-	check_range_bytes("shm-sysv-bytes", shm_sysv_bytes,
+	shm_sysv_bytes = (size_t)stress_get_uint64_byte(opt);
+	stress_check_range_bytes("shm-sysv-bytes", shm_sysv_bytes,
 		MIN_SHM_SYSV_BYTES, MAX_MEM_LIMIT);
-	return set_setting("shm-sysv-bytes", TYPE_ID_SIZE_T, &shm_sysv_bytes);
+	return stress_set_setting("shm-sysv-bytes", TYPE_ID_SIZE_T, &shm_sysv_bytes);
 }
 
 static int stress_set_shm_sysv_segments(const char *opt)
 {
 	size_t shm_sysv_segments;
 
-	shm_sysv_segments = (size_t)get_uint64(opt);
-	check_range("shm-sysv-segs", shm_sysv_segments,
+	shm_sysv_segments = (size_t)stress_get_uint64(opt);
+	stress_check_range("shm-sysv-segs", shm_sysv_segments,
 		MIN_SHM_SYSV_SEGMENTS, MAX_SHM_SYSV_SEGMENTS);
-	return set_setting("shm-sysv-segs", TYPE_ID_SIZE_T, &shm_sysv_segments);
+	return stress_set_setting("shm-sysv-segs", TYPE_ID_SIZE_T, &shm_sysv_segments);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_shm_bytes,		stress_set_shm_sysv_bytes },
 	{ OPT_shm_sysv_segments,	stress_set_shm_sysv_segments },
 	{ 0,				NULL }
@@ -163,7 +163,7 @@ static void stress_shm_get_procinfo(bool *get_procinfo)
  *	be reaped cleanly if this process gets prematurely killed.
  */
 static int stress_shm_sysv_child(
-	const args_t *args,
+	const stress_args_t *args,
 	const int fd,
 	const size_t max_sz,
 	const size_t page_size,
@@ -217,7 +217,7 @@ static int stress_shm_sysv_child(
 			for (count = 0; count < KEY_GET_RETRIES; count++) {
 				bool unique = true;
 				const int rnd =
-					mwc32() % SIZEOF_ARRAY(shm_flags);
+					stress_mwc32() % SIZEOF_ARRAY(shm_flags);
 				const int rnd_flag = shm_flags[rnd] & mask;
 
 				if (sz < page_size)
@@ -231,7 +231,7 @@ static int stress_shm_sysv_child(
 						goto reap;
 
 					/* Get a unique random key */
-					key = (key_t)mwc16();
+					key = (key_t)stress_mwc16();
 					for (j = 0; j < i; j++) {
 						if (key == keys[j]) {
 							unique = false;
@@ -293,7 +293,7 @@ static int stress_shm_sysv_child(
 			if (!keep_stressing())
 				goto reap;
 			(void)stress_mincore_touch_pages(addr, sz);
-			(void)shim_msync(addr, sz, mwc1() ? MS_ASYNC : MS_SYNC);
+			(void)shim_msync(addr, sz, stress_mwc1() ? MS_ASYNC : MS_SYNC);
 
 			if (!keep_stressing())
 				goto reap;
@@ -410,7 +410,7 @@ reap:
  *  stress_shm_sysv()
  *	stress SYSTEM V shared memory
  */
-static int stress_shm_sysv(const args_t *args)
+static int stress_shm_sysv(const stress_args_t *args)
 {
 	const size_t page_size = args->page_size;
 	size_t orig_sz, sz;
@@ -423,7 +423,7 @@ static int stress_shm_sysv(const args_t *args)
 	size_t shm_sysv_bytes = DEFAULT_SHM_SYSV_BYTES;
 	size_t shm_sysv_segments = DEFAULT_SHM_SYSV_SEGMENTS;
 
-	if (!get_setting("shm-sysv-bytes", &shm_sysv_bytes)) {
+	if (!stress_get_setting("shm-sysv-bytes", &shm_sysv_bytes)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			shm_sysv_bytes = MAX_SHM_SYSV_BYTES;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -432,7 +432,7 @@ static int stress_shm_sysv(const args_t *args)
 	if (shm_sysv_bytes < page_size)
 		shm_sysv_bytes = page_size;
 
-	if (!get_setting("shm-sysv-segs", &shm_sysv_segments)) {
+	if (!stress_get_setting("shm-sysv-segs", &shm_sysv_segments)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			shm_sysv_segments = MAX_SHM_SYSV_SEGMENTS;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -513,7 +513,7 @@ fork_again:
 			if (WIFSIGNALED(status)) {
 				if ((WTERMSIG(status) == SIGKILL) ||
 				    (WTERMSIG(status) == SIGBUS)) {
-					log_system_mem_info();
+					stress_log_system_mem_info();
 					pr_dbg("%s: assuming killed by OOM killer, "
 						"restarting again (instance %d)\n",
 						args->name, args->instance);
