@@ -31,7 +31,7 @@ typedef struct {
 	char	shm_name[SHM_NAME_LEN];
 } stress_shm_msg_t;
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"shm N",	"start N workers that exercise POSIX shared memory" },
 	{ NULL,	"shm-ops N",	"stop after N POSIX shared memory bogo operations" },
 	{ NULL,	"shm-bytes N",	"allocate/free N bytes of POSIX shared memory" },
@@ -43,23 +43,23 @@ static int stress_set_shm_posix_bytes(const char *opt)
 {
 	size_t shm_posix_bytes;
 
-	shm_posix_bytes = (size_t)get_uint64_byte_memory(opt, 1);
-	check_range_bytes("shm-bytes", shm_posix_bytes,
+	shm_posix_bytes = (size_t)stress_get_uint64_byte_memory(opt, 1);
+	stress_check_range_bytes("shm-bytes", shm_posix_bytes,
 		MIN_SHM_POSIX_BYTES, MAX_MEM_LIMIT);
-	return set_setting("shm-bytes", TYPE_ID_SIZE_T, &shm_posix_bytes);
+	return stress_set_setting("shm-bytes", TYPE_ID_SIZE_T, &shm_posix_bytes);
 }
 
 static int stress_set_shm_posix_objects(const char *opt)
 {
 	size_t shm_posix_objects;
 
-	shm_posix_objects = (size_t)get_uint64(opt);
-	check_range("shm-objs", shm_posix_objects,
+	shm_posix_objects = (size_t)stress_get_uint64(opt);
+	stress_check_range("shm-objs", shm_posix_objects,
 		MIN_SHM_POSIX_OBJECTS, MAX_48);
-	return set_setting("shm-objs", TYPE_ID_SIZE_T, &shm_posix_objects);
+	return stress_set_setting("shm-objs", TYPE_ID_SIZE_T, &shm_posix_objects);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_shm_bytes,	stress_set_shm_posix_bytes },
 	{ OPT_shm_objects,	stress_set_shm_posix_objects },
 	{ 0,			NULL }
@@ -101,7 +101,7 @@ static int stress_shm_posix_check(
  *	be reaped cleanly if this process gets prematurely killed.
  */
 static int stress_shm_posix_child(
-	const args_t *args,
+	const stress_args_t *args,
 	const int fd,
 	size_t sz,
 	size_t shm_posix_objects)
@@ -162,7 +162,7 @@ static int stress_shm_posix_child(
 
 			(void)snprintf(shm_name, SHM_NAME_LEN,
 				"/stress-ng-%d-%" PRIx64 "-%" PRIx32,
-					(int)pid, id, mwc32());
+					(int)pid, id, stress_mwc32());
 
 			shm_fd = shm_open(shm_name, O_CREAT | O_RDWR | O_TRUNC,
 				S_IRUSR | S_IWUSR);
@@ -221,7 +221,7 @@ static int stress_shm_posix_child(
 			(void)shim_fallocate(shm_fd, 0, 0, sz + page_size);
 
 			(void)stress_madvise_random(addr, sz);
-			(void)shim_msync(addr, sz, mwc1() ? MS_ASYNC : MS_SYNC);
+			(void)shim_msync(addr, sz, stress_mwc1() ? MS_ASYNC : MS_SYNC);
 			(void)shim_fsync(shm_fd);
 			off = lseek(shm_fd, (off_t)0, SEEK_SET);
 			(void)off;
@@ -261,7 +261,7 @@ static int stress_shm_posix_child(
 			if (newpid > 0) {
 				int status;
 
-				waitpid(newpid, &status, 0);
+				(void)shim_waitpid(newpid, &status, 0);
 			}
 
 			if (!keep_stressing())
@@ -319,7 +319,7 @@ reap:
  *  stress_shm()
  *	stress SYSTEM V shared memory
  */
-static int stress_shm(const args_t *args)
+static int stress_shm(const stress_args_t *args)
 {
 	const size_t page_size = args->page_size;
 	size_t orig_sz, sz;
@@ -332,7 +332,7 @@ static int stress_shm(const args_t *args)
 	size_t shm_posix_bytes = DEFAULT_SHM_POSIX_BYTES;
 	size_t shm_posix_objects = DEFAULT_SHM_POSIX_OBJECTS;
 
-	if (!get_setting("shm-bytes", &shm_posix_bytes)) {
+	if (!stress_get_setting("shm-bytes", &shm_posix_bytes)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			shm_posix_bytes = MAX_SHM_POSIX_BYTES;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -344,7 +344,7 @@ static int stress_shm(const args_t *args)
 	if (shm_posix_bytes < page_size)
 		shm_posix_bytes = page_size;
 
-	if (!get_setting("shm-objs", &shm_posix_objects)) {
+	if (!stress_get_setting("shm-objs", &shm_posix_objects)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			shm_posix_objects = MAX_SHM_POSIX_OBJECTS;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -422,7 +422,7 @@ fork_again:
 			if (WIFSIGNALED(status)) {
 				if ((WTERMSIG(status) == SIGKILL) ||
 				    (WTERMSIG(status) == SIGKILL)) {
-					log_system_mem_info();
+					stress_log_system_mem_info();
 					pr_dbg("%s: assuming killed by OOM killer, "
 						"restarting again (instance %d)\n",
 						args->name, args->instance);
