@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"sigfpe N",	"start N workers generating floating point math faults" },
 	{ NULL,	"sigfpe-ops N",	"stop after N bogo floating point math faults" },
 	{ NULL,	NULL,		NULL }
@@ -118,7 +118,7 @@ static char *stress_sigfpe_errstr(const int err)
  *  stress_sigfpe
  *	stress by generating floating point errors
  */
-static int stress_sigfpe(const args_t *args)
+static int stress_sigfpe(const stress_args_t *args)
 {
 	struct sigaction action;
 	static int i = 0;
@@ -222,10 +222,10 @@ static int stress_sigfpe(const args_t *args)
 
 			switch(exception) {
 			case SNG_FLTDIV:
-				float_put(1.0 / (float)zero);
+				stress_float_put(1.0 / (float)zero);
 				break;
 			case SNG_INTDIV:
-				uint64_put(1 / zero);
+				stress_uint64_put(1 / zero);
 				break;
 			default:
 				/* Raise fault otherwise */
