@@ -24,9 +24,9 @@
  */
 #include "stress-ng.h"
 
-static const args_t *s_args;
+static const stress_args_t *s_args;
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"sigpipe N",	 "start N workers exercising SIGPIPE" },
 	{ NULL,	"sigpipe-ops N", "stop after N SIGPIPE bogo operations" },
 	{ NULL,	NULL,		 NULL }
@@ -50,7 +50,7 @@ static int NORETURN pipe_child(void *ptr)
 }
 
 static inline int stress_sigpipe_write(
-	const args_t *args,
+	const stress_args_t *args,
 	const char *buf,
 	const size_t buf_len)
 {
@@ -86,7 +86,7 @@ again:
 				(CLONE_STACK_SIZE - 64);
 			char *stack_top = stack + stack_offset;
 
-			pid = clone(pipe_child, align_stack(stack_top),
+			pid = clone(pipe_child, stress_align_stack(stack_top),
 				CLONE_VM | CLONE_FS | CLONE_SIGHAND | SIGCHLD, NULL);
 			/*
 			 *  May not have clone, so fall back to fork instead.
@@ -137,7 +137,7 @@ again:
  *  stress_sigpipe
  *	stress by generating SIGPIPE signals on pipe I/O
  */
-static int stress_sigpipe(const args_t *args)
+static int stress_sigpipe(const stress_args_t *args)
 {
 	s_args = args;
 	char buf[args->page_size * 2];
