@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"sigq N",	"start N workers sending sigqueue signals" },
 	{ NULL,	"sigq-ops N",	"stop after N sigqueue bogo operations" },
 	{ NULL,	NULL,		NULL }
@@ -42,7 +42,7 @@ static void MLOCKED_TEXT stress_sigqhandler(int signum)
  *  stress_sigq
  *	stress by heavy sigqueue message sending
  */
-static int stress_sigq(const args_t *args)
+static int stress_sigq(const stress_args_t *args)
 {
 	pid_t pid;
 
