@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"sigrt N",	"start N workers sending real time signals" },
 	{ NULL,	"sigrt-ops N",	"stop after N real time signal bogo operations" },
 	{ NULL,	NULL,		NULL }
@@ -46,7 +46,7 @@ static void MLOCKED_TEXT stress_sigrthandler(int signum)
  *  stress_sigrt
  *	stress by heavy real time sigqueue message sending
  */
-static int stress_sigrt(const args_t *args)
+static int stress_sigrt(const stress_args_t *args)
 {
 	pid_t pids[MAX_RTPIDS];
 	union sigval s;
