@@ -31,7 +31,7 @@ static volatile int signo;
 static volatile int code;
 #endif
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"sigsegv N",	 "start N workers generating segmentation faults" },
 	{ NULL,	"sigsegv-ops N", "stop after N bogo segmentation faults" },
 	{ NULL,	NULL,		 NULL }
@@ -70,7 +70,7 @@ static void MLOCKED_TEXT stress_segvhandler(int signum)
  *	stress by generating segmentation faults by
  *	writing to a read only page
  */
-static int stress_sigsegv(const args_t *args)
+static int stress_sigsegv(const stress_args_t *args)
 {
 	uint8_t *ptr;
 	NOCLOBBER int rc = EXIT_FAILURE;
