@@ -27,7 +27,7 @@
 #if defined(HAVE_LIB_PTHREAD)
 
 typedef struct {
-	const args_t *args;
+	const stress_args_t *args;
 	uint64_t counter;
 	uint64_t sleep_max;
 	pthread_t pthread;
@@ -37,7 +37,7 @@ static volatile bool thread_terminate;
 static sigset_t set;
 #endif
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"sleep N",	"start N workers performing various duration sleeps" },
 	{ NULL,	"sleep-ops N",	"stop after N bogo sleep operations" },
 	{ NULL,	"sleep-max P",	"create P threads at a time by each worker" },
@@ -48,13 +48,13 @@ static int stress_set_sleep_max(const char *opt)
 {
 	uint64_t sleep_max;
 
-	sleep_max = get_uint64(opt);
-	check_range("sleep-max", sleep_max,
+	sleep_max = stress_get_uint64(opt);
+	stress_check_range("sleep-max", sleep_max,
 		MIN_SLEEP, MAX_SLEEP);
-	return set_setting("sleep-max", TYPE_ID_UINT64, &sleep_max);
+	return stress_set_setting("sleep-max", TYPE_ID_UINT64, &sleep_max);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_sleep_max,	stress_set_sleep_max },
 	{ 0,			NULL }
 };
@@ -74,21 +74,11 @@ static void MLOCKED_TEXT stress_sigalrm_handler(int signum)
  */
 static void *stress_pthread_func(void *c)
 {
-	uint8_t stack[SIGSTKSZ + STACK_ALIGNMENT];
 	static void *nowt = NULL;
 	stress_ctxt_t *ctxt = (stress_ctxt_t *)c;
-	const args_t *args = ctxt->args;
+	const stress_args_t *args = ctxt->args;
 	const uint64_t max_ops =
 		args->max_ops ? (args->max_ops / ctxt->sleep_max) + 1 : 0;
-	/*
-	 *  According to POSIX.1 a thread should have
-	 *  a distinct alternative signal stack.
-	 *  However, we block signals in this thread
-	 *  so this is probably just totally unncessary.
-	 */
-	(void)memset(stack, 0, sizeof(stack));
-	if (stress_sigaltstack(stack, SIGSTKSZ) < 0)
-		goto die;
 
 	while (keep_stressing() &&
 	       !thread_terminate &&
@@ -142,7 +132,6 @@ static void *stress_pthread_func(void *c)
 
 		ctxt->counter++;
 	}
-die:
 	return &nowt;
 }
 
@@ -150,14 +139,14 @@ die:
  *  stress_sleep()
  *	stress by many sleeping threads
  */
-static int stress_sleep(const args_t *args)
+static int stress_sleep(const stress_args_t *args)
 {
 	uint64_t i, n, limited = 0;
 	uint64_t sleep_max = DEFAULT_SLEEP;
 	static stress_ctxt_t ctxts[MAX_SLEEP];
 	int ret = EXIT_SUCCESS;
 
-	if (!get_setting("sleep-max", &sleep_max)) {
+	if (!stress_get_setting("sleep-max", &sleep_max)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			sleep_max = MAX_SLEEP;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
