@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"sockdiag N",	  "start N workers exercising sockdiag netlink" },
 	{ NULL,	"sockdiag-ops N", "stop sockdiag workers after N bogo messages" },
 	{ NULL,	NULL,		  NULL }
@@ -41,7 +41,7 @@ typedef struct {
 	struct unix_diag_req udr;
 } stress_sockdiag_request_t;
 
-static int sockdiag_send(const args_t *args, const int fd)
+static int sockdiag_send(const stress_args_t *args, const int fd)
 {
 	static struct sockaddr_nl nladdr = {
 		.nl_family = AF_NETLINK
@@ -93,7 +93,7 @@ static int sockdiag_send(const args_t *args, const int fd)
 }
 
 static int stress_sockdiag_parse(
-	const args_t *args,
+	const stress_args_t *args,
 	struct unix_diag_msg *diag,
 	unsigned int len)
 {
@@ -129,7 +129,7 @@ static int stress_sockdiag_parse(
 	return 0;
 }
 
-static int sockdiag_recv(const args_t *args, const int fd)
+static int sockdiag_recv(const stress_args_t *args, const int fd)
 {
 	static uint32_t buf[4096];
 	int flags = 0;
@@ -186,7 +186,7 @@ static int sockdiag_recv(const args_t *args, const int fd)
  *  stress_sockdiag
  *	stress by heavy socket I/O
  */
-static int stress_sockdiag(const args_t *args)
+static int stress_sockdiag(const stress_args_t *args)
 {
 	int ret = EXIT_SUCCESS;
 
