@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"sockfd N",	 "start N workers sending file descriptors over sockets" },
 	{ NULL,	"sockfd-ops N",	 "stop after N sockfd bogo operations" },
 	{ NULL,	"sockfd-port P", "use socket fd ports P to P + number of workers - 1" },
@@ -42,10 +42,10 @@ static int stress_set_socket_fd_port(const char *opt)
 	stress_set_net_port("sockfd-port", opt,
 		MIN_SOCKET_FD_PORT, MAX_SOCKET_FD_PORT - STRESS_PROCS_MAX,
 		&socket_fd_port);
-	return set_setting("sockfd-port", TYPE_ID_INT, &socket_fd_port);
+	return stress_set_setting("sockfd-port", TYPE_ID_INT, &socket_fd_port);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_sockfd_port,	stress_set_socket_fd_port },
 	{ 0,			NULL }
 };
@@ -136,7 +136,7 @@ static inline int stress_socket_fd_recv(const int fd)
  *	client reader
  */
 static void stress_socket_client(
-	const args_t *args,
+	const stress_args_t *args,
 	const pid_t ppid,
 	const ssize_t max_fd,
 	const int socket_fd_port)
@@ -228,7 +228,7 @@ finish:
  *	server writer
  */
 static int stress_socket_server(
-	const args_t *args,
+	const stress_args_t *args,
 	const pid_t pid,
 	const pid_t ppid,
 	const ssize_t max_fd,
@@ -330,14 +330,14 @@ die:
  *  stress_sockfd
  *	stress socket fd passing
  */
-static int stress_sockfd(const args_t *args)
+static int stress_sockfd(const stress_args_t *args)
 {
 	pid_t pid, ppid = getppid();
 	ssize_t max_fd = stress_get_file_limit();
 	int socket_fd_port = DEFAULT_SOCKET_FD_PORT;
 	int ret = EXIT_SUCCESS;
 
-	(void)get_setting("sockfd-port", &socket_fd_port);
+	(void)stress_get_setting("sockfd-port", &socket_fd_port);
 
 	/*
 	 * When run as root, we really don't want to use up all
