@@ -26,7 +26,7 @@
 
 #define MAX_SOCKET_PAIRS	(32768)
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"sockpair N",	  "start N workers exercising socket pair I/O activity" },
 	{ NULL,	"sockpair-ops N", "stop after N socket pair bogo operations" },
 	{ NULL,	NULL,		  NULL }
@@ -82,7 +82,7 @@ static void socket_pair_close(
  *	this stressor needs to be oom-able in the parent
  *	and child cases
  */
-static int stress_sockpair_oomable(const args_t *args)
+static int stress_sockpair_oomable(const stress_args_t *args)
 {
 	pid_t pid;
 	static int socket_pair_fds[MAX_SOCKET_PAIRS][2];
@@ -185,7 +185,7 @@ abort:
  *  stress_sockpair
  *	stress by heavy socket_pair I/O
  */
-static int stress_sockpair(const args_t *args)
+static int stress_sockpair(const stress_args_t *args)
 {
 	pid_t pid;
 	uint32_t restarts = 0;
@@ -216,7 +216,7 @@ again:
 				args->instance);
 			/* If we got killed by OOM killer, re-start */
 			if (WTERMSIG(status) == SIGKILL) {
-				log_system_mem_info();
+				stress_log_system_mem_info();
 				pr_dbg("%s: assuming killed by OOM killer, "
 					"restarting again (instance %d)\n",
 					args->name, args->instance);
