@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"softlockup N",     "start N workers that cause softlockups" },
 	{ NULL,	"softlockup-ops N", "stop after N softlockup bogo operations" },
 	{ NULL,	NULL,		    NULL }
@@ -83,11 +83,10 @@ static void MLOCKED_TEXT stress_rlimit_handler(int signum)
  */
 static void drop_niceness(void)
 {
-	int nice_val, old_nice_val, i;
+	int nice_val, i;
 
 	errno = 0;
 	nice_val = nice(0);
-	old_nice_val = nice_val + 1;
 
 	/* Should never fail */
 	if (errno)
@@ -99,8 +98,9 @@ static void drop_niceness(void)
 	 *  at nice level 19
 	 */
 	for (i = 0; i < 40; i++) {
+		int old_nice_val = nice_val;
+
 		errno = 0;
-		old_nice_val = nice_val;
 		nice_val = nice(-1);
 		if (errno)
 			return;
@@ -109,7 +109,7 @@ static void drop_niceness(void)
 	}
 }
 
-static int stress_softlockup(const args_t *args)
+static int stress_softlockup(const stress_args_t *args)
 {
 	size_t policy = 0;
 	int max_prio = 0;
