@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"spawn N",	"start N workers spawning stress-ng using posix_spawn" },
 	{ NULL,	"spawn-ops N",	"stop after N spawn bogo operations" },
 	{ NULL,	NULL,		NULL }
@@ -55,7 +55,7 @@ static int stress_spawn_supported(void)
  *  stress_spawn()
  *	stress by forking and spawn'ing
  */
-static int stress_spawn(const args_t *args)
+static int stress_spawn(const stress_args_t *args)
 {
 	char path[PATH_MAX + 1];
 	ssize_t len;
