@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"splice N",	  "start N workers reading/writing using splice" },
 	{ NULL,	"splice-ops N",	  "stop after N bogo splice operations" },
 	{ NULL,	"splice-bytes N", "number of bytes to transfer per splice call" },
@@ -35,13 +35,13 @@ static int stress_set_splice_bytes(const char *opt)
 {
 	size_t splice_bytes;
 
-	splice_bytes = (size_t)get_uint64_byte_memory(opt, 1);
-	check_range_bytes("splice-bytes", splice_bytes,
+	splice_bytes = (size_t)stress_get_uint64_byte_memory(opt, 1);
+	stress_check_range_bytes("splice-bytes", splice_bytes,
 		MIN_SPLICE_BYTES, MAX_MEM_LIMIT);
-	return set_setting("splice-bytes", TYPE_ID_SIZE_T, &splice_bytes);
+	return stress_set_setting("splice-bytes", TYPE_ID_SIZE_T, &splice_bytes);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_splice_bytes,	stress_set_splice_bytes },
 	{ 0,			NULL }
 };
@@ -53,12 +53,12 @@ static const opt_set_func_t opt_set_funcs[] = {
  *  stress_splice
  *	stress copying of /dev/zero to /dev/null
  */
-static int stress_splice(const args_t *args)
+static int stress_splice(const stress_args_t *args)
 {
 	int fd_in, fd_out, fds[2];
 	size_t splice_bytes = DEFAULT_SPLICE_BYTES;
 
-	if (!get_setting("splice-bytes", &splice_bytes)) {
+	if (!stress_get_setting("splice-bytes", &splice_bytes)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			splice_bytes = MAX_SPLICE_BYTES;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
