@@ -42,7 +42,7 @@ typedef struct {
 	const void 		*libc_func;
 } stress_str_method_info_t;
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"str N",	   "start N workers exercising lib C string functions" },
 	{ NULL,	"str-method func", "specify the string function to stress" },
 	{ NULL,	"str-ops N",	   "stop after N bogo string operations" },
@@ -635,7 +635,7 @@ static int stress_set_str_method(const char *name)
 
 	for (info = str_methods; keep_stressing_flag() && info->func; info++) {
 		if (!strcmp(info->name, name)) {
-			set_setting("str-method", TYPE_ID_UINTPTR_T, &info);
+			stress_set_setting("str-method", TYPE_ID_UINTPTR_T, &info);
 			return 0;
 		}
 	}
@@ -653,7 +653,7 @@ static int stress_set_str_method(const char *name)
  *  stress_str()
  *	stress CPU by doing various string operations
  */
-static int stress_str(const args_t *args)
+static int stress_str(const stress_args_t *args)
 {
 	const stress_str_method_info_t *str_method = &str_methods[0];
 	stress_str_func func;
@@ -664,7 +664,7 @@ static int stress_str(const args_t *args)
 	register size_t len1, len2;
 	const char *name = args->name;
 
-	(void)get_setting("str-method", &str_method);
+	(void)stress_get_setting("str-method", &str_method);
 	func = str_method->func;
 	libc_func = str_method->libc_func;
 
@@ -701,7 +701,7 @@ static void stress_str_set_default(void)
 	stress_set_str_method("all");
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_str_method,	stress_set_str_method },
 	{ 0,			NULL }
 };
