@@ -40,7 +40,7 @@ typedef struct {
         const int advice;
 } stress_stream_madvise_info_t;
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"stream N",		"start N workers exercising memory bandwidth" },
 	{ NULL,	"stream-ops N",		"stop after N bogo stream operations" },
 	{ NULL,	"stream-index",		"specify number of indices into the data (0..3)" },
@@ -71,10 +71,10 @@ static int stress_set_stream_L3_size(const char *opt)
 {
 	uint64_t stream_L3_size;
 
-	stream_L3_size = get_uint64_byte(opt);
-	check_range_bytes("stream-L3-size", stream_L3_size,
+	stream_L3_size = stress_get_uint64_byte(opt);
+	stress_check_range_bytes("stream-L3-size", stream_L3_size,
 		MIN_STREAM_L3_SIZE, MAX_STREAM_L3_SIZE);
-	return set_setting("stream-L3-size", TYPE_ID_UINT64, &stream_L3_size);
+	return stress_set_setting("stream-L3-size", TYPE_ID_UINT64, &stream_L3_size);
 }
 
 static int stress_set_stream_madvise(const char *opt)
@@ -83,7 +83,7 @@ static int stress_set_stream_madvise(const char *opt)
 
 	for (info = stream_madvise_info; info->name; info++) {
 		if (!strcmp(opt, info->name)) {
-			set_setting("stream-madvise", TYPE_ID_INT, &info->advice);
+			stress_set_setting("stream-madvise", TYPE_ID_INT, &info->advice);
 			return 0;
 		}
 	}
@@ -99,9 +99,9 @@ static int stress_set_stream_index(const char *opt)
 {
 	uint32_t stream_index;
 
-	stream_index = get_int32(opt);
-	check_range("stream-index", stream_index, 0, 3);
-	return set_setting("stream-index", TYPE_ID_UINT32, &stream_index);
+	stream_index = stress_get_int32(opt);
+	stress_check_range("stream-index", stream_index, 0, 3);
+	return stress_set_setting("stream-index", TYPE_ID_UINT32, &stream_index);
 }
 
 static inline void OPTIMIZE3 stress_stream_copy_index0(
@@ -327,10 +327,10 @@ static void stress_stream_init_data(
 	uint64_t i;
 
 	for (i = 0; i < n; i++)
-		data[i] = (double)mwc32() / (double)mwc64();
+		data[i] = (double)stress_mwc32() / (double)stress_mwc64();
 }
 
-static inline void *stress_stream_mmap(const args_t *args, uint64_t sz)
+static inline void *stress_stream_mmap(const stress_args_t *args, uint64_t sz)
 {
 	void *ptr;
 
@@ -353,7 +353,7 @@ static inline void *stress_stream_mmap(const args_t *args, uint64_t sz)
 #if defined(HAVE_MADVISE)
 		int ret, advice = MADV_NORMAL;
 
-		(void)get_setting("stream-madvise", &advice);
+		(void)stress_get_setting("stream-madvise", &advice);
 
 		ret = madvise(ptr, sz, advice);
 		(void)ret;
@@ -362,44 +362,44 @@ static inline void *stress_stream_mmap(const args_t *args, uint64_t sz)
 	return ptr;
 }
 
-static inline uint64_t get_stream_L3_size(const args_t *args)
+static inline uint64_t get_stream_L3_size(const stress_args_t *args)
 {
 	uint64_t cache_size = MEM_CACHE_SIZE;
 #if defined(__linux__)
-	cpus_t *cpu_caches;
-	cpu_cache_t *cache = NULL;
+	stress_cpus_t *cpu_caches;
+	stress_cpu_cache_t *cache = NULL;
 	uint16_t max_cache_level;
 
-	cpu_caches = get_all_cpu_cache_details();
+	cpu_caches = stress_get_all_cpu_cache_details();
 	if (!cpu_caches) {
 		if (!args->instance)
 			pr_inf("%s: using built-in defaults as unable to "
 				"determine cache details\n", args->name);
 		return cache_size;
 	}
-	max_cache_level = get_max_cache_level(cpu_caches);
+	max_cache_level = stress_get_max_cache_level(cpu_caches);
 	if ((max_cache_level > 0) && (max_cache_level < 3) && (!args->instance))
 		pr_inf("%s: no L3 cache, using L%" PRIu16 " size instead\n",
 			args->name, max_cache_level);
 
-	cache = get_cpu_cache(cpu_caches, max_cache_level);
+	cache = stress_get_cpu_cache(cpu_caches, max_cache_level);
 	if (!cache) {
 		if (!args->instance)
 			pr_inf("%s: using built-in defaults as no suitable "
 				"cache found\n", args->name);
-		free_cpu_caches(cpu_caches);
+		stress_free_cpu_caches(cpu_caches);
 		return cache_size;
 	}
 	if (!cache->size) {
 		if (!args->instance)
 			pr_inf("%s: using built-in defaults as unable to "
 				"determine cache size\n", args->name);
-		free_cpu_caches(cpu_caches);
+		stress_free_cpu_caches(cpu_caches);
 		return cache_size;
 	}
 	cache_size = cache->size;
 
-	free_cpu_caches(cpu_caches);
+	stress_free_cpu_caches(cpu_caches);
 #else
 	if (!args->instance)
 		pr_inf("%s: using built-in defaults as unable to "
@@ -418,7 +418,7 @@ static void stress_stream_init_index(
 		idx[i] = i;
 
 	for (i = 0; i < n; i++) {
-		register uint64_t j = mwc64() % n;
+		register uint64_t j = stress_mwc64() % n;
 		register uint64_t tmp;
 
 		tmp = idx[i];
@@ -431,7 +431,7 @@ static void stress_stream_init_index(
  *  stress_stream()
  *	stress cache/memory/CPU with stream stressors
  */
-static int stress_stream(const args_t *args)
+static int stress_stream(const stress_args_t *args)
 {
 	int rc = EXIT_FAILURE;
 	double *a, *b, *c;
@@ -443,12 +443,12 @@ static int stress_stream(const args_t *args)
 	uint64_t stream_L3_size = DEFAULT_STREAM_L3_SIZE;
 	bool guess = false;
 
-	if (get_setting("stream-L3-size", &stream_L3_size))
+	if (stress_get_setting("stream-L3-size", &stream_L3_size))
 		L3 = stream_L3_size;
 	else
 		L3 = get_stream_L3_size(args);
 
-	(void)get_setting("stream-index", &stream_index);
+	(void)stress_get_setting("stream-index", &stream_index);
 
 	/* Have to take a hunch and badly guess size */
 	if (!L3) {
@@ -590,7 +590,7 @@ err_a:
 	return rc;
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_stream_index,	stress_set_stream_index },
 	{ OPT_stream_l3_size,	stress_set_stream_L3_size },
 	{ OPT_stream_madvise,	stress_set_stream_madvise },
