@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ "s N","switch N",	 "start N workers doing rapid context switches" },
 	{ NULL,	"switch-ops N",	 "stop after N context switch bogo operations" },
 	{ NULL, "switch-freq N", "set frequency of context switches" },
@@ -43,23 +43,23 @@ static int stress_set_switch_freq(const char *opt)
 {
 	uint64_t switch_freq;
 
-	switch_freq = get_uint64(opt);
-	check_range("switch-freq", switch_freq, 0, NANO_SECS);
-	return set_setting("switch-freq", TYPE_ID_UINT64, &switch_freq);
+	switch_freq = stress_get_uint64(opt);
+	stress_check_range("switch-freq", switch_freq, 0, NANO_SECS);
+	return stress_set_setting("switch-freq", TYPE_ID_UINT64, &switch_freq);
 }
 
 /*
  *  stress_switch
  *	stress by heavy context switching
  */
-static int stress_switch(const args_t *args)
+static int stress_switch(const stress_args_t *args)
 {
 	pid_t pid;
 	int pipefds[2];
 	size_t buf_size;
 	uint64_t switch_freq = 0;
 
-	(void)get_setting("switch-freq", &switch_freq);
+	(void)stress_get_setting("switch-freq", &switch_freq);
 
 #if defined(HAVE_PIPE2) &&	\
     defined(O_DIRECT)
@@ -208,7 +208,7 @@ again:
 	return EXIT_SUCCESS;
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_switch_freq,	stress_set_switch_freq },
 	{ 0,			NULL }
 };
