@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"sync-file N",	     "start N workers exercise sync_file_range" },
 	{ NULL,	"sync-file-ops N",   "stop after N sync_file_range bogo operations" },
 	{ NULL,	"sync-file-bytes N", "size of file to be sync'd" },
@@ -46,13 +46,13 @@ static int stress_set_sync_file_bytes(const char *opt)
 {
 	off_t sync_file_bytes;
 
-	sync_file_bytes = (off_t)get_uint64_byte_filesystem(opt, 1);
-	check_range_bytes("sync_file-bytes", sync_file_bytes,
+	sync_file_bytes = (off_t)stress_get_uint64_byte_filesystem(opt, 1);
+	stress_check_range_bytes("sync_file-bytes", sync_file_bytes,
 		MIN_SYNC_FILE_BYTES, MAX_SYNC_FILE_BYTES);
-	return set_setting("sync_file-bytes", TYPE_ID_OFF_T, &sync_file_bytes);
+	return stress_set_setting("sync_file-bytes", TYPE_ID_OFF_T, &sync_file_bytes);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_sync_file_bytes,	stress_set_sync_file_bytes },
 	{ 0,			NULL }
 };
@@ -64,7 +64,7 @@ static const opt_set_func_t opt_set_funcs[] = {
  *
  */
 static int stress_sync_allocate(
-	const args_t *args,
+	const stress_args_t *args,
 	const int fd,
 	const off_t sync_file_bytes)
 {
@@ -99,13 +99,13 @@ static int stress_sync_allocate(
  *  stress_sync_file
  *	stress the sync_file_range system call
  */
-static int stress_sync_file(const args_t *args)
+static int stress_sync_file(const stress_args_t *args)
 {
 	int fd, ret;
 	off_t sync_file_bytes = DEFAULT_SYNC_FILE_BYTES;
 	char filename[PATH_MAX];
 
-	if (!get_setting("sync_file-bytes", &sync_file_bytes)) {
+	if (!stress_get_setting("sync_file-bytes", &sync_file_bytes)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			sync_file_bytes = MAXIMIZED_FILE_SIZE;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -120,7 +120,7 @@ static int stress_sync_file(const args_t *args)
 		return exit_status(-ret);
 
 	(void)stress_temp_filename_args(args,
-		filename, sizeof(filename), mwc32());
+		filename, sizeof(filename), stress_mwc32());
 	if ((fd = open(filename, O_CREAT | O_RDWR, S_IRUSR | S_IWUSR)) < 0) {
 		ret = exit_status(errno);
 		pr_fail_err("open");
@@ -131,14 +131,14 @@ static int stress_sync_file(const args_t *args)
 
 	do {
 		shim_off64_t i, offset;
-		const size_t mode_index = mwc32() % SIZEOF_ARRAY(sync_modes);
+		const size_t mode_index = stress_mwc32() % SIZEOF_ARRAY(sync_modes);
 		const int mode = sync_modes[mode_index];
 
 		if (stress_sync_allocate(args, fd, sync_file_bytes) < 0)
 			break;
 		for (offset = 0; keep_stressing_flag() &&
 		     (offset < (shim_off64_t)sync_file_bytes); ) {
-			shim_off64_t sz = (mwc32() & 0x1fc00) + KB;
+			shim_off64_t sz = (stress_mwc32() & 0x1fc00) + KB;
 
 			ret = shim_sync_file_range(fd, offset, sz, mode);
 			if (ret < 0) {
@@ -159,7 +159,7 @@ static int stress_sync_file(const args_t *args)
 			break;
 		for (offset = 0; keep_stressing_flag() &&
 		     (offset < (shim_off64_t)sync_file_bytes); ) {
-			shim_off64_t sz = (mwc32() & 0x1fc00) + KB;
+			shim_off64_t sz = (stress_mwc32() & 0x1fc00) + KB;
 
 			ret = shim_sync_file_range(fd, sync_file_bytes - offset, sz, mode);
 			if (ret < 0) {
@@ -180,7 +180,7 @@ static int stress_sync_file(const args_t *args)
 			break;
 		for (i = 0; i < keep_stressing_flag() &&
 		     ((shim_off64_t)(sync_file_bytes / (128 * KB))); i++) {
-			offset = (mwc64() % sync_file_bytes) & ~((128 * KB) - 1);
+			offset = (stress_mwc64() % sync_file_bytes) & ~((128 * KB) - 1);
 			ret = shim_sync_file_range(fd, offset, 128 * KB, mode);
 			if (ret < 0) {
 				if (errno == ENOSYS) {
