@@ -22,7 +22,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"sysfs N",	"start N workers reading files from /sys" },
 	{ NULL,	"sysfs-ops N",	"stop after sysfs bogo operations" },
 	{ NULL,	NULL,		NULL }
@@ -47,7 +47,7 @@ static uint32_t os_release;
 static stress_hash_table_t *sysfs_hash_table;
 
 typedef struct stress_ctxt {
-	const args_t *args;		/* stressor args */
+	const stress_args_t *args;		/* stressor args */
 	int kmsgfd;			/* /dev/kmsg file descriptor */
 	bool sys_admin;			/* true if sys admin capable */
 } stress_ctxt_t;
@@ -126,7 +126,7 @@ static inline bool stress_sys_rw(const stress_ctxt_t *ctxt)
 	ssize_t i = 0, ret;
 	char buffer[SYS_BUF_SZ];
 	char path[PATH_MAX];
-	const args_t *args = ctxt->args;
+	const stress_args_t *args = ctxt->args;
 	const double threshold = 0.2;
 	size_t page_size = ctxt->args->page_size;
 
@@ -167,7 +167,7 @@ static inline bool stress_sys_rw(const stress_ctxt_t *ctxt)
 		 *  Multiple randomly sized reads
 		 */
 		while (i < (4096 * SYS_BUF_SZ)) {
-			ssize_t sz = 1 + (mwc32() % (sizeof(buffer) - 1));
+			ssize_t sz = 1 + (stress_mwc32() % (sizeof(buffer) - 1));
 			if (!keep_stressing_flag())
 				break;
 			ret = read(fd, buffer, sz);
@@ -221,7 +221,7 @@ static inline bool stress_sys_rw(const stress_ctxt_t *ctxt)
 		ptr = mmap(NULL, page_size, PROT_READ,
 			MAP_SHARED | MAP_ANONYMOUS, fd, 0);
 		if (ptr != MAP_FAILED) {
-			uint8_put(*ptr);
+			stress_uint8_put(*ptr);
 			(void)munmap(ptr, page_size);
 		}
 		if (stress_time_now() - t_start > threshold)
@@ -367,9 +367,8 @@ drain:
 static void *stress_sys_rw_thread(void *ctxt_ptr)
 {
 	static void *nowt = NULL;
-	uint8_t stack[SIGSTKSZ + STACK_ALIGNMENT];
 	stress_ctxt_t *ctxt = (stress_ctxt_t *)ctxt_ptr;
-	const args_t *args = ctxt->args;
+	const stress_args_t *args = ctxt->args;
 
 	/*
 	 *  Block all signals, let controlling thread
@@ -377,16 +376,6 @@ static void *stress_sys_rw_thread(void *ctxt_ptr)
 	 */
 	(void)sigprocmask(SIG_BLOCK, &set, NULL);
 
-	/*
-	 *  According to POSIX.1 a thread should have
-	 *  a distinct alternative signal stack.
-	 *  However, we block signals in this thread
-	 *  so this is probably just totally unncessary.
-	 */
-	(void)memset(stack, 0, sizeof(stack));
-	if (stress_sigaltstack(stack, SIGSTKSZ) < 0)
-		return &nowt;
-
 	while (keep_stressing())
 		stress_sys_rw(ctxt);
 
@@ -438,7 +427,7 @@ static void stress_sys_dir(
 	const int depth)
 {
 	struct dirent **dlist;
-	const args_t *args = ctxt->args;
+	const stress_args_t *args = ctxt->args;
 	mode_t flags = S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH;
 	int i, n;
 
@@ -449,7 +438,7 @@ static void stress_sys_dir(
 	if (depth > 20)
 		return;
 
-	mixup = mwc32();
+	mixup = stress_mwc32();
 	dlist = NULL;
 	n = scandir(path, &dlist, NULL, mixup_sort);
 	if (n <= 0)
@@ -544,7 +533,7 @@ done:
  *  stress_sysfs
  *	stress reading all of /sys
  */
-static int stress_sysfs(const args_t *args)
+static int stress_sysfs(const stress_args_t *args)
 {
 	size_t i;
 	pthread_t pthreads[MAX_SYSFS_THREADS];
