@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"sysinfo N",	 "start N workers reading system information" },
 	{ NULL,	"sysinfo-ops N", "stop after sysinfo bogo operations" },
 	{ NULL,	NULL,		 NULL }
@@ -38,7 +38,7 @@ static const help_t help[] = {
  *  stress on system information
  *	stress system by rapid fetches of system information
  */
-static int stress_sysinfo(const args_t *args)
+static int stress_sysinfo(const stress_args_t *args)
 {
 	int n_mounts;
 	char *mnts[128];
@@ -120,7 +120,6 @@ static int stress_sysinfo(const args_t *args)
 		}
 #endif
 
-#if defined(HAVE_USTAT)
 		{
 			int i;
 
@@ -128,16 +127,17 @@ static int stress_sysinfo(const args_t *args)
 
 			for (i = 0; i < n_mounts; i++) {
 				struct stat sbuf;
-				struct ustat ubuf;
+				struct shim_ustat ubuf;
 				int ret;
 
 				ret = stat(mnts[i], &sbuf);
 				if (ret < 0)
 					continue;
 
-				ret = ustat(sbuf.st_dev, &ubuf);
+				ret = shim_ustat(sbuf.st_dev, &ubuf);
 				if ((ret < 0) && (g_opt_flags & OPT_FLAGS_VERIFY)) {
 					if (errno != EINVAL &&
+					    errno != EFAULT &&
 					    errno != ENOSYS) {
 						pr_fail("%s: ustat on %s "
 							"failed: errno=%d (%s)\n",
@@ -147,7 +147,7 @@ static int stress_sysinfo(const args_t *args)
 				}
 			}
 		}
-#endif
+
 		check_do_run();
 
 #if defined(HAVE_SYS_STATVFS_H)
