@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ "T N", "timer N",	"start N workers producing timer events" },
 	{ NULL, "timer-ops N",	"stop after N timer bogo events" },
 	{ NULL, "timer-freq F",	"run timer(s) at F Hz, range 1 to 1000000000" },
@@ -53,10 +53,10 @@ static int stress_set_timer_freq(const char *opt)
 {
 	uint64_t timer_freq;
 
-	timer_freq = get_uint64(opt);
-	check_range("timer-freq", timer_freq,
+	timer_freq = stress_get_uint64(opt);
+	stress_check_range("timer-freq", timer_freq,
 		MIN_TIMER_FREQ, MAX_TIMER_FREQ);
-	return set_setting("timer-freq", TYPE_ID_UINT64, &timer_freq);
+	return stress_set_setting("timer-freq", TYPE_ID_UINT64, &timer_freq);
 }
 
 static int stress_set_timer_rand(const char *opt)
@@ -64,10 +64,10 @@ static int stress_set_timer_rand(const char *opt)
 	bool timer_rand = true;
 
 	(void)opt;
-	return set_setting("timer-rand", TYPE_ID_BOOL, &timer_rand);
+	return stress_set_setting("timer-rand", TYPE_ID_BOOL, &timer_rand);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_timer_freq,	stress_set_timer_freq },
 	{ OPT_timer_rand,	stress_set_timer_rand },
 	{ 0,			NULL }
@@ -88,11 +88,11 @@ static void stress_timer_set(struct itimerspec *timer)
 	double rate;
 	bool timer_rand = false;
 
-	(void)get_setting("timer-rand", &timer_rand);
+	(void)stress_get_setting("timer-rand", &timer_rand);
 
 	if (timer_rand) {
 		/* Mix in some random variation */
-		double r = ((double)(mwc32() % 10000) - 5000.0) / 40000.0;
+		double r = ((double)(stress_mwc32() % 10000) - 5000.0) / 40000.0;
 		rate = rate_ns + (rate_ns * r);
 	} else {
 		rate = rate_ns;
@@ -159,7 +159,7 @@ cancel:
  *  stress_timer
  *	stress timers
  */
-static int stress_timer(const args_t *args)
+static int stress_timer(const stress_args_t *args)
 {
 	struct sigevent sev;
 	struct itimerspec timer;
@@ -173,7 +173,7 @@ static int stress_timer(const args_t *args)
 	max_ops = args->max_ops;
 	start = stress_time_now();
 
-	if (!get_setting("timer-freq", &timer_freq)) {
+	if (!stress_get_setting("timer-freq", &timer_freq)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			timer_freq = MAX_TIMER_FREQ;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
