@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"timerfd N",	  "start N workers producing timerfd events" },
 	{ NULL,	"timerfd-ops N",  "stop after N timerfd bogo events" },
 	{ NULL,	"timerfd-freq F", "run timer(s) at F Hz, range 1 to 1000000000" },
@@ -43,10 +43,10 @@ static int stress_set_timerfd_freq(const char *opt)
 {
 	uint64_t timerfd_freq;
 
-	timerfd_freq = get_uint64(opt);
-	check_range("timerfd-freq", timerfd_freq,
+	timerfd_freq = stress_get_uint64(opt);
+	stress_check_range("timerfd-freq", timerfd_freq,
 		MIN_TIMERFD_FREQ, MAX_TIMERFD_FREQ);
-	return set_setting("timerfd-freq", TYPE_ID_UINT64, &timerfd_freq);
+	return stress_set_setting("timerfd-freq", TYPE_ID_UINT64, &timerfd_freq);
 }
 
 static int stress_set_timerfd_rand(const char *opt)
@@ -54,10 +54,10 @@ static int stress_set_timerfd_rand(const char *opt)
 	bool timerfd_rand = true;
 
 	(void)opt;
-	return set_setting("timerfd-rand", TYPE_ID_BOOL, &timerfd_rand);
+	return stress_set_setting("timerfd-rand", TYPE_ID_BOOL, &timerfd_rand);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_timerfd_freq,	stress_set_timerfd_freq },
 	{ OPT_timerfd_rand,	stress_set_timerfd_rand },
 	{ 0,			NULL }
@@ -79,7 +79,7 @@ static void stress_timerfd_set(
 
 	if (timerfd_rand) {
 		/* Mix in some random variation */
-		double r = ((double)(mwc32() % 10000) - 5000.0) / 40000.0;
+		double r = ((double)(stress_mwc32() % 10000) - 5000.0) / 40000.0;
 		rate = rate_ns + (rate_ns * r);
 	} else {
 		rate = rate_ns;
@@ -100,7 +100,7 @@ static void stress_timerfd_set(
  *  stress_timerfd
  *	stress timerfd
  */
-static int stress_timerfd(const args_t *args)
+static int stress_timerfd(const stress_args_t *args)
 {
 	struct itimerspec timer;
 	uint64_t timerfd_freq = DEFAULT_TIMERFD_FREQ;
@@ -108,9 +108,9 @@ static int stress_timerfd(const args_t *args)
 	char filename[PATH_MAX];
 	bool timerfd_rand = false;
 
-	(void)get_setting("timerfd-rand", &timerfd_rand);
+	(void)stress_get_setting("timerfd-rand", &timerfd_rand);
 
-	if (!get_setting("timerfd-freq", &timerfd_freq)) {
+	if (!stress_get_setting("timerfd-freq", &timerfd_freq)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			timerfd_freq = MAX_TIMERFD_FREQ;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
