@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"tmpfs N",	    "start N workers mmap'ing a file on tmpfs" },
 	{ NULL,	"tmpfs-ops N",	    "stop after N tmpfs bogo ops" },
 	{ NULL,	"tmpfs-mmap-async", "using asynchronous msyncs for tmpfs file based mmap" },
@@ -37,7 +37,7 @@ static int stress_set_tmpfs_mmap_file(const char *opt)
 	bool tmpfs_mmap_file = true;
 
 	(void)opt;
-	return set_setting("tmpfs-mmap-file", TYPE_ID_BOOL, &tmpfs_mmap_file);
+	return stress_set_setting("tmpfs-mmap-file", TYPE_ID_BOOL, &tmpfs_mmap_file);
 }
 
 static int stress_set_tmpfs_mmap_async(const char *opt)
@@ -45,10 +45,10 @@ static int stress_set_tmpfs_mmap_async(const char *opt)
 	bool tmpfs_mmap_async = true;
 
 	(void)opt;
-	return set_setting("tmpfs-mmap-async", TYPE_ID_BOOL, &tmpfs_mmap_async);
+	return stress_set_setting("tmpfs-mmap-async", TYPE_ID_BOOL, &tmpfs_mmap_async);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_tmpfs_mmap_async,	stress_set_tmpfs_mmap_async },
 	{ OPT_tmpfs_mmap_file,	stress_set_tmpfs_mmap_file },
 	{ 0,			NULL }
@@ -93,9 +93,9 @@ typedef struct {
  *	will enforce and automatic space reap if the child process
  *	exits prematurely.
  */
-static int stress_tmpfs_open(const args_t *args, off_t *len)
+static int stress_tmpfs_open(const stress_args_t *args, off_t *len)
 {
-	const uint32_t rnd = mwc32();
+	const uint32_t rnd = stress_mwc32();
 	char path[PATH_MAX];
 	char *mnts[MAX_MOUNTS];
 	int i, n, fd = -1;
@@ -166,7 +166,7 @@ static int stress_tmpfs_open(const args_t *args, off_t *len)
 	return fd;
 }
 
-static int stress_tmpfs_child(const args_t *args, void *ctxt)
+static int stress_tmpfs_child(const stress_args_t *args, void *ctxt)
 {
 	stress_tmpfs_context_t *context = (stress_tmpfs_context_t *)ctxt;
 	const size_t page_size = args->page_size;
@@ -183,8 +183,8 @@ static int stress_tmpfs_child(const args_t *args, void *ctxt)
 	flags |= MAP_POPULATE;
 #endif
 
-	(void)get_setting("tmpfs-mmap-async", &tmpfs_mmap_async);
-	(void)get_setting("tmpfs-mmap-file", &tmpfs_mmap_file);
+	(void)stress_get_setting("tmpfs-mmap-async", &tmpfs_mmap_async);
+	(void)stress_get_setting("tmpfs-mmap-file", &tmpfs_mmap_file);
 
 	ms_flags = tmpfs_mmap_async ? MS_ASYNC : MS_SYNC;
 
@@ -192,7 +192,7 @@ static int stress_tmpfs_child(const args_t *args, void *ctxt)
 		uint8_t mapped[pages4k];
 		uint8_t *mappings[pages4k];
 		size_t n;
-		const int rnd = mwc32() % SIZEOF_ARRAY(mmap_flags);
+		const int rnd = stress_mwc32() % SIZEOF_ARRAY(mmap_flags);
 		const int rnd_flag = mmap_flags[rnd];
 		uint8_t *buf = NULL;
 
@@ -251,7 +251,7 @@ static int stress_tmpfs_child(const args_t *args, void *ctxt)
 		 */
 		(void)stress_mincore_touch_pages(buf, sz);
 		for (n = pages4k; n; ) {
-			uint64_t j, i = mwc64() % pages4k;
+			uint64_t j, i = stress_mwc64() % pages4k;
 
 			for (j = 0; j < n; j++) {
 				uint64_t page = (i + j) % pages4k;
@@ -273,7 +273,7 @@ static int stress_tmpfs_child(const args_t *args, void *ctxt)
 		 *  Step #2, map them back in random order
 		 */
 		for (n = pages4k; n; ) {
-			uint64_t j, i = mwc64() % pages4k;
+			uint64_t j, i = stress_mwc64() % pages4k;
 
 			for (j = 0; j < n; j++) {
 				uint64_t page = (i + j) % pages4k;
@@ -334,7 +334,7 @@ cleanup:
  *  stress_tmpfs()
  *	stress tmpfs
  */
-static int stress_tmpfs(const args_t *args)
+static int stress_tmpfs(const stress_args_t *args)
 {
 	stress_tmpfs_context_t context;
 	int ret;
