@@ -24,14 +24,14 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"tsc N",	"start N workers reading the TSC (x86 only)" },
 	{ NULL,	"tsc-ops N",	"stop after N TSC bogo operations" },
 	{ NULL,	NULL,		NULL }
 };
 
 #if defined(HAVE_CPUID_H) &&	\
-    defined(STRESS_X86) && 	\
+    defined(STRESS_ARCH_X86) && 	\
     defined(HAVE_CPUID) &&	\
     NEED_GNUC(4,6,0)
 
@@ -77,7 +77,7 @@ static inline void rdtsc(void)
 }
 
 
-#elif defined(STRESS_PPC64) &&			\
+#elif defined(STRESS_ARCH_PPC64) &&			\
       defined(HAVE_SYS_PLATFORM_PPC_H) &&	\
       defined(HAVE_PPC_GET_TIMEBASE)
 
@@ -141,7 +141,7 @@ static inline void rdtsc(void)
  *  stress_tsc()
  *      stress Intel tsc instruction
  */
-static int stress_tsc(const args_t *args)
+static int stress_tsc(const stress_args_t *args)
 {
 	if (tsc_supported) {
 		do {
