@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"tsearch N",		"start N workers that exercise a tree search" },
 	{ NULL,	"tsearch-ops N",	"stop after N tree search bogo operations" },
 	{ NULL,	"tsearch-size N",	"number of 32 bit integers to tsearch" },
@@ -39,10 +39,10 @@ static int stress_set_tsearch_size(const char *opt)
 {
 	uint64_t tsearch_size;
 
-	tsearch_size = get_uint64(opt);
-	check_range("tsearch-size", tsearch_size,
+	tsearch_size = stress_get_uint64(opt);
+	stress_check_range("tsearch-size", tsearch_size,
 		MIN_TSEARCH_SIZE, MAX_TSEARCH_SIZE);
-	return set_setting("tsearch-size", TYPE_ID_UINT64, &tsearch_size);
+	return stress_set_setting("tsearch-size", TYPE_ID_UINT64, &tsearch_size);
 }
 
 /*
@@ -66,13 +66,13 @@ static int cmp(const void *p1, const void *p2)
  *  stress_tsearch()
  *	stress tsearch
  */
-static int stress_tsearch(const args_t *args)
+static int stress_tsearch(const stress_args_t *args)
 {
 	uint64_t tsearch_size = DEFAULT_TSEARCH_SIZE;
 	int32_t *data;
 	size_t i, n;
 
-	if (!get_setting("tsearch-size", &tsearch_size)) {
+	if (!stress_get_setting("tsearch-size", &tsearch_size)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			tsearch_size = MAX_TSEARCH_SIZE;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -90,7 +90,7 @@ static int stress_tsearch(const args_t *args)
 
 		/* Step #1, populate tree */
 		for (i = 0; i < n; i++) {
-			data[i] = ((mwc32() & 0xfff) << 20) ^ i;
+			data[i] = ((stress_mwc32() & 0xfff) << 20) ^ i;
 			if (tsearch(&data[i], &root, cmp) == NULL) {
 				size_t j;
 
@@ -139,7 +139,7 @@ abort:
 	return EXIT_SUCCESS;
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_tsearch_size,	stress_set_tsearch_size },
 	{ 0,			NULL }
 };
