@@ -26,7 +26,7 @@
 
 #define PACKETS_TO_SEND		(64)
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"tun N",	"start N workers exercising tun interface" },
 	{ NULL,	"tun-ops N",	"stop after N tun bogo operations" },
 	{ NULL, "tun-tap",	"use TAP interface instead of TUN" },
@@ -73,14 +73,14 @@ static int stress_set_tun_tap(const char *opt)
         bool tun_tap = true;
 
         (void)opt;
-        return set_setting("tun-tap", TYPE_ID_BOOL, &tun_tap);
+        return stress_set_setting("tun-tap", TYPE_ID_BOOL, &tun_tap);
 }
 
 /*
  *  stress_tun
  *	stress tun interface
  */
-static int stress_tun(const args_t *args)
+static int stress_tun(const stress_args_t *args)
 {
 	int rc = EXIT_SUCCESS;
 	const uid_t owner = geteuid();
@@ -88,14 +88,14 @@ static int stress_tun(const args_t *args)
 	char ip_addr[32];
         bool tun_tap = false;
 
-        (void)get_setting("tun-tap", &tun_tap);
+        (void)stress_get_setting("tun-tap", &tun_tap);
 
 	do {
 		int i, fd, sfd, ret, status;
 		pid_t pid;
 		struct ifreq ifr;
 		struct sockaddr_in *tun_addr;
-		int port = 2000 + (mwc16() & 0xfff);
+		int port = 2000 + (stress_mwc16() & 0xfff);
 
 		fd = open(tun_dev, O_RDWR);
 		if (fd < 0) {
@@ -146,8 +146,8 @@ static int stress_tun(const args_t *args)
 		 */
 		for (i = 0; i < 32; i++) {
 			(void)snprintf(ip_addr, sizeof(ip_addr), "192.168.%" PRIu8 ".%" PRIu8,
-				(mwc8() % 252) + 2,
-				(mwc8() % 254) + 1);
+				(stress_mwc8() % 252) + 2,
+				(stress_mwc8() % 254) + 1);
 
 			(void)inet_pton(AF_INET, ip_addr, &tun_addr->sin_addr);
 			ret = ioctl(sfd, SIOCSIFADDR, &ifr);
@@ -187,7 +187,7 @@ static int stress_tun(const args_t *args)
 					rc = EXIT_FAILURE;
 					break;
 				}
-				goto child_cleanup;
+				goto child_cleanup_fd;
 			}
 
 			(void)memset(&addr, 0, sizeof(addr));
@@ -212,7 +212,6 @@ static int stress_tun(const args_t *args)
 					rc = EXIT_FAILURE;
 					break;
 				}
-				(void)close(sfd);
 				goto child_cleanup;
 			}
 
@@ -224,6 +223,7 @@ static int stress_tun(const args_t *args)
 			}
 child_cleanup:
 			(void)close(sfd);
+child_cleanup_fd:
 			(void)close(fd);
 			_exit(rc);
 		} else {
@@ -346,7 +346,7 @@ clean_up:
 	return rc;
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_tun_tap,		stress_set_tun_tap },
         { 0,                    NULL }
 };
