@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"udp-flood N",		"start N workers that performs a UDP flood attack" },
 	{ NULL,	"udp-flood-ops N",	"stop after N udp flood bogo operations" },
 	{ NULL,	"udp-flood-domain D",	"specify domain, default is ipv4" },
@@ -41,12 +41,12 @@ static int stress_set_udp_flood_domain(const char *name)
 
 	ret = stress_set_net_domain(DOMAIN_INET_ALL, "udp-flood-domain",
 		name, &udp_flood_domain);
-	set_setting("udp-flood-domain", TYPE_ID_INT, &udp_flood_domain);
+	stress_set_setting("udp-flood-domain", TYPE_ID_INT, &udp_flood_domain);
 
 	return ret;
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_udp_flood_domain,	stress_set_udp_flood_domain },
 	{ 0,			NULL }
 };
@@ -57,7 +57,7 @@ static const opt_set_func_t opt_set_funcs[] = {
  *  stress_udp_flood
  *	UDP flood
  */
-static int stress_udp_flood(const args_t *args)
+static int stress_udp_flood(const stress_args_t *args)
 {
 	int fd, rc = EXIT_SUCCESS, j = 0;
 	int udp_flood_domain = AF_INET;
@@ -71,7 +71,7 @@ static int stress_udp_flood(const args_t *args)
 		"0123456789ABCDEFGHIJKLMNOPQRSTUV"
 		"WXYZabcdefghijklmnopqrstuvwxyz@!";
 
-	(void)get_setting("udp-flood-domain", &udp_flood_domain);
+	(void)stress_get_setting("udp-flood-domain", &udp_flood_domain);
 
 	if ((fd = socket(udp_flood_domain, SOCK_DGRAM, AF_PACKET)) < 0) {
 		if (errno == EPROTONOSUPPORT) {
@@ -109,7 +109,7 @@ static int stress_udp_flood(const args_t *args)
 		if (!keep_stressing())
 			break;
 
-		rand_port = 1024 + (mwc16() % (65535 - 1024));
+		rand_port = 1024 + (stress_mwc16() % (65535 - 1024));
 		stress_set_sockaddr_port(udp_flood_domain, rand_port, addr);
 		if (sendto(fd, buf, sz, 0, addr, addr_len) > 0)
 			inc_counter(args);
