@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ "u N","urandom N",	 "start N workers reading /dev/urandom" },
 	{ NULL, "urandom-ops N", "stop after N urandom bogo read operations" },
 	{ NULL, NULL,		 NULL }
@@ -35,7 +35,7 @@ static const help_t help[] = {
     defined(RNDADDTOENTCNT) ||	\
     defined(RNDRESEEDCRNG) || 	\
     defined(__linux__)
-static void check_eperm(const args_t *args, const int ret, const int err)
+static void check_eperm(const stress_args_t *args, const int ret, const int err)
 {
 	if ((g_opt_flags & OPT_FLAGS_VERIFY) &&
 	    ((ret == 0) || ((err != EPERM) && (err != EINVAL) && (err != ENOTTY)))) {
@@ -50,7 +50,7 @@ static void check_eperm(const args_t *args, const int ret, const int err)
  *  stress_urandom
  *	stress reading of /dev/urandom and /dev/random
  */
-static int stress_urandom(const args_t *args)
+static int stress_urandom(const stress_args_t *args)
 {
 	int fd_urnd, fd_rnd, rc = EXIT_FAILURE;
 #if defined(__linux__)
@@ -82,6 +82,10 @@ static int stress_urandom(const args_t *args)
 	if ((fd_urnd < 0) && (fd_rnd < 0)) {
 		pr_inf("%s: random device(s) do not exist, skipping stressor\n",
 			args->name);
+#if defined(__linux__)
+		if (fd_rnd_wr >= 0)
+			(void)close(fd_rnd_wr);
+#endif
 		return EXIT_NOT_IMPLEMENTED;
 	}
 
@@ -146,17 +150,17 @@ next:
 				check_eperm(args, ret, errno);
 #endif
 #if defined(RNDADDTOENTCNT)
-				ret = ioctl(fd_rnd, RNDADDTOENTCNT, mwc32());
+				ret = ioctl(fd_rnd, RNDADDTOENTCNT, stress_mwc32());
 				check_eperm(args, ret, errno);
 #endif
 #if defined(RNDRESEEDCRNG)
-				ret = ioctl(fd_rnd, RNDRESEEDCRNG, mwc32());
+				ret = ioctl(fd_rnd, RNDRESEEDCRNG, stress_mwc32());
 				check_eperm(args, ret, errno);
 #endif
 
 #if defined(__linux__)
 				if (fd_rnd_wr >= 0) {
-					buffer[0] = mwc8();
+					buffer[0] = stress_mwc8();
 					ret = write(fd_rnd_wr, buffer, 1);
 					check_eperm(args, ret, errno);
 				}
