@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"userfaultfd N",	"start N page faulting workers with userspace handling" },
 	{ NULL,	"userfaultfd-ops N",	"stop after N page faults have been handled" },
 	{ NULL,	NULL,			NULL }
@@ -40,7 +40,7 @@ static const help_t help[] = {
 
 /* Context for clone */
 typedef struct {
-	const args_t *args;
+	const stress_args_t *args;
 	uint8_t *data;
 	size_t page_size;
 	size_t sz;
@@ -53,13 +53,13 @@ static int stress_set_userfaultfd_bytes(const char *opt)
 {
 	size_t userfaultfd_bytes;
 
-	userfaultfd_bytes = (size_t)get_uint64_byte_memory(opt, 1);
-	check_range_bytes("userfaultfd-bytes", userfaultfd_bytes,
+	userfaultfd_bytes = (size_t)stress_get_uint64_byte_memory(opt, 1);
+	stress_check_range_bytes("userfaultfd-bytes", userfaultfd_bytes,
 		MIN_MMAP_BYTES, MAX_MEM_LIMIT);
-	return set_setting("userfaultfd-bytes", TYPE_ID_SIZE_T, &userfaultfd_bytes);
+	return stress_set_setting("userfaultfd-bytes", TYPE_ID_SIZE_T, &userfaultfd_bytes);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_userfaultfd_bytes,	stress_set_userfaultfd_bytes },
 	{ 0,				NULL }
 };
@@ -86,7 +86,7 @@ static void MLOCKED_TEXT stress_child_alarm_handler(int signum)
 static int stress_userfaultfd_clone(void *arg)
 {
 	stress_context_t *c = (stress_context_t *)arg;
-	const args_t *args = c->args;
+	const stress_args_t *args = c->args;
 
 	(void)setpgid(0, g_pgrp);
 	stress_parent_died_alarm();
@@ -115,7 +115,7 @@ static int stress_userfaultfd_clone(void *arg)
  *	handle a write page fault caused by child
  */
 static inline int handle_page_fault(
-	const args_t *args,
+	const stress_args_t *args,
 	const int fd,
 	uint8_t *addr,
 	void *zero_page,
@@ -128,7 +128,7 @@ static inline int handle_page_fault(
 		return -1;
 	}
 
-	if (mwc32() & 1) {
+	if (stress_mwc32() & 1) {
 		struct uffdio_copy copy;
 
 		copy.copy = 0;
@@ -161,7 +161,7 @@ static inline int handle_page_fault(
  *	is an OOM-able child process that the
  *	parent can restart
  */
-static int stress_userfaultfd_child(const args_t *args, void *context)
+static int stress_userfaultfd_child(const stress_args_t *args, void *context)
 {
 	const size_t page_size = args->page_size;
 	size_t sz;
@@ -184,7 +184,7 @@ static int stress_userfaultfd_child(const args_t *args, void *context)
 
 	(void)context;
 
-	if (!get_setting("userfaultfd-bytes", &userfaultfd_bytes)) {
+	if (!stress_get_setting("userfaultfd-bytes", &userfaultfd_bytes)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			userfaultfd_bytes = MAX_32;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -288,7 +288,7 @@ static int stress_userfaultfd_child(const args_t *args, void *context)
 	 *  We need to clone and share the same VM address space
 	 *  as parent so we can perform the page fault handling
 	 */
-	pid = clone(stress_userfaultfd_clone, align_stack(stack_top),
+	pid = clone(stress_userfaultfd_clone, stress_align_stack(stack_top),
 		SIGCHLD | CLONE_FILES | CLONE_FS | CLONE_SIGHAND | CLONE_VM, &c);
 	if (pid < 0) {
 		pr_err("%s: fork failed, errno = %d (%s)\n",
@@ -407,7 +407,7 @@ free_zeropage:
  *  stress_userfaultfd()
  *	stress userfaultfd
  */
-static int stress_userfaultfd(const args_t *args)
+static int stress_userfaultfd(const stress_args_t *args)
 {
 	return stress_oomable_child(args, NULL, stress_userfaultfd_child, STRESS_OOMABLE_NORMAL);
 }
