@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"utime N",	"start N workers updating file timestamps" },
 	{ NULL,	"utime-ops N",	"stop after N utime bogo operations" },
 	{ NULL,	"utime-fsync",	"force utime meta data sync to the file system" },
@@ -36,27 +36,27 @@ static int stress_set_utime_fsync(const char *opt)
 	bool utime_fsync = true;
 
 	(void)opt;
-	return set_setting("utime-fsync", TYPE_ID_BOOL, &utime_fsync);
+	return stress_set_setting("utime-fsync", TYPE_ID_BOOL, &utime_fsync);
 }
 
 /*
  *  stress_utime()
  *	stress system by setting file utime
  */
-static int stress_utime(const args_t *args)
+static int stress_utime(const stress_args_t *args)
 {
 	char filename[PATH_MAX];
 	int ret, fd;
 	bool utime_fsync = false;
 
-	(void)get_setting("utime-fsync", &utime_fsync);
+	(void)stress_get_setting("utime-fsync", &utime_fsync);
 
 	ret = stress_temp_dir_mk_args(args);
 	if (ret < 0)
 		return exit_status(-ret);
 
 	(void)stress_temp_filename_args(args,
-		filename, sizeof(filename), mwc32());
+		filename, sizeof(filename), stress_mwc32());
 	if ((fd = open(filename, O_WRONLY | O_CREAT, S_IRUSR | S_IWUSR)) < 0) {
 		ret = exit_status(errno);
 		pr_err("%s: open failed: errno=%d: (%s)\n",
@@ -178,7 +178,7 @@ static int stress_utime(const args_t *args)
 	return EXIT_SUCCESS;
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
         { OPT_utime_fsync,	stress_set_utime_fsync },
 	{ 0,			NULL }
 };
