@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"vdso N",	"start N workers exercising functions in the VDSO" },
 	{ NULL,	"vdso-ops N",	"stop after N vDSO function calls" },
 	{ NULL,	"vdso-func F",	"use just vDSO function F" },
@@ -37,10 +37,10 @@ static const help_t help[] = {
  */
 static int stress_set_vdso_func(const char *name)
 {
-	return set_setting("vdso-func", TYPE_ID_STR, name);
+	return stress_set_setting("vdso-func", TYPE_ID_STR, name);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_vdso_func,	stress_set_vdso_func },
 	{ 0,			NULL }
 };
@@ -409,7 +409,7 @@ static int vdso_sym_list_check_vdso_func(stress_vdso_sym_t **list)
 	stress_vdso_sym_t *vs1;
 	char *name;
 
-	if (!get_setting("vdso-func", &name))
+	if (!stress_get_setting("vdso-func", &name))
 		return 0;
 
 	for (vs1 = vdso_sym_list; vs1; vs1 = vs1->next) {
@@ -439,7 +439,7 @@ static int vdso_sym_list_check_vdso_func(stress_vdso_sym_t **list)
  *  stress_vdso()
  *	stress system wraps in vDSO
  */
-static int stress_vdso(const args_t *args)
+static int stress_vdso(const stress_args_t *args)
 {
 	char *str;
 	double t1, t2, t3, overhead_ns;
