@@ -27,14 +27,14 @@
 #define STACK_SIZE      (16384)
 #define WASTE_SIZE	(64 * MB)
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"vforkmany N",     "start N workers spawning many vfork children" },
 	{ NULL,	"vforkmany-ops N", "stop after spawning N vfork children" },
 	{ NULL,	NULL,		   NULL }
 };
 
-PRAGMA_PUSH
-PRAGMA_WARN_OFF
+STRESS_PRAGMA_PUSH
+STRESS_PRAGMA_WARN_OFF
 static inline pid_t stress_shim_vfork(void)
 {
 #if defined(__NR_vfork)
@@ -43,7 +43,7 @@ static inline pid_t stress_shim_vfork(void)
 	return vfork();
 #endif
 }
-PRAGMA_POP
+STRESS_PRAGMA_POP
 
 /*
  *  stress_vforkmany()
@@ -54,7 +54,7 @@ PRAGMA_POP
  *	careful not to overrite shared variables across
  *	all the processes.
  */
-static int stress_vforkmany(const args_t *args)
+static int stress_vforkmany(const stress_args_t *args)
 {
 	static int status;
 	static pid_t chpid;
@@ -88,7 +88,7 @@ fork_again:
 			goto fork_again;
 		pr_err("%s: fork failed: errno=%d: (%s)\n",
 			args->name, errno, strerror(errno));
-		munmap((void *)terminate_mmap, args->page_size);
+		(void)munmap((void *)terminate_mmap, args->page_size);
 		return EXIT_FAILURE;
 	} else if (chpid == 0) {
 		static uint8_t *waste;
@@ -172,7 +172,7 @@ vfork_again:
 		} while (keep_stressing());
 
 		if (waste != MAP_FAILED)
-			munmap((void *)waste, WASTE_SIZE);
+			(void)munmap((void *)waste, WASTE_SIZE);
 		_exit(0);
 	} else {
 		/*
