@@ -45,7 +45,7 @@ typedef struct {
 
 static const stress_vm_addr_method_info_t vm_addr_methods[];
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"vm-addr N",	 "start N vm address exercising workers" },
 	{ NULL,	"vm-addr-ops N", "stop after N vm address bogo operations" },
 	{ NULL,	NULL,		 NULL }
@@ -55,7 +55,7 @@ static const help_t help[] = {
  *  keep_stressing()
  *	returns true if we can keep on running a stressor
  */
-static bool HOT OPTIMIZE3 keep_stressing_vm(const args_t *args)
+static bool HOT OPTIMIZE3 keep_stressing_vm(const stress_args_t *args)
 {
 	return (LIKELY(keep_stressing_flag()) &&
 	        LIKELY(!args->max_ops || (get_counter(args) < args->max_ops)));
@@ -84,7 +84,7 @@ static size_t TARGET_CLONES stress_vm_addr_pwr2(
 	const size_t sz)
 {
 	size_t n, errs = 0;
-	uint8_t rnd = mwc8();
+	uint8_t rnd = stress_mwc8();
 
 	for (n = 1; n < sz; n++) {
 		*(buf + n) = rnd;
@@ -105,7 +105,7 @@ static size_t TARGET_CLONES stress_vm_addr_pwr2inv(
 	const size_t sz)
 {
 	size_t mask = sz - 1, n, errs = 0;
-	uint8_t rnd = mwc8();
+	uint8_t rnd = stress_mwc8();
 
 	for (n = 1; n < sz; n++) {
 		*(buf + (n ^ mask)) = rnd;
@@ -127,7 +127,7 @@ static size_t TARGET_CLONES stress_vm_addr_gray(
 	const size_t sz)
 {
 	size_t mask = sz - 1, n, errs = 0;
-	uint8_t rnd = mwc8();
+	uint8_t rnd = stress_mwc8();
 
 	for (n = 0; n < sz; n++) {
 		size_t gray = ((n >> 1) ^ n) & mask;
@@ -151,7 +151,7 @@ static size_t TARGET_CLONES stress_vm_addr_grayinv(
 	const size_t sz)
 {
 	size_t mask = sz - 1, n, errs = 0;
-	uint8_t rnd = mwc8();
+	uint8_t rnd = stress_mwc8();
 
 	for (n = 0; n < sz; n++) {
 		size_t gray = (((n >> 1) ^ n) ^ mask) & mask;
@@ -177,7 +177,7 @@ static size_t TARGET_CLONES stress_vm_addr_rev(
 	const size_t sz)
 {
 	size_t mask = sz - 1, n, errs = 0, shift;
-	uint8_t rnd = mwc8();
+	uint8_t rnd = stress_mwc8();
 
 	for (shift = 0, n = sz; n; shift++, n <<= 1)
 		;
@@ -206,7 +206,7 @@ static size_t TARGET_CLONES stress_vm_addr_revinv(
 	const size_t sz)
 {
 	size_t mask = sz - 1, n, errs = 0, shift;
-	uint8_t rnd = mwc8();
+	uint8_t rnd = stress_mwc8();
 
 	for (shift = 0, n = sz; n; shift++, n <<= 1)
 		;
@@ -232,7 +232,7 @@ static size_t TARGET_CLONES stress_vm_addr_inc(
 	const size_t sz)
 {
 	size_t n, errs = 0;
-	uint8_t rnd = mwc8();
+	uint8_t rnd = stress_mwc8();
 
 	for (n = 0; n < sz; n++) {
 		*(buf + n) = rnd;
@@ -253,7 +253,7 @@ static size_t TARGET_CLONES stress_vm_addr_incinv(
 	const size_t sz)
 {
 	size_t mask = sz - 1, n, errs = 0;
-	uint8_t rnd = mwc8();
+	uint8_t rnd = stress_mwc8();
 
 	for (n = 0; n < sz; n++) {
 		size_t i = (n ^ mask) & mask;
@@ -276,7 +276,7 @@ static size_t TARGET_CLONES stress_vm_addr_dec(
 	const size_t sz)
 {
 	size_t n, errs = 0;
-	uint8_t rnd = mwc8();
+	uint8_t rnd = stress_mwc8();
 
 	for (n = sz; n; n--) {
 		*(buf + n - 1) = rnd;
@@ -298,7 +298,7 @@ static size_t TARGET_CLONES stress_vm_addr_decinv(
 	const size_t sz)
 {
 	size_t mask = sz - 1, n, errs = 0;
-	uint8_t rnd = mwc8();
+	uint8_t rnd = stress_mwc8();
 
 	for (n = sz; n; n--) {
 		size_t i = ((n - 1) ^ mask) & mask;
@@ -356,7 +356,7 @@ static int stress_set_vm_addr_method(const char *name)
 
 	for (info = vm_addr_methods; info->func; info++) {
 		if (!strcmp(info->name, name)) {
-			set_setting("vm-addr-method", TYPE_ID_UINTPTR_T, &info);
+			stress_set_setting("vm-addr-method", TYPE_ID_UINTPTR_T, &info);
 			return 0;
 		}
 	}
@@ -370,7 +370,7 @@ static int stress_set_vm_addr_method(const char *name)
 	return -1;
 }
 
-static int stress_vm_addr_child(const args_t *args, void *ctxt)
+static int stress_vm_addr_child(const stress_args_t *args, void *ctxt)
 {
 	int no_mem_retries = 0;
 	void *vm_base_addr;
@@ -417,7 +417,7 @@ next:
  *  stress_vm_addr()
  *	stress virtual memory addressing
  */
-static int stress_vm_addr(const args_t *args)
+static int stress_vm_addr(const stress_args_t *args)
 {
         const size_t page_size = args->page_size;
 	size_t retries;
@@ -427,7 +427,7 @@ static int stress_vm_addr(const args_t *args)
 	context.vm_addr_method = &vm_addr_methods[0];
 	context.bit_error_count = MAP_FAILED;
 
-	(void)get_setting("vm-addr-method", &context.vm_addr_method);
+	(void)stress_get_setting("vm-addr-method", &context.vm_addr_method);
 
 	pr_dbg("%s using method '%s'\n", args->name, context.vm_addr_method->name);
 
@@ -466,7 +466,7 @@ static int stress_vm_addr(const args_t *args)
 	return ret;
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_vm_addr_method,	stress_set_vm_addr_method },
 	{ 0,			NULL }
 };
