@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"vm-rw N",	 "start N vm read/write process_vm* copy workers" },
 	{ NULL,	"vm-rw-bytes N", "transfer N bytes of memory per bogo operation" },
 	{ NULL,	"vm-rw-ops N",	 "stop after N vm process_vm* copy bogo operations" },
@@ -39,7 +39,7 @@ static const help_t help[] = {
 #define STACK_SIZE	(64 * 1024)
 
 typedef struct {
-	const args_t *args;
+	const stress_args_t *args;
 	size_t sz;
 	pid_t pid;
 	int pipe_wr[2];
@@ -57,13 +57,13 @@ static int stress_set_vm_rw_bytes(const char *opt)
 {
 	size_t vm_rw_bytes;
 
-	vm_rw_bytes = (size_t)get_uint64_byte_memory(opt, 1);
-	check_range_bytes("vm-rw-bytes", vm_rw_bytes,
+	vm_rw_bytes = (size_t)stress_get_uint64_byte_memory(opt, 1);
+	stress_check_range_bytes("vm-rw-bytes", vm_rw_bytes,
 		MIN_VM_RW_BYTES, MAX_MEM_LIMIT);
-	return set_setting("vm-rw-bytes", TYPE_ID_SIZE_T, &vm_rw_bytes);
+	return stress_set_setting("vm-rw-bytes", TYPE_ID_SIZE_T, &vm_rw_bytes);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_vm_rw_bytes,	stress_set_vm_rw_bytes },
 	{ 0,			NULL }
 };
@@ -76,7 +76,7 @@ static const opt_set_func_t opt_set_funcs[] = {
 static int stress_vm_child(void *arg)
 {
 	const stress_context_t *ctxt = (stress_context_t *)arg;
-	const args_t *args = ctxt->args;
+	const stress_args_t *args = ctxt->args;
 
 	uint8_t *buf;
 	int ret = EXIT_SUCCESS;
@@ -167,7 +167,7 @@ static int stress_vm_parent(stress_context_t *ctxt)
 	uint8_t val = 0;
 	uint8_t *localbuf;
 	stress_addr_msg_t msg_rd, msg_wr;
-	const args_t *args = ctxt->args;
+	const stress_args_t *args = ctxt->args;
 
 	(void)setpgid(ctxt->pid, g_pgrp);
 
@@ -287,7 +287,7 @@ fail:
  *  stress_vm_rw
  *	stress vm_read_v/vm_write_v
  */
-static int stress_vm_rw(const args_t *args)
+static int stress_vm_rw(const stress_args_t *args)
 {
 	stress_context_t ctxt;
 	uint8_t stack[64*1024];
@@ -296,7 +296,7 @@ static int stress_vm_rw(const args_t *args)
 	uint8_t *stack_top = stack + stack_offset;
 	size_t vm_rw_bytes = DEFAULT_VM_RW_BYTES;
 
-	if (!get_setting("vm-rw-bytes", &vm_rw_bytes)) {
+	if (!stress_get_setting("vm-rw-bytes", &vm_rw_bytes)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			vm_rw_bytes = MAX_32;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -322,7 +322,7 @@ static int stress_vm_rw(const args_t *args)
 	}
 
 again:
-	ctxt.pid = clone(stress_vm_child, align_stack(stack_top),
+	ctxt.pid = clone(stress_vm_child, stress_align_stack(stack_top),
 		SIGCHLD | CLONE_VM, &ctxt);
 	if (ctxt.pid < 0) {
 		if (keep_stressing_flag() && (errno == EAGAIN))
