@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"vm-segv N",	 "start N workers that unmap their address space" },
 	{ NULL,	"vm-segv-ops N", "stop after N vm-segv unmap'd SEGV faults" },
 	{ NULL,	NULL,		 NULL }
@@ -37,9 +37,9 @@ static NOINLINE void vm_unmap_child(const size_t page_size)
 
 	len = len ^ (len >> 1);
 	while (len > page_size) {
-		munmap((void *)0, len - page_size);
+		(void)munmap((void *)0, len - page_size);
 		len >>= 1;
-		clflush(addr);
+		shim_clflush(addr);
 		shim_clear_cache(addr, (void *)(((uint8_t *)addr) + 64));
 	}
 }
@@ -48,8 +48,8 @@ static NOINLINE void vm_unmap_self(const size_t page_size)
 {
 	void *addr = stress_align_address((void *)vm_unmap_self, page_size);
 
-	munmap(addr, page_size);
-	clflush(addr);
+	(void)munmap(addr, page_size);
+	shim_clflush(addr);
 	shim_clear_cache(addr, (void *)(((uint8_t *)addr) + 64));
 }
 
@@ -59,7 +59,7 @@ static NOINLINE void vm_unmap_self(const size_t page_size)
  *	and generating a segv on return because child has
  *	no address space on return.
  */
-static int stress_vm_segv(const args_t *args)
+static int stress_vm_segv(const stress_args_t *args)
 {
 	stress_set_oom_adjustment(args->name, true);
 
