@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"vm-splice N",		"start N workers reading/writing using vmsplice" },
 	{ NULL,	"vm-splice-ops N",	"stop after N bogo splice operations" },
 	{ NULL,	"vm-splice-bytes N",	"number of bytes to transfer per vmsplice call" },
@@ -35,13 +35,13 @@ static int stress_set_vm_splice_bytes(const char *opt)
 {
 	size_t vm_splice_bytes;
 
-	vm_splice_bytes = (size_t)get_uint64_byte_memory(opt, 1);
-	check_range_bytes("vm-splice-bytes", vm_splice_bytes,
+	vm_splice_bytes = (size_t)stress_get_uint64_byte_memory(opt, 1);
+	stress_check_range_bytes("vm-splice-bytes", vm_splice_bytes,
 		MIN_VM_SPLICE_BYTES, MAX_MEM_LIMIT);
-	return set_setting("vm-splice-bytes", TYPE_ID_SIZE_T, &vm_splice_bytes);
+	return stress_set_setting("vm-splice-bytes", TYPE_ID_SIZE_T, &vm_splice_bytes);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_vm_splice_bytes,	stress_set_vm_splice_bytes },
 	{ 0,			NULL }
 };
@@ -53,14 +53,14 @@ static const opt_set_func_t opt_set_funcs[] = {
  *  stress_splice
  *	stress copying of /dev/zero to /dev/null
  */
-static int stress_vm_splice(const args_t *args)
+static int stress_vm_splice(const stress_args_t *args)
 {
 	int fd, fds[2];
 	uint8_t *buf;
 	const size_t page_size = args->page_size;
 	size_t sz, vm_splice_bytes = DEFAULT_VM_SPLICE_BYTES;
 
-	if (!get_setting("vm-splice-bytes", &vm_splice_bytes)) {
+	if (!stress_get_setting("vm-splice-bytes", &vm_splice_bytes)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			vm_splice_bytes = MAX_VM_SPLICE_BYTES;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
