@@ -38,7 +38,7 @@
  *  the VM stress test has diffent methods of vm stressor
  */
 typedef size_t (*stress_vm_func)(uint8_t *buf, const size_t sz,
-		const args_t *args, const uint64_t max_ops);
+		const stress_args_t *args, const uint64_t max_ops);
 
 typedef struct {
 	const char *name;
@@ -57,7 +57,7 @@ typedef struct {
 
 static const stress_vm_method_info_t vm_methods[];
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ "m N", "vm N",	 "start N workers spinning on anonymous mmap" },
 	{ NULL,	 "vm-bytes N",	 "allocate N bytes per vm worker (default 256MB)" },
 	{ NULL,	 "vm-hang N",	 "sleep N seconds before freeing memory" },
@@ -114,7 +114,7 @@ static const stress_vm_madvise_info_t vm_madvise_info[] = {
  *  keep_stressing()
  *	returns true if we can keep on running a stressor
  */
-static bool HOT OPTIMIZE3 keep_stressing_vm(const args_t *args)
+static bool HOT OPTIMIZE3 keep_stressing_vm(const stress_args_t *args)
 {
 	return (LIKELY(keep_stressing_flag()) &&
 	        LIKELY(!args->max_ops || ((get_counter(args) >> VM_BOGO_SHIFT) < args->max_ops)));
@@ -124,20 +124,20 @@ static int stress_set_vm_hang(const char *opt)
 {
 	uint64_t vm_hang;
 
-	vm_hang = get_uint64_time(opt);
-	check_range("vm-hang", vm_hang,
+	vm_hang = stress_get_uint64_time(opt);
+	stress_check_range("vm-hang", vm_hang,
 		MIN_VM_HANG, MAX_VM_HANG);
-	return set_setting("vm-hang", TYPE_ID_UINT64, &vm_hang);
+	return stress_set_setting("vm-hang", TYPE_ID_UINT64, &vm_hang);
 }
 
 static int stress_set_vm_bytes(const char *opt)
 {
 	size_t vm_bytes;
 
-	vm_bytes = (size_t)get_uint64_byte_memory(opt, 1);
-	check_range_bytes("vm-bytes", vm_bytes,
+	vm_bytes = (size_t)stress_get_uint64_byte_memory(opt, 1);
+	stress_check_range_bytes("vm-bytes", vm_bytes,
 		MIN_VM_BYTES, MAX_MEM_LIMIT);
-	return set_setting("vm-bytes", TYPE_ID_SIZE_T, &vm_bytes);
+	return stress_set_setting("vm-bytes", TYPE_ID_SIZE_T, &vm_bytes);
 }
 
 #if defined(MAP_LOCKED) || defined(MAP_POPULATE)
@@ -145,9 +145,9 @@ static int stress_set_vm_flags(const int flag)
 {
 	int vm_flags = 0;
 
-	(void)get_setting("vm-flags", &vm_flags);
+	(void)stress_get_setting("vm-flags", &vm_flags);
 	vm_flags |= flag;
-	return set_setting("vm-flags", TYPE_ID_INT, &vm_flags);
+	return stress_set_setting("vm-flags", TYPE_ID_INT, &vm_flags);
 }
 #endif
 
@@ -179,7 +179,7 @@ static int stress_set_vm_madvise(const char *opt)
 
 	for (info = vm_madvise_info; info->name; info++) {
 		if (!strcmp(opt, info->name)) {
-			set_setting("vm-madvise", TYPE_ID_INT, &info->advice);
+			stress_set_setting("vm-madvise", TYPE_ID_INT, &info->advice);
 			return 0;
 		}
 	}
@@ -196,7 +196,7 @@ static int stress_set_vm_keep(const char *opt)
 	bool vm_keep = true;
 
 	(void)opt;
-	return set_setting("vm-keep", TYPE_ID_BOOL, &vm_keep);
+	return stress_set_setting("vm-keep", TYPE_ID_BOOL, &vm_keep);
 }
 
 #define SET_AND_TEST(ptr, val, bit_errors)	\
@@ -324,7 +324,7 @@ static inline size_t stress_vm_count_bits(uint64_t v)
 static size_t TARGET_CLONES stress_vm_moving_inversion(
 	uint8_t *buf,
 	const size_t sz,
-	const args_t *args,
+	const stress_args_t *args,
 	const uint64_t max_ops)
 {
 	uint64_t w, z, *buf_end, c = get_counter(args);
@@ -333,18 +333,18 @@ static size_t TARGET_CLONES stress_vm_moving_inversion(
 
 	buf_end = (uint64_t *)(buf + sz);
 
-	mwc_reseed();
-	w = mwc64();
-	z = mwc64();
+	stress_mwc_reseed();
+	w = stress_mwc64();
+	z = stress_mwc64();
 
-	mwc_seed(w, z);
+	stress_mwc_seed(w, z);
 	for (ptr = (uint64_t *)buf; ptr < buf_end; ) {
-		*(ptr++) = mwc64();
+		*(ptr++) = stress_mwc64();
 	}
 
-	mwc_seed(w, z);
+	stress_mwc_seed(w, z);
 	for (bit_errors = 0, ptr = (uint64_t *)buf; ptr < buf_end; ) {
-		uint64_t val = mwc64();
+		uint64_t val = stress_mwc64();
 
 		if (UNLIKELY(*ptr != val))
 			bit_errors++;
@@ -360,9 +360,9 @@ static size_t TARGET_CLONES stress_vm_moving_inversion(
 
 	inject_random_bit_errors(buf, sz);
 
-	mwc_seed(w, z);
+	stress_mwc_seed(w, z);
 	for (bit_errors = 0, ptr = (uint64_t *)buf; ptr < buf_end; ) {
-		uint64_t val = mwc64();
+		uint64_t val = stress_mwc64();
 		if (UNLIKELY(*(ptr++) != ~val))
 			bit_errors++;
 		c++;
@@ -372,9 +372,9 @@ static size_t TARGET_CLONES stress_vm_moving_inversion(
 			goto abort;
 	}
 
-	mwc_seed(w, z);
+	stress_mwc_seed(w, z);
 	for (ptr = (uint64_t *)buf_end; ptr > (uint64_t *)buf; ) {
-		*--ptr = mwc64();
+		*--ptr = stress_mwc64();
 		c++;
 		if (UNLIKELY(max_ops && c >= max_ops))
 			goto abort;
@@ -383,9 +383,9 @@ static size_t TARGET_CLONES stress_vm_moving_inversion(
 	inject_random_bit_errors(buf, sz);
 
 	(void)stress_mincore_touch_pages(buf, sz);
-	mwc_seed(w, z);
+	stress_mwc_seed(w, z);
 	for (ptr = (uint64_t *)buf_end; ptr > (uint64_t *)buf; ) {
-		uint64_t val = mwc64();
+		uint64_t val = stress_mwc64();
 		if (UNLIKELY(*--ptr != val))
 			bit_errors++;
 		*ptr = ~val;
@@ -395,9 +395,9 @@ static size_t TARGET_CLONES stress_vm_moving_inversion(
 		if (UNLIKELY(!keep_stressing_flag()))
 			goto abort;
 	}
-	mwc_seed(w, z);
+	stress_mwc_seed(w, z);
 	for (ptr = (uint64_t *)buf_end; ptr > (uint64_t *)buf; ) {
-		uint64_t val = mwc64();
+		uint64_t val = stress_mwc64();
 		if (UNLIKELY(*--ptr != ~val))
 			bit_errors++;
 		if (UNLIKELY(!keep_stressing_flag()))
@@ -420,7 +420,7 @@ abort:
 static size_t TARGET_CLONES stress_vm_modulo_x(
 	uint8_t *buf,
 	const size_t sz,
-	const args_t *args,
+	const stress_args_t *args,
 	const uint64_t max_ops)
 {
 	uint32_t i, j;
@@ -431,8 +431,8 @@ static size_t TARGET_CLONES stress_vm_modulo_x(
 	size_t bit_errors = 0;
 	uint64_t c = get_counter(args);
 
-	mwc_reseed();
-	pattern = mwc8();
+	stress_mwc_reseed();
+	pattern = stress_mwc8();
 	compliment = ~pattern;
 
 	for (i = 0; i < stride; i++) {
@@ -485,7 +485,7 @@ abort:
 static size_t TARGET_CLONES stress_vm_walking_one_data(
 	uint8_t *buf,
 	const size_t sz,
-	const args_t *args,
+	const stress_args_t *args,
 	const uint64_t max_ops)
 {
 	size_t bit_errors = 0;
@@ -522,7 +522,7 @@ static size_t TARGET_CLONES stress_vm_walking_one_data(
 static size_t TARGET_CLONES stress_vm_walking_zero_data(
 	uint8_t *buf,
 	const size_t sz,
-	const args_t *args,
+	const stress_args_t *args,
 	const uint64_t max_ops)
 {
 	size_t bit_errors = 0;
@@ -560,7 +560,7 @@ static size_t TARGET_CLONES stress_vm_walking_zero_data(
 static size_t TARGET_CLONES stress_vm_walking_one_addr(
 	uint8_t *buf,
 	const size_t sz,
-	const args_t *args,
+	const stress_args_t *args,
 	const uint64_t max_ops)
 {
 	volatile uint8_t *ptr;
@@ -608,7 +608,7 @@ static size_t TARGET_CLONES stress_vm_walking_one_addr(
 static size_t TARGET_CLONES stress_vm_walking_zero_addr(
 	uint8_t *buf,
 	const size_t sz,
-	const args_t *args,
+	const stress_args_t *args,
 	const uint64_t max_ops)
 {
 	volatile uint8_t *ptr;
@@ -662,7 +662,7 @@ static size_t TARGET_CLONES stress_vm_walking_zero_addr(
 static size_t TARGET_CLONES stress_vm_gray(
 	uint8_t *buf,
 	const size_t sz,
-	const args_t *args,
+	const stress_args_t *args,
 	const uint64_t max_ops)
 {
 	static uint8_t val;
@@ -710,7 +710,7 @@ static size_t TARGET_CLONES stress_vm_gray(
 static size_t TARGET_CLONES stress_vm_incdec(
 	uint8_t *buf,
 	const size_t sz,
-	const args_t *args,
+	const stress_args_t *args,
 	const uint64_t max_ops)
 {
 	static uint8_t val = 0;
@@ -757,7 +757,7 @@ static size_t TARGET_CLONES stress_vm_incdec(
 static size_t TARGET_CLONES stress_vm_prime_incdec(
 	uint8_t *buf,
 	const size_t sz,
-	const args_t *args,
+	const stress_args_t *args,
 	const uint64_t max_ops)
 {
 	static uint8_t val = 0;
@@ -814,7 +814,7 @@ static size_t TARGET_CLONES stress_vm_prime_incdec(
 static size_t TARGET_CLONES stress_vm_swap(
 	uint8_t *buf,
 	const size_t sz,
-	const args_t *args,
+	const stress_args_t *args,
 	const uint64_t max_ops)
 {
 	const size_t chunk_sz = 64, chunks = sz / chunk_sz;
@@ -824,9 +824,9 @@ static size_t TARGET_CLONES stress_vm_swap(
 	size_t bit_errors = 0, i;
 	size_t *swaps;
 
-	mwc_reseed();
-	z1 = mwc64();
-	w1 = mwc64();
+	stress_mwc_reseed();
+	z1 = stress_mwc64();
+	w1 = stress_mwc64();
 
 	if ((swaps = calloc(chunks, sizeof(*swaps))) == NULL) {
 		pr_fail("%s: calloc failed on vm_swap\n", args->name);
@@ -834,12 +834,12 @@ static size_t TARGET_CLONES stress_vm_swap(
 	}
 
 	for (i = 0; i < chunks; i++) {
-		swaps[i] = (mwc64() % chunks) * chunk_sz;
+		swaps[i] = (stress_mwc64() % chunks) * chunk_sz;
 	}
 
-	mwc_seed(w1, z1);
+	stress_mwc_seed(w1, z1);
 	for (ptr = buf; ptr < buf_end; ptr += chunk_sz) {
-		uint8_t val = mwc8();
+		uint8_t val = stress_mwc8();
 		(void)memset((void *)ptr, val, chunk_sz);
 	}
 
@@ -885,11 +885,11 @@ static size_t TARGET_CLONES stress_vm_swap(
 	(void)stress_mincore_touch_pages(buf, sz);
 	inject_random_bit_errors(buf, sz);
 
-	mwc_seed(w1, z1);
+	stress_mwc_seed(w1, z1);
 	for (ptr = buf; ptr < buf_end; ptr += chunk_sz) {
 		volatile uint8_t *p = (volatile uint8_t *)ptr;
 		volatile uint8_t *p_end = (volatile uint8_t *)ptr + chunk_sz;
-		uint8_t val = mwc8();
+		uint8_t val = stress_mwc8();
 
 		while (p < p_end) {
 			if (UNLIKELY(*p != val))
@@ -915,7 +915,7 @@ abort:
 static size_t TARGET_CLONES stress_vm_rand_set(
 	uint8_t *buf,
 	const size_t sz,
-	const args_t *args,
+	const stress_args_t *args,
 	const uint64_t max_ops)
 {
 	volatile uint8_t *ptr;
@@ -924,13 +924,13 @@ static size_t TARGET_CLONES stress_vm_rand_set(
 	uint64_t w, z, c = get_counter(args);
 	size_t bit_errors = 0;
 
-	mwc_reseed();
-	w = mwc64();
-	z = mwc64();
+	stress_mwc_reseed();
+	w = stress_mwc64();
+	z = stress_mwc64();
 
-	mwc_seed(w, z);
+	stress_mwc_seed(w, z);
 	for (ptr = buf; ptr < buf_end; ptr += chunk_sz) {
-		uint8_t val = mwc8();
+		uint8_t val = stress_mwc8();
 
 		*(ptr + 0) = val;
 		*(ptr + 1) = val;
@@ -950,9 +950,9 @@ static size_t TARGET_CLONES stress_vm_rand_set(
 	(void)stress_mincore_touch_pages(buf, sz);
 	inject_random_bit_errors(buf, sz);
 
-	mwc_seed(w, z);
+	stress_mwc_seed(w, z);
 	for (ptr = buf; ptr < buf_end; ptr += chunk_sz) {
-		uint8_t val = mwc8();
+		uint8_t val = stress_mwc8();
 
 		bit_errors += (*(ptr + 0) != val);
 		bit_errors += (*(ptr + 1) != val);
@@ -982,7 +982,7 @@ abort:
 static size_t TARGET_CLONES stress_vm_ror(
 	uint8_t *buf,
 	const size_t sz,
-	const args_t *args,
+	const stress_args_t *args,
 	const uint64_t max_ops)
 {
 	volatile uint8_t *ptr;
@@ -991,13 +991,13 @@ static size_t TARGET_CLONES stress_vm_ror(
 	size_t bit_errors = 0;
 	const size_t chunk_sz = sizeof(*ptr) * 8;
 
-	mwc_reseed();
-	w = mwc64();
-	z = mwc64();
+	stress_mwc_reseed();
+	w = stress_mwc64();
+	z = stress_mwc64();
 
-	mwc_seed(w, z);
+	stress_mwc_seed(w, z);
 	for (ptr = buf; ptr < buf_end; ptr += chunk_sz) {
-		uint8_t val = mwc8();
+		uint8_t val = stress_mwc8();
 
 		*(ptr + 0) = val;
 		*(ptr + 1) = val;
@@ -1034,9 +1034,9 @@ static size_t TARGET_CLONES stress_vm_ror(
 
 	inject_random_bit_errors(buf, sz);
 
-	mwc_seed(w, z);
+	stress_mwc_seed(w, z);
 	for (ptr = buf; ptr < buf_end; ptr += chunk_sz) {
-		uint8_t val = mwc8();
+		uint8_t val = stress_mwc8();
 		ROR64(val);
 
 		bit_errors += (*(ptr + 0) != val);
@@ -1067,7 +1067,7 @@ abort:
 static size_t TARGET_CLONES stress_vm_flip(
 	uint8_t *buf,
 	const size_t sz,
-	const args_t *args,
+	const stress_args_t *args,
 	const uint64_t max_ops)
 {
 	volatile uint8_t *ptr;
@@ -1076,13 +1076,13 @@ static size_t TARGET_CLONES stress_vm_flip(
 	size_t bit_errors = 0, i;
 	const size_t chunk_sz = sizeof(*ptr) * 8;
 
-	mwc_reseed();
-	w = mwc64();
-	z = mwc64();
+	stress_mwc_reseed();
+	w = stress_mwc64();
+	z = stress_mwc64();
 
-	mwc_seed(w, z);
+	stress_mwc_seed(w, z);
 	for (ptr = buf; ptr < buf_end; ptr += chunk_sz) {
-		uint8_t val = mwc8();
+		uint8_t val = stress_mwc8();
 
 		*(ptr + 0) = val;
 		ROR8(val);
@@ -1129,9 +1129,9 @@ static size_t TARGET_CLONES stress_vm_flip(
 
 	inject_random_bit_errors(buf, sz);
 
-	mwc_seed(w, z);
+	stress_mwc_seed(w, z);
 	for (ptr = buf; ptr < buf_end; ptr += chunk_sz) {
-		uint8_t val = mwc8();
+		uint8_t val = stress_mwc8();
 
 		bit_errors += (*(ptr + 0) != val);
 		ROR8(val);
@@ -1167,7 +1167,7 @@ abort:
 static size_t TARGET_CLONES stress_vm_zero_one(
 	uint8_t *buf,
 	const size_t sz,
-	const args_t *args,
+	const stress_args_t *args,
 	const uint64_t max_ops)
 {
 	volatile uint64_t *ptr;
@@ -1230,7 +1230,7 @@ abort:
 static size_t TARGET_CLONES stress_vm_galpat_zero(
 	uint8_t *buf,
 	const size_t sz,
-	const args_t *args,
+	const stress_args_t *args,
 	const uint64_t max_ops)
 {
 	volatile uint64_t *ptr;
@@ -1241,12 +1241,12 @@ static size_t TARGET_CLONES stress_vm_galpat_zero(
 
 	(void)memset(buf, 0x00, sz);
 
-	mwc_reseed();
+	stress_mwc_reseed();
 
 	for (i = 0; i < bits_bad; i++) {
 		for (;;) {
-			size_t offset = mwc64() % sz;
-			uint8_t bit = mwc32() & 3;
+			size_t offset = stress_mwc64() % sz;
+			uint8_t bit = stress_mwc32() & 3;
 
 			if (!buf[offset]) {
 				buf[offset] |= (1 << bit);
@@ -1292,7 +1292,7 @@ static size_t TARGET_CLONES stress_vm_galpat_zero(
 static size_t TARGET_CLONES stress_vm_galpat_one(
 	uint8_t *buf,
 	const size_t sz,
-	const args_t *args,
+	const stress_args_t *args,
 	const uint64_t max_ops)
 {
 	volatile uint64_t *ptr;
@@ -1303,12 +1303,12 @@ static size_t TARGET_CLONES stress_vm_galpat_one(
 
 	(void)memset(buf, 0xff, sz);
 
-	mwc_reseed();
+	stress_mwc_reseed();
 
 	for (i = 0; i < bits_bad; i++) {
 		for (;;) {
-			size_t offset = mwc64() % sz;
-			uint8_t bit = mwc32() & 3;
+			size_t offset = stress_mwc64() % sz;
+			uint8_t bit = stress_mwc32() & 3;
 
 			if (buf[offset] == 0xff) {
 				buf[offset] &= ~(1 << bit);
@@ -1352,7 +1352,7 @@ static size_t TARGET_CLONES stress_vm_galpat_one(
 static size_t TARGET_CLONES stress_vm_inc_nybble(
 	uint8_t *buf,
 	const size_t sz,
-	const args_t *args,
+	const stress_args_t *args,
 	const uint64_t max_ops)
 {
 	static uint8_t val = 0;
@@ -1365,7 +1365,7 @@ static size_t TARGET_CLONES stress_vm_inc_nybble(
 	INC_LO_NYBBLE(val);
 	INC_HI_NYBBLE(val);
 
-	mwc_reseed();
+	stress_mwc_reseed();
 	for (ptr = buf; ptr < buf_end; ptr += 8) {
 		INC_LO_NYBBLE(*(ptr + 0));
 		INC_LO_NYBBLE(*(ptr + 1));
@@ -1428,7 +1428,7 @@ abort:
 static size_t TARGET_CLONES stress_vm_rand_sum(
 	uint8_t *buf,
 	const size_t sz,
-	const args_t *args,
+	const stress_args_t *args,
 	const uint64_t max_ops)
 {
 	volatile uint64_t *ptr;
@@ -1437,20 +1437,20 @@ static size_t TARGET_CLONES stress_vm_rand_sum(
 	size_t bit_errors = 0;
 	const size_t chunk_sz = sizeof(*ptr) * 8;
 
-	mwc_reseed();
-	w = mwc64();
-	z = mwc64();
+	stress_mwc_reseed();
+	w = stress_mwc64();
+	z = stress_mwc64();
 
-	mwc_seed(w, z);
+	stress_mwc_seed(w, z);
 	for (ptr = (uint64_t *)buf; ptr < buf_end; ptr += chunk_sz) {
-		*(ptr + 0) = mwc64();
-		*(ptr + 1) = mwc64();
-		*(ptr + 2) = mwc64();
-		*(ptr + 3) = mwc64();
-		*(ptr + 4) = mwc64();
-		*(ptr + 5) = mwc64();
-		*(ptr + 6) = mwc64();
-		*(ptr + 7) = mwc64();
+		*(ptr + 0) = stress_mwc64();
+		*(ptr + 1) = stress_mwc64();
+		*(ptr + 2) = stress_mwc64();
+		*(ptr + 3) = stress_mwc64();
+		*(ptr + 4) = stress_mwc64();
+		*(ptr + 5) = stress_mwc64();
+		*(ptr + 6) = stress_mwc64();
+		*(ptr + 7) = stress_mwc64();
 		c++;
 		if (UNLIKELY(max_ops && c >= max_ops))
 			goto abort;
@@ -1461,16 +1461,16 @@ static size_t TARGET_CLONES stress_vm_rand_sum(
 	(void)stress_mincore_touch_pages(buf, sz);
 	inject_random_bit_errors(buf, sz);
 
-	mwc_seed(w, z);
+	stress_mwc_seed(w, z);
 	for (ptr = (uint64_t *)buf; ptr < buf_end; ptr += chunk_sz) {
-		bit_errors += stress_vm_count_bits(*(ptr + 0) ^ mwc64());
-		bit_errors += stress_vm_count_bits(*(ptr + 1) ^ mwc64());
-		bit_errors += stress_vm_count_bits(*(ptr + 2) ^ mwc64());
-		bit_errors += stress_vm_count_bits(*(ptr + 3) ^ mwc64());
-		bit_errors += stress_vm_count_bits(*(ptr + 4) ^ mwc64());
-		bit_errors += stress_vm_count_bits(*(ptr + 5) ^ mwc64());
-		bit_errors += stress_vm_count_bits(*(ptr + 6) ^ mwc64());
-		bit_errors += stress_vm_count_bits(*(ptr + 7) ^ mwc64());
+		bit_errors += stress_vm_count_bits(*(ptr + 0) ^ stress_mwc64());
+		bit_errors += stress_vm_count_bits(*(ptr + 1) ^ stress_mwc64());
+		bit_errors += stress_vm_count_bits(*(ptr + 2) ^ stress_mwc64());
+		bit_errors += stress_vm_count_bits(*(ptr + 3) ^ stress_mwc64());
+		bit_errors += stress_vm_count_bits(*(ptr + 4) ^ stress_mwc64());
+		bit_errors += stress_vm_count_bits(*(ptr + 5) ^ stress_mwc64());
+		bit_errors += stress_vm_count_bits(*(ptr + 6) ^ stress_mwc64());
+		bit_errors += stress_vm_count_bits(*(ptr + 7) ^ stress_mwc64());
 		if (UNLIKELY(!keep_stressing_flag()))
 			break;
 	}
@@ -1490,7 +1490,7 @@ abort:
 static size_t TARGET_CLONES stress_vm_prime_zero(
 	uint8_t *buf,
 	const size_t sz,
-	const args_t *args,
+	const stress_args_t *args,
 	const uint64_t max_ops)
 {
 	size_t i;
@@ -1547,7 +1547,7 @@ abort:
 static size_t TARGET_CLONES stress_vm_prime_one(
 	uint8_t *buf,
 	const size_t sz,
-	const args_t *args,
+	const stress_args_t *args,
 	const uint64_t max_ops)
 {
 	size_t i;
@@ -1605,7 +1605,7 @@ abort:
 static size_t TARGET_CLONES stress_vm_prime_gray_zero(
 	uint8_t *buf,
 	const size_t sz,
-	const args_t *args,
+	const stress_args_t *args,
 	const uint64_t max_ops)
 {
 	size_t i;
@@ -1672,7 +1672,7 @@ abort:
 static size_t TARGET_CLONES stress_vm_prime_gray_one(
 	uint8_t *buf,
 	const size_t sz,
-	const args_t *args,
+	const stress_args_t *args,
 	const uint64_t max_ops)
 {
 	size_t i;
@@ -1738,7 +1738,7 @@ abort:
 static size_t TARGET_CLONES stress_vm_write64(
 	uint8_t *buf,
 	const size_t sz,
-	const args_t *args,
+	const stress_args_t *args,
 	const uint64_t max_ops)
 {
 	static uint64_t val;
@@ -1799,7 +1799,7 @@ static size_t TARGET_CLONES stress_vm_write64(
 static size_t TARGET_CLONES stress_vm_read64(
 	uint8_t *buf,
 	const size_t sz,
-	const args_t *args,
+	const stress_args_t *args,
 	const uint64_t max_ops)
 {
 	volatile uint64_t *ptr = (uint64_t *)buf;
@@ -1858,7 +1858,7 @@ static size_t TARGET_CLONES stress_vm_read64(
 static size_t TARGET_CLONES stress_vm_rowhammer(
 	uint8_t *buf,
 	const size_t sz,
-	const args_t *args,
+	const stress_args_t *args,
 	const uint64_t max_ops)
 {
 	size_t bit_errors = 0;
@@ -1883,27 +1883,27 @@ static size_t TARGET_CLONES stress_vm_rowhammer(
 		buf32[j] = val;
 
 	/* Pick two random addresses */
-	addr0 = &buf32[(mwc64() << 12) % n];
-	addr1 = &buf32[(mwc64() << 12) % n];
+	addr0 = &buf32[(stress_mwc64() << 12) % n];
+	addr1 = &buf32[(stress_mwc64() << 12) % n];
 
 	/* Hammer the rows */
 	for (j = VM_ROWHAMMER_LOOPS / 4; j; j--) {
 		*addr0;
 		*addr1;
-		clflush(addr0);
-		clflush(addr1);
+		shim_clflush(addr0);
+		shim_clflush(addr1);
 		*addr0;
 		*addr1;
-		clflush(addr0);
-		clflush(addr1);
+		shim_clflush(addr0);
+		shim_clflush(addr1);
 		*addr0;
 		*addr1;
-		clflush(addr0);
-		clflush(addr1);
+		shim_clflush(addr0);
+		shim_clflush(addr1);
 		*addr0;
 		*addr1;
-		clflush(addr0);
-		clflush(addr1);
+		shim_clflush(addr0);
+		shim_clflush(addr1);
 	}
 	for (j = 0; j < n; j++)
 		if (UNLIKELY(buf32[j] != val))
@@ -1928,7 +1928,7 @@ static size_t TARGET_CLONES stress_vm_rowhammer(
 static size_t stress_vm_all(
 	uint8_t *buf,
 	const size_t sz,
-	const args_t *args,
+	const stress_args_t *args,
 	const uint64_t max_ops)
 {
 	static int i = 1;
@@ -1982,7 +1982,7 @@ static int stress_set_vm_method(const char *name)
 
 	for (info = vm_methods; info->func; info++) {
 		if (!strcmp(info->name, name)) {
-			set_setting("vm-method", TYPE_ID_UINTPTR_T, &info);
+			stress_set_setting("vm-method", TYPE_ID_UINTPTR_T, &info);
 			return 0;
 		}
 	}
@@ -1996,7 +1996,7 @@ static int stress_set_vm_method(const char *name)
 	return -1;
 }
 
-static int stress_vm_child(const args_t *args, void *ctxt)
+static int stress_vm_child(const stress_args_t *args, void *ctxt)
 {
 	int no_mem_retries = 0;
 	const uint64_t max_ops = args->max_ops << VM_BOGO_SHIFT;
@@ -2011,11 +2011,11 @@ static int stress_vm_child(const args_t *args, void *ctxt)
 	stress_vm_context_t *context = (stress_vm_context_t *)ctxt;
 	const stress_vm_func func = context->vm_method->func;
 
-	(void)get_setting("vm-hang", &vm_hang);
-	(void)get_setting("vm-keep", &vm_keep);
-	(void)get_setting("vm-flags", &vm_flags);
+	(void)stress_get_setting("vm-hang", &vm_hang);
+	(void)stress_get_setting("vm-keep", &vm_keep);
+	(void)stress_get_setting("vm-flags", &vm_flags);
 
-	if (!get_setting("vm-bytes", &vm_bytes)) {
+	if (!stress_get_setting("vm-bytes", &vm_bytes)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			vm_bytes = MAX_32;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -2025,7 +2025,7 @@ static int stress_vm_child(const args_t *args, void *ctxt)
 	if (vm_bytes < MIN_VM_BYTES)
 		vm_bytes = MIN_VM_BYTES;
 	buf_sz = vm_bytes & ~(page_size - 1);
-	(void)get_setting("vm-madvise", &vm_madvise);
+	(void)stress_get_setting("vm-madvise", &vm_madvise);
 
 	do {
 		if (no_mem_retries >= NO_MEM_RETRIES_MAX) {
@@ -2080,7 +2080,7 @@ static int stress_vm_child(const args_t *args, void *ctxt)
  *  stress_vm()
  *	stress virtual memory
  */
-static int stress_vm(const args_t *args)
+static int stress_vm(const stress_args_t *args)
 {
 	uint64_t tmp_counter;
         const size_t page_size = args->page_size;
@@ -2091,7 +2091,7 @@ static int stress_vm(const args_t *args)
 	context.vm_method = &vm_methods[0];
 	context.bit_error_count = MAP_FAILED;
 
-	(void)get_setting("vm-method", &context.vm_method);
+	(void)stress_get_setting("vm-method", &context.vm_method);
 
 	pr_dbg("%s using method '%s'\n", args->name, context.vm_method->name);
 
@@ -2139,7 +2139,7 @@ static void stress_vm_set_default(void)
 	stress_set_vm_method("all");
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_vm_bytes,		stress_set_vm_bytes },
 	{ OPT_vm_hang,		stress_set_vm_hang },
 	{ OPT_vm_keep,		stress_set_vm_keep },
