@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"watchdog N",	  "start N workers that exercise /dev/watchdog" },
 	{ NULL,	"watchdog-ops N", "stop after N bogo watchdog operations" },
 	{ NULL,	NULL,		  NULL }
@@ -101,7 +101,7 @@ static void MLOCKED_TEXT stress_watchdog_handler(int signum)
  *  stress_watchdog()
  *	stress /dev/watchdog
  */
-static int stress_watchdog(const args_t *args)
+static int stress_watchdog(const stress_args_t *args)
 {
 	int ret, rc = EXIT_SUCCESS;
 	size_t i;
