@@ -28,7 +28,7 @@
 #define STR1LEN 256
 #define STR2LEN 128
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"wcs N",	   "start N workers on lib C wide char string functions" },
 	{ NULL,	"wcs-method func", "specify the wide character string function to stress" },
 	{ NULL,	"wcs-ops N",	   "stop after N bogo wide character string operations" },
@@ -63,7 +63,7 @@ static void stress_wcs_fill(wchar_t *wcstr, const size_t len)
 	register size_t i;
 
 	for (i = 0; i < (len-1); i++) {
-		*wcstr++ = (mwc8() % 26) + L'a';
+		*wcstr++ = (stress_mwc8() % 26) + L'a';
 	}
 	*wcstr = L'\0';
 }
@@ -633,7 +633,7 @@ static int stress_set_wcs_method(const char *name)
 
 	for (info = wcs_methods; info->func; info++) {
 		if (!strcmp(info->name, name)) {
-			set_setting("wcs-method", TYPE_ID_UINTPTR_T, &info);
+			stress_set_setting("wcs-method", TYPE_ID_UINTPTR_T, &info);
 			return 0;
 		}
 	}
@@ -651,7 +651,7 @@ static int stress_set_wcs_method(const char *name)
  *  stress_wcs()
  *	stress CPU by doing wide character string ops
  */
-static int stress_wcs(const args_t *args)
+static int stress_wcs(const stress_args_t *args)
 {
 	stress_wcs_method_info_t const *wcs_method = &wcs_methods[0];
 	stress_wcs_func func;
@@ -665,7 +665,7 @@ static int stress_wcs(const args_t *args)
 	if (SIZEOF_ARRAY(wcs_methods) <= 2)
 		return stress_not_implemented(args);
 
-	(void)get_setting("wcs-method", &wcs_method);
+	(void)stress_get_setting("wcs-method", &wcs_method);
 	func = wcs_method->func;
 	libc_func = wcs_method->libc_func;
 
@@ -702,7 +702,7 @@ static void stress_wcs_set_default(void)
 	stress_set_wcs_method("all");
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_wcs_method,	stress_set_wcs_method },
 	{ 0,			NULL }
 };
