@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"x86syscall N",		"start N workers exercising functions using syscall" },
 	{ NULL,	"x86syscall-ops N",	"stop after N syscall function calls" },
 	{ NULL,	"x86syscall-func F",	"use just syscall function F" },
@@ -37,10 +37,10 @@ static const help_t help[] = {
  */
 static int stress_set_x86syscall_func(const char *name)
 {
-	return set_setting("x86syscall-func", TYPE_ID_STR, name);
+	return stress_set_setting("x86syscall-func", TYPE_ID_STR, name);
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_x86syscall_func,	stress_set_x86syscall_func },
 	{ 0,			NULL }
 };
@@ -260,7 +260,7 @@ static int x86syscall_check_x86syscall_func(void)
 	size_t i;
 	bool exercise = false;
 
-	if (!get_setting("x86syscall-func", &name))
+	if (!stress_get_setting("x86syscall-func", &name))
 		return 0;
 
 	for (i = 0; i < SIZEOF_ARRAY(x86syscalls); i++) {
@@ -284,7 +284,7 @@ static int x86syscall_check_x86syscall_func(void)
  *  stress_x86syscall()
  *	stress x86 syscall instruction
  */
-static int stress_x86syscall(const args_t *args)
+static int stress_x86syscall(const stress_args_t *args)
 {
 	char *str;
 	double t1, t2, t3, overhead_ns;
