@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"xattr N",	"start N workers stressing file extended attributes" },
 	{ NULL,	"xattr-ops N",	"stop after N bogo xattr operations" },
 	{ NULL,	NULL,		NULL }
@@ -38,9 +38,6 @@ static const help_t help[] = {
     defined(HAVE_FSETXATTR) &&		\
     defined(HAVE_GETXATTR) &&		\
     defined(HAVE_LISTXATTR) &&		\
-    defined(HAVE_LGETXATTR) &&		\
-    defined(HAVE_LLISTXATTR) &&		\
-    defined(HAVE_LSETXATTR) &&		\
     defined(HAVE_SETXATTR)
 
 #define MAX_XATTRS		(4096)
@@ -49,7 +46,7 @@ static const help_t help[] = {
  *  stress_xattr
  *	stress the xattr operations
  */
-static int stress_xattr(const args_t *args)
+static int stress_xattr(const stress_args_t *args)
 {
 	int ret, fd, rc = EXIT_FAILURE;
 	char filename[PATH_MAX];
@@ -58,7 +55,7 @@ static int stress_xattr(const args_t *args)
 	if (ret < 0)
 		return exit_status(-ret);
 
-	(void)stress_temp_filename_args(args, filename, sizeof(filename), mwc32());
+	(void)stress_temp_filename_args(args, filename, sizeof(filename), stress_mwc32());
 	if ((fd = open(filename, O_CREAT | O_RDWR, S_IRUSR | S_IWUSR)) < 0) {
 		rc = exit_status(errno);
 		pr_fail_err("open");
@@ -76,7 +73,7 @@ static int stress_xattr(const args_t *args)
 			(void)snprintf(attrname, sizeof(attrname), "user.var_%d", i);
 			(void)snprintf(value, sizeof(value), "orig-value-%d", i);
 
-			ret = fsetxattr(fd, attrname, value, strlen(value), XATTR_CREATE);
+			ret = shim_fsetxattr(fd, attrname, value, strlen(value), XATTR_CREATE);
 			if (ret < 0) {
 				if (errno == ENOTSUP) {
 					pr_inf("%s stressor will be "
@@ -93,7 +90,7 @@ static int stress_xattr(const args_t *args)
 			(void)snprintf(attrname, sizeof(attrname), "user.var_%d", j);
 			(void)snprintf(value, sizeof(value), "value-%d", j);
 
-			ret = fsetxattr(fd, attrname, value, strlen(value),
+			ret = shim_fsetxattr(fd, attrname, value, strlen(value),
 				XATTR_REPLACE);
 			if (ret < 0) {
 				if (errno == ENOSPC || errno == EDQUOT)
@@ -103,7 +100,7 @@ static int stress_xattr(const args_t *args)
 			}
 
 			/* ..and do it again using setxattr */
-			ret = setxattr(filename, attrname, value, strlen(value),
+			ret = shim_setxattr(filename, attrname, value, strlen(value),
 				XATTR_REPLACE);
 			if (ret < 0) {
 				if (errno == ENOSPC || errno == EDQUOT)
@@ -112,8 +109,9 @@ static int stress_xattr(const args_t *args)
 				goto out_close;
 			}
 
+#if defined(HAVE_LSETXATTR)
 			/* Although not a link, it's good to exercise this call */
-			ret = lsetxattr(filename, attrname, value, strlen(value),
+			ret = shim_lsetxattr(filename, attrname, value, strlen(value),
 				XATTR_REPLACE);
 			if (ret < 0) {
 				if (errno == ENOSPC || errno == EDQUOT)
@@ -121,6 +119,7 @@ static int stress_xattr(const args_t *args)
 				pr_fail_err("lsetxattr");
 				goto out_close;
 			}
+#endif
 		}
 		for (j = 0; j < i; j++) {
 			char tmp[sizeof(value)];
@@ -128,7 +127,8 @@ static int stress_xattr(const args_t *args)
 			(void)snprintf(attrname, sizeof(attrname), "user.var_%d", j);
 			(void)snprintf(value, sizeof(value), "value-%d", j);
 
-			ret = fgetxattr(fd, attrname, tmp, sizeof(tmp));
+			(void)memset(tmp, 0, sizeof(tmp));
+			ret = shim_fgetxattr(fd, attrname, tmp, sizeof(tmp));
 			if (ret < 0) {
 				pr_fail_err("fgetxattr");
 				goto out_close;
@@ -152,7 +152,8 @@ static int stress_xattr(const args_t *args)
 				goto out_close;
 			}
 
-			ret = lgetxattr(filename, attrname, tmp, sizeof(tmp));
+#if defined(HAVE_LGETXATTR)
+			ret = shim_lgetxattr(filename, attrname, tmp, sizeof(tmp));
 			if (ret < 0) {
 				pr_fail_err("getxattr");
 				goto out_close;
@@ -163,9 +164,10 @@ static int stress_xattr(const args_t *args)
 					args->name, ret, value, ret, tmp);
 				goto out_close;
 			}
+#endif
 		}
 		/* Determine how large a buffer we required... */
-		sz = flistxattr(fd, NULL, 0);
+		sz = shim_flistxattr(fd, NULL, 0);
 		if (sz < 0) {
 			pr_fail_err("flistxattr");
 			goto out_close;
@@ -173,7 +175,7 @@ static int stress_xattr(const args_t *args)
 		buffer = malloc(sz);
 		if (buffer) {
 			/* ...and fetch */
-			sz = listxattr(filename, buffer, sz);
+			sz = shim_listxattr(filename, buffer, sz);
 			free(buffer);
 
 			if (sz < 0) {
@@ -184,17 +186,19 @@ static int stress_xattr(const args_t *args)
 		for (j = 0; j < i; j++) {
 			(void)snprintf(attrname, sizeof(attrname), "user.var_%d", j);
 
-			ret = fremovexattr(fd, attrname);
+			ret = shim_fremovexattr(fd, attrname);
 			if (ret < 0) {
 				pr_fail_err("fremovexattr");
 				goto out_close;
 			}
 		}
-		sz = llistxattr(filename, NULL, 0);
+#if defined(HAVE_LLISTXATTR)
+		sz = shim_llistxattr(filename, NULL, 0);
 		if (sz < 0) {
 			pr_fail_err("flistxattr");
 			goto out_close;
 		}
+#endif
 		inc_counter(args);
 	} while (keep_stressing());
 
