@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ "y N", "yield N",	"start N workers doing sched_yield() calls" },
 	{ NULL,	 "yield-ops N",	"stop after N bogo yield operations" },
 	{ NULL,	 NULL,		NULL }
@@ -36,7 +36,7 @@ static const help_t help[] = {
  *  stress on sched_yield()
  *	stress system by sched_yield
  */
-static int stress_yield(const args_t *args)
+static int stress_yield(const stress_args_t *args)
 {
 	uint64_t *counters;
 	uint64_t max_ops_per_yielder;
