@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"zero N",	"start N workers reading /dev/zero" },
 	{ NULL,	"zero-ops N",	"stop after N /dev/zero bogo read operations" },
 	{ NULL,	NULL,		NULL }
@@ -34,7 +34,7 @@ static const help_t help[] = {
  *  stress_zero
  *	stress reading of /dev/zero
  */
-static int stress_zero(const args_t *args)
+static int stress_zero(const stress_args_t *args)
 {
 	int fd;
 	const size_t page_size = args->page_size;
@@ -85,7 +85,7 @@ static int stress_zero(const args_t *args)
 		 *  check if we can mmap /dev/zero
 		 */
 		ptr = mmap(NULL, page_size, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS,
-			fd, page_size * mwc16());
+			fd, page_size * stress_mwc16());
 		if (ptr == MAP_FAILED) {
 			if (errno == ENOMEM)
 				continue;
