@@ -24,7 +24,7 @@
  */
 #include "stress-ng.h"
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"zlib N",	 "start N workers compressing data with zlib" },
 	{ NULL,	"zlib-ops N",	 "stop after N zlib bogo compression operations" },
 	{ NULL,	"zlib-level L",	 "specify zlib compression level 0=fast, 9=best" },
@@ -44,7 +44,7 @@ static const help_t help[] = {
 
 #define DATA_SIZE DATA_SIZE_64K
 
-typedef void (*stress_zlib_rand_data_func)(const args_t *args, uint32_t *data, const int size);
+typedef void (*stress_zlib_rand_data_func)(const stress_args_t *args, uint32_t *data, const int size);
 
 typedef struct {
 	const char *name;			/* human readable form of random data generation selection */
@@ -58,6 +58,51 @@ typedef struct {
 	bool		interrupted;
 } stress_xsum_t;
 
+typedef struct morse {
+	char ch;
+	char *str;
+} morse_t;
+
+static const morse_t morse[] = {
+	{ 'a', ".-" },
+	{ 'b', "-.." },
+	{ 'c', "-.-." },
+	{ 'd', "-.." },
+	{ 'e', "." },
+	{ 'f', "..-." },
+	{ 'g', "--." },
+	{ 'h', "...." },
+	{ 'i', ".." },
+	{ 'j', ".---" },
+	{ 'k', "-.-" },
+	{ 'l', ".-.." },
+	{ 'm', "--" },
+	{ 'n', "-." },
+	{ 'o', "---" },
+	{ 'p', ".--." },
+	{ 'q', "--.-" },
+	{ 'r', ".-." },
+	{ 's', "..." },
+	{ 't', "-" },
+	{ 'u', "..-" },
+	{ 'v', "...-" },
+	{ 'w', ".--" },
+	{ 'x', "-..-" },
+	{ 'y', "-.--" },
+	{ 'z', "--.." },
+	{ '0', "-----" },
+	{ '1', ".----" },
+	{ '2', "..---" },
+	{ '3', "...--" },
+	{ '4', "....-" },
+	{ '5', "....." },
+	{ '6', "-...." },
+	{ '7', "--..." },
+	{ '8', "---.." },
+	{ '9', "----." },
+	{ ' ', " " }
+};
+
 static stress_zlib_rand_data_info_t zlib_rand_data_methods[];
 static volatile bool pipe_broken = false;
 static sigjmp_buf jmpbuf;
@@ -127,7 +172,7 @@ static void MLOCKED_TEXT stress_bad_read_handler(int signum)
  *  stress_rand_data_bcd()
  *	fill buffer with random binary coded decimal digits
  */
-static void stress_rand_data_bcd(const args_t *args, uint32_t *data, const int size)
+static void stress_rand_data_bcd(const stress_args_t *args, uint32_t *data, const int size)
 {
 	register uint8_t *ptr = (uint8_t *)data;
 	const uint8_t *end = ptr + size;
@@ -135,7 +180,7 @@ static void stress_rand_data_bcd(const args_t *args, uint32_t *data, const int s
 	(void)args;
 
 	while (ptr < end) {
-		uint8_t rndval = mwc8() % 100;
+		uint8_t rndval = stress_mwc8() % 100;
 
 		/* Not the most efficient but it works */
 		*ptr++ = (rndval % 10) | ((rndval / 10) << 4);
@@ -146,7 +191,7 @@ static void stress_rand_data_bcd(const args_t *args, uint32_t *data, const int s
  *  stress_rand_data_utf8()
  *	fill buffer with random bytes converted into utf8
  */
-static void stress_rand_data_utf8(const args_t *args, uint32_t *data, const int size)
+static void stress_rand_data_utf8(const stress_args_t *args, uint32_t *data, const int size)
 {
 	const int n = size / sizeof(uint16_t);
 	register uint8_t *ptr = (uint8_t *)data;
@@ -155,7 +200,7 @@ static void stress_rand_data_utf8(const args_t *args, uint32_t *data, const int
 	(void)args;
 
 	while (ptr < end) {
-		uint8_t ch = mwc8();
+		uint8_t ch = stress_mwc8();
 
 		if (ch <= 0x7f)
 			*ptr++ = ch;
@@ -175,7 +220,7 @@ static void stress_rand_data_utf8(const args_t *args, uint32_t *data, const int
  *  stress_rand_data_binary()
  *	fill buffer with random binary data
  */
-static void stress_rand_data_binary(const args_t *args, uint32_t *data, const int size)
+static void stress_rand_data_binary(const stress_args_t *args, uint32_t *data, const int size)
 {
 	const int n = size / sizeof(*data);
 	register int i;
@@ -183,14 +228,14 @@ static void stress_rand_data_binary(const args_t *args, uint32_t *data, const in
 	(void)args;
 
 	for (i = 0; i < n; i++, data++)
-		*data = mwc32();
+		*data = stress_mwc32();
 }
 
 /*
  *  stress_rand_data_text()
  *	fill buffer with random ASCII text
  */
-static void stress_rand_data_text(const args_t *args, uint32_t *data, const int size)
+static void stress_rand_data_text(const stress_args_t *args, uint32_t *data, const int size)
 {
 	(void)args;
 
@@ -201,7 +246,7 @@ static void stress_rand_data_text(const args_t *args, uint32_t *data, const int
  *  stress_rand_data_01()
  *	fill buffer with random ASCII 0 or 1
  */
-static void stress_rand_data_01(const args_t *args, uint32_t *data, const int size)
+static void stress_rand_data_01(const stress_args_t *args, uint32_t *data, const int size)
 {
 	unsigned char *ptr = (unsigned char *)data;
 	register int i;
@@ -209,7 +254,7 @@ static void stress_rand_data_01(const args_t *args, uint32_t *data, const int si
 	(void)args;
 
 	for (i = 0; i < size; i += 8, ptr += 8) {
-		uint8_t v = mwc8();
+		uint8_t v = stress_mwc8();
 
 		*(ptr + 0) = '0' + (v & 1);
 		v >>= 1;
@@ -233,7 +278,7 @@ static void stress_rand_data_01(const args_t *args, uint32_t *data, const int si
  *  stress_rand_data_digits()
  *	fill buffer with random ASCII '0' .. '9'
  */
-static void stress_rand_data_digits(const args_t *args, uint32_t *data, const int size)
+static void stress_rand_data_digits(const stress_args_t *args, uint32_t *data, const int size)
 {
 	unsigned char *ptr = (unsigned char *)data;
 	register int i;
@@ -241,14 +286,14 @@ static void stress_rand_data_digits(const args_t *args, uint32_t *data, const in
 	(void)args;
 
 	for (i = 0; i < size; i++, ptr++)
-		*ptr = '0' + (mwc32() % 10);
+		*ptr = '0' + (stress_mwc32() % 10);
 }
 
 /*
  *  stress_rand_data_00_ff()
  *	fill buffer with random 0x00 or 0xff
  */
-static void stress_rand_data_00_ff(const args_t *args, uint32_t *data, const int size)
+static void stress_rand_data_00_ff(const stress_args_t *args, uint32_t *data, const int size)
 {
 	unsigned char *ptr = (unsigned char *)data;
 	register int i;
@@ -256,7 +301,7 @@ static void stress_rand_data_00_ff(const args_t *args, uint32_t *data, const int
 	(void)args;
 
 	for (i = 0; i < size; i += 8, ptr += 8) {
-		uint8_t v = mwc8();
+		uint8_t v = stress_mwc8();
 
 		*(ptr + 0) = (v & 1) ? 0x00 : 0xff;
 		*(ptr + 1) = (v & 2) ? 0x00 : 0xff;
@@ -273,7 +318,7 @@ static void stress_rand_data_00_ff(const args_t *args, uint32_t *data, const int
  *  stress_rand_data_nybble()
  *	fill buffer with 0x00..0x0f
  */
-static void stress_rand_data_nybble(const args_t *args, uint32_t *data, const int size)
+static void stress_rand_data_nybble(const stress_args_t *args, uint32_t *data, const int size)
 {
 	unsigned char *ptr = (unsigned char *)data;
 	register int i;
@@ -281,7 +326,7 @@ static void stress_rand_data_nybble(const args_t *args, uint32_t *data, const in
 	(void)args;
 
 	for (i = 0; i < size; i += 8, ptr += 8) {
-		uint32_t v = mwc32();
+		uint32_t v = stress_mwc32();
 
 		*(ptr + 0) = v & 0xf;
 		v >>= 4;
@@ -305,7 +350,7 @@ static void stress_rand_data_nybble(const args_t *args, uint32_t *data, const in
  *  stress_rand_data_rarely_1()
  *	fill buffer with data that is 1 in every 32 bits 1
  */
-static void stress_rand_data_rarely_1(const args_t *args, uint32_t *data, const int size)
+static void stress_rand_data_rarely_1(const stress_args_t *args, uint32_t *data, const int size)
 {
 	const int n = size / sizeof(*data);
 	register int i;
@@ -313,14 +358,14 @@ static void stress_rand_data_rarely_1(const args_t *args, uint32_t *data, const
 	(void)args;
 
 	for (i = 0; i < n; i++, data++)
-		*data = 1 << (mwc32() & 0x1f);
+		*data = 1 << (stress_mwc32() & 0x1f);
 }
 
 /*
  *  stress_rand_data_rarely_0()
  *	fill buffer with data that is 1 in every 32 bits 0
  */
-static void stress_rand_data_rarely_0(const args_t *args, uint32_t *data, const int size)
+static void stress_rand_data_rarely_0(const stress_args_t *args, uint32_t *data, const int size)
 {
 	const int n = size / sizeof(*data);
 	register int i;
@@ -328,14 +373,14 @@ static void stress_rand_data_rarely_0(const args_t *args, uint32_t *data, const
 	(void)args;
 
 	for (i = 0; i < n; i++, data++)
-		*data = ~(1 << (mwc32() & 0x1f));
+		*data = ~(1 << (stress_mwc32() & 0x1f));
 }
 
 /*
  *  stress_rand_data_fixed()
  *	fill buffer with data that is 0x04030201
  */
-static void stress_rand_data_fixed(const args_t *args, uint32_t *data, const int size)
+static void stress_rand_data_fixed(const stress_args_t *args, uint32_t *data, const int size)
 {
 	const int n = size / sizeof(*data);
 	register int i;
@@ -350,7 +395,7 @@ static void stress_rand_data_fixed(const args_t *args, uint32_t *data, const int
  *  stress_rand_data_double()
  *	fill buffer with double precision floating point binary data
  */
-static void stress_rand_data_double(const args_t *args, uint32_t *data, const int size)
+static void stress_rand_data_double(const stress_args_t *args, uint32_t *data, const int size)
 {
 	const int n = size / sizeof(double);
 	uint8_t *ptr = (uint8_t *)data;
@@ -374,7 +419,7 @@ static void stress_rand_data_double(const args_t *args, uint32_t *data, const in
  *	fill buffer with gray code of incrementing 16 bit values
  *
  */
-static void stress_rand_data_gray(const args_t *args, uint32_t *data, const int size)
+static void stress_rand_data_gray(const stress_args_t *args, uint32_t *data, const int size)
 {
 	const int n = size / sizeof(uint16_t);
 	static uint16_t val = 0;
@@ -395,7 +440,7 @@ static void stress_rand_data_gray(const args_t *args, uint32_t *data, const int
  *  stress_rand_data_parity()
  *	fill buffer with 7 bit data + 1 parity bit
  */
-static void stress_rand_data_parity(const args_t *args, uint32_t *data, const int size)
+static void stress_rand_data_parity(const stress_args_t *args, uint32_t *data, const int size)
 {
 	uint8_t *ptr = (uint8_t *)data;
 	register int i;
@@ -403,7 +448,7 @@ static void stress_rand_data_parity(const args_t *args, uint32_t *data, const in
 	(void)args;
 
 	for (i = 0; i < size; i++, ptr++) {
-		uint8_t v = mwc8();
+		uint8_t v = stress_mwc8();
 		uint8_t p = v & 0xfe;
 		p ^= p >> 4;
 		p &= 0xf;
@@ -459,7 +504,7 @@ static inline uint32_t stress_builtin_ctz(register uint32_t x)
  *	the Gardner method with the McCartney
  *	selection tree optimization
  */
-static void stress_rand_data_pink(const args_t *args, uint32_t *data, const int size)
+static void stress_rand_data_pink(const stress_args_t *args, uint32_t *data, const int size)
 {
 	int i;
 	unsigned char *ptr = (unsigned char *)data;
@@ -485,11 +530,11 @@ static void stress_rand_data_pink(const args_t *args, uint32_t *data, const int
 #endif
 
 			sum -= rows[j];
-			rnd = (int64_t)mwc64() >> PINK_SHIFT;
+			rnd = (int64_t)stress_mwc64() >> PINK_SHIFT;
 			sum += rnd;
 			rows[j] = rnd;
 		}
-		rnd = (int64_t)mwc64() >> PINK_SHIFT;
+		rnd = (int64_t)stress_mwc64() >> PINK_SHIFT;
 		*(ptr++) = (int)((scalar * ((int64_t)sum + rnd)) + 128.0);
 	}
 }
@@ -498,7 +543,7 @@ static void stress_rand_data_pink(const args_t *args, uint32_t *data, const int
  *  stress_rand_data_brown()
  *	fills buffer with brown noise.
  */
-static void stress_rand_data_brown(const args_t *args, uint32_t *data, const int size)
+static void stress_rand_data_brown(const stress_args_t *args, uint32_t *data, const int size)
 {
 	static uint8_t val = 127;
 	register int i;
@@ -507,7 +552,7 @@ static void stress_rand_data_brown(const args_t *args, uint32_t *data, const int
 	(void)args;
 
 	for (i = 0; i < size; i++) {
-		val += ((mwc8() % 31) - 15);
+		val += ((stress_mwc8() % 31) - 15);
 		*(ptr++) = val;
 	}
 }
@@ -518,7 +563,7 @@ static void stress_rand_data_brown(const args_t *args, uint32_t *data, const int
  *	x = r * x * (x - 1.0) where r is the accumulation point
  *	based on A098587. Data is scaled in the range 0..255
  */
-static void stress_rand_data_logmap(const args_t *args, uint32_t *data, const int size)
+static void stress_rand_data_logmap(const stress_args_t *args, uint32_t *data, const int size)
 {
 	double x = 0.4;
 	/*
@@ -551,14 +596,14 @@ static void stress_rand_data_logmap(const args_t *args, uint32_t *data, const in
  *  stress_rand_data_lrand48()
  *	fills buffer with random data from lrand48
  */
-static void stress_rand_data_lrand48(const args_t *args, uint32_t *data, const int size)
+static void stress_rand_data_lrand48(const stress_args_t *args, uint32_t *data, const int size)
 {
 	static bool seeded = false;
 	const int n = size / sizeof(*data);
 	register int i;
 
 	if (UNLIKELY(!seeded)) {
-		srand48(mwc32());
+		srand48(stress_mwc32());
 		seeded = true;
 	}
 
@@ -572,7 +617,7 @@ static void stress_rand_data_lrand48(const args_t *args, uint32_t *data, const i
  *  stress_rand_data_latin()
  *	fill buffer with random latin Lorum Ipsum text.
  */
-static void stress_rand_data_latin(const args_t *args, uint32_t *data, const int size)
+static void stress_rand_data_latin(const stress_args_t *args, uint32_t *data, const int size)
 {
 	register int i;
 	static const char *ptr = NULL;
@@ -581,22 +626,67 @@ static void stress_rand_data_latin(const args_t *args, uint32_t *data, const int
 	(void)args;
 
 	if (!ptr)
-		ptr = lorem_ipsum[mwc32() % SIZEOF_ARRAY(lorem_ipsum)];
+		ptr = lorem_ipsum[stress_mwc32() % SIZEOF_ARRAY(lorem_ipsum)];
 
 	for (i = 0; i < size; i++) {
 		if (!*ptr)
-			ptr = lorem_ipsum[mwc32() % SIZEOF_ARRAY(lorem_ipsum)];
+			ptr = lorem_ipsum[stress_mwc32() % SIZEOF_ARRAY(lorem_ipsum)];
 
 		*dataptr++ = *ptr++;
 	}
 }
 
+/*
+ *  stress_rand_data_morse()
+ *	fill buffer with morse encoded random latin Lorum Ipsum text.
+ */
+static void stress_rand_data_morse(const stress_args_t *args, uint32_t *data, const int size)
+{
+	register int i;
+	static const char *ptr = NULL;
+	char *dataptr = (char *)data;
+	static char *morse_table[256];
+	static bool morse_table_init = false;
+
+	(void)args;
+
+	if (!morse_table_init) {
+		(void)memset(morse_table, 0, sizeof(morse_table));
+		for (i = 0; i < (int)SIZEOF_ARRAY(morse); i++)
+			morse_table[tolower((int)morse[i].ch)] = morse[i].str;
+		morse_table_init = true;
+	}
+
+	ptr = "";
+	for (i = 0; i < size; ) {
+		register int ch;
+		register char *mptr;
+
+		if (!*ptr)
+			ptr = lorem_ipsum[stress_mwc32() % SIZEOF_ARRAY(lorem_ipsum)];
+
+		ch = tolower((int)*ptr);
+		mptr = morse_table[ch];
+		if (mptr) {
+			for (; *mptr && (i < size); mptr++) {
+				*dataptr++ = *mptr;
+				i++;
+			}
+			for (mptr = " "; *mptr && (i < size); mptr++) {
+				*dataptr++ = *mptr;
+				i++;
+			}
+		}
+		ptr++;
+	}
+}
+
 
 /*
  *  stress_rand_data_objcode()
  *	fill buffer with object code data from stress-ng
  */
-static void stress_rand_data_objcode(const args_t *args, uint32_t *const data, const int size)
+static void stress_rand_data_objcode(const stress_args_t *args, uint32_t *const data, const int size)
 {
 	const int n = size / sizeof(*data);
 	register int i;
@@ -643,7 +733,7 @@ static void stress_rand_data_objcode(const args_t *args, uint32_t *const data, c
 		return;
 	}
 
-	text = text_start + (mwc64() % (text_end - text_start));
+	text = text_start + (stress_mwc64() % (text_end - text_start));
 
 	for (dataptr = (char *)data, i = 0; i < n; i++, dataptr++) {
 		*dataptr = *text;
@@ -658,7 +748,7 @@ static void stress_rand_data_objcode(const args_t *args, uint32_t *const data, c
  *  stress_rand_data_zero()
  *	fill buffer with zeros
  */
-static void stress_rand_data_zero(const args_t *args, uint32_t *data, const int size)
+static void stress_rand_data_zero(const stress_args_t *args, uint32_t *data, const int size)
 {
 	(void)args;
 	(void)memset(data, 0, size);
@@ -692,9 +782,9 @@ static const stress_zlib_rand_data_func rand_data_funcs[] = {
  *  stress_zlib_random_test()
  *	randomly select data generation function
  */
-static HOT OPTIMIZE3 void stress_zlib_random_test(const args_t *args, uint32_t *data, const int size)
+static HOT OPTIMIZE3 void stress_zlib_random_test(const stress_args_t *args, uint32_t *data, const int size)
 {
-	rand_data_funcs[mwc32() % SIZEOF_ARRAY(rand_data_funcs)](args, data, size);
+	rand_data_funcs[stress_mwc32() % SIZEOF_ARRAY(rand_data_funcs)](args, data, size);
 }
 
 
@@ -716,6 +806,7 @@ static stress_zlib_rand_data_info_t zlib_rand_data_methods[] = {
 	{ "latin",	stress_rand_data_latin },
 	{ "logmap",	stress_rand_data_logmap },
 	{ "lrand48",	stress_rand_data_lrand48 },
+	{ "morse",	stress_rand_data_morse },
 	{ "nybble",	stress_rand_data_nybble },
 	{ "objcode",	stress_rand_data_objcode },
 	{ "parity",	stress_rand_data_parity },
@@ -737,9 +828,9 @@ static int stress_set_zlib_level(const char *opt)
 {
         uint32_t zlib_level;
 
-        zlib_level = get_uint32(opt);
-        check_range("zlib-level", zlib_level, 0, Z_BEST_COMPRESSION);
-        return set_setting("zlib-level", TYPE_ID_UINT32, &zlib_level);
+        zlib_level = stress_get_uint32(opt);
+        stress_check_range("zlib-level", zlib_level, 0, Z_BEST_COMPRESSION);
+        return stress_set_setting("zlib-level", TYPE_ID_UINT32, &zlib_level);
 }
 
 /*
@@ -752,7 +843,7 @@ static int stress_set_zlib_method(const char *opt)
 
 	for (info = zlib_rand_data_methods; info->func; info++) {
 		if (!strcmp(info->name, opt)) {
-			set_setting("zlib-method", TYPE_ID_UINTPTR_T, &info);
+			stress_set_setting("zlib-method", TYPE_ID_UINTPTR_T, &info);
 			return 0;
 		}
 	}
@@ -766,7 +857,7 @@ static int stress_set_zlib_method(const char *opt)
 	return -1;
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_zlib_level,	stress_set_zlib_level },
 	{ OPT_zlib_method,	stress_set_zlib_method },
 	{ 0,			NULL }
@@ -808,7 +899,7 @@ static const char *stress_zlib_err(const int zlib_err)
  *	end of a pipe fd
  */
 static int stress_zlib_inflate(
-		const args_t *args,
+		const stress_args_t *args,
 		const int fd,
 		const int xsum_fd)
 {
@@ -924,7 +1015,7 @@ xsum_error:
  *	write end of a pipe fd
  */
 static int stress_zlib_deflate(
-		const args_t *args,
+		const stress_args_t *args,
 		const int fd,
 		const int xsum_fd,
 		const int zlib_level)
@@ -939,7 +1030,7 @@ static int stress_zlib_deflate(
 	double t1, t2;
 	stress_xsum_t xsum;
 
-	(void)get_setting("zlib-method", &opt_zlib_rand_data_func);
+	(void)stress_get_setting("zlib-method", &opt_zlib_rand_data_func);
 
 	xsum.xsum = 0;
 	xsum.error = false;
@@ -1047,7 +1138,7 @@ xsum_error:
  *  stress_zlib()
  *	stress cpu with compression and decompression
  */
-static int stress_zlib(const args_t *args)
+static int stress_zlib(const stress_args_t *args)
 {
 	int ret = EXIT_SUCCESS, fds[2], deflate_xsum_fds[2], inflate_xsum_fds[2], status;
 	int err = 0;
@@ -1065,7 +1156,7 @@ static int stress_zlib(const args_t *args)
 	if (stress_sighandler(args->name, SIGPIPE, stress_sigpipe_handler, NULL) < 0)
 		return EXIT_FAILURE;
 
-	(void)get_setting("zlib-level", &zlib_level);
+	(void)stress_get_setting("zlib-level", &zlib_level);
 
 	if (pipe(fds) < 0) {
 		pr_err("%s: pipe failed, errno=%d (%s)\n",
