@@ -38,7 +38,7 @@ typedef struct {
 
 static stress_zombie_list_t zombies;
 
-static const help_t help[] = {
+static const stress_help_t help[] = {
 	{ NULL,	"zombie N",	"start N workers that rapidly create and reap zombies" },
 	{ NULL,	"zombie-ops N",	"stop after N bogo zombie fork operations" },
 	{ NULL,	"zombie-max N",	"set upper limit of N zombies per worker" },
@@ -132,22 +132,22 @@ static int stress_set_zombie_max(const char *opt)
 {
 	uint32_t zombie_max;
 
-	zombie_max = get_uint32(opt);
-	check_range("zombie-max", zombie_max,
+	zombie_max = stress_get_uint32(opt);
+	stress_check_range("zombie-max", zombie_max,
 		MIN_ZOMBIES, MAX_ZOMBIES);
-	return set_setting("zombie-max", TYPE_ID_INT32, &zombie_max);
+	return stress_set_setting("zombie-max", TYPE_ID_INT32, &zombie_max);
 }
 
 /*
  *  stress_zombie()
  *	stress by zombieing and exiting
  */
-static int stress_zombie(const args_t *args)
+static int stress_zombie(const stress_args_t *args)
 {
 	uint32_t max_zombies = 0;
 	uint32_t zombie_max = DEFAULT_ZOMBIES;
 
-	if (!get_setting("zombie-max", &zombie_max)) {
+	if (!stress_get_setting("zombie-max", &zombie_max)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
 			zombie_max = MAX_ZOMBIES;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
@@ -200,7 +200,7 @@ static int stress_zombie(const args_t *args)
 	return EXIT_SUCCESS;
 }
 
-static const opt_set_func_t opt_set_funcs[] = {
+static const stress_opt_set_func_t opt_set_funcs[] = {
 	{ OPT_zombie_max,	stress_set_zombie_max },
 	{ 0,			NULL }
 };
