@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2019 Canonical, Ltd.
+ * Copyright (C) 2013-2020 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -30,8 +30,8 @@
 
 int main(void)
 {
-	const char passwd[] = "somerandomtext";
-	const char salt[] = "examplesalt";
+	static const char passwd[] = "somerandomtext";
+	static const char salt[] = "examplesalt";
 	char *crypted;
 #if defined (__linux__)
 	static struct crypt_data data;
